@@ -1,13 +1,31 @@
+ChromeUtils.defineModuleGetter(
+  this,
+  "AddonTestUtils",
+  "resource://testing-common/AddonTestUtils.jsm"
+);
 
-const BASE = getRootDirectory(gTestPath)
-  .replace("chrome://mochitests/content/", "https://example.com/");
+const BASE = getRootDirectory(gTestPath).replace(
+  "chrome://mochitests/content/",
+  "https://example.com/"
+);
 
-ChromeUtils.import("resource:///modules/ExtensionsUI.jsm");
+var { ExtensionsUI } = ChromeUtils.import(
+  "resource:///modules/ExtensionsUI.jsm"
+);
 XPCOMUtils.defineLazyGetter(this, "Management", () => {
-  const {Management} = ChromeUtils.import("resource://gre/modules/Extension.jsm", {});
+  // eslint-disable-next-line no-shadow
+  const { Management } = ChromeUtils.import(
+    "resource://gre/modules/Extension.jsm",
+    null
+  );
   return Management;
 });
 
+ChromeUtils.import(
+  "resource://testing-common/CustomizableUITestUtils.jsm",
+  this
+);
+let gCUITestUtils = new CustomizableUITestUtils(window);
 
 /**
  * Wait for the given PopupNotification to display
@@ -22,19 +40,46 @@ function promisePopupNotificationShown(name) {
   return new Promise(resolve => {
     function popupshown() {
       let notification = PopupNotifications.getNotification(name);
-      if (!notification) { return; }
+      if (!notification) {
+        return;
+      }
 
       ok(notification, `${name} notification shown`);
       ok(PopupNotifications.isPanelOpen, "notification panel open");
 
       PopupNotifications.panel.removeEventListener("popupshown", popupshown);
-      resolve(PopupNotifications.panel.firstChild);
+      resolve(PopupNotifications.panel.firstElementChild);
     }
 
     PopupNotifications.panel.addEventListener("popupshown", popupshown);
   });
 }
 
+function promiseAppMenuNotificationShown(id) {
+  const { AppMenuNotifications } = ChromeUtils.import(
+    "resource://gre/modules/AppMenuNotifications.jsm"
+  );
+  return new Promise(resolve => {
+    function popupshown() {
+      let notification = AppMenuNotifications.activeNotification;
+      if (!notification) {
+        return;
+      }
+
+      is(notification.id, id, `${id} notification shown`);
+      ok(PanelUI.isNotificationPanelOpen, "notification panel open");
+
+      PanelUI.notificationPanel.removeEventListener("popupshown", popupshown);
+
+      let popupnotificationID = PanelUI._getPopupId(notification);
+      let popupnotification = document.getElementById(popupnotificationID);
+
+      resolve(popupnotification);
+    }
+    PanelUI.notificationPanel.addEventListener("popupshown", popupshown);
+  });
+}
+
 /**
  * Wait for a specific install event to fire for a given addon
  *
@@ -65,13 +110,15 @@ function promiseInstallEvent(addon, event) {
  *
  * @param {string} url
  *        URL of the .xpi file to install
+ * @param {Object?} installTelemetryInfo
+ *        an optional object that contains additional details used by the telemetry events.
  *
  * @returns {Promise}
  *          Resolves when the extension has been installed with the Addon
  *          object as the resolution value.
  */
-async function promiseInstallAddon(url) {
-  let install = await AddonManager.getInstallForURL(url, null, "application/x-xpinstall");
+async function promiseInstallAddon(url, telemetryInfo) {
+  let install = await AddonManager.getInstallForURL(url, { telemetryInfo });
   install.install();
 
   let addon = await new Promise(resolve => {
@@ -120,7 +167,7 @@ async function waitForUpdate(addon) {
     Management.on("ready", listener);
   });
 
-  let [newAddon, ] = await Promise.all([installPromise, readyPromise]);
+  let [newAddon] = await Promise.all([installPromise, readyPromise]);
   return newAddon;
 }
 
@@ -128,40 +175,10 @@ function isDefaultIcon(icon) {
   // These are basically the same icon, but code within webextensions
   // generates references to the former and generic add-ons manager code
   // generates referces to the latter.
-  return (icon == "chrome://browser/content/extension.svg" ||
-          icon == "chrome://mozapps/skin/extensions/extensionGeneric.svg");
-}
-
-function is_hidden(element) {
-  var style = element.ownerGlobal.getComputedStyle(element);
-  if (style.display == "none")
-    return true;
-  if (style.visibility != "visible")
-    return true;
-  if (style.display == "-moz-popup")
-    return ["hiding", "closed"].includes(element.state);
-
-  // Hiding a parent element will hide all its children
-  if (element.parentNode != element.ownerDocument)
-    return is_hidden(element.parentNode);
-
-  return false;
-}
-
-function is_visible(element) {
-  var style = element.ownerGlobal.getComputedStyle(element);
-  if (style.display == "none")
-    return false;
-  if (style.visibility != "visible")
-    return false;
-  if (style.display == "-moz-popup" && element.state != "open")
-    return false;
-
-  // Hiding a parent element will hide all its children
-  if (element.parentNode != element.ownerDocument)
-    return is_visible(element.parentNode);
-
-  return true;
+  return (
+    icon == "chrome://browser/content/extension.svg" ||
+    icon == "chrome://mozapps/skin/extensions/extensionGeneric.svg"
+  );
 }
 
 /**
@@ -180,9 +197,9 @@ function is_visible(element) {
  *        The message to be emitted as part of the actual test.
  */
 function checkPermissionString(string, key, param, msg) {
-  let localizedString = param ?
-                        gBrowserBundle.formatStringFromName(key, [param], 1) :
-                        gBrowserBundle.GetStringFromName(key);
+  let localizedString = param
+    ? gBrowserBundle.formatStringFromName(key, [param], 1)
+    : gBrowserBundle.GetStringFromName(key);
 
   // If this is a parameterized string and the parameter isn't given,
   // just do a simple comparison of the text before and after the %S
@@ -216,26 +233,48 @@ function checkNotification(panel, checkIcon, permissions) {
   let icon = panel.getAttribute("icon");
   let ul = document.getElementById("addon-webext-perm-list");
   let header = document.getElementById("addon-webext-perm-intro");
+  let learnMoreLink = document.getElementById("addon-webext-perm-info");
 
   if (checkIcon instanceof RegExp) {
-    ok(checkIcon.test(icon), `Notification icon is correct ${JSON.stringify(icon)} ~= ${checkIcon}`);
+    ok(
+      checkIcon.test(icon),
+      `Notification icon is correct ${JSON.stringify(icon)} ~= ${checkIcon}`
+    );
   } else if (typeof checkIcon == "function") {
     ok(checkIcon(icon), "Notification icon is correct");
   } else {
     is(icon, checkIcon, "Notification icon is correct");
   }
 
-  is(ul.childElementCount, permissions.length, `Permissions list has ${permissions.length} entries`);
+  is(
+    ul.childElementCount,
+    permissions.length,
+    `Permissions list has ${permissions.length} entries`
+  );
   if (permissions.length == 0) {
     is(header.getAttribute("hidden"), "true", "Permissions header is hidden");
+    is(
+      learnMoreLink.getAttribute("hidden"),
+      "true",
+      "Permissions learn more is hidden"
+    );
   } else {
     is(header.getAttribute("hidden"), "", "Permissions header is visible");
+    is(
+      learnMoreLink.getAttribute("hidden"),
+      "",
+      "Permissions learn more is visible"
+    );
   }
 
   for (let i in permissions) {
     let [key, param] = permissions[i];
-    checkPermissionString(ul.children[i].textContent, key, param,
-                          `Permission number ${i + 1} is correct`);
+    checkPermissionString(
+      ul.children[i].textContent,
+      key,
+      param,
+      `Permission number ${i + 1} is correct`
+    );
   }
 }
 
@@ -258,10 +297,12 @@ async function testInstallMethod(installFn, telemetryBase) {
   const NO_PERMS_XPI = "browser_webext_nopermissions.xpi";
   const ID = "permissions@test.mozilla.org";
 
-  await SpecialPowers.pushPrefEnv({set: [
-    ["extensions.webapi.testing", true],
-    ["extensions.install.requireBuiltInCerts", false],
-  ]});
+  await SpecialPowers.pushPrefEnv({
+    set: [
+      ["extensions.webapi.testing", true],
+      ["extensions.install.requireBuiltInCerts", false],
+    ],
+  });
 
   if (telemetryBase !== undefined) {
     hookExtensionsTelemetry();
@@ -331,7 +372,9 @@ async function testInstallMethod(installFn, telemetryBase) {
       } catch (err) {}
     } else {
       // Look for post-install notification
-      let postInstallPromise = promisePopupNotificationShown("addon-installed");
+      let postInstallPromise = promiseAppMenuNotificationShown(
+        "addon-installed"
+      );
       panel.button.click();
 
       // Press OK on the post-install notification
@@ -349,10 +392,10 @@ async function testInstallMethod(installFn, telemetryBase) {
     } else {
       ok(result, "Installation completed");
       isnot(addon, null, "Extension is installed");
-      addon.uninstall();
+      await addon.uninstall();
     }
 
-    await BrowserTestUtils.removeTab(tab);
+    BrowserTestUtils.removeTab(tab);
   }
 
   // A few different tests for each installation method:
@@ -371,7 +414,11 @@ async function testInstallMethod(installFn, telemetryBase) {
   if (telemetryBase !== undefined) {
     // Should see 2 canceled installs followed by 1 successful install
     // for this method.
-    expectTelemetry([`${telemetryBase}Rejected`, `${telemetryBase}Rejected`, `${telemetryBase}Accepted`]);
+    expectTelemetry([
+      `${telemetryBase}Rejected`,
+      `${telemetryBase}Rejected`,
+      `${telemetryBase}Accepted`,
+    ]);
   }
 
   await SpecialPowers.popPrefEnv();
@@ -382,18 +429,25 @@ async function testInstallMethod(installFn, telemetryBase) {
 // `autoUpdate` specifies whether the test should be run with
 // updates applied automatically or not.
 async function interactiveUpdateTest(autoUpdate, checkFn) {
+  AddonTestUtils.initMochitest(this);
+
   const ID = "update2@tests.mozilla.org";
+  const FAKE_INSTALL_SOURCE = "fake-install-source";
 
-  await SpecialPowers.pushPrefEnv({set: [
-    // We don't have pre-pinned certificates for the local mochitest server
-    ["extensions.install.requireBuiltInCerts", false],
-    ["extensions.update.requireBuiltInCerts", false],
+  await SpecialPowers.pushPrefEnv({
+    set: [
+      // We don't have pre-pinned certificates for the local mochitest server
+      ["extensions.install.requireBuiltInCerts", false],
+      ["extensions.update.requireBuiltInCerts", false],
 
-    ["extensions.update.autoUpdateDefault", autoUpdate],
+      ["extensions.update.autoUpdateDefault", autoUpdate],
 
-    // Point updates to the local mochitest server
-    ["extensions.update.url", `${BASE}/browser_webext_update.json`],
-  ]});
+      // Point updates to the local mochitest server
+      ["extensions.update.url", `${BASE}/browser_webext_update.json`],
+    ],
+  });
+
+  AddonTestUtils.hookAMTelemetryEvents();
 
   // Trigger an update check, manually applying the update if we're testing
   // without auto-update.
@@ -416,25 +470,43 @@ async function interactiveUpdateTest(autoUpdate, checkFn) {
     if (manualUpdatePromise) {
       await manualUpdatePromise;
 
-      let list = win.document.getElementById("addon-list");
-
-      // Make sure we have XBL bindings
-      list.clientHeight;
-
-      let item = list.children.find(_item => _item.value == ID);
-      EventUtils.synthesizeMouseAtCenter(item._updateBtn, {}, win);
+      if (win.useHtmlViews) {
+        // about:addons is using the new HTML views.
+        const availableUpdates = win.document.getElementById(
+          "updates-manualUpdatesFound-btn"
+        );
+        availableUpdates.click();
+        let doc = win.getHtmlBrowser().contentDocument;
+        let card = await BrowserTestUtils.waitForCondition(() => {
+          return doc.querySelector(`addon-card[addon-id="${ID}"]`);
+        }, `Wait addon card for "${ID}"`);
+        let updateBtn = card.querySelector(
+          'panel-item[action="install-update"]'
+        );
+        ok(updateBtn, `Found update button for "${ID}"`);
+        updateBtn.click();
+      } else {
+        // about:addons is still using the legacy XUL views.
+        let list = win.document.getElementById("addon-list");
+        // Make sure we have XBL bindings
+        list.clientHeight;
+        let item = list.itemChildren.find(_item => _item.value == ID);
+        EventUtils.synthesizeMouseAtCenter(item._updateBtn, {}, win);
+      }
     }
 
-    return {promise};
+    return { promise };
   }
 
   // Navigate away from the starting page to force about:addons to load
   // in a new tab during the tests below.
-  gBrowser.selectedBrowser.loadURI("about:robots");
+  BrowserTestUtils.loadURI(gBrowser.selectedBrowser, "about:robots");
   await BrowserTestUtils.browserLoaded(gBrowser.selectedBrowser);
 
   // Install version 1.0 of the test extension
-  let addon = await promiseInstallAddon(`${BASE}/browser_webext_update1.xpi`);
+  let addon = await promiseInstallAddon(`${BASE}/browser_webext_update1.xpi`, {
+    source: FAKE_INSTALL_SOURCE,
+  });
   ok(addon, "Addon was installed");
   is(addon.version, "1.0", "Version 1 of the addon is installed");
 
@@ -442,7 +514,7 @@ async function interactiveUpdateTest(autoUpdate, checkFn) {
 
   // Trigger an update check
   let popupPromise = promisePopupNotificationShown("addon-webext-permissions");
-  let {promise: checkPromise} = await triggerUpdate(win, addon);
+  let { promise: checkPromise } = await triggerUpdate(win, addon);
   let panel = await popupPromise;
 
   // Click the cancel button, wait to see the cancel event
@@ -470,9 +542,78 @@ async function interactiveUpdateTest(autoUpdate, checkFn) {
 
   await checkPromise;
 
-  await BrowserTestUtils.removeTab(gBrowser.selectedTab);
-  addon.uninstall();
+  BrowserTestUtils.removeTab(gBrowser.selectedTab);
+  await addon.uninstall();
   await SpecialPowers.popPrefEnv();
+
+  const collectedUpdateEvents = AddonTestUtils.getAMTelemetryEvents().filter(
+    evt => {
+      return evt.method === "update";
+    }
+  );
+
+  Assert.deepEqual(
+    collectedUpdateEvents.map(evt => evt.extra.step),
+    [
+      // First update is cancelled on the permission prompt.
+      "started",
+      "download_started",
+      "download_completed",
+      "permissions_prompt",
+      "cancelled",
+      // Second update is expected to be completed.
+      "started",
+      "download_started",
+      "download_completed",
+      "permissions_prompt",
+      "completed",
+    ],
+    "Got the expected sequence on update telemetry events"
+  );
+
+  ok(
+    collectedUpdateEvents.every(evt => evt.extra.addon_id === ID),
+    "Every update telemetry event should have the expected addon_id extra var"
+  );
+
+  ok(
+    collectedUpdateEvents.every(
+      evt => evt.extra.source === FAKE_INSTALL_SOURCE
+    ),
+    "Every update telemetry event should have the expected source extra var"
+  );
+
+  ok(
+    collectedUpdateEvents.every(evt => evt.extra.updated_from === "user"),
+    "Every update telemetry event should have the update_from extra var 'user'"
+  );
+
+  let hasPermissionsExtras = collectedUpdateEvents
+    .filter(evt => {
+      return evt.extra.step === "permissions_prompt";
+    })
+    .every(evt => {
+      return Number.isInteger(parseInt(evt.extra.num_strings, 10));
+    });
+
+  ok(
+    hasPermissionsExtras,
+    "Every 'permissions_prompt' update telemetry event should have the permissions extra vars"
+  );
+
+  let hasDownloadTimeExtras = collectedUpdateEvents
+    .filter(evt => {
+      return evt.extra.step === "download_completed";
+    })
+    .every(evt => {
+      const download_time = parseInt(evt.extra.download_time, 10);
+      return !isNaN(download_time) && download_time > 0;
+    });
+
+  ok(
+    hasDownloadTimeExtras,
+    "Every 'download_completed' update telemetry event should have a download_time extra vars"
+  );
 }
 
 // The tests in this directory install a bunch of extensions but they
@@ -496,9 +637,17 @@ add_task(async function() {
     }
 
     for (let addon of await AddonManager.getAllAddons()) {
-      if (!existingAddons.has(addon.id)) {
-        ok(false, `Addon ${addon.id} was left installed at the end of the test`);
-        addon.uninstall();
+      // Builtin search extensions may have been installed by SearchService
+      // during the test run, ignore those.
+      if (
+        !existingAddons.has(addon.id) &&
+        !(addon.isBuiltin && addon.id.endsWith("@search.mozilla.org"))
+      ) {
+        ok(
+          false,
+          `Addon ${addon.id} was left installed at the end of the test`
+        );
+        await addon.uninstall();
       }
     }
   });
@@ -508,10 +657,16 @@ let collectedTelemetry = [];
 function hookExtensionsTelemetry() {
   let originalHistogram = ExtensionsUI.histogram;
   ExtensionsUI.histogram = {
-    add(value) { collectedTelemetry.push(value); },
+    add(value) {
+      collectedTelemetry.push(value);
+    },
   };
   registerCleanupFunction(() => {
-    is(collectedTelemetry.length, 0, "No unexamined telemetry after test is finished");
+    is(
+      collectedTelemetry.length,
+      0,
+      "No unexamined telemetry after test is finished"
+    );
     ExtensionsUI.histogram = originalHistogram;
   });
 }
@@ -520,4 +675,3 @@ function expectTelemetry(values) {
   Assert.deepEqual(values, collectedTelemetry);
   collectedTelemetry = [];
 }
-
