@@ -10,14 +10,17 @@ var gNumLinksCalledBack = 0;
 var gStartedAllChecks = false;
 var gLinkCheckTimerID = 0;
 
+document.addEventListener("dialogaccept", onAccept);
+document.addEventListener("dialogcancel", onCancelLinkChecker);
+
 // Implement nsIRequestObserver:
 var gRequestObserver =
 {
   // urichecker requires that we have an OnStartRequest even tho it's a nop.
-  onStartRequest: function(request, ctxt) { },
+  onStartRequest: function(request) { },
 
   // onStopRequest is where we really handle the status.
-  onStopRequest: function(request, ctxt, status)
+  onStopRequest: function(request, status)
   {
     var linkChecker = request.QueryInterface(Ci.nsIURIChecker);
     if (linkChecker)
@@ -153,8 +156,8 @@ function SetItemStatus(url, status)
   if (!status)
     status = "busy";
 
-  // Just set attribute for status icon 
-  // if we already have this url 
+  // Just set attribute for status icon
+  // if we already have this url
   let listitem = document.querySelector('listitem[label="' + url + '"]');
   if (listitem)
   {
@@ -163,7 +166,7 @@ function SetItemStatus(url, status)
   }
 
   // We're adding a new item to list
-  listitem = document.createElementNS(XUL_NS, "listitem");
+  listitem = document.createXULElement("listitem");
   if (listitem)
   {
     listitem.setAttribute("class", "listitem-iconic progressitem");
@@ -178,16 +181,14 @@ function SetItemStatus(url, status)
 function onAccept()
 {
   SaveWindowLocation();
-  return true; // do close the window
 }
 
-function onCancelLinkChecker()
+function onCancelLinkChecker(event)
 {
   if (gLinkCheckTimerID)
     clearTimeout(gLinkCheckTimerID);
 
-/*
-  LinkCheckTimeOut();
-*/
-  return onCancel();
+  // LinkCheckTimeOut();
+
+  onCancel(event);
 }
