@@ -2,32 +2,37 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-ChromeUtils.import("resource:///modules/StringBundle.js");
+var { StringBundle } = ChromeUtils.import(
+  "resource:///modules/StringBundle.js"
+);
 
-ChromeUtils.import("resource:///modules/gloda/facet.js");
+var { FacetDriver } = ChromeUtils.import("resource:///modules/gloda/facet.js");
 // needed by search.xml to use us
-ChromeUtils.import("resource:///modules/gloda/msg_search.js");
+var { GlodaMsgSearcher } = ChromeUtils.import(
+  "resource:///modules/gloda/msg_search.js"
+);
 
 var glodaFacetTabType = {
   name: "glodaFacet",
   perTabPanel: "vbox",
-  strings:
-    new StringBundle("chrome://messenger/locale/glodaFacetView.properties"),
+  lastTabId: 0,
+  strings: new StringBundle(
+    "chrome://messenger/locale/glodaFacetView.properties"
+  ),
   modes: {
     glodaFacet: {
       // this is what get exposed on the tab for icon purposes
-      type: "glodaSearch"
-    }
+      type: "glodaSearch",
+    },
   },
-  openTab: function glodaFacetTabType_openTab(aTab, aArgs) {
+  openTab(aTab, aArgs) {
     // we have no browser until our XUL document loads
     aTab.browser = null;
 
     // First clone the page and set up the basics.
-    let clone = document.getElementById("glodaTab")
-                        .firstChild
-                        .cloneNode(true);
+    let clone = document.getElementById("glodaTab").firstChild.cloneNode(true);
 
+    aTab.panel.setAttribute("id", "glodaTab" + this.lastTabId);
     aTab.panel.appendChild(clone);
     aTab.iframe = aTab.panel.querySelector("iframe");
 
@@ -41,8 +46,7 @@ var glodaFacetTabType = {
 
       aTab.title = this.strings.get("glodaFacetView.tab.query.label");
       aTab.searchString = null;
-    }
-    else if ("searcher" in aArgs) {
+    } else if ("searcher" in aArgs) {
       aTab.searcher = aArgs.searcher;
       aTab.collection = aTab.searcher.getCollection();
       aTab.query = aTab.searcher.query;
@@ -54,10 +58,10 @@ var glodaFacetTabType = {
 
       let searchString = aTab.searcher.searchString;
       aTab.searchInputValue = aTab.searchString = searchString;
-      aTab.title = searchString ? searchString
-                   : this.strings.get("glodaFacetView.tab.search.label");
-    }
-    else if ("collection" in aArgs) {
+      aTab.title = searchString
+        ? searchString
+        : this.strings.get("glodaFacetView.tab.search.label");
+    } else if ("collection" in aArgs) {
       aTab.collection = aArgs.collection;
 
       aTab.title = this.strings.get("glodaFacetView.tab.query.label");
@@ -67,24 +71,31 @@ var glodaFacetTabType = {
     function xulLoadHandler() {
       aTab.iframe.contentWindow.tab = aTab;
       aTab.browser = aTab.iframe.contentDocument.getElementById("browser");
-      aTab.browser.setAttribute("src",
-        "chrome://messenger/content/glodaFacetView.xhtml");
+      aTab.browser.setAttribute(
+        "src",
+        "chrome://messenger/content/glodaFacetView.xhtml"
+      );
     }
 
-    aTab.iframe.contentWindow.addEventListener("load", xulLoadHandler, {capture: false, once: true});
-    aTab.iframe.setAttribute("src",
-      "chrome://messenger/content/glodaFacetViewWrapper.xul");
-  },
-  closeTab: function glodaFacetTabType_closeTab(aTab) {
-  },
-  saveTabState: function glodaFacetTabType_saveTabState(aTab) {
-    // nothing to do; we are not multiplexed
-  },
-  showTab: function glodaFacetTabType_showTab(aTab) {
-    // nothing to do; we are not multiplexed
-  },
-  getBrowser: function(aTab) {
-    return aTab.browser;
-  }
-};
+    aTab.iframe.contentWindow.addEventListener("load", xulLoadHandler, {
+      capture: false,
+      once: true,
+    });
+    aTab.iframe.setAttribute(
+      "src",
+      "chrome://messenger/content/glodaFacetViewWrapper.xul"
+    );
 
+    this.lastTabId++;
+  },
+  closeTab(aTab) {},
+  saveTabState(aTab) {
+    // nothing to do; we are not multiplexed
+  },
+  showTab(aTab) {
+    // nothing to do; we are not multiplexed
+  },
+  getBrowser(aTab) {
+    return aTab.browser;
+  },
+};
