@@ -2,13 +2,13 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-ChromeUtils.import("resource:///modules/StringBundle.js");
+var { StringBundle } = ChromeUtils.import(
+  "resource:///modules/StringBundle.js"
+);
 
 var gSearchBundle;
 
-var gStatusBar = document.getElementById('statusbar-icon');
-
-var gGlodaCompleteStrings = new StringBundle("chrome://messenger/locale/glodaComplete.properties");
+var gStatusBar = document.getElementById("statusbar-icon");
 
 /**
  * The glodasearch widget is a UI widget (the #searchInput textbox) which is
@@ -32,26 +32,27 @@ var gGlodaCompleteStrings = new StringBundle("chrome://messenger/locale/glodaCom
 var GlodaSearchBoxTabMonitor = {
   monitorName: "glodaSearchBox",
 
-  onTabTitleChanged: function() {
-  },
+  onTabTitleChanged() {},
 
-  onTabOpened: function GSBTM_onTabOpened(aTab, aFirstTab, aOldTab) {
+  onTabOpened(aTab, aFirstTab, aOldTab) {
     aTab._ext.glodaSearchBox = {
-      value: (aTab.mode.name === "glodaFacet") ? aTab.searchString : "",
+      value: aTab.mode.name === "glodaFacet" ? aTab.searchString : "",
     };
 
     if (aTab.mode.name === "glodaFacet") {
-      let searchInput = aTab.panel
-                            .querySelector(".remote-gloda-search");
-      if (searchInput)
+      let searchInput = aTab.panel.querySelector(".remote-gloda-search");
+      if (searchInput) {
         searchInput.value = aTab.searchString;
+      }
     }
   },
 
-  onTabSwitched: function (aTab, aOldTab) {
+  onTabSwitched(aTab, aOldTab) {
     let searchInput = document.getElementById("searchInput");
-    if (!searchInput) // customized out of the way
+    if (!searchInput) {
+      // customized out of the way
       return;
+    }
 
     // save the current search field value
     if (aOldTab) {
@@ -61,8 +62,8 @@ var GlodaSearchBoxTabMonitor = {
     // (We check first to avoid weird blank field / empty text transitions on
     // tab change.)
     let desiredValue = aTab._ext.glodaSearchBox.value || "";
-    if (searchInput.value != desiredValue)
+    if (searchInput.value != desiredValue) {
       searchInput.value = desiredValue;
-  }
+    }
+  },
 };
-
