@@ -5,9 +5,15 @@
 
 // This dialog can only be opened if we have a shell service.
 
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { SearchIntegration } = ChromeUtils.import(
+  "resource:///modules/SearchIntegration.jsm"
+);
+
 var gSystemIntegrationDialog = {
-  _shellSvc: Cc["@mozilla.org/mail/shell-service;1"]
-               .getService(Ci.nsIShellService),
+  _shellSvc: Cc["@mozilla.org/mail/shell-service;1"].getService(
+    Ci.nsIShellService
+  ),
 
   _mailCheckbox: null,
 
@@ -19,26 +25,22 @@ var gSystemIntegrationDialog = {
 
   _searchCheckbox: null,
 
-  onLoad: function()
-  {
-    // Makes Services and SearchIntegration accessible via this.Services
-    // and this.SearchIntegration.
-    ChromeUtils.import("resource://gre/modules/Services.jsm", this);
-    ChromeUtils.import("resource:///modules/SearchIntegration.js", this);
-
+  onLoad() {
     // initialize elements
-    this._mailCheckbox    = document.getElementById("checkMail");
-    this._newsCheckbox    = document.getElementById("checkNews");
-    this._rssCheckbox     = document.getElementById("checkRSS");
+    this._mailCheckbox = document.getElementById("checkMail");
+    this._newsCheckbox = document.getElementById("checkNews");
+    this._rssCheckbox = document.getElementById("checkRSS");
     this._startupCheckbox = document.getElementById("checkOnStartup");
-    this._searchCheckbox  = document.getElementById("searchIntegration");
+    this._searchCheckbox = document.getElementById("searchIntegration");
 
     // Initialize the check boxes based on the default app states.
-    this._mailCheckbox.disabled =
-      this._shellSvc.isDefaultClient(false, this._shellSvc.MAIL);
+    this._mailCheckbox.disabled = this._shellSvc.isDefaultClient(
+      false,
+      this._shellSvc.MAIL
+    );
 
-    let calledFromPrefs = ("arguments" in window) &&
-                          (window.arguments[0] == "calledFromPrefs");
+    let calledFromPrefs =
+      "arguments" in window && window.arguments[0] == "calledFromPrefs";
 
     if (!calledFromPrefs) {
       // As an optimization, if we aren't already the default mail client,
@@ -51,46 +53,55 @@ var gSystemIntegrationDialog = {
 
       // If called from preferences, use only a simpler "Cancel" label on the
       // cancel button.
-      document.documentElement.getButton("cancel").label =
-        document.documentElement.getAttribute("buttonlabelcancel2");
+      document.documentElement.getButton(
+        "cancel"
+      ).label = document.documentElement.getAttribute("buttonlabelcancel2");
     }
 
-    if (!this._mailCheckbox.disabled)
+    if (!this._mailCheckbox.disabled) {
       this._mailCheckbox.removeAttribute("tooltiptext");
+    }
 
-    this._newsCheckbox.checked = this._newsCheckbox.disabled =
-      this._shellSvc.isDefaultClient(false, this._shellSvc.NEWS);
-    if (!this._newsCheckbox.disabled)
+    this._newsCheckbox.checked = this._newsCheckbox.disabled = this._shellSvc.isDefaultClient(
+      false,
+      this._shellSvc.NEWS
+    );
+    if (!this._newsCheckbox.disabled) {
       this._newsCheckbox.removeAttribute("tooltiptext");
+    }
 
-    this._rssCheckbox.checked  = this._rssCheckbox.disabled  =
-      this._shellSvc.isDefaultClient(false, this._shellSvc.RSS);
-    if (!this._rssCheckbox.disabled)
+    this._rssCheckbox.checked = this._rssCheckbox.disabled = this._shellSvc.isDefaultClient(
+      false,
+      this._shellSvc.RSS
+    );
+    if (!this._rssCheckbox.disabled) {
       this._rssCheckbox.removeAttribute("tooltiptext");
+    }
 
     // read the raw pref value and not shellSvc.shouldCheckDefaultMail
-    this._startupCheckbox.checked =
-      this.Services.prefs.getBoolPref("mail.shell.checkDefaultClient");
+    this._startupCheckbox.checked = Services.prefs.getBoolPref(
+      "mail.shell.checkDefaultClient"
+    );
 
     // Search integration - check whether we should show/disable integration options
-    if (this.SearchIntegration)
-    {
-      this._searchCheckbox.checked = this.SearchIntegration.prefEnabled;
+    if (SearchIntegration) {
+      this._searchCheckbox.checked = SearchIntegration.prefEnabled;
       // On Windows, do not offer the option on startup as it does not perform well.
-      if ((this.Services.appinfo.OS == "WINNT") && !calledFromPrefs &&
-          !this._searchCheckbox.checked) {
+      if (
+        Services.appinfo.OS == "WINNT" &&
+        !calledFromPrefs &&
+        !this._searchCheckbox.checked
+      ) {
         this._searchCheckbox.hidden = true;
         // Even if the user wasn't presented the choice,
         // we do not want to ask again automatically.
-        this.SearchIntegration.firstRunDone = true;
-      } else {
+        SearchIntegration.firstRunDone = true;
+      } else if (!SearchIntegration.osVersionTooLow) {
         // Hide/disable the options if the OS does not support them.
-        if (!this.SearchIntegration.osVersionTooLow) {
-          this._searchCheckbox.hidden = false;
-          if (this.SearchIntegration.osComponentsNotRunning) {
-            this._searchCheckbox.checked = false;
-            this._searchCheckbox.disabled = true;
-          }
+        this._searchCheckbox.hidden = false;
+        if (SearchIntegration.osComponentsNotRunning) {
+          this._searchCheckbox.checked = false;
+          this._searchCheckbox.disabled = true;
         }
       }
     }
@@ -102,8 +113,7 @@ var gSystemIntegrationDialog = {
    * @param aSetAsDefault  If true, set TB as the default application for the
    *                       checked actions (mail/news/rss). Otherwise do nothing.
    */
-  onDialogClose: function(aSetAsDefault)
-  {
+  onDialogClose(aSetAsDefault) {
     // In all cases, save the user's decision for "always check at startup".
     this._shellSvc.shouldCheckDefaultClient = this._startupCheckbox.checked;
 
@@ -111,15 +121,16 @@ var gSystemIntegrationDialog = {
     // So do not ask next time.
     let searchIntegPossible = !this._searchCheckbox.hidden;
     if (searchIntegPossible) {
-      this.SearchIntegration.firstRunDone = true;
+      SearchIntegration.firstRunDone = true;
     }
 
     // If the "skip integration" button was used do not set any defaults
     // and close the dialog.
     if (!aSetAsDefault) {
       // Disable search integration in this case.
-      if (searchIntegPossible)
-        this.SearchIntegration.prefEnabled = false;
+      if (searchIntegPossible) {
+        SearchIntegration.prefEnabled = false;
+      }
 
       return true;
     }
@@ -128,26 +139,44 @@ var gSystemIntegrationDialog = {
     // make us the default.
     let appTypes = 0;
 
-    if (this._mailCheckbox.checked &&
-        !this._shellSvc.isDefaultClient(false, this._shellSvc.MAIL))
+    if (
+      this._mailCheckbox.checked &&
+      !this._shellSvc.isDefaultClient(false, this._shellSvc.MAIL)
+    ) {
       appTypes |= this._shellSvc.MAIL;
+    }
 
-    if (this._newsCheckbox.checked &&
-        !this._shellSvc.isDefaultClient(false, this._shellSvc.NEWS))
+    if (
+      this._newsCheckbox.checked &&
+      !this._shellSvc.isDefaultClient(false, this._shellSvc.NEWS)
+    ) {
       appTypes |= this._shellSvc.NEWS;
+    }
 
-    if (this._rssCheckbox.checked &&
-        !this._shellSvc.isDefaultClient(false, this._shellSvc.RSS))
+    if (
+      this._rssCheckbox.checked &&
+      !this._shellSvc.isDefaultClient(false, this._shellSvc.RSS)
+    ) {
       appTypes |= this._shellSvc.RSS;
+    }
 
-    if (appTypes)
+    if (appTypes) {
       this._shellSvc.setDefaultClient(false, appTypes);
+    }
 
     // Set the search integration pref if it is changed.
     // The integration will handle the rest.
-    if (searchIntegPossible)
-      this.SearchIntegration.prefEnabled = this._searchCheckbox.checked;
+    if (searchIntegPossible) {
+      SearchIntegration.prefEnabled = this._searchCheckbox.checked;
+    }
 
     return true;
-  }
+  },
 };
+
+document.addEventListener("dialogaccept", () =>
+  gSystemIntegrationDialog.onDialogClose(true)
+);
+document.addEventListener("dialogcancel", () =>
+  gSystemIntegrationDialog.onDialogClose(false)
+);
