@@ -20,67 +20,65 @@
  * for values stored.
  */
 
-function AccountConfig()
-{
+/* import-globals-from emailWizard.js */
+
+function AccountConfig() {
   this.incoming = this.createNewIncoming();
   this.incomingAlternatives = [];
   this.outgoing = this.createNewOutgoing();
   this.outgoingAlternatives = [];
-  this.identity =
-  {
+  this.identity = {
     // displayed real name of user
-    realname : "%REALNAME%",
+    realname: "%REALNAME%",
     // email address of user, as shown in From of outgoing mails
-    emailAddress : "%EMAILADDRESS%",
+    emailAddress: "%EMAILADDRESS%",
   };
   this.inputFields = [];
   this.domains = [];
-};
-AccountConfig.prototype =
-{
+}
+AccountConfig.prototype = {
   // @see createNewIncoming()
-  incoming : null,
+  incoming: null,
   // @see createNewOutgoing()
-  outgoing : null,
+  outgoing: null,
   /**
    * Other servers which can be used instead of |incoming|,
    * in order of decreasing preference.
    * (|incoming| itself should not be included here.)
    * { Array of incoming/createNewIncoming() }
    */
-  incomingAlternatives : null,
-  outgoingAlternatives : null,
+  incomingAlternatives: null,
+  outgoingAlternatives: null,
   // OAuth2 configuration, if needed.
-  oauthSettings : null,
+  oauthSettings: null,
   // just an internal string to refer to this. Do not show to user.
-  id : null,
+  id: null,
   // who created the config.
   // { one of kSource* }
-  source : 0,
-  displayName : null,
+  source: 0,
+  displayName: null,
   // { Array of { varname (value without %), displayName, exampleValue } }
-  inputFields : null,
+  inputFields: null,
   // email address domains for which this config is applicable
   // { Array of Strings }
-  domains : null,
+  domains: null,
 
   /**
    * Factory function for incoming and incomingAlternatives
    */
-  createNewIncoming : function()
-  {
+  createNewIncoming() {
     return {
       // { String-enum: "pop3", "imap", "nntp", "exchange" }
-      type : null,
-      hostname : null,
+      type: null,
+      hostname: null,
       // { Integer }
-      port : null,
+      port: null,
       // May be a placeholder (starts and ends with %). { String }
-      username : null,
-      password : null,
+      username: null,
+      password: null,
       // { enum: 1 = plain, 2 = SSL/TLS, 3 = STARTTLS always, 0 = not inited }
       // ('TLS when available' is insecure and not supported here)
-      socketType : 0,
+      socketType: 0,
       /**
        * true when the cert is invalid (and thus SSL useless), because it's
        * 1) not from an accepted CA (including self-signed certs)
@@ -88,62 +86,65 @@ AccountConfig.prototype =
        * 3) expired.
        * May go back to false when user explicitly accepted the cert.
        */
-      badCert : false,
+      badCert: false,
       /**
        * How to log in to the server: plaintext or encrypted pw, GSSAPI etc.
        * Defined by Ci.nsMsgAuthMethod
        * Same as server pref "authMethod".
        */
-      auth : 0,
+      auth: 0,
       /**
        * Other auth methods that we think the server supports.
        * They are ordered by descreasing preference.
        * (|auth| itself is not included in |authAlternatives|)
        * {Array of Ci.nsMsgAuthMethod} (same as .auth)
        */
-      authAlternatives : null,
+      authAlternatives: null,
       // in minutes { Integer }
-      checkInterval : 10,
-      loginAtStartup : true,
+      checkInterval: 10,
+      loginAtStartup: true,
       // POP3 only:
       // Not yet implemented. { Boolean }
-      useGlobalInbox : false,
-      leaveMessagesOnServer : true,
-      daysToLeaveMessagesOnServer : 14,
-      deleteByAgeFromServer : true,
+      useGlobalInbox: false,
+      leaveMessagesOnServer: true,
+      daysToLeaveMessagesOnServer: 14,
+      deleteByAgeFromServer: true,
       // When user hits delete, delete from local store and from server
-      deleteOnServerWhenLocalDelete : true,
-      downloadOnBiff : true,
+      deleteOnServerWhenLocalDelete: true,
+      downloadOnBiff: true,
+      // Override `addThisServer` for a specific incoming server
+      useGlobalPreferredServer: false,
 
       // for Microsoft Exchange servers. Optional.
       owaURL: null,
       ewsURL: null,
       easURL: null,
+      // for when an addon overrides the account type. Optional.
+      addonAccountType: null,
     };
   },
   /**
    * Factory function for outgoing and outgoingAlternatives
    */
-  createNewOutgoing : function()
-  {
+  createNewOutgoing() {
     return {
-      type : "smtp",
-      hostname : null,
-      port : null, // see incoming
-      username : null, // see incoming. may be null, if auth is 0.
-      password : null, // see incoming. may be null, if auth is 0.
-      socketType : 0, // see incoming
-      badCert : false, // see incoming
-      auth : 0, // see incoming
-      authAlternatives : null, // see incoming
-      addThisServer : true, // if we already have an SMTP server, add this
+      type: "smtp",
+      hostname: null,
+      port: null, // see incoming
+      username: null, // see incoming. may be null, if auth is 0.
+      password: null, // see incoming. may be null, if auth is 0.
+      socketType: 0, // see incoming
+      badCert: false, // see incoming
+      auth: 0, // see incoming
+      authAlternatives: null, // see incoming
+      addThisServer: true, // if we already have an SMTP server, add this
       // if we already have an SMTP server, use it.
-      useGlobalPreferredServer : false,
+      useGlobalPreferredServer: false,
       // we should reuse an already configured SMTP server.
       // nsISmtpServer.key
-      existingServerKey : null,
+      existingServerKey: null,
       // user display value for existingServerKey
-      existingServerLabel : null,
+      existingServerLabel: null,
     };
   },
 
@@ -197,8 +198,7 @@ AccountConfig.prototype =
    * Returns a deep copy of this object,
    * i.e. modifying the copy will not affect the original object.
    */
-  copy : function()
-  {
+  copy() {
     // Workaround: deepCopy() fails to preserve base obj (instanceof)
     let result = new AccountConfig();
     for (let prop in this) {
@@ -208,16 +208,21 @@ AccountConfig.prototype =
     return result;
   },
 
-  isComplete : function()
-  {
-    return (!!this.incoming.hostname && !!this.incoming.port &&
-         !!this.incoming.socketType && !!this.incoming.auth &&
-         !!this.incoming.username &&
-         (!!this.outgoing.existingServerKey ||
-          this.outgoing.useGlobalPreferredServer ||
-          (!!this.outgoing.hostname && !!this.outgoing.port &&
-           !!this.outgoing.socketType && !!this.outgoing.auth &&
-           !!this.outgoing.username)));
+  isComplete() {
+    return (
+      !!this.incoming.hostname &&
+      !!this.incoming.port &&
+      !!this.incoming.socketType &&
+      !!this.incoming.auth &&
+      !!this.incoming.username &&
+      (!!this.outgoing.existingServerKey ||
+        this.outgoing.useGlobalPreferredServer ||
+        (!!this.outgoing.hostname &&
+          !!this.outgoing.port &&
+          !!this.outgoing.socketType &&
+          !!this.outgoing.auth &&
+          !!this.outgoing.username))
+    );
   },
 
   toString() {
@@ -272,18 +277,28 @@ AccountConfig.prototype =
       return password ? "set" : "not set";
     }
     function configToString(config) {
-      return config.type +
-      ", " + config.hostname + ":" + config.port +
-      ", " + sslToString(config.socketType) +
-      ", auth: " + authToString(config.auth) +
-       ", username: " + usernameToString(config.username) +
-      ", password: " + passwordToString(config.password);
+      return (
+        config.type +
+        ", " +
+        config.hostname +
+        ":" +
+        config.port +
+        ", " +
+        sslToString(config.socketType) +
+        ", auth: " +
+        authToString(config.auth) +
+        ", username: " +
+        usernameToString(config.username) +
+        ", password: " +
+        passwordToString(config.password)
+      );
     }
 
-    let result =
-      "Incoming: " + configToString(this.incoming) +
-      "\nOutgoing: ";
-    if (this.outgoing.useGlobalPreferredServer) {
+    let result = "Incoming: " + configToString(this.incoming) + "\nOutgoing: ";
+    if (
+      this.outgoing.useGlobalPreferredServer ||
+      this.incoming.useGlobalPreferredServer
+    ) {
       result += "Use global server";
     } else if (this.outgoing.existingServerKey) {
       result += "Use existing server " + this.outgoing.existingServerKey;
@@ -298,8 +313,28 @@ AccountConfig.prototype =
     }
     return result;
   },
-};
 
+  /**
+   * Sort the config alternatives such that exchange is the last of the
+   * alternatives.
+   */
+  preferStandardProtocols() {
+    let alternatives = this.incomingAlternatives;
+    // Add default incoming as one alternative.
+    alternatives.unshift(this.incoming);
+    alternatives.sort((a, b) => {
+      if (a.type == "exchange") {
+        return 1;
+      }
+      if (b.type == "exchange") {
+        return -1;
+      }
+      return 0;
+    });
+    this.incomingAlternatives = alternatives;
+    this.incoming = alternatives.shift();
+  },
+};
 
 // enum consts
 
@@ -309,7 +344,6 @@ AccountConfig.kSourceXML = 2; // config from XML from ISP or Mozilla DB
 AccountConfig.kSourceGuess = 3; // guessConfig()
 AccountConfig.kSourceExchange = 4; // from Microsoft Exchange AutoDiscover
 
-
 /**
  * Some fields on the account config accept placeholders (when coming from XML).
  *
@@ -343,12 +377,13 @@ AccountConfig.kSourceExchange = 4; // from Microsoft Exchange AutoDiscover
  * @param password {String}
  * The password for the incoming server and (if necessary) the outgoing server
  */
-function replaceVariables(account, realname, emailfull, password)
-{
+function replaceVariables(account, realname, emailfull, password) {
   sanitize.nonemptystring(emailfull);
   let emailsplit = emailfull.split("@");
-  assert(emailsplit.length == 2,
-         "email address not in expected format: must contain exactly one @");
+  assert(
+    emailsplit.length == 2,
+    "email address not in expected format: must contain exactly one @"
+  );
   let emaillocal = sanitize.nonemptystring(emailsplit[0]);
   let emaildomain = sanitize.hostname(emailsplit[1]);
   sanitize.label(realname);
@@ -364,30 +399,45 @@ function replaceVariables(account, realname, emailfull, password)
     account.incoming.password = password;
     account.outgoing.password = password; // set member only if auth required?
   }
-  account.incoming.username = _replaceVariable(account.incoming.username,
-                                               otherVariables);
-  account.outgoing.username = _replaceVariable(account.outgoing.username,
-                                               otherVariables);
-  account.incoming.hostname =
-      _replaceVariable(account.incoming.hostname, otherVariables);
-  if (account.outgoing.hostname) // will be null if user picked existing server.
-    account.outgoing.hostname =
-        _replaceVariable(account.outgoing.hostname, otherVariables);
-  account.identity.realname =
-      _replaceVariable(account.identity.realname, otherVariables);
-  account.identity.emailAddress =
-      _replaceVariable(account.identity.emailAddress, otherVariables);
+  account.incoming.username = _replaceVariable(
+    account.incoming.username,
+    otherVariables
+  );
+  account.outgoing.username = _replaceVariable(
+    account.outgoing.username,
+    otherVariables
+  );
+  account.incoming.hostname = _replaceVariable(
+    account.incoming.hostname,
+    otherVariables
+  );
+  if (account.outgoing.hostname) {
+    // will be null if user picked existing server.
+    account.outgoing.hostname = _replaceVariable(
+      account.outgoing.hostname,
+      otherVariables
+    );
+  }
+  account.identity.realname = _replaceVariable(
+    account.identity.realname,
+    otherVariables
+  );
+  account.identity.emailAddress = _replaceVariable(
+    account.identity.emailAddress,
+    otherVariables
+  );
   account.displayName = _replaceVariable(account.displayName, otherVariables);
 }
 
-function _replaceVariable(variable, values)
-{
+function _replaceVariable(variable, values) {
   let str = variable;
-  if (typeof(str) != "string")
+  if (typeof str != "string") {
     return str;
+  }
 
-  for (let varname in values)
-      str = str.replace("%" + varname + "%", values[varname]);
+  for (let varname in values) {
+    str = str.replace("%" + varname + "%", values[varname]);
+  }
 
   return str;
 }
