@@ -15,7 +15,10 @@
  * but not for bigger file downloads.
  */
 
-ChromeUtils.import("resource:///modules/JXON.js");
+/* import-globals-from emailWizard.js */
+
+var { JXON } = ChromeUtils.import("resource:///modules/JXON.js");
+var { logException } = ChromeUtils.import("resource:///modules/errUtils.js");
 
 /**
  * Set up a fetch.
@@ -81,8 +84,8 @@ ChromeUtils.import("resource:///modules/JXON.js");
  *   This also applies to both https: to http: and http: to https: redirects.
  */
 function FetchHTTP(url, args, successCallback, errorCallback) {
-  assert(typeof(successCallback) == "function", "BUG: successCallback");
-  assert(typeof(errorCallback) == "function", "BUG: errorCallback");
+  assert(typeof successCallback == "function", "BUG: successCallback");
+  assert(typeof errorCallback == "function", "BUG: errorCallback");
   this._url = sanitize.string(url);
   if (!args) {
     args = {};
@@ -96,16 +99,19 @@ function FetchHTTP(url, args, successCallback, errorCallback) {
 
   this._args = args;
   this._args.post = sanitize.boolean(args.post || false); // default false
-  this._args.allowCache = "allowCache" in args ? sanitize.boolean(args.allowCache) : true; // default true
+  this._args.allowCache =
+    "allowCache" in args ? sanitize.boolean(args.allowCache) : true; // default true
   this._args.allowAuthPrompt = sanitize.boolean(args.allowAuthPrompt || false); // default false
-  this._args.requireSecureAuth = sanitize.boolean(args.requireSecureAuth || false); // default false
+  this._args.requireSecureAuth = sanitize.boolean(
+    args.requireSecureAuth || false
+  ); // default false
+  this._args.timeout = sanitize.integer(args.timeout || 5000); // default 5 seconds
   this._successCallback = successCallback;
   this._errorCallback = errorCallback;
   this._logger = Log4Moz.getConfiguredLogger("mail.setup");
   this._logger.info("Requesting <" + url + ">");
 }
-FetchHTTP.prototype =
-{
+FetchHTTP.prototype = {
   __proto__: Abortable.prototype,
   _url: null, // URL as passed to ctor, without arguments
   _args: null,
@@ -114,24 +120,33 @@ FetchHTTP.prototype =
   _request: null, // the XMLHttpRequest object
   result: null,
 
-  start : function()
-  {
+  start() {
     let url = this._url;
     for (let name in this._args.urlArgs) {
-      url += (!url.includes("?") ? "?" : "&") +
-             name + "=" + encodeURIComponent(this._args.urlArgs[name]);
+      url +=
+        (!url.includes("?") ? "?" : "&") +
+        name +
+        "=" +
+        encodeURIComponent(this._args.urlArgs[name]);
     }
     this._request = new XMLHttpRequest();
     let request = this._request;
     request.mozBackgroundRequest = !this._args.allowAuthPrompt;
-    let username = null, password = null;
+    let username = null,
+      password = null;
     if (url.startsWith("https:") || !this._args.requireSecureAuth) {
       username = this._args.username;
       password = this._args.password;
     }
-    request.open(this._args.post ? "POST" : "GET", url, true, username, password);
+    request.open(
+      this._args.post ? "POST" : "GET",
+      url,
+      true,
+      username,
+      password
+    );
     request.channel.loadGroup = null;
-    request.timeout = 5000; // 5 seconds
+    request.timeout = this._args.timeout;
     // needs bug 407190 patch v4 (or higher) - uncomment if that lands.
     // try {
     //    var channel = request.channel.QueryInterface(Ci.nsIHttpChannel2);
@@ -147,15 +162,15 @@ FetchHTTP.prototype =
     // body
     let mimetype = null;
     let body = this._args.uploadBody;
-    if (typeof(body) == "object" && "nodeType" in body) {
+    if (typeof body == "object" && "nodeType" in body) {
       // XML
       mimetype = "text/xml; charset=UTF-8";
       body = new XMLSerializer().serializeToString(body);
-    } else if (typeof(body) == "object") {
+    } else if (typeof body == "object") {
       // JSON
       mimetype = "text/json; charset=UTF-8";
       body = JSON.stringify(body);
-    } else if (typeof(body) == "string") {
+    } else if (typeof body == "string") {
       // Plaintext
       // You can override the mimetype with { headers: {"Content-Type" : "text/foo" } }
       mimetype = "text/plain; charset=UTF-8";
@@ -164,8 +179,11 @@ FetchHTTP.prototype =
       mimetype = "application/x-www-form-urlencoded; charset=UTF-8";
       body = "";
       for (let name in this._args.bodyFormArgs) {
-        body += (body ? "&" : "") + name + "=" +
-            encodeURIComponent(this._args.bodyFormArgs[name]);
+        body +=
+          (body ? "&" : "") +
+          name +
+          "=" +
+          encodeURIComponent(this._args.bodyFormArgs[name]);
       }
     }
 
@@ -175,7 +193,10 @@ FetchHTTP.prototype =
     }
     if (username && password) {
       // workaround, because open(..., username, password) does not work.
-      request.setRequestHeader("Authorization", "Basic " + btoa(username + ":" + password));
+      request.setRequestHeader(
+        "Authorization",
+        "Basic " + btoa(username + ":" + password)
+      );
     }
     for (let name in this._args.headers) {
       request.setRequestHeader(name, this._args.headers[name]);
@@ -189,128 +210,134 @@ FetchHTTP.prototype =
     }
 
     var me = this;
-    request.onload = function() { me._response(true); };
-    request.onerror = function() { me._response(false); };
-    request.ontimeout = function() { me._response(false); };
+    request.onload = function() {
+      me._response(true);
+    };
+    request.onerror = function() {
+      me._response(false);
+    };
+    request.ontimeout = function() {
+      me._response(false);
+    };
     request.send(body);
     // Store the original stack so we can use it if there is an exception
     this._callStack = Error().stack;
   },
-  _response : function(success, exStored)
-  {
-    try
-    {
-    var errorCode = null;
-    var errorStr = null;
+  _response(success, exStored) {
+    try {
+      var errorCode = null;
+      var errorStr = null;
 
-    if (success && this._request.status >= 200 &&
-        this._request.status < 300) // HTTP level success
-    {
-      try
-      {
-
-        // response
-        var mimetype = this._request.getResponseHeader("Content-Type");
-        if (!mimetype)
-          mimetype = "";
-        mimetype = mimetype.split(";")[0];
-        if (mimetype == "text/xml" ||
+      if (
+        success &&
+        this._request.status >= 200 &&
+        this._request.status < 300
+      ) {
+        // HTTP level success
+        try {
+          // response
+          var mimetype = this._request.getResponseHeader("Content-Type");
+          if (!mimetype) {
+            mimetype = "";
+          }
+          mimetype = mimetype.split(";")[0];
+          if (
+            mimetype == "text/xml" ||
             mimetype == "application/xml" ||
-            mimetype == "text/rdf")
-        {
-          // XML
-          this.result = JXON.build(this._request.responseXML);
+            mimetype == "text/rdf"
+          ) {
+            // XML
+            this.result = JXON.build(this._request.responseXML);
+          } else if (
+            mimetype == "text/json" ||
+            mimetype == "application/json"
+          ) {
+            // JSON
+            this.result = JSON.parse(this._request.responseText);
+          } else {
+            // Plaintext (fallback)
+            // ddump("mimetype: " + mimetype + " only supported as text");
+            this.result = this._request.responseText;
+          }
+        } catch (e) {
+          success = false;
+          errorStr = getStringBundle(
+            "chrome://messenger/locale/accountCreationUtil.properties"
+          ).GetStringFromName("bad_response_content.error");
+          errorCode = -4;
         }
-        else if (mimetype == "text/json" ||
-                 mimetype == "application/json")
-        {
-          // JSON
-          this.result = JSON.parse(this._request.responseText);
-        }
-        else
-        {
-          // Plaintext (fallback)
-          //ddump("mimetype: " + mimetype + " only supported as text");
-          this.result = this._request.responseText;
-        }
-
-      }
-      catch (e)
-      {
+      } else if (
+        this._args.username &&
+        this._request.responseURL.replace(/\/\/.*@/, "//") != this._url &&
+        this._request.responseURL.startsWith(
+          this._args.requireSecureAuth ? "https" : "http"
+        ) &&
+        !this._isRetry
+      ) {
+        // Redirects lack auth, see <https://stackoverflow.com/a/28411170>
+        this._logger.info(
+          "Call to <" +
+            this._url +
+            "> was redirected to <" +
+            this._request.responseURL +
+            ">, and failed. Re-trying the new URL with authentication again."
+        );
+        this._url = this._request.responseURL;
+        this._isRetry = true;
+        this.start();
+        return;
+      } else {
         success = false;
-        errorStr = getStringBundle(
-                   "chrome://messenger/locale/accountCreationUtil.properties")
-                   .GetStringFromName("bad_response_content.error");
-        errorCode = -4;
+        try {
+          errorCode = this._request.status;
+          errorStr = this._request.statusText;
+        } catch (e) {
+          // In case .statusText throws (it's marked as [Throws] in the webidl),
+          // continue with empty errorStr.
+          console.error(e);
+        }
+        if (!errorStr) {
+          // If we can't resolve the hostname in DNS etc., .statusText is empty.
+          errorCode = -2;
+          errorStr = getStringBundle(
+            "chrome://messenger/locale/accountCreationUtil.properties"
+          ).GetStringFromName("cannot_contact_server.error");
+          ddump(errorStr + " on <" + this._url + ">");
+        }
       }
-    }
-    else if (this._args.username &&
-             this._request.responseURL.replace(/\/\/.*@/, "//") != this._url &&
-             this._request.responseURL.startsWith(this._args.requireSecureAuth ? "https" : "http") &&
-             !this._isRetry)
-    {
-      // Redirects lack auth, see <https://stackoverflow.com/a/28411170>
-      this._logger.info("Call to <" + this._url + "> was redirected to <" + this._request.responseURL + ">, and failed. Re-trying the new URL with authentication again.");
-      this._url = this._request.responseURL;
-      this._isRetry = true;
-      this.start();
-      return;
-    }
-    else
-    {
-      success = false;
-      try
-      {
-        errorCode = this._request.status;
-        errorStr = this._request.statusText;
-      } catch (e) {
-        // If we can't resolve the hostname in DNS etc., .statusText throws
-        errorCode = -2;
-        errorStr = getStringBundle(
-                   "chrome://messenger/locale/accountCreationUtil.properties")
-                   .GetStringFromName("cannot_contact_server.error");
-        ddump(errorStr);
-      }
-    }
 
-    // Callbacks
-    if (success)
-    {
-      try {
-        this._successCallback(this.result);
-      } catch (e) {
-        logException(e);
+      // Callbacks
+      if (success) {
+        try {
+          this._successCallback(this.result);
+        } catch (e) {
+          logException(e);
+          e.stack = this._callStack;
+          this._error(e);
+        }
+      } else if (exStored) {
+        this._error(exStored);
+      } else {
+        // Put the caller's stack into the exception
+        let e = new ServerException(errorStr, errorCode, this._url);
         e.stack = this._callStack;
         this._error(e);
       }
-    }
-    else if (exStored)
-      this._error(exStored);
-    else
-    {
-      // Put the caller's stack into the exception
-      let e = new ServerException(errorStr, errorCode, this._url);
-      e.stack = this._callStack;
-      this._error(e);
-    }
 
-    if (this._finishedCallback)
-    {
-      try {
-        this._finishedCallback(this);
-      } catch (e) {
-        logException(e);
+      if (this._finishedCallback) {
+        try {
+          this._finishedCallback(this);
+        } catch (e) {
+          logException(e);
+        }
       }
-    }
-
     } catch (e) {
       // error in our fetchhttp._response() code
       logException(e);
       this._error(e);
     }
   },
-  _error : function(e)
-  {
+  _error(e) {
     try {
       this._errorCallback(e);
     } catch (e) {
@@ -322,8 +349,7 @@ FetchHTTP.prototype =
   /**
    * Call this between start() and finishedCallback fired.
    */
-  cancel : function(ex)
-  {
+  cancel(ex) {
     assert(!this.result, "Call already returned");
 
     this._request.abort();
@@ -337,32 +363,29 @@ FetchHTTP.prototype =
    * This is useful to enable and disable a Cancel button in the UI,
    * which allows to cancel the network request.
    */
-  setFinishedCallback : function(finishedCallback)
-  {
+  setFinishedCallback(finishedCallback) {
     this._finishedCallback = finishedCallback;
-  }
-}
+  },
+};
 
-function CancelledException(msg)
-{
+function CancelledException(msg) {
   Exception.call(this, msg);
 }
 CancelledException.prototype = Object.create(Exception.prototype);
 CancelledException.prototype.constructor = CancelledException;
 
-function UserCancelledException(msg)
-{
+function UserCancelledException(msg) {
   // The user knows they cancelled so I don't see a need
   // for a message to that effect.
-  if (!msg)
+  if (!msg) {
     msg = "User cancelled";
+  }
   CancelledException.call(this, msg);
 }
 UserCancelledException.prototype = Object.create(CancelledException.prototype);
 UserCancelledException.prototype.constructor = UserCancelledException;
 
-function ServerException(msg, code, uri)
-{
+function ServerException(msg, code, uri) {
   Exception.call(this, msg);
   this.code = code;
   this.uri = uri;
