@@ -27,6 +27,13 @@ ChromeUtils.defineModuleGetter(
   "toXPCOMArray",
   "resource:///modules/iteratorUtils.jsm"
 );
+ChromeUtils.defineModuleGetter(
+  this,
+  "NetUtil",
+  "resource://gre/modules/NetUtil.jsm"
+);
+
+Cu.importGlobalProperties(["fetch"]);
 
 var { DefaultMap } = ExtensionUtils;
 
@@ -48,7 +55,7 @@ function convertMessagePart(part) {
       partObject[key] = part[key];
     }
   }
-  if (Array.isArray(part.parts) && part.parts.length > 0) {
+  if ("parts" in part && Array.isArray(part.parts) && part.parts.length > 0) {
     partObject.parts = part.parts.map(convertMessagePart);
   }
   return partObject;
@@ -153,6 +160,44 @@ this.messages = class extends ExtensionAPI {
             });
           });
         },
+        async getRaw(messageId) {
+          let messenger = Cc["@mozilla.org/messenger;1"].createInstance(
+            Ci.nsIMessenger
+          );
+          let msgHdr = messageTracker.getMessage(messageId);
+          let msgUri = msgHdr.folder.generateMessageURI(msgHdr.messageKey);
+          let service = messenger.messageServiceFromURI(msgUri);
+
+          let streamListener = Cc[
+            "@mozilla.org/network/sync-stream-listener;1"
+          ].createInstance(Ci.nsISyncStreamListener);
+          await new Promise((resolve, reject) => {
+            service.streamMessage(
+              msgUri,
+              streamListener,
+              null,
+              {
+                OnStartRunningUrl() {},
+                OnStopRunningUrl(url, exitCode) {
+                  if (exitCode !== 0) {
+                    Cu.reportError(exitCode);
+                    reject();
+                    return;
+                  }
+                  resolve();
+                },
+              },
+              false,
+              ""
+            );
+          }).catch(() => {
+            throw new ExtensionError(`Error reading message ${messageId}`);
+          });
+          return NetUtil.readInputStreamToString(
+            streamListener.inputStream,
+            streamListener.available()
+          );
+        },
         async query(queryInfo) {
           let query = Gloda.newQuery(Gloda.NOUN_MESSAGE);
 
@@ -181,6 +226,11 @@ this.messages = class extends ExtensionAPI {
             query.starred(queryInfo.flagged);
           }
           if (queryInfo.folder) {
+            if (!context.extension.hasPermission("accountsRead")) {
+              throw new ExtensionError(
+                'Querying by folder requires the "accountsRead" permission'
+              );
+            }
             let folder = MailServices.folderLookup.getFolderForURL(
               folderPathToURI(queryInfo.folder.accountId, queryInfo.folder.path)
             );
@@ -221,23 +271,33 @@ this.messages = class extends ExtensionAPI {
           if (!msgHdr) {
             return;
           }
+          const msgs = Cc["@mozilla.org/array;1"].createInstance(
+            Ci.nsIMutableArray
+          );
+          msgs.appendElement(msgHdr);
+
           if (newProperties.read !== null) {
-            msgHdr.markRead(newProperties.read);
+            msgHdr.folder.markMessagesRead(msgs, newProperties.read);
           }
           if (newProperties.flagged !== null) {
-            msgHdr.markFlagged(newProperties.flagged);
+            msgHdr.folder.markMessagesFlagged(msgs, newProperties.flagged);
+          }
+          if (newProperties.junk !== null) {
+            let score = newProperties.junk
+              ? Ci.nsIJunkMailPlugin.IS_SPAM_SCORE
+              : Ci.nsIJunkMailPlugin.IS_HAM_SCORE;
+            msgHdr.folder.setJunkScoreForMessages(msgs, score);
           }
           if (Array.isArray(newProperties.tags)) {
             let currentTags = msgHdr.getStringProperty("keywords").split(" ");
-            let msgHdrArray = toXPCOMArray([msgHdr], Ci.nsIMutableArray);
 
             for (let { key: tagKey } of MailServices.tags.getAllTags({})) {
               if (newProperties.tags.includes(tagKey)) {
                 if (!currentTags.includes(tagKey)) {
-                  msgHdr.folder.addKeywordsToMessages(msgHdrArray, tagKey);
+                  msgHdr.folder.addKeywordsToMessages(msgs, tagKey);
                 }
               } else if (currentTags.includes(tagKey)) {
-                msgHdr.folder.removeKeywordsFromMessages(msgHdrArray, tagKey);
+                msgHdr.folder.removeKeywordsFromMessages(msgs, tagKey);
               }
             }
           }
