@@ -7,21 +7,32 @@
  * when certain special or invalid values are entered into the fields.
  */
 
+"use strict";
+
+/* import-globals-from ../shared-modules/test-account-manager-helpers.js */
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-keyboard-helpers.js */
+/* import-globals-from ../shared-modules/test-window-helpers.js */
+
 var MODULE_NAME = "test-account-values";
-
 var RELATIVE_ROOT = "../shared-modules";
-var MODULE_REQUIRES = ["folder-display-helpers", "window-helpers",
-                         "account-manager-helpers"];
+var MODULE_REQUIRES = [
+  "folder-display-helpers",
+  "window-helpers",
+  "account-manager-helpers",
+  "keyboard-helpers",
+];
 
-var elib = {};
-ChromeUtils.import("resource://mozmill/modules/elementslib.js", elib);
+var elib = ChromeUtils.import(
+  "chrome://mozmill/content/modules/elementslib.jsm"
+);
 
 var gPopAccount, gOriginalAccountCount;
 
 function setupModule(module) {
-  collector.getModule("window-helpers").installInto(module);
-  collector.getModule("folder-display-helpers").installInto(module);
-  collector.getModule("account-manager-helpers").installInto(module);
+  for (let lib of MODULE_REQUIRES) {
+    collector.getModule(lib).installInto(module);
+  }
 
   // There may be pre-existing accounts from other tests.
   gOriginalAccountCount = MailServices.accounts.allServers.length;
@@ -39,7 +50,10 @@ function setupModule(module) {
   gPopAccount.addIdentity(identity);
 
   // Now there should be one more account.
-  assert_equals(MailServices.accounts.allServers.length, gOriginalAccountCount + 1);
+  assert_equals(
+    MailServices.accounts.allServers.length,
+    gOriginalAccountCount + 1
+  );
 }
 
 function teardownModule(module) {
@@ -66,14 +80,14 @@ function test_default_CC_address() {
  *
  * @param amc  the account options controller
  */
-function subtest_check_default_CC_address(amc)
-{
+function subtest_check_default_CC_address(amc) {
   let accountRow = get_account_tree_row(gPopAccount.key, "am-copies.xul", amc);
   click_account_tree_row(amc, accountRow);
 
   let iframe = amc.window.document.getElementById("contentFrame");
 
-  let defaultAddress = iframe.contentDocument.getElementById("identity.email").value;
+  let defaultAddress = iframe.contentDocument.getElementById("identity.email")
+    .value;
   let ccCheck = iframe.contentDocument.getElementById("identity.doCc");
   let ccAddress = iframe.contentDocument.getElementById("identity.doCcList");
   // The CC checkbox is not enabled and the address value is empty.
@@ -107,14 +121,17 @@ function test_account_name() {
     .createIncomingServer(null, "example.nntp.invalid", "nntp")
     .QueryInterface(Ci.nsINntpIncomingServer);
 
-  identity = MailServices.accounts.createIdentity();
+  let identity = MailServices.accounts.createIdentity();
   identity.email = "tinderbox2@example.invalid";
 
   let nntpAccount = MailServices.accounts.createAccount();
   nntpAccount.incomingServer = nntpServer;
   nntpAccount.addIdentity(identity);
 
-  assert_equals(gPopAccount.incomingServer.prettyName, "nobody on example.invalid");
+  assert_equals(
+    gPopAccount.incomingServer.prettyName,
+    "nobody on example.invalid"
+  );
   assert_equals(nntpAccount.incomingServer.prettyName, "example.nntp.invalid");
 
   // The automatic account name update works only if the name is
@@ -170,7 +187,10 @@ function test_account_name() {
   });
 
   // And the account name should not be touched.
-  assert_equals(gPopAccount.incomingServer.prettyName, newUser + "@example.invalid");
+  assert_equals(
+    gPopAccount.incomingServer.prettyName,
+    newUser + "@example.invalid"
+  );
 
   MailServices.accounts.removeAccount(nntpAccount);
 }
@@ -183,8 +203,7 @@ function test_account_name() {
  * @param aNewUsername  the username value to set
  * @param amc           the account options controller
  */
-function subtest_check_account_name(aAccount, aNewHostname, aNewUsername, amc)
-{
+function subtest_check_account_name(aAccount, aNewHostname, aNewUsername, amc) {
   let accountRow = get_account_tree_row(aAccount.key, "am-server.xul", amc);
   click_account_tree_row(amc, accountRow);
 
@@ -215,8 +234,9 @@ function subtest_check_account_name(aAccount, aNewHostname, aNewUsername, amc)
   }
   // We really need to save the new values so click OK on the Account settings.
   amc.window.document.documentElement.acceptDialog();
-  if (aNewUsername)
+  if (aNewUsername) {
     wait_for_modal_dialog("commonDialog");
+  }
 }
 
 /**
@@ -225,7 +245,9 @@ function subtest_check_account_name(aAccount, aNewHostname, aNewUsername, amc)
  */
 function test_invalid_junk_target() {
   // Set the junk target prefs to invalid values.
-  let branch = Services.prefs.getBranch("mail.server." + gPopAccount.incomingServer.key + ".");
+  let branch = Services.prefs.getBranch(
+    "mail.server." + gPopAccount.incomingServer.key + "."
+  );
   branch.setCharPref("spamActionTargetAccount", "some random non-existent URI");
   branch.setCharPref("spamActionTargetFolder", "some random non-existent URI");
   let moveOnSpam = true;
@@ -235,11 +257,7 @@ function test_invalid_junk_target() {
   });
 
   // The pref has no default so its non-existence means it was cleared.
-  try {
-    moveOnSpam = branch.getBoolPref("moveOnSpam");
-  } catch (e) {
-    moveOnSpam = false;
-  }
+  moveOnSpam = branch.getBoolPref("moveOnSpam", false);
   assert_false(moveOnSpam);
   // The targets should point to the same pop account now.
   let targetAccount = branch.getCharPref("spamActionTargetAccount");
@@ -253,8 +271,7 @@ function test_invalid_junk_target() {
  *
  * @param amc  the account options controller
  */
-function subtest_check_invalid_junk_target(amc)
-{
+function subtest_check_invalid_junk_target(amc) {
   let accountRow = get_account_tree_row(gPopAccount.key, "am-junk.xul", amc);
   click_account_tree_row(amc, accountRow);
 
@@ -267,7 +284,9 @@ function subtest_check_invalid_junk_target(amc)
  * Checks if invalid server hostnames are not accepted.
  */
 function test_invalid_hostname() {
-  let branch = Services.prefs.getBranch("mail.server." + gPopAccount.incomingServer.key + ".");
+  let branch = Services.prefs.getBranch(
+    "mail.server." + gPopAccount.incomingServer.key + "."
+  );
   let origHostname = branch.getCharPref("realhostname");
 
   open_advanced_settings(function(amc) {
@@ -289,8 +308,7 @@ function test_invalid_hostname() {
  * @param aExitSettings      Attempt to close the Account settings dialog.
  * @param aOriginalHostname  Original hostname of this server.
  */
-function subtest_check_invalid_hostname(amc, aExitSettings, aOriginalHostname)
-{
+function subtest_check_invalid_hostname(amc, aExitSettings, aOriginalHostname) {
   let accountRow = get_account_tree_row(gPopAccount.key, "am-server.xul", amc);
   click_account_tree_row(amc, accountRow);
 
@@ -325,3 +343,44 @@ function subtest_check_invalid_hostname(amc, aExitSettings, aOriginalHostname)
     wait_for_modal_dialog("commonDialog");
   }
 }
+
+/**
+ * Bug 1426328.
+ * Check that the AM will trim user added spaces around text values.
+ */
+const badName = "trailing  space ";
+const badEmail = " leading_space@example.com";
+
+function test_trailing_spaces() {
+  open_advanced_settings(function(amc) {
+    subtest_check_trailing_spaces(amc);
+  });
+  assert_equals(gPopAccount.incomingServer.prettyName, badName.trim());
+  assert_equals(gPopAccount.defaultIdentity.email, badEmail.trim());
+}
+
+/**
+ * Check that the AM will trim user added spaces around text values
+ * when storing them into the account.
+ *
+ * @param amc  the account options controller
+ */
+function subtest_check_trailing_spaces(amc) {
+  let accountRow = get_account_tree_row(gPopAccount.key, null, amc);
+  click_account_tree_row(amc, accountRow);
+
+  let iframe = amc.window.document.getElementById("contentFrame");
+
+  let accountName = iframe.contentDocument.getElementById("server.prettyName");
+  let defaultAddress = iframe.contentDocument.getElementById("identity.email");
+  delete_all_existing(amc, new elib.Elem(accountName));
+  delete_all_existing(amc, new elib.Elem(defaultAddress));
+  input_value(amc, badName, new elib.Elem(accountName));
+  input_value(amc, badEmail, new elib.Elem(defaultAddress));
+
+  assert_equals(accountName.value, badName);
+  assert_equals(defaultAddress.value, badEmail);
+
+  // We really need to save the new values so click OK on the Account settings.
+  amc.window.document.documentElement.acceptDialog();
+}
