@@ -2,17 +2,30 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
+"use strict";
+
+/* import-globals-from ../shared-modules/test-account-manager-helpers.js */
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-keyboard-helpers.js */
+/* import-globals-from ../shared-modules/test-window-helpers.js */
+
 var MODULE_NAME = "test-mail-account-setup-wizard";
-
 var RELATIVE_ROOT = "../shared-modules";
-var MODULE_REQUIRES = ["folder-display-helpers", "window-helpers",
-                       "account-manager-helpers", "keyboard-helpers" ];
+var MODULE_REQUIRES = [
+  "folder-display-helpers",
+  "window-helpers",
+  "account-manager-helpers",
+  "keyboard-helpers",
+];
 
-ChromeUtils.import("resource://gre/modules/Services.jsm");
-ChromeUtils.import("resource:///modules/mailServices.js");
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { MailServices } = ChromeUtils.import(
+  "resource:///modules/MailServices.jsm"
+);
 
-var elib = {};
-ChromeUtils.import("resource://mozmill/modules/elementslib.js", elib);
+var elib = ChromeUtils.import(
+  "chrome://mozmill/content/modules/elementslib.jsm"
+);
 
 var user = {
   name: "Yamato Nadeshiko",
@@ -36,13 +49,16 @@ function remove_account_internal(amc, aAccount, aOutgoing) {
     // Remove the account and incoming server
     let serverId = aAccount.incomingServer.serverURI;
     MailServices.accounts.removeAccount(aAccount);
-    if (serverId in win.accountArray)
+    aAccount = null;
+    if (serverId in win.accountArray) {
       delete win.accountArray[serverId];
+    }
     win.selectServer(null, null);
 
     // Remove the outgoing server
+    let smtpKey = aOutgoing.key;
     MailServices.smtp.deleteServer(aOutgoing);
-    win.replaceWithDefaultSmtpServer(aOutgoing.key);
+    win.replaceWithDefaultSmtpServer(smtpKey);
   } catch (ex) {
     throw new Error("failure to remove account: " + ex + "\n");
   }
@@ -57,7 +73,7 @@ function test_mail_account_setup() {
   // Force .com MIME-Type to text/xml
   collector.httpd.registerContentType("com", "text/xml");
 
-  open_mail_account_setup_wizard(function (awc) {
+  open_mail_account_setup_wizard(function(awc) {
     // Input user's account information
     awc.click(awc.eid("realname"));
     if (awc.e("realname").value) {
@@ -74,9 +90,12 @@ function test_mail_account_setup() {
     awc.click(awc.eid("next_button"));
 
     // XXX: This should probably use a notification, once we fix bug 561143.
-    awc.waitFor(() => awc.window.gEmailConfigWizard._currentConfig != null,
-                "Timeout waiting for current config to become non-null",
-                8000, 600);
+    awc.waitFor(
+      () => awc.window.gEmailConfigWizard._currentConfig != null,
+      "Timeout waiting for current config to become non-null",
+      8000,
+      600
+    );
 
     // Open the advanced settings (Account Manager) to create the account
     // immediately.  We use an invalid email/password so the setup will fail
@@ -89,8 +108,10 @@ function test_mail_account_setup() {
 }
 
 function subtest_verify_account(amc) {
-  amc.waitFor(() => amc.window.currentAccount != null,
-              "Timeout waiting for currentAccount to become non-null");
+  amc.waitFor(
+    () => amc.window.currentAccount != null,
+    "Timeout waiting for currentAccount to become non-null"
+  );
   let account = amc.window.currentAccount;
   let identity = account.defaultIdentity;
   let incoming = account.incomingServer;
@@ -98,28 +119,39 @@ function subtest_verify_account(amc) {
 
   let config = {
     "incoming server username": {
-      actual: incoming.username, expected: user.email.split("@")[0]
+      actual: incoming.username,
+      expected: user.email.split("@")[0],
     },
     "outgoing server username": {
-      actual: outgoing.username, expected: user.email
+      actual: outgoing.username,
+      expected: user.email,
     },
     "incoming server hostname": {
       // Note: N in the hostName is uppercase
-      actual: incoming.hostName, expected: user.incomingHost
+      actual: incoming.hostName,
+      expected: user.incomingHost,
     },
     "outgoing server hostname": {
       // And this is lowercase
-      actual: outgoing.hostname, expected: user.outgoingHost
+      actual: outgoing.hostname,
+      expected: user.outgoingHost,
     },
     "user real name": { actual: identity.fullName, expected: user.name },
-    "user email address": { actual: identity.email, expected: user.email }
+    "user email address": { actual: identity.email, expected: user.email },
   };
 
   try {
     for (let i in config) {
       if (config[i].actual != config[i].expected) {
-        throw new Error("Configured " + i + " is " + config[i].actual +
-                        ". It should be " + config[i].expected + ".");
+        throw new Error(
+          "Configured " +
+            i +
+            " is " +
+            config[i].actual +
+            ". It should be " +
+            config[i].expected +
+            "."
+        );
       }
     }
   } finally {
@@ -143,7 +175,7 @@ function test_bad_password_uses_old_settings() {
   collector.httpd.registerContentType("com", "text/xml");
 
   mc.sleep(0);
-  open_mail_account_setup_wizard(function (awc) {
+  open_mail_account_setup_wizard(function(awc) {
     try {
       // Input user's account information
       awc.click(awc.eid("realname"));
@@ -160,25 +192,41 @@ function test_bad_password_uses_old_settings() {
       // Load the autoconfig file from http://localhost:433**/autoconfig/example.com
       awc.e("next_button").click();
 
-      let config = null;
-
-      awc.waitFor(function() { return this.disabled == false && this.hidden == false; },
-                  "Timeout waiting for create button to be visible and active",
-                  8000, 600, awc.e("create_button"));
+      awc.waitFor(
+        function() {
+          return !this.disabled && !this.hidden;
+        },
+        "Timeout waiting for create button to be visible and active",
+        8000,
+        600,
+        awc.e("create_button")
+      );
       awc.e("create_button").click();
 
-      awc.waitFor(function() { return this.disabled == false; },
-                  "Timeout waiting for create button to be visible and active",
-                  8000, 600, awc.e("create_button"));
+      awc.waitFor(
+        function() {
+          return !this.disabled;
+        },
+        "Timeout waiting for create button to be visible and active",
+        8000,
+        600,
+        awc.e("create_button")
+      );
       awc.e("create_button").click();
       awc.e("manual-edit_button").click();
 
       // Make sure all the values are the same as in the user object.
       awc.sleep(1000);
-      assert_equals(awc.e("outgoing_hostname").value, user.outgoingHost,
-                    "Outgoing server changed!");
-      assert_equals(awc.e("incoming_hostname").value, user.incomingHost,
-                    "incoming server changed!");
+      assert_equals(
+        awc.e("outgoing_hostname").value,
+        user.outgoingHost,
+        "Outgoing server changed!"
+      );
+      assert_equals(
+        awc.e("incoming_hostname").value,
+        user.incomingHost,
+        "incoming server changed!"
+      );
     } finally {
       // Clean up
       Services.prefs.clearUserPref(pref_name);
@@ -198,18 +246,22 @@ function test_remember_password() {
  */
 function remember_password_test(aPrefValue) {
   // save the pref for backup purpose
-  let rememberSignons_pref_save =
-      Services.prefs.getBoolPref("signon.rememberSignons", true);
+  let rememberSignons_pref_save = Services.prefs.getBoolPref(
+    "signon.rememberSignons",
+    true
+  );
 
   Services.prefs.setBoolPref("signon.rememberSignons", aPrefValue);
 
   // without this, it breaks the test, don't know why
   mc.sleep(0);
-  open_mail_account_setup_wizard(function (awc) {
+  open_mail_account_setup_wizard(function(awc) {
     try {
       let password = new elementslib.ID(awc.window.document, "password");
-      let rememberPassword =
-          new elementslib.ID(awc.window.document, "remember_password");
+      let rememberPassword = new elementslib.ID(
+        awc.window.document,
+        "remember_password"
+      );
 
       // type something in the password field
       awc.e("password").focus();
@@ -218,8 +270,7 @@ function remember_password_test(aPrefValue) {
       awc.assertProperty(rememberPassword, "disabled", !aPrefValue);
       if (aPrefValue) {
         awc.assertChecked(rememberPassword);
-      }
-      else {
+      } else {
         awc.assertNotChecked(rememberPassword);
       }
 
@@ -227,11 +278,13 @@ function remember_password_test(aPrefValue) {
       delete_all_existing(awc, password);
 
       // restore the saved signon.rememberSignons value
-      Services.prefs.setBoolPref("signon.rememberSignons", rememberSignons_pref_save);
+      Services.prefs.setBoolPref(
+        "signon.rememberSignons",
+        rememberSignons_pref_save
+      );
     } finally {
       // close the wizard
       awc.e("cancel_button").click();
     }
   });
 }
-
