@@ -6,24 +6,38 @@
  * Tests that the cloudfile notifications work as they should.
  */
 
-var MODULE_NAME = 'test-cloudfile-notifications';
+"use strict";
 
-var RELATIVE_ROOT = '../shared-modules';
-var MODULE_REQUIRES = ['folder-display-helpers',
-                       'compose-helpers',
-                       'cloudfile-helpers',
-                       'attachment-helpers',
-                       'prompt-helpers',
-                       'notificationbox-helpers'];
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-compose-helpers.js */
+/* import-globals-from ../shared-modules/test-cloudfile-helpers.js */
+/* import-globals-from ../shared-modules/test-attachment-helpers.js */
+/* import-globals-from ../shared-modules/test-prompt-helpers.js */
+/* import-globals-from ../shared-modules/test-notificationbox-helpers.js */
 
-ChromeUtils.import('resource://gre/modules/Services.jsm');
+var MODULE_NAME = "test-cloudfile-notifications";
+var RELATIVE_ROOT = "../shared-modules";
+var MODULE_REQUIRES = [
+  "folder-display-helpers",
+  "compose-helpers",
+  "cloudfile-helpers",
+  "attachment-helpers",
+  "prompt-helpers",
+  "notificationbox-helpers",
+];
+
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { cloudFileAccounts } = ChromeUtils.import(
+  "resource:///modules/cloudFileAccounts.jsm"
+);
 
 var maxSize, oldInsertNotificationPref;
 
 var kOfferThreshold = "mail.compose.big_attachments.threshold_kb";
-var kInsertNotificationPref = "mail.compose.big_attachments.insert_notification";
+var kInsertNotificationPref =
+  "mail.compose.big_attachments.insert_notification";
 
-var kBoxId = "attachmentNotificationBox";
+var kBoxId = "compose-notification-bottom";
 
 function setupModule(module) {
   for (let lib of MODULE_REQUIRES) {
@@ -34,16 +48,19 @@ function setupModule(module) {
   gMockFilePickReg.register();
 
   maxSize = Services.prefs.getIntPref(kOfferThreshold, 0) * 1024;
-  oldInsertNotificationPref = Services.prefs
-                                      .getBoolPref(kInsertNotificationPref);
+  oldInsertNotificationPref = Services.prefs.getBoolPref(
+    kInsertNotificationPref
+  );
   Services.prefs.setBoolPref(kInsertNotificationPref, true);
 }
 
 function teardownModule(module) {
   gMockCloudfileManager.unregister();
   gMockFilePickReg.unregister();
-  Services.prefs.setBoolPref(kInsertNotificationPref,
-                             oldInsertNotificationPref);
+  Services.prefs.setBoolPref(
+    kInsertNotificationPref,
+    oldInsertNotificationPref
+  );
 }
 
 /**
@@ -55,7 +72,12 @@ function teardownModule(module) {
  *                   otherwise.
  */
 function assert_cloudfile_notification_displayed(aController, aDisplayed) {
-  assert_notification_displayed(aController, kBoxId, "bigAttachment", aDisplayed);
+  assert_notification_displayed(
+    aController,
+    kBoxId,
+    "bigAttachment",
+    aDisplayed
+  );
 }
 
 /**
@@ -67,8 +89,12 @@ function assert_cloudfile_notification_displayed(aController, aDisplayed) {
  *                   otherwise.
  */
 function assert_upload_notification_displayed(aController, aDisplayed) {
-  assert_notification_displayed(aController, kBoxId, "bigAttachmentUploading",
-                                aDisplayed);
+  assert_notification_displayed(
+    aController,
+    kBoxId,
+    "bigAttachmentUploading",
+    aDisplayed
+  );
 }
 
 /**
@@ -79,9 +105,16 @@ function assert_upload_notification_displayed(aController, aDisplayed) {
  * @param aDisplayed true if the notification should be displayed, false
  *                   otherwise.
  */
-function assert_privacy_warning_notification_displayed(aController, aDisplayed) {
-  assert_notification_displayed(aController, kBoxId, "bigAttachmentPrivacyWarning",
-                                aDisplayed);
+function assert_privacy_warning_notification_displayed(
+  aController,
+  aDisplayed
+) {
+  assert_notification_displayed(
+    aController,
+    kBoxId,
+    "bigAttachmentPrivacyWarning",
+    aDisplayed
+  );
 }
 
 /**
@@ -171,7 +204,7 @@ function test_no_notification_if_disabled() {
  * notification bar displayed (unless preffed off).
  */
 function test_link_insertion_notification_single() {
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile1'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(["./data/testFile1"], __file__);
   let provider = new MockCloudfileAccount();
   provider.init("aKey");
 
@@ -182,7 +215,7 @@ function test_link_insertion_notification_single() {
   close_upload_notification(cwc);
 
   Services.prefs.setBoolPref(kInsertNotificationPref, false);
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile2'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(["./data/testFile2"], __file__);
   add_cloud_attachments(cwc, provider);
 
   assert_upload_notification_displayed(cwc, false);
@@ -196,8 +229,10 @@ function test_link_insertion_notification_single() {
  * notification bar displayed (unless preffed off).
  */
 function test_link_insertion_notification_multiple() {
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile1',
-                                              './data/testFile2'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(
+    ["./data/testFile1", "./data/testFile2"],
+    __file__
+  );
   let provider = new MockCloudfileAccount();
   provider.init("aKey");
 
@@ -208,8 +243,10 @@ function test_link_insertion_notification_multiple() {
   close_upload_notification(cwc);
 
   Services.prefs.setBoolPref(kInsertNotificationPref, false);
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile3',
-                                              './data/testFile4'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(
+    ["./data/testFile3", "./data/testFile4"],
+    __file__
+  );
   add_cloud_attachments(cwc, provider);
 
   assert_upload_notification_displayed(cwc, false);
@@ -225,16 +262,18 @@ function test_link_insertion_notification_multiple() {
 function test_link_insertion_goes_away_on_error() {
   gMockPromptService.register();
   gMockPromptService.returnValue = false;
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile1',
-                                              './data/testFile2'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(
+    ["./data/testFile1", "./data/testFile2"],
+    __file__
+  );
   let provider = new MockCloudfileAccount();
   provider.init("aKey");
 
-  provider.uploadFile = function(aFile, aListener) {
-    aListener.onStartRequest(null, null);
-    cwc.window.setTimeout(function() {
-      aListener.onStopRequest(null, null,
-                              Ci.nsIMsgCloudFileProvider.uploadErr);
+  provider.uploadFile = function(aFile) {
+    return new Promise((resolve, reject) => {
+      cwc.window.setTimeout(() =>
+        reject(cloudFileAccounts.constants.uploadErr)
+      );
     }, 500);
   };
 
@@ -253,7 +292,7 @@ function test_link_insertion_goes_away_on_error() {
  * a Filelink back into a normal attachment.
  */
 function test_no_offer_on_conversion() {
-  const kFiles = ['./data/testFile1', './data/testFile2'];
+  const kFiles = ["./data/testFile1", "./data/testFile2"];
   // Set the notification threshold to 0 to ensure that we get it.
   Services.prefs.setIntPref(kOfferThreshold, 0);
 
@@ -265,9 +304,10 @@ function test_no_offer_on_conversion() {
   // Override uploadFile to succeed instantaneously so that we don't have
   // to worry about waiting for the onStopRequest method being called
   // asynchronously.
-  provider.uploadFile = function(aFile, aListener) {
-    aListener.onStartRequest(null, null);
-    aListener.onStopRequest(null, null, Cr.NS_OK);
+  provider.uploadFile = function(aFile) {
+    return Promise.resolve({
+      id: 1,
+    });
   };
 
   let cw = open_compose_new_mail();
@@ -291,15 +331,16 @@ function test_no_offer_on_conversion() {
  * the upload notification is shown.
  */
 function test_offer_then_upload_notifications() {
-  const kFiles = ['./data/testFile1', './data/testFile2'];
+  const kFiles = ["./data/testFile1", "./data/testFile2"];
   // Set the notification threshold to 0 to ensure that we get it.
   Services.prefs.setIntPref(kOfferThreshold, 0);
 
   // We're going to add attachments to the attachmentbucket, and we'll
   // use the add_attachments helper function to do it.  First, retrieve
   // some file URIs...
-  let fileURIs = collectFiles(kFiles, __file__).
-    map(file => Services.io.newFileURI(file).spec);
+  let fileURIs = collectFiles(kFiles, __file__).map(
+    file => Services.io.newFileURI(file).spec
+  );
 
   // Create our mock provider
   let provider = new MockCloudfileAccount();
@@ -308,9 +349,10 @@ function test_offer_then_upload_notifications() {
   // Override uploadFile to succeed instantaneously so that we don't have
   // to worry about waiting for the onStopRequest method being called
   // asynchronously.
-  provider.uploadFile = function(aFile, aListener) {
-    aListener.onStartRequest(null, null);
-    aListener.onStopRequest(null, null, Cr.NS_OK);
+  provider.uploadFile = function(aFile) {
+    return Promise.resolve({
+      id: 1,
+    });
   };
 
   let cw = open_compose_new_mail();
@@ -344,18 +386,22 @@ function test_offer_then_upload_notifications() {
 function test_privacy_warning_notification() {
   gMockPromptService.register();
   gMockPromptService.returnValue = false;
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile1',
-                                              './data/testFile2'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(
+    ["./data/testFile1", "./data/testFile2"],
+    __file__
+  );
   let provider = new MockCloudfileAccount();
   provider.init("aKey");
 
   provider.uploadFile = function(aFile, aListener) {
-    aListener.onStartRequest(null, null);
-    cwc.window.setTimeout(function() {
-      aListener.onStopRequest(null, null,
-                              Cr.NS_OK);
-    }, 500);
-  }
+    return new Promise(resolve =>
+      cwc.window.setTimeout(() => {
+        resolve({
+          id: 1,
+        });
+      }, 500)
+    );
+  };
   let cwc = open_compose_new_mail(mc);
   add_cloud_attachments(cwc, provider);
 
@@ -369,8 +415,10 @@ function test_privacy_warning_notification() {
   close_privacy_warning_notification(cwc);
 
   // And now upload some more files. We shouldn't get the warning again.
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile3',
-                                              './data/testFile4'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(
+    ["./data/testFile3", "./data/testFile4"],
+    __file__
+  );
   add_cloud_attachments(cwc, provider, false);
   assert_privacy_warning_notification_displayed(cwc, false);
 
@@ -385,18 +433,22 @@ function test_privacy_warning_notification() {
 function test_privacy_warning_notification_no_persist() {
   gMockPromptService.register();
   gMockPromptService.returnValue = false;
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile1',
-                                              './data/testFile2'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(
+    ["./data/testFile1", "./data/testFile2"],
+    __file__
+  );
   let provider = new MockCloudfileAccount();
   provider.init("aKey");
 
   provider.uploadFile = function(aFile, aListener) {
-    aListener.onStartRequest(null, null);
-    cwc.window.setTimeout(function() {
-      aListener.onStopRequest(null, null,
-                              Cr.NS_OK);
-    }, 500);
-  }
+    return new Promise(resolve =>
+      cwc.window.setTimeout(() => {
+        resolve({
+          id: 1,
+        });
+      }, 500)
+    );
+  };
   let cwc = open_compose_new_mail(mc);
   add_cloud_attachments(cwc, provider, false);
 
@@ -426,18 +478,22 @@ function test_privacy_warning_notification_no_persist() {
 function test_privacy_warning_notification_open_after_close() {
   gMockPromptService.register();
   gMockPromptService.returnValue = false;
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile1',
-                                              './data/testFile2'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(
+    ["./data/testFile1", "./data/testFile2"],
+    __file__
+  );
   let provider = new MockCloudfileAccount();
   provider.init("aKey");
 
   provider.uploadFile = function(aFile, aListener) {
-    aListener.onStartRequest(null, null);
-    cwc.window.setTimeout(function() {
-      aListener.onStopRequest(null, null,
-                              Cr.NS_OK);
-    }, 500);
-  }
+    return new Promise(resolve =>
+      cwc.window.setTimeout(() => {
+        resolve({
+          id: 1,
+        });
+      }, 500)
+    );
+  };
   let cwc = open_compose_new_mail(mc);
   add_cloud_attachments(cwc, provider, false);
 
@@ -455,8 +511,10 @@ function test_privacy_warning_notification_open_after_close() {
   // Open a new compose window
   cwc = open_compose_new_mail(mc);
 
-  gMockFilePicker.returnFiles = collectFiles(['./data/testFile3',
-                                              './data/testFile4'], __file__);
+  gMockFilePicker.returnFiles = collectFiles(
+    ["./data/testFile3", "./data/testFile4"],
+    __file__
+  );
   add_cloud_attachments(cwc, provider);
 
   assert_upload_notification_displayed(cwc, true);
