@@ -6,17 +6,16 @@
  * Tests that messages in cp932, Thunderbirds alias for Shift_JIS, are correctly displayed.
  */
 
-// mozmake SOLO_TEST=composition/test-cp932-display.js mozmill-one
-
 "use strict";
 
-var MODULE_NAME = "test-cp932-display.js";
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-window-helpers.js */
 
+var MODULE_NAME = "test-cp932-display.js";
 var RELATIVE_ROOT = "../shared-modules";
 var MODULE_REQUIRES = ["folder-display-helpers", "window-helpers"];
 
-var os = {};
-ChromeUtils.import("resource://mozmill/stdlib/os.js", os);
+var os = ChromeUtils.import("chrome://mozmill/content/stdlib/os.jsm");
 
 function setupModule(module) {
   for (let lib of MODULE_REQUIRES) {
@@ -25,16 +24,21 @@ function setupModule(module) {
 }
 
 function test_cp932_display() {
-  let file = os.getFileForPath(os.abspath("./charset-cp932.eml",
-                               os.getFileForPath(__file__)));
+  let file = os.getFileForPath(
+    os.abspath("./charset-cp932.eml", os.getFileForPath(__file__))
+  );
   let msgc = open_message_from_file(file);
-  let subjectText = msgc.e("expandedsubjectBox").boxObject.firstChild.textContent;
-  let bodyText = msgc.e("messagepane").contentDocument
-                     .querySelector("body").textContent;
+  let subjectText = msgc.e("expandedsubjectBox").textContent;
+  let bodyText = msgc.e("messagepane").contentDocument.querySelector("body")
+    .textContent;
   close_window(msgc);
 
-  assert_true(subjectText.includes("ここに本文がきます。"),
-              "Decoded cp932 text not found in message subject.");
-  assert_true(bodyText.includes("ここに本文がきます。"),
-              "Decoded cp932 text not found in message body.");
+  assert_true(
+    subjectText.includes("ここに本文がきます。"),
+    "Decoded cp932 text not found in message subject."
+  );
+  assert_true(
+    bodyText.includes("ここに本文がきます。"),
+    "Decoded cp932 text not found in message body."
+  );
 }
