@@ -5,11 +5,20 @@
 /*
  * Test that cycling through the focus of the 3pane's panes works correctly.
  */
-var MODULE_NAME = "test-focus";
 
+"use strict";
+
+/* import-globals-from ../shared-modules/test-compose-helpers.js */
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-window-helpers.js */
+
+var MODULE_NAME = "test-focus";
 var RELATIVE_ROOT = "../shared-modules";
-var MODULE_REQUIRES = ["folder-display-helpers", "compose-helpers",
-                       "window-helpers"];
+var MODULE_REQUIRES = [
+  "folder-display-helpers",
+  "compose-helpers",
+  "window-helpers",
+];
 
 function setupModule(module) {
   for (let lib of MODULE_REQUIRES) {
@@ -28,46 +37,40 @@ function setupModule(module) {
  */
 function check_element_cycling(controller, attachmentsExpanded, ctrlTab) {
   let addressingElement = controller.e("addressingWidget");
-  let subjectElement    = controller.e("msgSubject");
+  let subjectElement = controller.e("msgSubject");
   let attachmentElement = controller.e("attachmentBucket");
-  let contentElement    = controller.window.content;
-  let identityElement   = controller.e("msgIdentity");
+  let contentElement = controller.window.content;
+  let identityElement = controller.e("msgIdentity");
 
   let key = ctrlTab ? "VK_TAB" : "VK_F6";
 
   // We start on the addressing widget and go from there.
-  // If we added an attachment, the attachment bucket got focused so
-  // we need to fix this first.
-  if (attachmentsExpanded) {
-    assert_equals(attachmentElement, controller.window.WhichElementHasFocus());
-    controller.window.SetMsgAddressingWidgetTreeElementFocus();
-  }
 
-  controller.keypress(null, key, {ctrlKey: ctrlTab});
+  controller.keypress(null, key, { ctrlKey: ctrlTab });
   assert_equals(subjectElement, controller.window.WhichElementHasFocus());
   if (attachmentsExpanded) {
-    controller.keypress(null, key, {ctrlKey: ctrlTab});
+    controller.keypress(null, key, { ctrlKey: ctrlTab });
     assert_equals(attachmentElement, controller.window.WhichElementHasFocus());
   }
-  controller.keypress(null, key, {ctrlKey: ctrlTab});
+  controller.keypress(null, key, { ctrlKey: ctrlTab });
   assert_equals(contentElement, controller.window.WhichElementHasFocus());
-  controller.keypress(null, key, {ctrlKey: ctrlTab});
+  controller.keypress(null, key, { ctrlKey: ctrlTab });
   assert_equals(identityElement, controller.window.WhichElementHasFocus());
-  controller.keypress(null, key, {ctrlKey: ctrlTab});
+  controller.keypress(null, key, { ctrlKey: ctrlTab });
   mc.sleep(0); // Focusing the addressing element happens in a timeout...
   assert_equals(addressingElement, controller.window.WhichElementHasFocus());
 
-  controller.keypress(null, key, {ctrlKey: ctrlTab, shiftKey: true});
+  controller.keypress(null, key, { ctrlKey: ctrlTab, shiftKey: true });
   assert_equals(identityElement, controller.window.WhichElementHasFocus());
-  controller.keypress(null, key, {ctrlKey: ctrlTab, shiftKey: true});
+  controller.keypress(null, key, { ctrlKey: ctrlTab, shiftKey: true });
   assert_equals(contentElement, controller.window.WhichElementHasFocus());
   if (attachmentsExpanded) {
-    controller.keypress(null, key, {ctrlKey: ctrlTab, shiftKey: true});
+    controller.keypress(null, key, { ctrlKey: ctrlTab, shiftKey: true });
     assert_equals(attachmentElement, controller.window.WhichElementHasFocus());
   }
-  controller.keypress(null, key, {ctrlKey: ctrlTab, shiftKey: true});
+  controller.keypress(null, key, { ctrlKey: ctrlTab, shiftKey: true });
   assert_equals(subjectElement, controller.window.WhichElementHasFocus());
-  controller.keypress(null, key, {ctrlKey: ctrlTab, shiftKey: true});
+  controller.keypress(null, key, { ctrlKey: ctrlTab, shiftKey: true });
   mc.sleep(0); // Focusing the addressing element happens in a timeout...
   assert_equals(addressingElement, controller.window.WhichElementHasFocus());
 }
@@ -80,7 +83,7 @@ function test_f6_no_attachment() {
 
 function test_f6_attachment() {
   let cwc = open_compose_new_mail();
-  add_attachment(cwc, "http://www.mozilla.org/");
+  add_attachments(cwc, "http://www.mozilla.org/");
   check_element_cycling(cwc, true, false);
   close_compose_window(cwc);
 }
@@ -93,7 +96,7 @@ function test_ctrl_tab_no_attachment() {
 
 function test_ctrl_tab_attachment() {
   let cwc = open_compose_new_mail();
-  add_attachment(cwc, "http://www.mozilla.org/");
+  add_attachments(cwc, "http://www.mozilla.org/");
   check_element_cycling(cwc, true, true);
   close_compose_window(cwc);
 }
