@@ -7,23 +7,32 @@
  * set properly when forwarding messages.
  */
 
+"use strict";
+
+/* import-globals-from ../shared-modules/test-compose-helpers.js */
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-message-helpers.js */
+/* import-globals-from ../shared-modules/test-window-helpers.js */
+
 var MODULE_NAME = "test-forward-headers";
-
 var RELATIVE_ROOT = "../shared-modules";
-var MODULE_REQUIRES = ["folder-display-helpers", "compose-helpers", "window-helpers",
-                         "message-helpers"];
+var MODULE_REQUIRES = [
+  "folder-display-helpers",
+  "compose-helpers",
+  "window-helpers",
+  "message-helpers",
+];
 
-ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
 
-var composeHelper = null;
 var cwc = null; // compose window controller
 var folder;
 var gDrafts;
 
-var setupModule = function (module) {
+function setupModule(module) {
   let fdh = collector.getModule("folder-display-helpers");
   fdh.installInto(module);
-  composeHelper = collector.getModule("compose-helpers");
+  let composeHelper = collector.getModule("compose-helpers");
   composeHelper.installInto(module);
   let wh = collector.getModule("window-helpers");
   wh.installInto(module);
@@ -31,7 +40,7 @@ var setupModule = function (module) {
   mh.installInto(module);
 
   folder = create_folder("Test");
-  thread1 = create_thread(10);
+  let thread1 = create_thread(10);
   add_sets_to_folders([folder], [thread1]);
 
   gDrafts = get_special_folder(Ci.nsMsgFolderFlags.Drafts, true);
@@ -40,7 +49,7 @@ var setupModule = function (module) {
   // The test checks for the first DOM node and expects a text and not
   // a paragraph.
   Services.prefs.setBoolPref("mail.compose.default_to_paragraph", false);
-};
+}
 
 function teardownModule(module) {
   Services.prefs.clearUserPref("mail.compose.default_to_paragraph");
@@ -57,13 +66,13 @@ function forward_selected_messages_and_go_to_drafts_folder(f) {
 
   plan_for_window_close(cwc);
   // mwc is modal window controller
-  plan_for_modal_dialog("commonDialog", function click_save (mwc) {
-      //accept saving
-      mwc.window.document.documentElement.getButton('accept').doCommand();
-    });
+  plan_for_modal_dialog("commonDialog", function click_save(mwc) {
+    // accept saving
+    mwc.window.document.documentElement.getButton("accept").doCommand();
+  });
 
   // quit -> do you want to save ?
-  cwc.window.goDoCommand('cmd_close');
+  cwc.window.goDoCommand("cmd_close");
   // wait for the modal dialog to return
   wait_for_modal_dialog();
   // Actually quit the window.
@@ -73,7 +82,7 @@ function forward_selected_messages_and_go_to_drafts_folder(f) {
   be_in_folder(gDrafts);
 }
 
-function test_forward_inline () {
+function test_forward_inline() {
   be_in_folder(folder);
   // original message header
   let oMsgHdr = select_click_row(0);
@@ -83,47 +92,72 @@ function test_forward_inline () {
   // forwarded message header
   let fMsgHdr = select_click_row(0);
 
-  assert_true(fMsgHdr.numReferences > 0, "No References Header in forwarded msg.");
-  assert_equals(fMsgHdr.getStringReference(0), oMsgHdr.messageId,
-    "The forwarded message should have References: = Message-Id: of the original msg");
+  assert_true(
+    fMsgHdr.numReferences > 0,
+    "No References Header in forwarded msg."
+  );
+  assert_equals(
+    fMsgHdr.getStringReference(0),
+    oMsgHdr.messageId,
+    "The forwarded message should have References: = Message-Id: of the original msg"
+  );
 
   // test for x-forwarded-message id and exercise the js mime representation as
   // well
   to_mime_message(fMsgHdr, null, function(aMsgHdr, aMimeMsg) {
-    assert_equals(aMimeMsg.headers["x-forwarded-message-id"],
-      "<"+oMsgHdr.messageId+">");
-    assert_equals(aMimeMsg.headers["references"],
-      "<"+oMsgHdr.messageId+">");
+    assert_equals(
+      aMimeMsg.headers["x-forwarded-message-id"],
+      "<" + oMsgHdr.messageId + ">"
+    );
+    assert_equals(aMimeMsg.headers.references, "<" + oMsgHdr.messageId + ">");
   });
   press_delete(mc);
 }
 
-function test_forward_as_attachments () {
+function test_forward_as_attachments() {
   be_in_folder(folder);
   // original message header
   let oMsgHdr0 = select_click_row(0);
   let oMsgHdr1 = select_click_row(1);
   select_shift_click_row(0);
 
-  forward_selected_messages_and_go_to_drafts_folder(open_compose_with_forward_as_attachments);
+  forward_selected_messages_and_go_to_drafts_folder(
+    open_compose_with_forward_as_attachments
+  );
 
   // forwarded message header
   let fMsgHdr = select_click_row(0);
 
-  assert_true(fMsgHdr.numReferences > 0, "No References Header in forwarded msg.");
-  assert_true(fMsgHdr.numReferences > 1, "Only one References Header in forwarded msg.");
-  assert_equals(fMsgHdr.getStringReference(1), oMsgHdr1.messageId,
-    "The forwarded message should have References: = Message-Id: of the original msg#1");
-  assert_equals(fMsgHdr.getStringReference(0), oMsgHdr0.messageId,
-    "The forwarded message should have References: = Message-Id: of the original msg#0");
+  assert_true(
+    fMsgHdr.numReferences > 0,
+    "No References Header in forwarded msg."
+  );
+  assert_true(
+    fMsgHdr.numReferences > 1,
+    "Only one References Header in forwarded msg."
+  );
+  assert_equals(
+    fMsgHdr.getStringReference(1),
+    oMsgHdr1.messageId,
+    "The forwarded message should have References: = Message-Id: of the original msg#1"
+  );
+  assert_equals(
+    fMsgHdr.getStringReference(0),
+    oMsgHdr0.messageId,
+    "The forwarded message should have References: = Message-Id: of the original msg#0"
+  );
 
   // test for x-forwarded-message id and exercise the js mime representation as
   // well
   to_mime_message(fMsgHdr, null, function(aMsgHdr, aMimeMsg) {
-    assert_equals(aMimeMsg.headers["x-forwarded-message-id"],
-      "<"+oMsgHdr0.messageId+"> <"+oMsgHdr1.messageId+">");
-    assert_equals(aMimeMsg.headers["references"],
-      "<"+oMsgHdr0.messageId+"> <"+oMsgHdr1.messageId+">");
+    assert_equals(
+      aMimeMsg.headers["x-forwarded-message-id"],
+      "<" + oMsgHdr0.messageId + "> <" + oMsgHdr1.messageId + ">"
+    );
+    assert_equals(
+      aMimeMsg.headers.references,
+      "<" + oMsgHdr0.messageId + "> <" + oMsgHdr1.messageId + ">"
+    );
   });
 
   press_delete(mc);
