@@ -8,19 +8,28 @@
  * markings on the messages are stored in the msgStore, not only in the database.
  * For now, it checks for bug 840418.
  */
+
+"use strict";
+
+/* import-globals-from ../shared-modules/test-compose-helpers.js */
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-window-helpers.js */
+
 var MODULE_NAME = "test-message-commands-on-msgstore";
-
 var RELATIVE_ROOT = "../shared-modules";
-var MODULE_REQUIRES = ["folder-display-helpers",
-                         "compose-helpers",
-                         "window-helpers"];
+var MODULE_REQUIRES = [
+  "folder-display-helpers",
+  "compose-helpers",
+  "window-helpers",
+];
 
-ChromeUtils.import("resource://gre/modules/Services.jsm");
-ChromeUtils.import("resource:///modules/mailServices.js");
-ChromeUtils.import("resource:///modules/IOUtils.js");
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { MailServices } = ChromeUtils.import(
+  "resource:///modules/MailServices.jsm"
+);
+var { IOUtils } = ChromeUtils.import("resource:///modules/IOUtils.js");
 
 var statusHeader = "X-Mozilla-Status: ";
-var nsMsgMessageFlags = Ci.nsMsgMessageFlags;
 
 var gInbox;
 var gOutbox;
@@ -36,7 +45,7 @@ function setupModule(module) {
 
   gOutbox = get_special_folder(Ci.nsMsgFolderFlags.Queue);
   gInbox = create_folder("MsgStoreChecks");
-  make_new_sets_in_folder(gInbox, [ {count: 6} ]);
+  make_new_sets_in_folder(gInbox, [{ count: 6 }]);
 
   // We delete the first message so that we have to compact anything.
   be_in_folder(gInbox);
@@ -47,13 +56,12 @@ function setupModule(module) {
   let urlListener = {
     compactDone: false,
 
-    OnStartRunningUrl: function (aUrl) {
-    },
-    OnStopRunningUrl: function (aUrl, aExitCode) {
+    OnStartRunningUrl(aUrl) {},
+    OnStopRunningUrl(aUrl, aExitCode) {
       assert_equals(aExitCode, 0);
       assert_true(gInbox.msgDatabase.summaryValid);
       this.compactDone = true;
-    }
+    },
   };
 
   // Compaction adds the X-Mozilla-Status rows into the messages
@@ -61,8 +69,14 @@ function setupModule(module) {
   assert_true(gInbox.msgStore.supportsCompaction);
   gInbox.compact(urlListener, null);
 
-  mc.waitFor(function() { return urlListener.compactDone; },
-             "Timeout waiting for compact to complete", 10000, 100);
+  mc.waitFor(
+    function() {
+      return urlListener.compactDone;
+    },
+    "Timeout waiting for compact to complete",
+    10000,
+    100
+  );
 }
 
 /**
@@ -75,25 +89,36 @@ function setupModule(module) {
  * @param aStatus        The required status of the message.
  */
 function check_status(aMsgHdr, aOffset, aStatusOffset, aStatus) {
-  if (aOffset == null)
+  if (aOffset == null) {
     aOffset = aMsgHdr.messageOffset;
-  if (aStatusOffset == null)
+  }
+  if (aStatusOffset == null) {
     aStatusOffset = aMsgHdr.statusOffset;
+  }
 
-  let folder = (aMsgHdr == null) ? gInbox : aMsgHdr.folder;
+  let folder = aMsgHdr == null ? gInbox : aMsgHdr.folder;
 
   let mboxstring = IOUtils.loadFileToString(folder.filePath);
 
   let expectedStatusString = aStatus.toString(16);
   while (expectedStatusString.length < 4) {
-    expectedStatusString = '0' + expectedStatusString;
+    expectedStatusString = "0" + expectedStatusString;
   }
 
-  assert_equals(mboxstring.substr(aOffset + aStatusOffset, statusHeader.length),
-                statusHeader,
-                "The header '" + statusHeader + "' not found at offset: " + aOffset + ", statusOffset: " + aStatusOffset);
-  assert_equals(mboxstring.substr(aOffset + aStatusOffset + statusHeader.length, 4),
-                expectedStatusString);
+  assert_equals(
+    mboxstring.substr(aOffset + aStatusOffset, statusHeader.length),
+    statusHeader,
+    "The header '" +
+      statusHeader +
+      "' not found at offset: " +
+      aOffset +
+      ", statusOffset: " +
+      aStatusOffset
+  );
+  assert_equals(
+    mboxstring.substr(aOffset + aStatusOffset + statusHeader.length, 4),
+    expectedStatusString
+  );
 }
 
 function test_mark_messages_read() {
@@ -107,8 +132,12 @@ function test_mark_messages_read() {
   check_status(curMessage, null, null, 0); // status = unread
   press_delete(mc);
   assert_not_equals(curMessage, select_click_row(0));
-  check_status(null, offset, statusOffset,
-               nsMsgMessageFlags.Read + nsMsgMessageFlags.Expunged);
+  check_status(
+    null,
+    offset,
+    statusOffset,
+    Ci.nsMsgMessageFlags.Read + Ci.nsMsgMessageFlags.Expunged
+  );
 
   // 4 messages in the folder.
   curMessage = select_click_row(0);
@@ -116,26 +145,30 @@ function test_mark_messages_read() {
 
   // Make sure we can mark all read with >0 messages unread.
   right_click_on_row(0);
-  mc.click_menus_in_sequence(mc.e("mailContext"), [{id: "mailContext-mark"},
-                                                   {id: "mailContext-markAllRead"}]);
+  mc.click_menus_in_sequence(mc.e("mailContext"), [
+    { id: "mailContext-mark" },
+    { id: "mailContext-markAllRead" },
+  ]);
 
   // All the 4 messages should now be read.
   assert_true(curMessage.isRead, "Message should have been marked Read!");
-  check_status(curMessage, null, null, nsMsgMessageFlags.Read);
+  check_status(curMessage, null, null, Ci.nsMsgMessageFlags.Read);
   curMessage = select_click_row(1);
   assert_true(curMessage.isRead, "Message should have been marked Read!");
-  check_status(curMessage, null, null, nsMsgMessageFlags.Read);
+  check_status(curMessage, null, null, Ci.nsMsgMessageFlags.Read);
   curMessage = select_click_row(2);
   assert_true(curMessage.isRead, "Message should have been marked Read!");
-  check_status(curMessage, null, null, nsMsgMessageFlags.Read);
+  check_status(curMessage, null, null, Ci.nsMsgMessageFlags.Read);
   curMessage = select_click_row(3);
   assert_true(curMessage.isRead, "Message should have been marked Read!");
-  check_status(curMessage, null, null, nsMsgMessageFlags.Read);
+  check_status(curMessage, null, null, Ci.nsMsgMessageFlags.Read);
 
   // Let's have the last message unread.
   right_click_on_row(3);
-  mc.click_menus_in_sequence(mc.e("mailContext"), [{id: "mailContext-mark"},
-                                                   {id: "mailContext-markUnread"}]);
+  mc.click_menus_in_sequence(mc.e("mailContext"), [
+    { id: "mailContext-mark" },
+    { id: "mailContext-markUnread" },
+  ]);
   assert_false(curMessage.isRead, "Message should have not been marked Read!");
   check_status(curMessage, null, null, 0);
 }
@@ -144,10 +177,17 @@ function test_mark_messages_flagged() {
   // Mark a message with the star.
   let curMessage = select_click_row(1);
   right_click_on_row(1);
-  mc.click_menus_in_sequence(mc.e("mailContext"), [{id: "mailContext-mark"},
-                                                   {id: "mailContext-markFlagged"}]);
+  mc.click_menus_in_sequence(mc.e("mailContext"), [
+    { id: "mailContext-mark" },
+    { id: "mailContext-markFlagged" },
+  ]);
   assert_true(curMessage.isFlagged, "Message should have been marked Flagged!");
-  check_status(curMessage, null, null, nsMsgMessageFlags.Read + nsMsgMessageFlags.Marked);
+  check_status(
+    curMessage,
+    null,
+    null,
+    Ci.nsMsgMessageFlags.Read + Ci.nsMsgMessageFlags.Marked
+  );
 }
 
 function subtest_check_queued_message() {
@@ -157,7 +197,7 @@ function subtest_check_queued_message() {
   while (queued.hasMoreElements()) {
     let msg = queued.getNext().QueryInterface(Ci.nsIMsgDBHdr);
     if (!queued.hasMoreElements()) {
-      check_status(msg, null, null, nsMsgMessageFlags.Queued);
+      check_status(msg, null, null, Ci.nsMsgMessageFlags.Queued);
     }
   }
 }
@@ -185,7 +225,10 @@ function reply_forward_message(aMsgRow, aReply) {
   // Send it later.
   plan_for_window_close(cwc);
   // Ctrl+Shift+Return = Send Later
-  cwc.keypress(cwc.eid("content-frame"), "VK_RETURN", {shiftKey: true, accelKey: true});
+  cwc.keypress(cwc.eid("content-frame"), "VK_RETURN", {
+    shiftKey: true,
+    accelKey: true,
+  });
   wait_for_window_close(cwc);
 
   subtest_check_queued_message();
@@ -198,16 +241,21 @@ function reply_forward_message(aMsgRow, aReply) {
   // a different function and the purpose of this test would be lost.
   be_in_folder(gInbox);
   let curMessage = select_click_row(aMsgRow);
-  let disposition = aReply ? gInbox.nsMsgDispositionState_Replied :
-                             gInbox.nsMsgDispositionState_Forwarded;
+  let disposition = aReply
+    ? gInbox.nsMsgDispositionState_Replied
+    : gInbox.nsMsgDispositionState_Forwarded;
   gInbox.addMessageDispositionState(curMessage, disposition);
 }
 
 function test_mark_messages_replied() {
   reply_forward_message(2, true);
   let curMessage = select_click_row(2);
-  check_status(curMessage, null, null,
-               nsMsgMessageFlags.Replied + nsMsgMessageFlags.Read);
+  check_status(
+    curMessage,
+    null,
+    null,
+    Ci.nsMsgMessageFlags.Replied + Ci.nsMsgMessageFlags.Read
+  );
 }
 
 function test_mark_messages_forwarded() {
@@ -215,14 +263,19 @@ function test_mark_messages_forwarded() {
   // Forward a clean message.
   reply_forward_message(3, false);
   let curMessage = select_click_row(3);
-  check_status(curMessage, null, null, nsMsgMessageFlags.Forwarded);
+  check_status(curMessage, null, null, Ci.nsMsgMessageFlags.Forwarded);
 
   // Forward a message that is read and already replied to.
   reply_forward_message(2, false);
   curMessage = select_click_row(2);
-  check_status(curMessage, null, null,
-               nsMsgMessageFlags.Forwarded + nsMsgMessageFlags.Replied +
-               nsMsgMessageFlags.Read);
+  check_status(
+    curMessage,
+    null,
+    null,
+    Ci.nsMsgMessageFlags.Forwarded +
+      Ci.nsMsgMessageFlags.Replied +
+      Ci.nsMsgMessageFlags.Read
+  );
 }
 
 function teardownModule(module) {
