@@ -3,23 +3,28 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 /**
- * Test that the phishing notification behaves properly.
+ * Test that phishing notifications behave properly.
  */
 
-// make SOLO_TEST=message-header/test-phishing-bar.js mozmill-one
+"use strict";
+
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-notificationbox-helpers.js */
+/* import-globals-from ../shared-modules/test-window-helpers.js */
 
 var MODULE_NAME = "test-phishing-bar";
-
 var RELATIVE_ROOT = "../shared-modules";
-var MODULE_REQUIRES = ["folder-display-helpers",
-                         "window-helpers", "notificationbox-helpers"];
+var MODULE_REQUIRES = [
+  "folder-display-helpers",
+  "window-helpers",
+  "notificationbox-helpers",
+];
 
-var os = {};
-ChromeUtils.import('resource://mozmill/stdlib/os.js', os);
+var os = ChromeUtils.import("chrome://mozmill/content/stdlib/os.jsm");
 
 var folder;
 
-var kBoxId = "msgNotificationBar";
+var kBoxId = "mail-notification-top";
 var kNotificationValue = "maybeScam";
 
 function setupModule(module) {
@@ -28,27 +33,62 @@ function setupModule(module) {
   }
 
   folder = create_folder("PhishingBarA");
-  add_message_to_folder(folder, create_message({body: {
-    body: '<a href="http://www.evil.com/google/">http://www.google.com</a>',
-    contentType: "text/html"
-  }}));
+  add_message_to_folder(
+    folder,
+    create_message({
+      body: {
+        body: '<form action="http://localhost/download-me"><input></form>.',
+        contentType: "text/html",
+      },
+    })
+  );
   add_message_to_folder(folder, create_message());
-  add_message_to_folder(folder, create_message({body: {
-    body: 'check out http://130.128.4.1. and http://130.128.4.2/.',
-    contentType: "text/plain"
-  }}));
-  add_message_to_folder(folder, create_message({body: {
-    body: '<a href="http://subdomain.google.com/">http://www.google.com</a>.',
-    contentType: "text/html"
-  }}));
-  add_message_to_folder(folder, create_message({body: {
-    body: '<a href="http://subdomain.google.com/">http://google.com</a>.',
-    contentType: "text/html"
-  }}));
-  add_message_to_folder(folder, create_message({body: {
-    body: '<a href="http://evilhost">http://localhost</a>.',
-    contentType: "text/html"
-  }}));
+  add_message_to_folder(
+    folder,
+    create_message({
+      body: {
+        body: "check out http://130.128.4.1. and http://130.128.4.2/.",
+        contentType: "text/plain",
+      },
+    })
+  );
+  add_message_to_folder(
+    folder,
+    create_message({
+      body: {
+        body:
+          '<a href="http://subdomain.google.com/">http://www.google.com</a>.',
+        contentType: "text/html",
+      },
+    })
+  );
+  add_message_to_folder(
+    folder,
+    create_message({
+      body: {
+        body: '<a href="http://subdomain.google.com/">http://google.com</a>.',
+        contentType: "text/html",
+      },
+    })
+  );
+  add_message_to_folder(
+    folder,
+    create_message({
+      body: {
+        body: '<a href="http://evilhost">http://localhost</a>.',
+        contentType: "text/html",
+      },
+    })
+  );
+  add_message_to_folder(
+    folder,
+    create_message({
+      body: {
+        body: '<form action="http://localhost/download-me"><input></form>.',
+        contentType: "text/html",
+      },
+    })
+  );
 }
 
 /**
@@ -57,14 +97,29 @@ function setupModule(module) {
  */
 function assert_ignore_works(aController) {
   wait_for_notification_to_show(aController, kBoxId, kNotificationValue);
-  let prefButton = get_notification_button(aController, kBoxId, kNotificationValue,
-                                           { popup: "phishingOptions" });
+  let prefButton = get_notification_button(
+    aController,
+    kBoxId,
+    kNotificationValue,
+    { popup: "phishingOptions" }
+  );
   aController.click(new elementslib.Elem(prefButton));
-  aController.click_menus_in_sequence(aController.e("phishingOptions"),
-                                      [{id: "phishingOptionIgnore"}]);
+  aController.click_menus_in_sequence(aController.e("phishingOptions"), [
+    { id: "phishingOptionIgnore" },
+  ]);
   wait_for_notification_to_stop(aController, kBoxId, kNotificationValue);
 }
 
+/**
+ * Helper function to click the first link in a message if one is available.
+ */
+function click_link_if_available() {
+  let msgBody = mc.e("messagepane").contentDocument.body;
+  if (msgBody.getElementsByTagName("a").length > 0) {
+    msgBody.getElementsByTagName("a")[0].click();
+  }
+}
+
 /**
  * Test that when viewing a message, choosing ignore hides the the phishing
  * notification.
@@ -110,7 +165,10 @@ function test_ignore_phishing_warning_from_eml_attachment() {
 
   // Open the attached message.
   plan_for_new_window("mail:messageWindow");
-  msgc.e("attachmentList").getItemAtIndex(0).attachment.open();
+  msgc
+    .e("attachmentList")
+    .getItemAtIndex(0)
+    .attachment.open();
   let msgc2 = wait_for_new_window("mail:messageWindow");
   wait_for_message_display_completion(msgc2, true);
 
@@ -123,34 +181,56 @@ function test_ignore_phishing_warning_from_eml_attachment() {
 
 /**
  * Test that when viewing a message with an auto-linked ip address, we don't
- * get a warning. We'll have http://130.128.4.1 vs. http://130.128.4.1/
+ * get a warning when clicking the link.
+ * We'll have http://130.128.4.1 vs. http://130.128.4.1/
  */
 function test_no_phishing_warning_for_ip_sameish_text() {
   be_in_folder(folder);
   select_click_row(2); // Mail with Public IP address.
+  click_link_if_available();
   assert_notification_displayed(mc, kBoxId, kNotificationValue, false); // not shown
 }
 
 /**
  * Test that when viewing a message with a link whose base domain matches but
  * has a different subdomain (e.g. http://subdomain.google.com/ vs
- * http://google.com/), we don't get a warning.
+ * http://google.com/), we don't get a warning if the link is pressed.
  */
 function test_no_phishing_warning_for_subdomain() {
   be_in_folder(folder);
   select_click_row(3);
+  click_link_if_available();
   assert_notification_displayed(mc, kBoxId, kNotificationValue, false); // not shown
 
   select_click_row(4);
+  click_link_if_available();
   assert_notification_displayed(mc, kBoxId, kNotificationValue, false); // not shown
 }
 
 /**
- * Test that when viewing a message with a link where the text and/or href
+ * Test that when clicking a link where the text and/or href
  * has no TLD, we still warn as appropriate.
  */
 function test_phishing_warning_for_local_domain() {
   be_in_folder(folder);
   select_click_row(5);
+
+  let dialogAppeared = false;
+
+  plan_for_modal_dialog("commonDialog", function(ctrler) {
+    dialogAppeared = true;
+  });
+
+  click_link_if_available();
+
+  return dialogAppeared;
+}
+
+/**
+ * Test that we warn about emails which contain <form>s with action attributes.
+ */
+function test_phishing_warning_for_action_form() {
+  be_in_folder(folder);
+  select_click_row(6);
   assert_notification_displayed(mc, kBoxId, kNotificationValue, true); // shown
 }
