@@ -6,13 +6,20 @@
  * Test that we can open and close a standalone message display window from the
  *  folder pane.
  */
-var MODULE_NAME = "test-display-names";
 
+"use strict";
+
+/* import-globals-from ../shared-modules/test-address-book-helpers.js */
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+
+var MODULE_NAME = "test-display-names";
 var RELATIVE_ROOT = "../shared-modules";
 var MODULE_REQUIRES = ["folder-display-helpers", "address-book-helpers"];
 
-ChromeUtils.import("resource:///modules/mailServices.js");
-ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { MailServices } = ChromeUtils.import(
+  "resource:///modules/MailServices.jsm"
+);
 
 var folder;
 var decoyFolder;
@@ -30,21 +37,28 @@ function setupModule(module) {
   let abh = collector.getModule("address-book-helpers");
   abh.installInto(module);
 
-  localAccount = MailServices.accounts.FindAccountForServer(MailServices.accounts.localFoldersServer);
+  localAccount = MailServices.accounts.FindAccountForServer(
+    MailServices.accounts.localFoldersServer
+  );
 
   // We need to make sure we have only one identity:
   // 1) Delete all accounts except for Local Folders
   for (let i = MailServices.accounts.accounts.length - 1; i >= 0; i--) {
-    let account = MailServices.accounts.accounts.queryElementAt(i, Ci.nsIMsgAccount);
-    if (account != localAccount)
+    let account = MailServices.accounts.accounts.queryElementAt(
+      i,
+      Ci.nsIMsgAccount
+    );
+    if (account != localAccount) {
       MailServices.accounts.removeAccount(account);
+    }
   }
 
   // 2) Delete all identities except for one
   for (let i = localAccount.identities.length - 1; i >= 0; i--) {
     let identity = localAccount.identities.queryElementAt(i, Ci.nsIMsgIdentity);
-    if (identity.email != myEmail)
+    if (identity.email != myEmail) {
       localAccount.removeIdentity(identity);
+    }
   }
 
   // 3) Create a second identity and hold onto it for later
@@ -54,32 +68,45 @@ function setupModule(module) {
   folder = create_folder("DisplayNamesA");
   decoyFolder = create_folder("DisplayNamesB");
 
-  add_message_to_folder(folder, create_message({to: [["", myEmail]] }));
-  add_message_to_folder(folder, create_message({from: ["", friendEmail] }));
-  add_message_to_folder(folder, create_message({from: [friendName, friendEmail] }));
+  add_message_to_folder(folder, create_message({ to: [["", myEmail]] }));
+  add_message_to_folder(folder, create_message({ from: ["", friendEmail] }));
+  add_message_to_folder(
+    folder,
+    create_message({ from: [friendName, friendEmail] })
+  );
 
   // Ensure all the directories are initialised.
   MailServices.ab.directories;
-  collectedAddresses = MailServices.ab.getDirectory("moz-abmdbdirectory://history.mab");
+  collectedAddresses = MailServices.ab.getDirectory(
+    "moz-abmdbdirectory://history.mab"
+  );
 
   let bundle = Services.strings.createBundle(
-                   "chrome://messenger/locale/messenger.properties");
+    "chrome://messenger/locale/messenger.properties"
+  );
   headertoFieldMe = bundle.GetStringFromName("headertoFieldMe");
 }
 
 function ensure_single_identity() {
-  if (localAccount.identities.length > 1)
+  if (localAccount.identities.length > 1) {
     localAccount.removeIdentity(secondIdentity);
-  assert_true(MailServices.accounts.allIdentities.length == 1,
-              "Expected 1 identity, but got " + MailServices.accounts.allIdentities.length +
-              " identities");
+  }
+  assert_true(
+    MailServices.accounts.allIdentities.length == 1,
+    "Expected 1 identity, but got " +
+      MailServices.accounts.allIdentities.length +
+      " identities"
+  );
 }
 
 function ensure_multiple_identities() {
-  if (localAccount.identities.length == 1)
+  if (localAccount.identities.length == 1) {
     localAccount.addIdentity(secondIdentity);
-  assert_true(MailServices.accounts.allIdentities.length > 1,
-              "Expected multiple identities, but got only one identity");
+  }
+  assert_true(
+    MailServices.accounts.allIdentities.length > 1,
+    "Expected multiple identities, but got only one identity"
+  );
 }
 
 function help_test_display_name(message, field, expectedValue) {
@@ -87,18 +114,17 @@ function help_test_display_name(message, field, expectedValue) {
   // looking at in order to update information changed in address book entries.
   be_in_folder(decoyFolder);
   be_in_folder(folder);
-  let curMessage = select_click_row(message);
+  select_click_row(message);
 
-  let value = mc.window.document.getAnonymousElementByAttribute(
-    mc.a("expanded"+field+"Box", {tagName: "mail-emailaddress"}),
-    "class", "emaillabel").value;
+  let value = mc
+    .e("expanded" + field + "Box", { tagName: "mail-emailaddress" })
+    .querySelector(".emaillabel").value;
 
-  if (value != expectedValue)
-    throw new Error("got '"+value+"' but expected '"+expectedValue+"'");
+  if (value != expectedValue) {
+    throw new Error("got '" + value + "' but expected '" + expectedValue + "'");
+  }
 }
 
-
-
 function test_single_identity() {
   ensure_no_card_exists(myEmail);
   ensure_single_identity();
@@ -117,12 +143,10 @@ function test_single_identity_in_abook_no_pdn() {
   help_test_display_name(0, "to", headertoFieldMe);
 }
 
-
-
 function test_multiple_identities() {
   ensure_no_card_exists(myEmail);
   ensure_multiple_identities();
-  help_test_display_name(0, "to", headertoFieldMe+" <"+myEmail+">");
+  help_test_display_name(0, "to", headertoFieldMe + " <" + myEmail + ">");
 }
 
 function test_multiple_identities_in_abook() {
@@ -134,11 +158,9 @@ function test_multiple_identities_in_abook() {
 function test_multiple_identities_in_abook_no_pdn() {
   ensure_card_exists(myEmail, "President Frankenstein");
   ensure_multiple_identities();
-  help_test_display_name(0, "to", headertoFieldMe+" <"+myEmail+">");
+  help_test_display_name(0, "to", headertoFieldMe + " <" + myEmail + ">");
 }
 
-
-
 function test_no_header_name() {
   ensure_no_card_exists(friendEmail);
   ensure_single_identity();
@@ -159,12 +181,10 @@ function test_no_header_name_in_abook_no_pdn() {
   help_test_display_name(1, "from", "carl@sagan.invalid");
 }
 
-
-
 function test_header_name() {
   ensure_no_card_exists(friendEmail);
   ensure_single_identity();
-  help_test_display_name(2, "from", friendName+" <"+friendEmail+">");
+  help_test_display_name(2, "from", friendName + " <" + friendEmail + ">");
 }
 
 function test_header_name_in_abook() {
