@@ -8,12 +8,16 @@
  * to false.
  */
 
+"use strict";
+
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-window-helpers.js */
+
 var MODULE_NAME = "test-override-mainmenu-collapse";
 var RELATIVE_ROOT = "../shared-modules";
-var MODULE_REQUIRES = ["folder-display-helpers",
-                       "window-helpers"];
+var MODULE_REQUIRES = ["folder-display-helpers", "window-helpers"];
 
-ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
 
 function setupModule(module) {
   collector.getModule("folder-display-helpers").installInto(module);
@@ -25,11 +29,11 @@ function test_main_menu_not_collapsed() {
   // is complete before running this test.
   let done = false;
   let observer = {
-    observe: function(aSubject, aTopic, aData) {
+    observe(aSubject, aTopic, aData) {
       if (aTopic == "mail-startup-done") {
         done = true;
       }
-    }
+    },
   };
   Services.obs.addObserver(observer, "mail-startup-done");
 
@@ -43,8 +47,10 @@ function test_main_menu_not_collapsed() {
   mc.waitFor(() => done);
 
   let mainMenu = mc.e("mail-toolbar-menubar2");
-  assert_false(mainMenu.hasAttribute("autohide"),
-               "The main menu should not have the autohide attribute.");
+  assert_false(
+    mainMenu.hasAttribute("autohide"),
+    "The main menu should not have the autohide attribute."
+  );
 
   Services.obs.removeObserver(observer, "mail-startup-done");
 }
