@@ -9,39 +9,60 @@
  * the unit test machines (see also testing/machine-configuration.json).
  */
 
+"use strict";
+
+/* import-globals-from ../shared-modules/test-dom-helpers.js */
+/* import-globals-from ../shared-modules/test-folder-display-helpers.js */
+/* import-globals-from ../shared-modules/test-quick-filter-bar-helpers.js */
+/* import-globals-from ../shared-modules/test-window-helpers.js */
+
 var MODULE_NAME = "test-display-issues";
-
-var RELATIVE_ROOT = '../shared-modules';
-
-var MODULE_REQUIRES = ['folder-display-helpers', 'window-helpers',
-                       'quick-filter-bar-helper'];
+var RELATIVE_ROOT = "../shared-modules";
+var MODULE_REQUIRES = [
+  "folder-display-helpers",
+  "window-helpers",
+  "quick-filter-bar-helpers",
+  "dom-helpers",
+];
 
 var folder;
 var setUnstarred, setStarred;
+var gOriginalPaneWidth;
+
+var gEnlargedWindowWidth = 1260;
+var gShrunkenWindowWidth = 600;
+
+var gTodayPane;
 
 function setupModule(module) {
-  collector.getModule('folder-display-helpers').installInto(module);
-  collector.getModule('window-helpers').installInto(module);
-  collector.getModule('quick-filter-bar-helper').installInto(module);
-  collector.getModule("dom-helpers").installInto(module);
+  for (let lib of MODULE_REQUIRES) {
+    collector.getModule(lib).installInto(module);
+  }
 
   folder = create_folder("QuickFilterBarDisplayIssues");
   be_in_folder(folder);
-}
 
-function wait_for_resize(width) {
-  mc.waitFor(() => (mc.window.outerWidth == width),
-             "Timeout waiting for resize (is the screen resolution 1280 x 1024?)", 1000, 50);
-}
+  // Let's check window dimensions so we can enlarge from them.
+  assert_default_window_size();
+  assert_true(
+    gEnlargedWindowWidth > gDefaultWindowWidth,
+    "Main window too large for the test logic"
+  );
 
-function resize_to(width, height) {
-  mark_action("test", "resize_to", [width, "x", height]);
-  mc.window.resizeTo(width, height);
-  // Give the event loop a spin in order to let the reality of an asynchronously
-  //  interacting window manager have its impact.  This still may not be
-  //  sufficient.
-  mc.sleep(0);
-  wait_for_resize(width);
+  // Store folder pane width that we will change temporarily.
+  let folderPaneBox = mc.e("folderPaneBox");
+  gOriginalPaneWidth = folderPaneBox.width;
+
+  // Hide Lightning's Today pane as it takes up too much room in the
+  // small TB window our tests run in.
+  gTodayPane = mc.e("today-pane-panel");
+  if (gTodayPane) {
+    if (!gTodayPane.collapsed) {
+      mc.keypress(null, "VK_F11", {});
+    } else {
+      gTodayPane = null;
+    }
+  }
 }
 
 /**
@@ -56,73 +77,70 @@ function test_buttons_collapse_and_expand() {
 
   let qfbCollapsy = mc.e("quick-filter-bar-collapsible-buttons");
   let qfbExemplarButton = mc.e("qfb-unread"); // (arbitrary labeled button)
-  let qfbExemplarLabel = mc.window
-                           .document.getAnonymousNodes(qfbExemplarButton)[1];
+  let qfbExemplarLabel = mc.window.document.getAnonymousNodes(
+    qfbExemplarButton
+  )[1];
 
   function logState(aWhen) {
-    mark_action("test", "log_window_state",
-                [aWhen,
-                 "location:", mc.window.screenX, mc.window.screenY,
-                 "dims:", mc.window.outerWidth, mc.window.outerHeight,
-                 "Collapsy bar width:", qfbCollapsy.clientWidth,
-                 "shrunk?", qfbCollapsy.getAttribute("shrink")]);
+    mark_action("test", "log_window_state", [
+      aWhen,
+      "location:",
+      mc.window.screenX,
+      mc.window.screenY,
+      "dims:",
+      mc.window.outerWidth,
+      mc.window.outerHeight,
+      "Collapsy bar width:",
+      qfbCollapsy.clientWidth,
+      "shrunk?",
+      qfbCollapsy.getAttribute("shrink"),
+    ]);
   }
 
-  function assertCollapsed(width) {
-    // It's possible the window hasn't actually resized yet, so double-check and
-    // spin if needed.
-    wait_for_resize(width);
-
+  function assertCollapsed() {
     // The bar should be shrunken and the button should be the same size as its
     // image!
-    if (qfbCollapsy.getAttribute("shrink") != "true")
+    if (qfbCollapsy.getAttribute("shrink") != "true") {
       throw new Error("The collapsy bar should be shrunk!");
-    if (qfbExemplarLabel.clientWidth != 0)
+    }
+    if (qfbExemplarLabel.clientWidth != 0) {
       throw new Error("The exemplar label should be collapsed!");
+    }
   }
-  function assertExpanded(width) {
-    // It's possible the window hasn't actually resized yet, so double-check and
-    // spin if needed.
-    wait_for_resize(width);
-
+  function assertExpanded() {
     // The bar should not be shrunken and the button should be smaller than its
     // label!
-    if (qfbCollapsy.hasAttribute("shrink"))
+    if (qfbCollapsy.hasAttribute("shrink")) {
       throw new Error("The collapsy bar should not be shrunk!");
-    if (qfbExemplarLabel.clientWidth == 0)
+    }
+    if (qfbExemplarLabel.clientWidth == 0) {
       throw new Error("The exemplar label should not be collapsed!");
+    }
   }
 
   logState("entry");
 
   // -- GIANT!
-  resize_to(1260, 600);
+  resize_to(mc, gEnlargedWindowWidth, gDefaultWindowHeight);
   // Right, so resizeTo caps us at the display size limit, so we may end up
   // smaller than we want.  So let's turn off the folder pane too.
   collapse_panes(mc.e("folderpane_splitter"), true);
-
-  // spin the event loop once
-  mc.sleep(50);
   logState("giant");
-  assertExpanded(1260);
+  assertExpanded();
   // NOTE! 1260 is actually not much above what's needed to get the
   // expanded qfb.
 
   // -- tiny.
   collapse_panes(mc.e("folderpane_splitter"), false);
-  resize_to(600, 600);
-  // spin the event loop once
-  mc.sleep(0);
+  resize_to(mc, gShrunkenWindowWidth, gDefaultWindowHeight);
   logState("tiny");
-  assertCollapsed(600);
+  assertCollapsed();
 
   // -- GIANT again!
-  resize_to(1260, 600);
+  resize_to(mc, gEnlargedWindowWidth, gDefaultWindowHeight);
   collapse_panes(mc.e("folderpane_splitter"), true);
-  // spin the event loop once
-  mc.sleep(50);
   logState("giant again!");
-  assertExpanded(1260);
+  assertExpanded();
 }
 
 function test_buttons_collapse_and_expand_on_spawn_in_vertical_mode() {
@@ -134,8 +152,7 @@ function test_buttons_collapse_and_expand_on_spawn_in_vertical_mode() {
   set_pane_layout(kVerticalMailLayout);
 
   // Make our window nice and wide.
-  resize_to(1200, 600);
-  wait_for_resize(1200);
+  resize_to(mc, gEnlargedWindowWidth, gDefaultWindowHeight);
 
   // Now expand the folder pane to cause the QFB buttons to shrink
   let folderPaneBox = mc.e("folderPaneBox");
@@ -144,17 +161,23 @@ function test_buttons_collapse_and_expand_on_spawn_in_vertical_mode() {
   // Now spawn a new 3pane...
   let mc2 = open_folder_in_new_window(folder);
   let qfb = mc2.e("quick-filter-bar-collapsible-buttons");
-  mc2.waitFor(() => (qfb.getAttribute("shrink") == "true"),
-              "New 3pane should have had a collapsed QFB");
+  mc2.waitFor(
+    () => qfb.getAttribute("shrink") == "true",
+    "New 3pane should have had a collapsed QFB"
+  );
   close_window(mc2);
 
   set_pane_layout(kClassicMailLayout);
 }
 
 function teardownModule() {
-  // restore window to nominal dimensions; saving was not working out
-  //  See also: message-header/test-message-header.js if we change the
-  //            default window size.
-  resize_to(1024, 768);
+  // Restore the window to original layout.
+  restore_default_window_size();
   collapse_panes(mc.e("folderpane_splitter"), false);
+  let folderPaneBox = mc.e("folderPaneBox");
+  folderPaneBox.width = gOriginalPaneWidth;
+
+  if (gTodayPane && gTodayPane.collapsed) {
+    mc.keypress(null, "VK_F11", {});
+  }
 }
