@@ -2,12 +2,15 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this file,
  * You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var MODULE_NAME = "cloudfile-backend-helpers";
+"use strict";
 
+var MODULE_NAME = "cloudfile-backend-helpers";
 var RELATIVE_ROOT = "../shared-modules";
 var MODULE_REQUIRES = ["window-helpers"];
 
-ChromeUtils.import('resource://gre/modules/XPCOMUtils.jsm');
+var { cloudFileAccounts } = ChromeUtils.import(
+  "resource:///modules/cloudFileAccounts.jsm"
+);
 
 var kUserAuthRequested = "cloudfile:auth";
 var kUserDataRequested = "cloudfile:user";
@@ -32,7 +35,7 @@ function installInto(module) {
 }
 
 function setupModule(module) {
-  wh = collector.getModule('window-helpers');
+  wh = collector.getModule("window-helpers");
 }
 
 function SimpleRequestObserverManager() {
@@ -40,43 +43,50 @@ function SimpleRequestObserverManager() {
 }
 
 SimpleRequestObserverManager.prototype = {
-  create: function(aName) {
+  create(aName) {
     let obs = new SimpleRequestObserver(aName);
     this._observers.push(obs);
     return obs;
   },
 
-  check: function() {
+  check() {
     for (let observer of this._observers) {
-      if (!observer.success)
-        throw new Error("An observer named " + observer.name + " was leftover, "
-                        + "with its success attribute set to: "
-                        + observer.success);
+      if (!observer.success) {
+        throw new Error(
+          "An observer named " +
+            observer.name +
+            " was leftover, " +
+            "with its success attribute set to: " +
+            observer.success
+        );
+      }
     }
   },
 
-  reset: function() {
+  reset() {
     this._observers = [];
-  }
-}
+  },
+};
 
 function SimpleRequestObserver(aName) {
   this.name = aName;
-};
+}
 
 SimpleRequestObserver.prototype = {
   success: null,
-  onStartRequest: function(aRequest, aContext) {},
-  onStopRequest: function(aRequest, aContext, aStatusCode) {
+  onStartRequest(aRequest) {},
+  onStopRequest(aRequest, aStatusCode) {
     if (Components.isSuccessCode(aStatusCode)) {
       this.success = true;
     } else {
       this.success = false;
     }
   },
-  QueryInterface: XPCOMUtils.generateQI([Ci.nsIRequestObserver,
-                                         Ci.nsISupportsWeakReference]),
-}
+  QueryInterface: ChromeUtils.generateQI([
+    Ci.nsIRequestObserver,
+    Ci.nsISupportsWeakReference,
+  ]),
+};
 
 /**
  * This function uploads one or more files, and then proceeds to cancel
@@ -94,17 +104,9 @@ function assert_can_cancel_uploads(aController, aProvider, aFiles) {
 
   for (let file of aFiles) {
     let mapping = {};
-    mapping.listener = {
-      onStartRequest: function(aRequest, aContext) {
-        mapping.started = true;
-      },
-      onStopRequest: function(aRequest, aContext, aStatusCode) {
-        if (aStatusCode == Ci.nsIMsgCloudFileProvider.uploadCanceled)
-          mapping.cancelled = true;
-      },
-    }
-
-    aProvider.uploadFile(file, mapping.listener);
+    aProvider.uploadFile(file).catch(() => {
+      mapping.cancelled = true;
+    });
     fileListenerMap.push(mapping);
   }
 
@@ -118,9 +120,11 @@ function assert_can_cancel_uploads(aController, aProvider, aFiles) {
   }
 
   aController.waitFor(function() {
-    return fileListenerMap.length == aFiles.length &&
-           fileListenerMap.every(function(aMapping) {
-             return aMapping.cancelled;
-           })
+    return (
+      fileListenerMap.length == aFiles.length &&
+      fileListenerMap.every(function(aMapping) {
+        return aMapping.cancelled;
+      })
+    );
   }, "Timed out waiting for cancellation to occur");
 }
