@@ -2,18 +2,20 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var MODULE_NAME = "mouse-event-helpers";
+"use strict";
 
+var MODULE_NAME = "mouse-event-helpers";
 var RELATIVE_ROOT = "../shared-modules";
 var MODULE_REQUIRES = ["folder-display-helpers"];
 
-var EventUtils = {};
-ChromeUtils.import('resource://mozmill/stdlib/EventUtils.js', EventUtils);
+var EventUtils = ChromeUtils.import(
+  "chrome://mozmill/content/stdlib/EventUtils.jsm"
+);
 
 var fdh;
 
 function setupModule() {
-  fdh = collector.getModule('folder-display-helpers');
+  fdh = collector.getModule("folder-display-helpers");
 }
 
 function installInto(module) {
@@ -46,20 +48,25 @@ function installInto(module) {
  * @param {XULElement} aListener
  *   the element who's drop target should be captured and returned.
  */
-function drag_n_drop_element(aDragObject, aDragWindow, aDropObject,
-                             aDropWindow, aRelDropX, aRelDropY, aListener)
-{
+function drag_n_drop_element(
+  aDragObject,
+  aDragWindow,
+  aDropObject,
+  aDropWindow,
+  aRelDropX,
+  aRelDropY,
+  aListener
+) {
   let dt = synthesize_drag_start(aDragWindow, aDragObject, aListener);
   fdh.assert_true(dt, "Drag target was undefined");
 
   synthesize_drag_over(aDropWindow, aDropObject, dt);
 
-  synthesize_drop(aDropWindow, aDropObject, dt,
-      { screenX : aDropObject.boxObject.screenX +
-                    (aDropObject.boxObject.width * aRelDropX),
-        screenY : aDropObject.boxObject.screenY +
-                    (aDropObject.boxObject.width * aRelDropY)
-      });
+  let dropRect = aDropObject.getBoundingClientRect();
+  synthesize_drop(aDropWindow, aDropObject, dt, {
+    screenX: aDropObject.screenX + dropRect.width * aRelDropX,
+    screenY: aDropObject.screenY + dropRect.height * aRelDropY,
+  });
 }
 
 /**
@@ -72,14 +79,13 @@ function drag_n_drop_element(aDragObject, aDragWindow, aDropObject,
  * @return {nsIDataTransfer}
  *   returns the DataTransfer Object of captured by aListener.
  */
-function synthesize_drag_start(aWindow, aDispatcher, aListener)
-{
+function synthesize_drag_start(aWindow, aDispatcher, aListener) {
   let dt;
 
   let trapDrag = function(event) {
-
-    if (!event.dataTransfer)
-      throw "no DataTransfer";
+    if (!event.dataTransfer) {
+      throw new Error("no DataTransfer");
+    }
 
     dt = event.dataTransfer;
 
@@ -88,9 +94,21 @@ function synthesize_drag_start(aWindow, aDispatcher, aListener)
 
   aListener.addEventListener("dragstart", trapDrag, true);
 
-  EventUtils.synthesizeMouse(aDispatcher, 5, 5, {type:"mousedown"}, aWindow);
-  EventUtils.synthesizeMouse(aDispatcher, 5, 10, {type:"mousemove"}, aWindow);
-  EventUtils.synthesizeMouse(aDispatcher, 5, 15, {type:"mousemove"}, aWindow);
+  EventUtils.synthesizeMouse(aDispatcher, 5, 5, { type: "mousedown" }, aWindow);
+  EventUtils.synthesizeMouse(
+    aDispatcher,
+    5,
+    10,
+    { type: "mousemove" },
+    aWindow
+  );
+  EventUtils.synthesizeMouse(
+    aDispatcher,
+    5,
+    15,
+    { type: "mousemove" },
+    aWindow
+  );
 
   aListener.removeEventListener("dragstart", trapDrag, true);
 
@@ -107,8 +125,7 @@ function synthesize_drag_start(aWindow, aDispatcher, aListener)
  * @param {} aArgs
  *   arguments passed to the mouse event.
  */
-function synthesize_drag_over(aWindow, aDispatcher, aDt, aArgs)
-{
+function synthesize_drag_over(aWindow, aDispatcher, aDt, aArgs) {
   _synthesizeDragEvent("dragover", aWindow, aDispatcher, aDt, aArgs);
 }
 
@@ -122,14 +139,19 @@ function synthesize_drag_over(aWindow, aDispatcher, aDt, aArgs)
  * @param {} aArgs
  *   arguments passed to the mouse event.
  */
-function synthesize_drag_end(aWindow, aDispatcher, aListener, aDt, aArgs)
-{
+function synthesize_drag_end(aWindow, aDispatcher, aListener, aDt, aArgs) {
   _synthesizeDragEvent("dragend", aWindow, aListener, aDt, aArgs);
 
-  //Ensure drag has ended.
-  EventUtils.synthesizeMouse(aDispatcher, 5, 5, {type:"mousemove"}, aWindow);
-  EventUtils.synthesizeMouse(aDispatcher, 5, 10, {type:"mousemove"}, aWindow);
-  EventUtils.synthesizeMouse(aDispatcher, 5, 5, {type:"mouseup"}, aWindow);
+  // Ensure drag has ended.
+  EventUtils.synthesizeMouse(aDispatcher, 5, 5, { type: "mousemove" }, aWindow);
+  EventUtils.synthesizeMouse(
+    aDispatcher,
+    5,
+    10,
+    { type: "mousemove" },
+    aWindow
+  );
+  EventUtils.synthesizeMouse(aDispatcher, 5, 5, { type: "mouseup" }, aWindow);
 }
 
 /**
@@ -142,14 +164,19 @@ function synthesize_drag_end(aWindow, aDispatcher, aListener, aDt, aArgs)
  * @param {} aArgs
  *   arguments passed to the mouse event.
  */
-function synthesize_drop(aWindow, aDispatcher, aDt, aArgs)
-{
+function synthesize_drop(aWindow, aDispatcher, aDt, aArgs) {
   _synthesizeDragEvent("drop", aWindow, aDispatcher, aDt, aArgs);
 
   // Ensure drag has ended.
-  EventUtils.synthesizeMouse(aDispatcher, 5, 5, {type:"mousemove"}, aWindow);
-  EventUtils.synthesizeMouse(aDispatcher, 5, 10, {type:"mousemove"}, aWindow);
-  EventUtils.synthesizeMouse(aDispatcher, 5, 5, {type:"mouseup"}, aWindow);
+  EventUtils.synthesizeMouse(aDispatcher, 5, 5, { type: "mousemove" }, aWindow);
+  EventUtils.synthesizeMouse(
+    aDispatcher,
+    5,
+    10,
+    { type: "mousemove" },
+    aWindow
+  );
+  EventUtils.synthesizeMouse(aDispatcher, 5, 5, { type: "mouseup" }, aWindow);
 }
 
 /**
@@ -164,22 +191,39 @@ function synthesize_drop(aWindow, aDispatcher, aDt, aArgs)
  * @param {} aArgs
  *   arguments passed to the mouse event.
  */
-function _synthesizeDragEvent(aType, aWindow, aDispatcher, aDt, aArgs)
-{
+function _synthesizeDragEvent(aType, aWindow, aDispatcher, aDt, aArgs) {
   let screenX;
-  if (aArgs && ("screenX" in aArgs))
+  if (aArgs && "screenX" in aArgs) {
     screenX = aArgs.screenX;
-  else
-    screenX = aDispatcher.boxObject.ScreenX;
+  } else {
+    screenX = aDispatcher.screenX;
+  }
 
   let screenY;
-  if (aArgs && ("screenY" in aArgs))
+  if (aArgs && "screenY" in aArgs) {
     screenY = aArgs.screenY;
-  else
-    screenY = aDispatcher.boxObject.ScreenY;
+  } else {
+    screenY = aDispatcher.screenY;
+  }
 
   let event = aWindow.document.createEvent("DragEvent");
-  event.initDragEvent(aType, true, true, aWindow, 0,
-      screenX, screenY, 0, 0, false, false, false, false, 0, null, aDt);
+  event.initDragEvent(
+    aType,
+    true,
+    true,
+    aWindow,
+    0,
+    screenX,
+    screenY,
+    0,
+    0,
+    false,
+    false,
+    false,
+    false,
+    0,
+    null,
+    aDt
+  );
   aDispatcher.dispatchEvent(event);
 }
