@@ -2,14 +2,16 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var MODULE_NAME = "prompt-helpers";
+"use strict";
 
+var MODULE_NAME = "prompt-helpers";
 var RELATIVE_ROOT = "../shared-modules";
-// we need this for the main controller
 var MODULE_REQUIRES = ["mock-object-helpers"];
 
-ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
-ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { XPCOMUtils } = ChromeUtils.import(
+  "resource://gre/modules/XPCOMUtils.jsm"
+);
 
 var kMockPromptServiceName = "Mock Prompt Service";
 var kPromptServiceContractID = "@mozilla.org/embedcomp/prompt-service;1";
@@ -18,9 +20,11 @@ var kPromptServiceName = "Prompt Service";
 var gMockAuthPromptReg;
 
 function setupModule() {
-  let moh = collector.getModule('mock-object-helpers');
-  gMockAuthPromptReg = new moh.MockObjectReplacer("@mozilla.org/prompter;1",
-                                                  MockAuthPromptFactoryConstructor);
+  let moh = collector.getModule("mock-object-helpers");
+  gMockAuthPromptReg = new moh.MockObjectReplacer(
+    "@mozilla.org/prompter;1",
+    MockAuthPromptFactoryConstructor
+  );
 }
 
 function installInto(module) {
@@ -37,47 +41,41 @@ function MockAuthPromptFactoryConstructor() {
 }
 
 var gMockAuthPromptFactory = {
-  QueryInterface: XPCOMUtils.generateQI([Ci.nsIPromptFactory]),
-  getPrompt: function(aParent, aIID, aResult) {
+  QueryInterface: ChromeUtils.generateQI([Ci.nsIPromptFactory]),
+  getPrompt(aParent, aIID, aResult) {
     return gMockAuthPrompt.QueryInterface(aIID);
-  }
-}
-
+  },
+};
 
 var gMockAuthPrompt = {
   password: "",
 
-  QueryInterface: XPCOMUtils.generateQI([Ci.nsIAuthPrompt]),
+  QueryInterface: ChromeUtils.generateQI([Ci.nsIAuthPrompt]),
 
-  prompt: function MAP_prompt(aTitle, aText, aRealm, aSave,
-                              aDefaultText) {
+  prompt(aTitle, aText, aRealm, aSave, aDefaultText) {
     throw Cr.NS_ERROR_NOT_IMPLEMENTED;
   },
 
-  promptUsernameAndPassword: function
-      MAP_promptUsernameAndPassword(aTitle, aText, aRealm, aSave,
-                                    aUser, aPwd) {
+  promptUsernameAndPassword(aTitle, aText, aRealm, aSave, aUser, aPwd) {
     throw Cr.NS_ERROR_NOT_IMPLEMENTED;
   },
 
-  promptPassword: function MAP_promptPassword(aTitle, aText,
-                                              aRealm, aSave,
-                                              aPwd) {
+  promptPassword(aTitle, aText, aRealm, aSave, aPwd) {
     aPwd.value = this.password;
     return true;
-  }
+  },
 };
 
 var gMockPromptService = {
   _registered: false,
-  QueryInterface: XPCOMUtils.generateQI([Ci.nsIPromptService]),
+  QueryInterface: ChromeUtils.generateQI([Ci.nsIPromptService]),
   _will_return: null,
   _inout_value: null,
   _promptState: null,
   _origFactory: null,
   _promptCb: null,
 
-  confirm: function(aParent, aDialogTitle, aText) {
+  confirm(aParent, aDialogTitle, aText) {
     this._promptState = {
       method: "confirm",
       parent: aParent,
@@ -90,9 +88,17 @@ var gMockPromptService = {
     return this._will_return;
   },
 
-  confirmEx: function(aParent, aDialogTitle, aText, aButtonFlags,
-                      aButton0Title, aButton1Title, aButton2Title,
-                      aCheckMsg, aCheckState) {
+  confirmEx(
+    aParent,
+    aDialogTitle,
+    aText,
+    aButtonFlags,
+    aButton0Title,
+    aButton1Title,
+    aButton2Title,
+    aCheckMsg,
+    aCheckState
+  ) {
     this._promptState = {
       method: "confirmEx",
       parent: aParent,
@@ -111,8 +117,7 @@ var gMockPromptService = {
     return this._will_return;
   },
 
-  prompt: function(aParent, aDialogTitle, aText, aValue, aCheckMsg,
-                   aCheckState) {
+  prompt(aParent, aDialogTitle, aText, aValue, aCheckMsg, aCheckState) {
     this._promptState = {
       method: "prompt",
       parent: aParent,
@@ -125,8 +130,9 @@ var gMockPromptService = {
 
     this.fireCb();
 
-    if (this._inout_value != null)
+    if (this._inout_value != null) {
       aValue.value = this._inout_value;
+    }
 
     return this._will_return;
   },
@@ -151,14 +157,15 @@ var gMockPromptService = {
     this._promptCb = aCb;
   },
 
-  fireCb: function() {
-    if (typeof(this._promptCb) == "function")
+  fireCb() {
+    if (typeof this._promptCb == "function") {
       this._promptCb.call();
+    }
   },
 
   /* Wipes out the prompt state and any return values.
    */
-  reset: function() {
+  reset() {
     this._will_return = null;
     this._promptState = null;
     this._promptCb = null;
@@ -172,73 +179,77 @@ var gMockPromptService = {
     return this._promptState;
   },
 
-  get CID() {
-    let registrar = Components.manager.QueryInterface(Ci.nsIComponentRegistrar);
-    return registrar.contractIDToCID(kPromptServiceContractID);
+  CID: Components.ID("{404ebfa2-d8f4-4c94-8416-e65a55f9df5b}"),
+
+  get registrar() {
+    delete this.registrar;
+    return (this.registrar = Components.manager.QueryInterface(
+      Ci.nsIComponentRegistrar
+    ));
   },
 
   /* Registers the Mock Prompt Service, and stores the original Prompt Service.
    */
-  register: function() {
-    if (this._registered)
-      return;
+  register() {
+    if (!this.originalCID) {
+      void Components.manager.getClassObject(
+        Cc[kPromptServiceContractID],
+        Ci.nsIFactory
+      );
 
-    let registrar = Components.manager.QueryInterface(Ci.nsIComponentRegistrar);
-
-    this._origFactory = Components.manager
-                                  .getClassObject(Cc[kPromptServiceContractID],
-                                                  Ci.nsIFactory);
-
-    registrar.unregisterFactory(Components.ID(this.CID),
-                                this._origFactory);
-
-    registrar.registerFactory(Components.ID(this.CID),
-                              kMockPromptServiceName,
-                              kPromptServiceContractID,
-                              gMockPromptServiceFactory);
-
-    this._resetServicesPrompt();
-    this._registered = true;
+      this.originalCID = this.registrar.contractIDToCID(
+        kPromptServiceContractID
+      );
+      this.registrar.registerFactory(
+        this.CID,
+        kMockPromptServiceName,
+        kPromptServiceContractID,
+        gMockPromptServiceFactory
+      );
+      this._resetServicesPrompt();
+    }
   },
 
   /* Unregisters the Mock Prompt Service, and re-registers the original
    * Prompt Service.
    */
-  unregister: function() {
-    if (!this._registered)
-      return;
+  unregister() {
+    if (this.originalCID) {
+      // Unregister the mock.
+      this.registrar.unregisterFactory(this.CID, gMockPromptServiceFactory);
 
-    let registrar = Components.manager.QueryInterface(Ci.nsIComponentRegistrar);
+      this.registrar.registerFactory(
+        this.originalCID,
+        kPromptServiceName,
+        kPromptServiceContractID,
+        null
+      );
 
-    registrar.unregisterFactory(Components.ID(this.CID),
-                                gMockPromptServiceFactory);
-
-    registrar.registerFactory(Components.ID(this.CID),
-                              kPromptServiceName,
-                              kPromptServiceContractID,
-                              this._origFactory);
-
-    delete this._origFactory;
-
-    this._resetServicesPrompt();
-    this._registered = false;
+      delete this.originalCID;
+      this._resetServicesPrompt();
+    }
   },
 
-  _resetServicesPrompt: function() {
-    XPCOMUtils.defineLazyServiceGetter(Services, "prompt",
-                                       kPromptServiceContractID,
-                                       "nsIPromptService");
+  _resetServicesPrompt() {
+    XPCOMUtils.defineLazyServiceGetter(
+      Services,
+      "prompt",
+      kPromptServiceContractID,
+      "nsIPromptService"
+    );
   },
 };
 
 var gMockPromptServiceFactory = {
-  createInstance: function(aOuter, aIID) {
-    if (aOuter != null)
+  createInstance(aOuter, aIID) {
+    if (aOuter != null) {
       throw Cr.NS_ERROR_NO_AGGREGATION;
+    }
 
-    if (!aIID.equals(Ci.nsIPromptService))
+    if (!aIID.equals(Ci.nsIPromptService)) {
       throw Cr.NS_ERROR_NO_INTERFACE;
+    }
 
     return gMockPromptService;
-  }
+  },
 };
