@@ -1,27 +1,27 @@
 # ***** BEGIN LICENSE BLOCK *****
 # Version: MPL 1.1/GPL 2.0/LGPL 2.1
-# 
+#
 # The contents of this file are subject to the Mozilla Public License Version
 # 1.1 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
 # http://www.mozilla.org/MPL/
-# 
+#
 # Software distributed under the License is distributed on an "AS IS" basis,
 # WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 # for the specific language governing rights and limitations under the
 # License.
-# 
+#
 # The Original Code is Mozilla Corporation Code.
-# 
+#
 # The Initial Developer of the Original Code is
 # Mikeal Rogers.
 # Portions created by the Initial Developer are Copyright (C) 2008 -2009
 # the Initial Developer. All Rights Reserved.
-# 
+#
 # Contributor(s):
 #  Mikeal Rogers <mikeal.rogers@gmail.com>
 #  Henrik Skupin <hskupin@mozilla.com>
-# 
+#
 # Alternatively, the contents of this file may be used under the terms of
 # either the GNU General Public License Version 2 or later (the "GPL"), or
 # the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
@@ -33,16 +33,15 @@
 # and other provisions required by the GPL or the LGPL. If you do not delete
 # the provisions above, a recipient may use your version of this file under
 # the terms of any one of the MPL, the GPL or the LGPL.
-# 
+#
 # ***** END LICENSE BLOCK *****
 
 import socket
 import os
-import copy
 import asyncore
 
 from time import sleep
-from network import Bridge, BackChannel, create_network
+from network import create_network
 from jsobjects import JSObject
 
 import mozrunner
@@ -54,7 +53,8 @@ extension_path = os.path.join(parent, 'extension')
 
 window_string = "Cc['@mozilla.org/appshell/window-mediator;1'].getService(Ci.nsIWindowMediator).getMostRecentWindow('')"
 
-wait_to_create_timeout = 60
+wait_to_create_timeout = 90
+
 
 def wait_and_create_network(host, port, timeout=wait_to_create_timeout):
     ttl = 0
@@ -70,34 +70,35 @@ def wait_and_create_network(host, port, timeout=wait_to_create_timeout):
         ttl += .25
     if ttl == timeout:
         raise Exception("Sorry, cannot connect to jsbridge extension, port %s" % port)
-    
+
     back_channel, bridge = create_network(host, port)
     sleep(.5)
-    
+
     while back_channel.registered is False:
         back_channel.close()
         bridge.close()
         asyncore.socket_map = {}
         sleep(1)
         back_channel, bridge = create_network(host, port)
-    
+
     return back_channel, bridge
 
+
 class CLI(mozrunner.CLI):
     """Command line interface."""
-    
+
     module = "jsbridge"
 
     def add_options(self, parser):
         """add options to parser"""
 
         mozrunner.CLI.add_options(self, parser)
-        parser.add_option('-D', '--debug', dest="debug", 
+        parser.add_option('-D', '--debug', dest="debug",
                           action="store_true",
-                          help="Debug mode", 
+                          help="Debug mode",
                           metavar="JSBRIDGE_DEBUG",
                           default=False)
-        parser.add_option('-s', '--shell', dest="shell", 
+        parser.add_option('-s', '--shell', dest="shell",
                           action="store_true",
                           help="Start a Python shell",
                           metavar="JSBRIDGE_SHELL",
@@ -112,7 +113,7 @@ class CLI(mozrunner.CLI):
     def profile_args(self):
         profargs = super(CLI, self).profile_args()
         # Bug 1103551: re-enable these preferences.
-        #if self.options.debug:
+        # if self.options.debug:
         #    profargs.setdefault('prefences', []).update({
         #      'extensions.checkCompatibility':False,
         #      'devtools.errorconsole.enabled':True,
@@ -125,10 +126,10 @@ class CLI(mozrunner.CLI):
         args = super(CLI, self).command_args()
         if self.options.debug:
             args.append('-jsconsole')
-        if not 'jsbridge' in args:
+        if 'jsbridge' not in args:
             args += ['-jsbridge', self.options.port]
         return args
-        
+
     def run(self):
         runner = self.create_runner()
         runner.start()
@@ -140,9 +141,9 @@ class CLI(mozrunner.CLI):
                 runner.wait()
             except KeyboardInterrupt:
                 runner.stop()
-                
+
         runner.profile.cleanup()
-    
+
     def start_shell(self, runner):
         try:
             import IPython
@@ -151,29 +152,33 @@ class CLI(mozrunner.CLI):
         if not hasattr(self, 'bridge'):
             self.start_jsbridge_network()
         jsobj = JSObject(self.bridge, window_string)
-        
+
         if IPython is None or self.options.usecode:
             import code
-            code.interact(local={"jsobj":jsobj, 
-                                 "getBrowserWindow":lambda : getBrowserWindow(self.bridge),
-                                 "back_channel":self.back_channel,
-                                 })
+            code.interact(local={
+                "jsobj": jsobj,
+                "getBrowserWindow": lambda: getBrowserWindow(self.bridge),
+                "back_channel": self.back_channel,
+            })
         else:
             from IPython.Shell import IPShellEmbed
             ipshell = IPShellEmbed([])
-            ipshell(local_ns={"jsobj":jsobj, 
-                              "getBrowserWindow":lambda : getBrowserWindow(self.bridge),
-                              "back_channel":self.back_channel,
-                              })
+            ipshell(local_ns={
+                "jsobj": jsobj,
+                "getBrowserWindow": lambda: getBrowserWindow(self.bridge),
+                "back_channel": self.back_channel,
+            })
         runner.stop()
-        
+
     def start_jsbridge_network(self, timeout=10):
         port = int(self.options.port)
         host = '127.0.0.1'
         self.back_channel, self.bridge = wait_and_create_network(host, port, timeout)
 
+
 def cli():
     CLI().run()
 
+
 def getBrowserWindow(bridge):
     return JSObject(bridge, "Cc['@mozilla.org/appshell/window-mediator;1'].getService(Ci.nsIWindowMediator).getMostRecentWindow('')")
