@@ -11,27 +11,44 @@
 var abListener = {
   result: [],
   maxResults: 1,
-  onItemAdded: function (parentItem, item) {
+  onItemAdded(parentItem, item) {
     Assert.ok(this.result.length < this.maxResults);
     this.result.push(["onItemAdded", parentItem, item]);
   },
-  onItemRemoved: function (parentItem, item) {
+  onItemRemoved(parentItem, item) {
     Assert.ok(this.result.length < this.maxResults);
     this.result.push(["onItemRemoved", parentItem, item]);
   },
-  onItemPropertyChanged: function (item, property, oldValue, newValue) {
+  onItemPropertyChanged(item, property, oldValue, newValue) {
     Assert.ok(this.result.length < this.maxResults);
-    this.result.push(["onItemPropertyChanged", item, property, oldValue, newValue]);
-  }
+    this.result.push([
+      "onItemPropertyChanged",
+      item,
+      property,
+      oldValue,
+      newValue,
+    ]);
+  },
+};
+
+var abObserver = {
+  result: [],
+  maxResults: 1,
+  observe(subject, topic, data) {
+    Assert.ok(this.result.length < this.maxResults);
+    this.result.push([subject, topic, data]);
+  },
 };
 
 function run_test() {
-  var i;
-
   // XXX Getting all directories ensures we create all ABs because the
   // address collecter can't currently create ABs itself (bug 314448).
   MailServices.ab.directories;
 
+  run_next_test();
+}
+
+add_test(function() {
   // Add a listener
   MailServices.ab.addAddressBookListener(abListener, Ci.nsIAbListener.all);
 
@@ -43,8 +60,9 @@ function run_test() {
 
   // Test - add a card
 
-  var card = Cc["@mozilla.org/addressbook/cardproperty;1"]
-               .createInstance(Ci.nsIAbCard);
+  var card = Cc["@mozilla.org/addressbook/cardproperty;1"].createInstance(
+    Ci.nsIAbCard
+  );
 
   card.firstName = "test";
   card.primaryEmail = "test@foo.invalid";
@@ -72,8 +90,9 @@ function run_test() {
 
   // Test - delete a card
 
-  var cardsToDelete = Cc["@mozilla.org/array;1"]
-                        .createInstance(Ci.nsIMutableArray);
+  var cardsToDelete = Cc["@mozilla.org/array;1"].createInstance(
+    Ci.nsIMutableArray
+  );
 
   cardsToDelete.appendElement(newCard);
 
@@ -88,8 +107,9 @@ function run_test() {
 
   // Test - add a mailing list
 
-  var mailList = Cc["@mozilla.org/addressbook/directoryproperty;1"]
-                   .createInstance(Ci.nsIAbDirectory);
+  var mailList = Cc[
+    "@mozilla.org/addressbook/directoryproperty;1"
+  ].createInstance(Ci.nsIAbDirectory);
 
   mailList.isMailList = true;
   mailList.dirName = "TestList";
@@ -140,7 +160,7 @@ function run_test() {
   Assert.equal(card.getProperty("Notes", "BAD"), "testdescription");
   Assert.equal(card.getProperty("NickName", "BAD"), "test");
 
-  var book = abListener.result[1][2].QueryInterface(Ci.nsIAbDirectory);
+  book = abListener.result[1][2].QueryInterface(Ci.nsIAbDirectory);
   Assert.ok(book.isMailList);
   Assert.equal(book.dirName, "TestList");
   Assert.equal(book.listNickName, "test");
@@ -149,4 +169,67 @@ function run_test() {
   // Remove listener
 
   MailServices.ab.removeAddressBookListener(abListener);
-};
+
+  run_next_test();
+});
+
+add_test(function() {
+  let dirName = MailServices.ab.newAddressBook(
+    "TestBook",
+    "",
+    kPABData.dirType
+  );
+  let AB = MailServices.ab.getDirectoryFromId(dirName);
+
+  let mailList = Cc[
+    "@mozilla.org/addressbook/directoryproperty;1"
+  ].createInstance(Ci.nsIAbDirectory);
+  mailList.isMailList = true;
+  mailList.dirName = "TestList";
+  mailList = AB.addMailList(mailList);
+
+  let card1 = Cc["@mozilla.org/addressbook/cardproperty;1"].createInstance(
+    Ci.nsIAbCard
+  );
+  card1.firstName = "test1";
+  card1.primaryEmail = "test1@foo.invalid";
+  card1 = AB.addCard(card1);
+
+  let card2 = Cc["@mozilla.org/addressbook/cardproperty;1"].createInstance(
+    Ci.nsIAbCard
+  );
+  card2.firstName = "test2";
+  card2.primaryEmail = "test2@foo.invalid";
+  card2 = AB.addCard(card2);
+  mailList.addCard(card2);
+
+  // Test: remove one card that ISN'T in the mailing list
+
+  Services.obs.addObserver(abObserver, "addrbook-list-member-removed");
+  abObserver.maxResults = 0;
+  abObserver.result = [];
+
+  let cardsToDelete = Cc["@mozilla.org/array;1"].createInstance(
+    Ci.nsIMutableArray
+  );
+  cardsToDelete.appendElement(card1);
+  AB.deleteCards(cardsToDelete);
+
+  // Test: remove one card that IS in the mailing list
+
+  abObserver.maxResults = 1;
+  abObserver.result = [];
+
+  cardsToDelete.clear();
+  cardsToDelete.appendElement(card2);
+  AB.deleteCards(cardsToDelete);
+
+  Assert.equal(abObserver.result.length, 1);
+  Assert.equal(abObserver.result[0][0], card2);
+  Assert.equal(abObserver.result[0][1], "addrbook-list-member-removed");
+  Assert.equal(abObserver.result[0][2], mailList.UID);
+
+  Services.obs.removeObserver(abObserver, "addrbook-list-member-removed");
+
+  run_next_test();
+});
