@@ -11,20 +11,20 @@ var ACR = Ci.nsIAutoCompleteResult;
 
 // Note the expected arrays are in expected sort order as well.
 
-var results =  [
+var results = [
   { email: "Tomas Doe <tomez.doe@foo.invalid>" }, // 0
   { email: "Tomas Doe <tomez.doe@foo2.invalid>" }, // 1
   { email: "Tomas Doe <tomez.doe@b.example.com>" }, // 2
   { email: "Tomas Doe <tomez.doe@a.example.com>" }, // 3
-  { email: "Tomek Smith <tomek@example.com>" } // 4
-]
+  { email: "Tomek Smith <tomek@example.com>" }, // 4
+];
 
 var inputs = [
   [
-    { search: "t",            expected: [2, 3, 0, 1, 4] },
-    { search: "tom",          expected: [0, 1, 2, 3, 4] },
-    { search: "tomek",        expected: [4] }
-  ]
+    { search: "t", expected: [2, 3, 0, 1, 4] },
+    { search: "tom", expected: [0, 1, 2, 3, 4] },
+    { search: "tomek", expected: [4] },
+  ],
 ];
 
 function acObserver() {}
@@ -33,44 +33,42 @@ acObserver.prototype = {
   _search: null,
   _result: null,
 
-  onSearchResult: function (aSearch, aResult) {
+  onSearchResult(aSearch, aResult) {
     this._search = aSearch;
     this._result = aResult;
-  }
+  },
 };
 
 var PAB_CARD_DATA = [
   {
-    "FirstName": "Tomas",
-    "LastName": "Doe",
-    "DisplayName": "Tomas Doe",
-    "NickName": "tom",
-    "PrimaryEmail": "tomez.doe@foo.invalid",
-    "SecondEmail": "tomez.doe@foo2.invalid",
-    "PreferDisplayName": true,
-    "PopularityIndex": 10
+    FirstName: "Tomas",
+    LastName: "Doe",
+    DisplayName: "Tomas Doe",
+    NickName: "tom",
+    PrimaryEmail: "tomez.doe@foo.invalid",
+    SecondEmail: "tomez.doe@foo2.invalid",
+    PreferDisplayName: true,
+    PopularityIndex: 10,
   },
   {
-    "FirstName": "Tomas",
-    "LastName": "Doe",
-    "DisplayName": "Tomas Doe",
-    "PrimaryEmail": "tomez.doe@b.example.com",
-    "SecondEmail": "tomez.doe@a.example.com",
-    "PreferDisplayName": true,
-    "PopularityIndex": 200
+    FirstName: "Tomas",
+    LastName: "Doe",
+    DisplayName: "Tomas Doe",
+    PrimaryEmail: "tomez.doe@b.example.com",
+    SecondEmail: "tomez.doe@a.example.com",
+    PreferDisplayName: true,
+    PopularityIndex: 200,
   },
   {
-    "FirstName": "Tomek",
-    "LastName": "Smith",
-    "DisplayName": "Tomek Smith",
-    "PrimaryEmail": "tomek@example.com",
-    "PreferDisplayName": true,
-    "PopularityIndex": 3
-  }
+    FirstName: "Tomek",
+    LastName: "Smith",
+    DisplayName: "Tomek Smith",
+    PrimaryEmail: "tomek@example.com",
+    PreferDisplayName: true,
+    PopularityIndex: 3,
+  },
 ];
 
-var ABMDB_PREFIX = "moz-abmdbdirectory://";
-
 function setupAddressBookData(aDirURI, aCardData, aMailListData) {
   let ab = MailServices.ab.getDirectory(aDirURI);
 
@@ -85,8 +83,9 @@ function setupAddressBookData(aDirURI, aCardData, aMailListData) {
   }
 
   aCardData.forEach(function(cd) {
-    let card = Cc["@mozilla.org/addressbook/cardproperty;1"]
-      .createInstance(Ci.nsIAbCard);
+    let card = Cc["@mozilla.org/addressbook/cardproperty;1"].createInstance(
+      Ci.nsIAbCard
+    );
     for (var prop in cd) {
       card.setProperty(prop, cd[prop]);
     }
@@ -94,8 +93,9 @@ function setupAddressBookData(aDirURI, aCardData, aMailListData) {
   });
 
   aMailListData.forEach(function(ld) {
-    let list = Cc["@mozilla.org/addressbook/directoryproperty;1"]
-      .createInstance(Ci.nsIAbDirectory);
+    let list = Cc[
+      "@mozilla.org/addressbook/directoryproperty;1"
+    ].createInstance(Ci.nsIAbDirectory);
     list.isMailList = true;
     for (var prop in ld) {
       list[prop] = ld[prop];
@@ -105,7 +105,7 @@ function setupAddressBookData(aDirURI, aCardData, aMailListData) {
 
   let childCards = ab.childCards;
   while (childCards.hasMoreElements()) {
-    let c = childCards.getNext().QueryInterface(Ci.nsIAbCard);
+    childCards.getNext().QueryInterface(Ci.nsIAbCard);
   }
 }
 
@@ -115,12 +115,11 @@ function run_test() {
 
   // Test - Create a new search component
 
-  var acs = Cc["@mozilla.org/autocomplete/search;1?name=addrbook"]
-    .getService(Ci.nsIAutoCompleteSearch);
+  var acs = Cc["@mozilla.org/autocomplete/search;1?name=addrbook"].getService(
+    Ci.nsIAutoCompleteSearch
+  );
 
   var obs = new acObserver();
-  let obsNews = new acObserver();
-  let obsFollowup = new acObserver();
 
   let param = JSON.stringify({ type: "addr_to" });
 
@@ -130,12 +129,18 @@ function run_test() {
     print("Search #" + index + ": search=" + element.search);
     acs.startSearch(element.search, param, prevRes, obs);
 
-    for (var i = 0; i < obs._result.matchCount; i++) {
+    for (let i = 0; i < obs._result.matchCount; i++) {
       print("... got " + i + ": " + obs._result.getValueAt(i));
     }
-    for (var i = 0; i < element.expected.length; i++) {
-      print("... expected " + i + " (result " + element.expected[i] + "): " +
-            results[element.expected[i]].email);
+    for (let i = 0; i < element.expected.length; i++) {
+      print(
+        "... expected " +
+          i +
+          " (result " +
+          element.expected[i] +
+          "): " +
+          results[element.expected[i]].email
+      );
     }
 
     Assert.equal(obs._search, acs);
@@ -145,9 +150,15 @@ function run_test() {
     Assert.equal(obs._result.matchCount, element.expected.length);
     Assert.equal(obs._result.defaultIndex, 0);
 
-    for (var i = 0; i < element.expected.length; ++i) {
-      Assert.equal(obs._result.getValueAt(i), results[element.expected[i]].email);
-      Assert.equal(obs._result.getLabelAt(i), results[element.expected[i]].email);
+    for (let i = 0; i < element.expected.length; ++i) {
+      Assert.equal(
+        obs._result.getValueAt(i),
+        results[element.expected[i]].email
+      );
+      Assert.equal(
+        obs._result.getLabelAt(i),
+        results[element.expected[i]].email
+      );
       Assert.equal(obs._result.getCommentAt(i), "");
       Assert.equal(obs._result.getStyleAt(i), "local-abook");
       Assert.equal(obs._result.getImageAt(i), "");
@@ -158,4 +169,4 @@ function run_test() {
   }
 
   inputs.forEach(checkInputSet);
-};
+}
