@@ -10,9 +10,7 @@ var profD = do_get_profile();
 add_test(function directoryUID() {
   newAddressBookFile();
 
-  let books = MailServices.ab.directories;
-  while (books.hasMoreElements()) {
-    let book = books.getNext().QueryInterface(Ci.nsIAbDirectory);
+  for (let book of MailServices.ab.directories) {
     equal(36, book.UID.length, "Existing directory has a UID");
   }
 
@@ -28,39 +26,74 @@ add_test(function directoryUID() {
 add_task(async function existingContactUID() {
   let book = newAddressBookFile();
 
-  let card = getChildCards(book).find(c => !c.isMailList);
+  let card = [...book.childCards].find(c => !c.isMailList);
   equal(36, card.UID.length, "Existing contact has a UID");
 
   let existingUID = card.UID;
-  card = getChildCards(book).find(c => !c.isMailList);
+  card = [...book.childCards].find(c => !c.isMailList);
   equal(existingUID, card.UID, "New reference to contact has the same UID");
 
   await checkFileForUID(card.UID, book.fileName);
 });
 
-// Tests that new contacts have UIDs. Do this test last so we don't muck up
-// the others by adding new things to the address book.
+// Tests that new contacts have UIDs.
 add_task(async function newContactUID() {
   let book = newAddressBookFile();
 
-  let contact = Cc["@mozilla.org/addressbook/cardproperty;1"].createInstance(Ci.nsIAbCard);
+  let contact = Cc["@mozilla.org/addressbook/cardproperty;1"].createInstance(
+    Ci.nsIAbCard
+  );
   let newContact = book.addCard(contact);
   equal(36, newContact.UID.length, "New contact has a UID");
 
   await checkFileForUID(newContact.UID, book.fileName);
+
+  Assert.throws(() => {
+    // Set the UID after it already exists.
+    newContact.UID = "This should not be possible";
+  }, /NS_ERROR_FAILURE/);
+
+  // Setting the UID to it's existing value should not fail.
+  newContact.UID = newContact.UID; // eslint-disable-line no-self-assign
+});
+
+// Tests that the UID on a new contact can be set.
+add_task(async function newContactWithUID() {
+  let book = newAddressBookFile();
+
+  let contact = Cc["@mozilla.org/addressbook/cardproperty;1"].createInstance(
+    Ci.nsIAbCard
+  );
+  contact.UID = "I'm a UID!";
+  let newContact = book.addCard(contact);
+  equal("I'm a UID!", newContact.UID, "New contact has the UID we set");
+
+  await checkFileForUID(newContact.UID, book.fileName);
+
+  Assert.throws(() => {
+    // Set the UID after it already exists.
+    newContact.UID = "This should not be possible";
+  }, /NS_ERROR_FAILURE/);
+
+  // Setting the UID to it's existing value should not fail.
+  newContact.UID = newContact.UID; // eslint-disable-line no-self-assign
 });
 
 // Tests that existing lists have UIDs. Reference the nsIAbCard first.
 add_task(async function existingListUID1() {
   let book = newAddressBookFile();
 
-  let card = getChildCards(book).find(c => c.isMailList);
+  let card = [...book.childCards].find(c => c.isMailList);
   equal(36, card.UID.length, "Existing list's card has a UID");
 
   let directory = MailServices.ab.getDirectory(card.mailListURI);
   equal(36, directory.UID.length, "Existing list's directory has a UID");
 
-  equal(card.UID, directory.UID, "Existing list's card and directory UIDs match");
+  equal(
+    card.UID,
+    directory.UID,
+    "Existing list's card and directory UIDs match"
+  );
 
   await checkFileForUID(card.UID, book.fileName);
 });
@@ -72,10 +105,14 @@ add_task(async function existingListUID2() {
   let directory = MailServices.ab.getDirectory(`${book.URI}/MailList1`);
   equal(36, directory.UID.length, "Existing list's directory has a UID");
 
-  let card = getChildCards(book).find(c => c.isMailList);
+  let card = [...book.childCards].find(c => c.isMailList);
   equal(36, card.UID.length, "Existing list's card has a UID");
 
-  equal(card.UID, directory.UID, "Existing list's card and directory UIDs match");
+  equal(
+    card.UID,
+    directory.UID,
+    "Existing list's card and directory UIDs match"
+  );
 
   await checkFileForUID(card.UID, book.fileName);
 });
@@ -84,14 +121,25 @@ add_task(async function existingListUID2() {
 add_task(async function newListUID() {
   let book = newAddressBookFile();
 
-  let list = Cc["@mozilla.org/addressbook/directoryproperty;1"].createInstance(Ci.nsIAbDirectory);
+  let list = Cc["@mozilla.org/addressbook/directoryproperty;1"].createInstance(
+    Ci.nsIAbDirectory
+  );
   list = book.addMailList(list);
 
   equal(36, list.UID.length, "New list's directory has a UID");
-  equal(list.UID, MailServices.ab.getDirectory(list.URI).UID, "New reference to list's directory has the same UID");
+  equal(
+    list.UID,
+    MailServices.ab.getDirectory(list.URI).UID,
+    "New reference to list's directory has the same UID"
+  );
 
-  let bookCards = getChildCards(book);
-  ok(!!bookCards.find(c => c.UID == list.UID, "New reference to list has the same UID"));
+  let bookCards = [...book.childNodes];
+  ok(
+    !!bookCards.find(
+      c => c.UID == list.UID,
+      "New reference to list has the same UID"
+    )
+  );
 
   await checkFileForUID(list.UID, book.fileName);
 });
@@ -99,15 +147,24 @@ add_task(async function newListUID() {
 // 3 seems to be the lowest number that works here. I don't know why.
 var count = 3;
 function newAddressBookFile() {
-  let foo = MailServices.ab.newAddressBook(`book${count}`, `moz-abmdbdirectory://abook-${count}.mab`, 2);
+  MailServices.ab.newAddressBook(
+    `book${count}`,
+    `moz-abmdbdirectory://abook-${count}.mab`,
+    2
+  );
 
   let testAB = do_get_file("data/existing.mab");
   testAB.copyTo(profD, `abook-${count}.mab`);
 
-  Services.prefs.setCharPref(`ldap_2.servers.book${count}.filename`, `abook-${count}.mab`);
+  Services.prefs.setCharPref(
+    `ldap_2.servers.book${count}.filename`,
+    `abook-${count}.mab`
+  );
 
-  let book = MailServices.ab.getDirectory(`moz-abmdbdirectory://abook-${count}.mab`);
-  equal(2, getChildCards(book).length);
+  let book = MailServices.ab.getDirectory(
+    `moz-abmdbdirectory://abook-${count}.mab`
+  );
+  equal(2, [...book.childCards].length);
 
   count++;
   return book;
@@ -121,11 +178,3 @@ async function checkFileForUID(needle, bookFileName) {
 
   ok(text.includes(needle), "UID has been saved to file");
 }
-
-function getChildCards(book) {
-  let bookCards = [];
-  childCards = book.childCards;
-  while (childCards.hasMoreElements())
-    bookCards.push(childCards.getNext().QueryInterface(Ci.nsIAbCard));
-  return bookCards;
-}
