@@ -19,61 +19,53 @@ namespace mozilla {
 namespace mailnews {
 NS_IMPL_ISUPPORTS(MailNewsDLF, nsIDocumentLoaderFactory)
 
-MailNewsDLF::MailNewsDLF()
-{
-}
+MailNewsDLF::MailNewsDLF() {}
 
-MailNewsDLF::~MailNewsDLF()
-{
-}
+MailNewsDLF::~MailNewsDLF() {}
 
 NS_IMETHODIMP
-MailNewsDLF::CreateInstance(const char* aCommand,
-                            nsIChannel* aChannel,
+MailNewsDLF::CreateInstance(const char* aCommand, nsIChannel* aChannel,
                             nsILoadGroup* aLoadGroup,
                             const nsACString& aContentType,
-                            nsIDocShell* aContainer,
-                            nsISupports* aExtraInfo,
+                            nsIDocShell* aContainer, nsISupports* aExtraInfo,
                             nsIStreamListener** aDocListener,
-                            nsIContentViewer** aDocViewer)
-{
+                            nsIContentViewer** aDocViewer) {
   nsresult rv;
 
-  bool viewSource = (PL_strstr(PromiseFlatCString(aContentType).get(),
-                               "view-source") != 0);
+  bool viewSource =
+      (PL_strstr(PromiseFlatCString(aContentType).get(), "view-source") != 0);
 
   aChannel->SetContentType(NS_LITERAL_CSTRING(TEXT_HTML));
 
   // Get the HTML category
   nsCOMPtr<nsICategoryManager> catMan(
-    do_GetService(NS_CATEGORYMANAGER_CONTRACTID, &rv));
+      do_GetService(NS_CATEGORYMANAGER_CONTRACTID, &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsAutoCString contractID;
-  rv = catMan->GetCategoryEntry("Gecko-Content-Viewers", TEXT_HTML,
-                                getter_Copies(contractID));
+  rv = catMan->GetCategoryEntry("Gecko-Content-Viewers", TEXT_HTML, contractID);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  nsCOMPtr<nsIDocumentLoaderFactory> factory(do_GetService(contractID.get(),
-                                             &rv));
+  nsCOMPtr<nsIDocumentLoaderFactory> factory(
+      do_GetService(contractID.get(), &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIStreamListener> listener;
 
   if (viewSource) {
-    rv = factory->CreateInstance("view-source", aChannel, aLoadGroup,
-                                 NS_LITERAL_CSTRING(TEXT_HTML "; x-view-type=view-source"),
-                                 aContainer, aExtraInfo, getter_AddRefs(listener),
-                                 aDocViewer);
+    rv = factory->CreateInstance(
+        "view-source", aChannel, aLoadGroup,
+        NS_LITERAL_CSTRING(TEXT_HTML "; x-view-type=view-source"), aContainer,
+        aExtraInfo, getter_AddRefs(listener), aDocViewer);
   } else {
-    rv = factory->CreateInstance("view", aChannel, aLoadGroup, NS_LITERAL_CSTRING(TEXT_HTML),
-                                 aContainer, aExtraInfo, getter_AddRefs(listener),
-                                 aDocViewer);
+    rv = factory->CreateInstance(
+        "view", aChannel, aLoadGroup, NS_LITERAL_CSTRING(TEXT_HTML), aContainer,
+        aExtraInfo, getter_AddRefs(listener), aDocViewer);
   }
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIStreamConverterService> scs(
-    do_GetService(NS_STREAMCONVERTERSERVICE_CONTRACTID, &rv));
+      do_GetService(NS_STREAMCONVERTERSERVICE_CONTRACTID, &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
   return scs->AsyncConvertData(MESSAGE_RFC822, TEXT_HTML, listener, aChannel,
@@ -82,12 +74,11 @@ MailNewsDLF::CreateInstance(const char* aCommand,
 
 NS_IMETHODIMP
 MailNewsDLF::CreateInstanceForDocument(nsISupports* aContainer,
-                                       nsIDocument* aDocument,
+                                       mozilla::dom::Document* aDocument,
                                        const char* aCommand,
-                                       nsIContentViewer** aDocViewer)
-{
+                                       nsIContentViewer** aDocViewer) {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
-}
-}
+}  // namespace mailnews
+}  // namespace mozilla
