@@ -12,19 +12,23 @@
 var iteratorUtils = {};
 ChromeUtils.import("resource:///modules/iteratorUtils.jsm", iteratorUtils);
 
-var gDOMParser = Cc["@mozilla.org/xmlextras/domparser;1"]
-                   .createInstance(Ci.nsIDOMParser);
+var gDOMParser = new DOMParser();
 
 /**
  * Given the name of an XML file, returns the node representation of the file.
  */
 function parse_xml_file(aFileName) {
   let file = do_get_file(aFileName);
-  let stream = Cc["@mozilla.org/network/file-input-stream;1"]
-                 .createInstance(Ci.nsIFileInputStream);
+  let stream = Cc["@mozilla.org/network/file-input-stream;1"].createInstance(
+    Ci.nsIFileInputStream
+  );
   stream.init(file, -1, -1, Ci.nsIFileInputStream.CLOSE_ON_EOF);
-  return gDOMParser.parseFromStream(stream, "UTF-8", file.fileSize,
-                                    "application/xml");
+  return gDOMParser.parseFromStream(
+    stream,
+    "UTF-8",
+    file.fileSize,
+    "application/xml"
+  );
 }
 
 /**
@@ -48,13 +52,17 @@ function test_fixIterator() {
 
   let nsIArrayJSArray = [];
   for (let val of JSArray) {
-    let nsIArrayMember = Cc["@mozilla.org/supports-PRUint8;1"]
-                           .createInstance(Ci.nsISupportsPRUint8);
+    let nsIArrayMember = Cc["@mozilla.org/supports-PRUint8;1"].createInstance(
+      Ci.nsISupportsPRUint8
+    );
     nsIArrayMember.data = val;
     nsIArrayJSArray.push(nsIArrayMember);
   }
 
-  let nsIArray = iteratorUtils.toXPCOMArray(nsIArrayJSArray, Ci.nsIMutableArray);
+  let nsIArray = iteratorUtils.toXPCOMArray(
+    nsIArrayJSArray,
+    Ci.nsIMutableArray
+  );
   Assert.equal(nsIArray.length, 5);
 
   i = 0;
@@ -70,7 +78,9 @@ function test_fixIterator() {
   Assert.ok(i > 0);
 
   i = 0;
-  let JSIteratorArray2 = iteratorUtils.toArray(iteratorUtils.fixIterator(nsIArray));
+  let JSIteratorArray2 = iteratorUtils.toArray(
+    iteratorUtils.fixIterator(nsIArray)
+  );
   for (let val of JSIteratorArray2) {
     Assert.equal(val, JSArray[i++]);
   }
@@ -80,31 +90,45 @@ function test_fixIterator() {
   let thrown = false;
   let tryIterate = { item: "An object, that is not supported by fixIterator." };
   try {
-    for (let val of iteratorUtils.fixIterator(tryIterate)) { dump(val); }
+    for (let val of iteratorUtils.fixIterator(tryIterate)) {
+      dump(val);
+    }
   } catch (e) {
     // A specific exception is the correct behaviour here.
-    if (e.message == "An unsupported object sent to fixIterator: [object Object]")
+    if (
+      e.message == "An unsupported object sent to fixIterator: [object Object]"
+    ) {
       thrown = true;
+    }
   }
   Assert.ok(thrown);
 
   thrown = false;
   try {
-    for (let val of iteratorUtils.fixIterator(tryIterate)) { dump(val); }
+    for (let val of iteratorUtils.fixIterator(tryIterate)) {
+      dump(val);
+    }
   } catch (e) {
     // A specific exception is the correct behaviour here.
-    if (e.message == "An unsupported object sent to fixIterator: [object Object]")
+    if (
+      e.message == "An unsupported object sent to fixIterator: [object Object]"
+    ) {
       thrown = true;
+    }
   }
   Assert.ok(thrown);
 
   thrown = false;
   try {
-    let result = iteratorUtils.toXPCOMArray(tryIterate, Ci.nsIArray);
+    iteratorUtils.toXPCOMArray(tryIterate, Ci.nsIArray);
   } catch (e) {
     // A specific exception is the correct behaviour here.
-    if (e.message == "An unsupported interface requested from toXPCOMArray: nsIArray")
+    if (
+      e.message ==
+      "An unsupported interface requested from toXPCOMArray: nsIArray"
+    ) {
       thrown = true;
+    }
   }
   Assert.ok(thrown);
 }
@@ -123,12 +147,13 @@ function test_toArray_NodeList() {
   Assert.ok(childNodes.length > 0);
   let childArray = iteratorUtils.toArray(childNodes);
   Assert.equal(childNodes.length, childArray.length);
-  for (let [i, node] of childArray.entries())
+  for (let [i, node] of childArray.entries()) {
     Assert.equal(node, childArray[i]);
+  }
 }
 
 /**
- * Test that toArray works correctly with the build-in generator construct.
+ * Test that toArray works correctly with the built-in generator construct.
  */
 function test_toArray_builtin_generator() {
   let arr = [11, 12, 13, 14, 15, 16, 17, 18, 19, 20];
@@ -136,7 +161,7 @@ function test_toArray_builtin_generator() {
     for (let elem of arr) {
       yield elem;
     }
-  }
+  };
   // The resulting array should be the same as 'arr'.
   let generatorArray = iteratorUtils.toArray(generator);
   Assert.equal(arr.length, generatorArray.length);
@@ -148,17 +173,20 @@ function test_toArray_builtin_generator() {
   let thrown = false;
   let tryIterate = { item: "An object, that is not supported by toArray." };
   try {
-    let result = iteratorUtils.toArray(tryIterate);
+    iteratorUtils.toArray(tryIterate);
   } catch (e) {
     // A specific exception is the correct behaviour here.
-    if (e.message == "An unsupported object sent to toArray: [object Object]")
+    if (e.message == "An unsupported object sent to toArray: [object Object]") {
       thrown = true;
+    }
   }
   Assert.ok(thrown);
 }
 
-var Symbol_iterator = typeof Symbol === "function" && Symbol.iterator ?
-  Symbol.iterator : "@@iterator";
+var Symbol_iterator =
+  typeof Symbol === "function" && Symbol.iterator
+    ? Symbol.iterator
+    : "@@iterator";
 
 /**
  * Test that toArray works correctly with a custom iterator.
@@ -169,14 +197,16 @@ function test_toArray_custom_iterator() {
     [Symbol_iterator]: function* testIterator() {
       // C-style for loop so that we don't confuse ourselves with yet another
       // iterator
-      for (let i = 0; i < arr.length; i++)
+      for (let i = 0; i < arr.length; i++) {
         yield arr[i];
+      }
     },
   };
   let iteratorArray = iteratorUtils.toArray(iterator);
   Assert.equal(arr.length, iteratorArray.length);
-  for (let [i, val] of arr.entries())
+  for (let [i, val] of arr.entries()) {
     Assert.equal(val, iteratorArray[i]);
+  }
 }
 
 var gTests = [
@@ -187,6 +217,7 @@ var gTests = [
 ];
 
 function run_test() {
-  for (let test of gTests)
+  for (let test of gTests) {
     test();
+  }
 }
