@@ -37,8 +37,7 @@
 nsresult nsMsgI18NConvertFromUnicode(const nsACString& aCharset,
                                      const nsAString& inString,
                                      nsACString& outString,
-                                     bool aReportUencNoMapping)
-{
+                                     bool aReportUencNoMapping) {
   if (inString.IsEmpty()) {
     outString.Truncate();
     return NS_OK;
@@ -66,8 +65,7 @@ nsresult nsMsgI18NConvertFromUnicode(const nsACString& aCharset,
 
 nsresult nsMsgI18NConvertToUnicode(const nsACString& aCharset,
                                    const nsACString& inString,
-                                   nsAString& outString)
-{
+                                   nsAString& outString) {
   if (inString.IsEmpty()) {
     outString.Truncate();
     return NS_OK;
@@ -85,7 +83,7 @@ nsresult nsMsgI18NConvertToUnicode(const nsACString& aCharset,
   // Look up Thunderbird's special aliases from charsetalias.properties.
   nsresult rv;
   nsCOMPtr<nsICharsetConverterManager> ccm =
-    do_GetService(NS_CHARSETCONVERTERMANAGER_CONTRACTID, &rv);
+      do_GetService(NS_CHARSETCONVERTERMANAGER_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCString newCharset;
@@ -93,37 +91,36 @@ nsresult nsMsgI18NConvertToUnicode(const nsACString& aCharset,
   NS_ENSURE_SUCCESS(rv, rv);
 
   if (newCharset.Equals("UTF-7", nsCaseInsensitiveCStringComparator())) {
-    // Special treatment for decoding UTF-7 since it's not handled by encoding_rs.
+    // Special treatment for decoding UTF-7 since it's not handled by
+    // encoding_rs.
     return CopyUTF7toUTF16(inString, outString);
   }
 
   auto encoding = mozilla::Encoding::ForLabelNoReplacement(newCharset);
-  if (!encoding)
-    return NS_ERROR_UCONV_NOCONV;
-  return encoding->DecodeWithoutBOMHandlingAndWithoutReplacement(inString,
-                                                                 outString);
+  if (!encoding) return NS_ERROR_UCONV_NOCONV;
+  return encoding->DecodeWithoutBOMHandling(inString, outString);
 }
 
 // This is used to decode UTF-7. No support for encoding in UTF-7.
-nsresult CopyUTF7toUTF16(const nsACString& aSrc, nsAString& aDest)
-{
+nsresult CopyUTF7toUTF16(const nsACString& aSrc, nsAString& aDest) {
   // UTF-7 encoding size cannot be larger than the size in UTF-16.
   nsUTF7ToUnicode converter;
   int32_t inLen = aSrc.Length();
   int32_t outLen = inLen;
-  aDest.SetCapacity(outLen);
-  converter.ConvertNoBuff(aSrc.BeginReading(), &inLen, aDest.BeginWriting(), &outLen);
-  MOZ_ASSERT(inLen == (int32_t)aSrc.Length(), "UTF-7 should not produce a longer output");
+  aDest.SetLength(outLen);
+  converter.ConvertNoBuff(aSrc.BeginReading(), &inLen, aDest.BeginWriting(),
+                          &outLen);
+  MOZ_ASSERT(inLen == (int32_t)aSrc.Length(),
+             "UTF-7 should not produce a longer output");
   aDest.SetLength(outLen);
   return NS_OK;
 }
 
-nsresult CopyUTF16toMUTF7(const nsAString &aSrc, nsACString& aDest)
-{
-  #define IMAP_UTF7_BUF_LENGTH 100
+nsresult CopyUTF16toMUTF7(const nsAString& aSrc, nsACString& aDest) {
+#define IMAP_UTF7_BUF_LENGTH 100
   nsUnicodeToMUTF7 converter;
   static char buffer[IMAP_UTF7_BUF_LENGTH];
-  const char16_t *in = aSrc.BeginReading();
+  const char16_t* in = aSrc.BeginReading();
   int32_t inLen = aSrc.Length();
   int32_t outLen;
   aDest.Truncate();
@@ -137,27 +134,26 @@ nsresult CopyUTF16toMUTF7(const nsAString &aSrc, nsACString& aDest)
   }
   outLen = IMAP_UTF7_BUF_LENGTH;
   converter.FinishNoBuff(buffer, &outLen);
-  if (outLen > 0)
-    aDest.Append(buffer, outLen);
+  if (outLen > 0) aDest.Append(buffer, outLen);
   return NS_OK;
 }
 
-nsresult CopyMUTF7toUTF16(const nsACString& aSrc, nsAString& aDest)
-{
+nsresult CopyMUTF7toUTF16(const nsACString& aSrc, nsAString& aDest) {
   // UTF-7 encoding size cannot be larger than the size in UTF-16.
   nsMUTF7ToUnicode converter;
   int32_t inLen = aSrc.Length();
   int32_t outLen = inLen;
-  aDest.SetCapacity(outLen);
-  converter.ConvertNoBuff(aSrc.BeginReading(), &inLen, aDest.BeginWriting(), &outLen);
-  MOZ_ASSERT(inLen == (int32_t)aSrc.Length(), "UTF-7 should not produce a longer output");
+  aDest.SetLength(outLen);
+  converter.ConvertNoBuff(aSrc.BeginReading(), &inLen, aDest.BeginWriting(),
+                          &outLen);
+  MOZ_ASSERT(inLen == (int32_t)aSrc.Length(),
+             "UTF-7 should not produce a longer output");
   aDest.SetLength(outLen);
   return NS_OK;
 }
 
 // Charset used by the file system.
-const nsACString& nsMsgI18NFileSystemCharset()
-{
+const nsACString& nsMsgI18NFileSystemCharset() {
   /* Get a charset used for the file. */
   static nsAutoCString fileSystemCharset;
 
@@ -168,21 +164,21 @@ const nsACString& nsMsgI18NFileSystemCharset()
 }
 
 // Charset used by the text file.
-void nsMsgI18NTextFileCharset(nsACString& aCharset)
-{
+void nsMsgI18NTextFileCharset(nsACString& aCharset) {
   mozilla::dom::FallbackEncoding::FromLocale()->Name(aCharset);
 }
 
 // MIME encoder, output string should be freed by PR_FREE
 // XXX : fix callers later to avoid allocation and copy
-char * nsMsgI18NEncodeMimePartIIStr(const char *header, bool structured, const char *charset, int32_t fieldnamelen, bool usemime)
-{
+char* nsMsgI18NEncodeMimePartIIStr(const char* header, bool structured,
+                                   const char* charset, int32_t fieldnamelen,
+                                   bool usemime) {
   // No MIME, convert to the outgoing mail charset.
   if (!usemime) {
     nsAutoCString convertedStr;
-    if (NS_SUCCEEDED(nsMsgI18NConvertFromUnicode(charset ? nsDependentCString(charset) : EmptyCString(),
-                                                 NS_ConvertUTF8toUTF16(header),
-                                                 convertedStr)))
+    if (NS_SUCCEEDED(nsMsgI18NConvertFromUnicode(
+            charset ? nsDependentCString(charset) : EmptyCString(),
+            NS_ConvertUTF8toUTF16(header), convertedStr)))
       return PL_strdup(convertedStr.get());
     else
       return PL_strdup(header);
@@ -190,26 +186,27 @@ char * nsMsgI18NEncodeMimePartIIStr(const char *header, bool structured, const c
 
   nsAutoCString encodedString;
   nsresult res;
-  nsCOMPtr<nsIMimeConverter> converter = do_GetService(NS_MIME_CONVERTER_CONTRACTID, &res);
-  if (NS_SUCCEEDED(res) && nullptr != converter)
-    res = converter->EncodeMimePartIIStr_UTF8(nsDependentCString(header),
-      structured, "UTF-8", fieldnamelen,
-      nsIMimeConverter::MIME_ENCODED_WORD_SIZE, encodedString);
+  nsCOMPtr<nsIMimeConverter> converter =
+      do_GetService(NS_MIME_CONVERTER_CONTRACTID, &res);
+  if (NS_SUCCEEDED(res) && nullptr != converter) {
+    res = converter->EncodeMimePartIIStr_UTF8(
+        nsDependentCString(header), structured, fieldnamelen,
+        nsIMimeConverter::MIME_ENCODED_WORD_SIZE, encodedString);
+  }
 
   return NS_SUCCEEDED(res) ? PL_strdup(encodedString.get()) : nullptr;
 }
 
 // Return True if a charset is stateful (e.g. JIS).
-bool nsMsgI18Nstateful_charset(const char *charset)
-{
-  //TODO: use charset manager's service
+bool nsMsgI18Nstateful_charset(const char* charset) {
+  // TODO: use charset manager's service
   return (PL_strcasecmp(charset, "ISO-2022-JP") == 0);
 }
 
-bool nsMsgI18Nmultibyte_charset(const char *charset)
-{
+bool nsMsgI18Nmultibyte_charset(const char* charset) {
   nsresult res;
-  nsCOMPtr <nsICharsetConverterManager> ccm = do_GetService(NS_CHARSETCONVERTERMANAGER_CONTRACTID, &res);
+  nsCOMPtr<nsICharsetConverterManager> ccm =
+      do_GetService(NS_CHARSETCONVERTERMANAGER_CONTRACTID, &res);
   bool result = false;
 
   if (NS_SUCCEEDED(res)) {
@@ -223,16 +220,15 @@ bool nsMsgI18Nmultibyte_charset(const char *charset)
   return result;
 }
 
-bool nsMsgI18Ncheck_data_in_charset_range(const char *charset, const char16_t* inString)
-{
-  if (!charset || !*charset || !inString || !*inString)
-    return true;
+bool nsMsgI18Ncheck_data_in_charset_range(const char* charset,
+                                          const char16_t* inString) {
+  if (!charset || !*charset || !inString || !*inString) return true;
 
   bool res = true;
 
-  auto encoding = mozilla::Encoding::ForLabelNoReplacement(nsDependentCString(charset));
-  if (!encoding)
-    return false;
+  auto encoding =
+      mozilla::Encoding::ForLabelNoReplacement(nsDependentCString(charset));
+  if (!encoding) return false;
   auto encoder = encoding->NewEncoder();
 
   uint8_t buffer[512];
@@ -243,12 +239,12 @@ bool nsMsgI18Ncheck_data_in_charset_range(const char *charset, const char16_t* i
     size_t read;
     size_t written;
     mozilla::Tie(result, read, written) =
-      encoder->EncodeFromUTF16WithoutReplacement(src, dst, false);
+        encoder->EncodeFromUTF16WithoutReplacement(src, dst, false);
     if (result == mozilla::kInputEmpty) {
       // All converted successfully.
       break;
     } else if (result != mozilla::kOutputFull) {
-      // Didn't use all the input but the outout isn't full, hence
+      // Didn't use all the input but the output isn't full, hence
       // there was an unencodable character.
       res = false;
       break;
@@ -262,10 +258,8 @@ bool nsMsgI18Ncheck_data_in_charset_range(const char *charset, const char16_t* i
 
 // Simple parser to parse META charset.
 // It only supports the case when the description is within one line.
-const char *
-nsMsgI18NParseMetaCharset(nsIFile* file)
-{
-  static char charset[nsIMimeConverter::MAX_CHARSET_NAME_LENGTH+1];
+const char* nsMsgI18NParseMetaCharset(nsIFile* file) {
+  static char charset[nsIMimeConverter::MAX_CHARSET_NAME_LENGTH + 1];
 
   *charset = '\0';
 
@@ -277,46 +271,42 @@ nsMsgI18NParseMetaCharset(nsIFile* file)
   }
 
   nsresult rv;
-  nsCOMPtr <nsIFileInputStream> fileStream = do_CreateInstance(NS_LOCALFILEINPUTSTREAM_CONTRACTID, &rv);
+  nsCOMPtr<nsIFileInputStream> fileStream =
+      do_CreateInstance(NS_LOCALFILEINPUTSTREAM_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv, charset);
 
   rv = fileStream->Init(file, PR_RDONLY, 0664, false);
-  nsCOMPtr <nsILineInputStream> lineStream = do_QueryInterface(fileStream, &rv);
+  nsCOMPtr<nsILineInputStream> lineStream = do_QueryInterface(fileStream, &rv);
 
   nsCString curLine;
   bool more = true;
   while (NS_SUCCEEDED(rv) && more) {
     rv = lineStream->ReadLine(curLine, &more);
-    if (curLine.IsEmpty())
-      continue;
+    if (curLine.IsEmpty()) continue;
 
     ToUpperCase(curLine);
 
-    if (curLine.Find("/HEAD") != -1)
-      break;
+    if (curLine.Find("/HEAD") != -1) break;
 
-    if (curLine.Find("META") != -1 &&
-        curLine.Find("HTTP-EQUIV") != -1 &&
-        curLine.Find("CONTENT-TYPE") != -1 &&
-        curLine.Find("CHARSET") != -1) {
-      char *cp = (char *) PL_strchr(PL_strstr(curLine.get(), "CHARSET"), '=');
-      char *token = nullptr;
-      if (cp)
-      {
-        char *newStr = cp + 1;
+    if (curLine.Find("META") != -1 && curLine.Find("HTTP-EQUIV") != -1 &&
+        curLine.Find("CONTENT-TYPE") != -1 && curLine.Find("CHARSET") != -1) {
+      char* cp = (char*)PL_strchr(PL_strstr(curLine.get(), "CHARSET"), '=');
+      char* token = nullptr;
+      if (cp) {
+        char* newStr = cp + 1;
         token = NS_strtok(" \"\'", &newStr);
       }
       if (token) {
         PL_strncpy(charset, token, sizeof(charset));
-        charset[sizeof(charset)-1] = '\0';
+        charset[sizeof(charset) - 1] = '\0';
 
         // this function cannot parse a file if it is really
         // encoded by one of the following charsets
         // so we can say that the charset label must be incorrect for
         // the .html if we actually see those charsets parsed
         // and we should ignore them
-        if (!PL_strncasecmp("UTF-16", charset, sizeof("UTF-16")-1) ||
-            !PL_strncasecmp("UTF-32", charset, sizeof("UTF-32")-1))
+        if (!PL_strncasecmp("UTF-16", charset, sizeof("UTF-16") - 1) ||
+            !PL_strncasecmp("UTF-32", charset, sizeof("UTF-32") - 1))
           charset[0] = '\0';
 
         break;
@@ -327,10 +317,8 @@ nsMsgI18NParseMetaCharset(nsIFile* file)
   return charset;
 }
 
-nsresult nsMsgI18NShrinkUTF8Str(const nsCString &inString,
-                                uint32_t aMaxLength,
-                                nsACString &outString)
-{
+nsresult nsMsgI18NShrinkUTF8Str(const nsCString& inString, uint32_t aMaxLength,
+                                nsACString& outString) {
   if (inString.IsEmpty()) {
     outString.Truncate();
     return NS_OK;
@@ -348,8 +336,7 @@ nsresult nsMsgI18NShrinkUTF8Str(const nsCString &inString,
   bool err = false;
   while (cur < last) {
     prev = cur;
-    if (!UTF8CharEnumerator::NextChar(&cur, end, &err) || err)
-      break;
+    if (!UTF8CharEnumerator::NextChar(&cur, end, &err) || err) break;
   }
   if (!prev || err) {
     outString.Truncate();
@@ -362,17 +349,14 @@ nsresult nsMsgI18NShrinkUTF8Str(const nsCString &inString,
 
 void nsMsgI18NConvertRawBytesToUTF16(const nsCString& inString,
                                      const nsACString& charset,
-                                     nsAString& outString)
-{
-  if (MsgIsUTF8(inString))
-  {
+                                     nsAString& outString) {
+  if (MsgIsUTF8(inString)) {
     CopyUTF8toUTF16(inString, outString);
     return;
   }
 
   nsresult rv = nsMsgI18NConvertToUnicode(charset, inString, outString);
-  if (NS_SUCCEEDED(rv))
-    return;
+  if (NS_SUCCEEDED(rv)) return;
 
   const char* cur = inString.BeginReading();
   const char* end = inString.EndReading();
@@ -388,18 +372,15 @@ void nsMsgI18NConvertRawBytesToUTF16(const nsCString& inString,
 
 void nsMsgI18NConvertRawBytesToUTF8(const nsCString& inString,
                                     const nsACString& charset,
-                                    nsACString& outString)
-{
-  if (MsgIsUTF8(inString))
-  {
+                                    nsACString& outString) {
+  if (MsgIsUTF8(inString)) {
     outString.Assign(inString);
     return;
   }
 
   nsAutoString utf16Text;
   nsresult rv = nsMsgI18NConvertToUnicode(charset, inString, utf16Text);
-  if (NS_SUCCEEDED(rv))
-  {
+  if (NS_SUCCEEDED(rv)) {
     CopyUTF16toUTF8(utf16Text, outString);
     return;
   }
