@@ -17,15 +17,17 @@
 #include "nsIMimeHeaders.h"
 #include "nsIMsgMailNewsUrl.h"
 #include "nsIURL.h"
-#include "nsIURIWithPrincipal.h"
+#include "nsIURIWithSpecialOrigin.h"
 #include "nsILoadGroup.h"
 #include "nsIMsgSearchSession.h"
 #include "nsICacheEntry.h"
 #include "nsICacheSession.h"
 #include "nsIMimeMiscStatus.h"
-#include "nsWeakReference.h"
+#include "nsIWeakReferenceUtils.h"
 #include "nsString.h"
 #include "nsIURIMutator.h"
+#include "nsISerializable.h"
+#include "nsIClassInfo.h"
 
 ///////////////////////////////////////////////////////////////////////////////////
 // Okay, I found that all of the mail and news url interfaces needed to support
@@ -35,22 +37,23 @@
 //
 //////////////////////////////////////////////////////////////////////////////////
 
-#undef  IMETHOD_VISIBILITY
-#define IMETHOD_VISIBILITY NS_VISIBILITY_DEFAULT
-
 class NS_MSG_BASE nsMsgMailNewsUrl : public nsIMsgMailNewsUrl,
-                                     public nsIURIWithPrincipal
-{
-public:
-    nsMsgMailNewsUrl();
+                                     public nsIURIWithSpecialOrigin,
+                                     public nsISerializable,
+                                     public nsIClassInfo {
+ public:
+  nsMsgMailNewsUrl();
 
-    NS_DECL_THREADSAFE_ISUPPORTS
-    NS_DECL_NSIMSGMAILNEWSURL
-    NS_DECL_NSIURI
-    NS_DECL_NSIURL
-    NS_DECL_NSIURIWITHPRINCIPAL
+  NS_DECL_THREADSAFE_ISUPPORTS
+  NS_DECL_NSIMSGMAILNEWSURL
+  NS_DECL_NSIURI
+  NS_DECL_NSIURL
+  NS_DECL_NSIURIWITHSPECIALORIGIN
+  NS_DECL_NSISERIALIZABLE
+  NS_DECL_NSICLASSINFO
 
-protected:
+ protected:
+  virtual nsresult Clone(nsIURI **_retval);
   virtual nsresult SetScheme(const nsACString &aScheme);
   virtual nsresult SetUserPass(const nsACString &aUserPass);
   virtual nsresult SetUsername(const nsACString &aUsername);
@@ -62,52 +65,46 @@ protected:
   virtual nsresult SetRef(const nsACString &aRef);
   virtual nsresult SetFilePath(const nsACString &aFilePath);
   virtual nsresult SetQuery(const nsACString &aQuery);
-  virtual nsresult SetQueryWithEncoding(const nsACString &aQuery, const mozilla::Encoding* aEncoding);
+  virtual nsresult SetQueryWithEncoding(const nsACString &aQuery,
+                                        const mozilla::Encoding *aEncoding);
+  virtual nsresult CreateURL(const nsACString &aSpec,
+                             nsIURL **aURL);  // nsMailboxUrl overrides this.
 
-public:
-  class Mutator
-      : public nsIURIMutator
-      , public BaseURIMutator<nsMsgMailNewsUrl>
-  {
+ public:
+  class Mutator : public nsIURIMutator,
+                  public BaseURIMutator<nsMsgMailNewsUrl> {
     NS_DECL_ISUPPORTS
     NS_FORWARD_SAFE_NSIURISETTERS_RET(mURI)
 
-    NS_IMETHOD Deserialize(const mozilla::ipc::URIParams& aParams) override
-    {
+    NS_IMETHOD Deserialize(const mozilla::ipc::URIParams &aParams) override {
       return NS_ERROR_NOT_IMPLEMENTED;
     }
 
-    NS_IMETHOD Read(nsIObjectInputStream* aStream) override
-    {
-      return NS_ERROR_NOT_IMPLEMENTED;
-    }
-
-    NS_IMETHOD Finalize(nsIURI** aURI) override
-    {
+    NS_IMETHOD Finalize(nsIURI **aURI) override {
       mURI.forget(aURI);
       return NS_OK;
     }
 
-    NS_IMETHOD SetSpec(const nsACString & aSpec, nsIURIMutator** aMutator) override
-    {
-      if (aMutator)
-        NS_ADDREF(*aMutator = this);
+    NS_IMETHOD SetSpec(const nsACString &aSpec,
+                       nsIURIMutator **aMutator) override {
+      if (aMutator) NS_ADDREF(*aMutator = this);
       return InitFromSpec(aSpec);
     }
 
-    explicit Mutator() { }
-  private:
-    virtual ~Mutator() { }
+    explicit Mutator() {}
+
+   private:
+    virtual ~Mutator() {}
 
     friend class nsMsgMailNewsUrl;
   };
   friend BaseURIMutator<nsMsgMailNewsUrl>;
 
-protected:
+ protected:
   virtual ~nsMsgMailNewsUrl();
 
   nsCOMPtr<nsIURL> m_baseURL;
-  nsCOMPtr<nsIPrincipal> m_principal;
+  nsCOMPtr<nsIURI> m_normalizedOrigin;
   nsWeakPtr m_statusFeedbackWeak;
   nsWeakPtr m_msgWindowWeak;
   nsWeakPtr m_loadGroupWeak;
@@ -115,26 +112,26 @@ protected:
   nsCOMPtr<nsIMsgSearchSession> m_searchSession;
   nsCOMPtr<nsICacheEntry> m_memCacheEntry;
   nsCOMPtr<nsIMsgHeaderSink> mMsgHeaderSink;
-  char *m_errorMessage;
+  nsCString m_errorCode;
+  nsString m_errorMessage;
+  nsString m_errorParameters;
   int64_t mMaxProgress;
   bool m_runningUrl;
   bool m_updatingFolder;
   bool m_msgIsInLocalCache;
   bool m_suppressErrorMsgs;
-  bool m_isPrincipalURL;
+  bool m_hasNormalizedOrigin;
 
   // the following field is really a bit of a hack to make
-  // open attachments work. The external applications code sometimes tries to figure out the right
-  // handler to use by looking at the file extension of the url we are trying to load. Unfortunately,
-  // the attachment file name really isn't part of the url string....so we'll store it here...and if
-  // the url we are running is an attachment url, we'll set it here. Then when the helper apps code
-  // asks us for it, we'll return the right value.
+  // open attachments work. The external applications code sometimes tries to
+  // figure out the right handler to use by looking at the file extension of the
+  // url we are trying to load. Unfortunately, the attachment file name really
+  // isn't part of the url string....so we'll store it here...and if the url we
+  // are running is an attachment url, we'll set it here. Then when the helper
+  // apps code asks us for it, we'll return the right value.
   nsCString mAttachmentFileName;
 
   nsTObserverArray<nsCOMPtr<nsIUrlListener> > mUrlListeners;
 };
 
-#undef  IMETHOD_VISIBILITY
-#define IMETHOD_VISIBILITY NS_VISIBILITY_HIDDEN
-
 #endif /* nsMsgMailNewsUrl_h___ */
