@@ -3,12 +3,13 @@
  * Most of this test was copied from test_messageHeaders.js.
  */
 
-ChromeUtils.import("resource://gre/modules/Services.jsm");
-ChromeUtils.import("resource:///modules/mailServices.js");
-ChromeUtils.import("resource:///modules/mimeParser.jsm");
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+const { MimeParser } = ChromeUtils.import("resource:///modules/mimeParser.jsm");
 
-var CompFields = CC("@mozilla.org/messengercompose/composefields;1",
-                    Ci.nsIMsgCompFields);
+var CompFields = CC(
+  "@mozilla.org/messengercompose/composefields;1",
+  Ci.nsIMsgCompFields
+);
 
 // Copied from jsmime.js.
 function stringToTypedArray(buffer) {
@@ -19,9 +20,15 @@ function stringToTypedArray(buffer) {
   return typedarray;
 }
 
-function checkDraftHeadersAndBody(expectedHeaders, expectedBody, charset = "UTF-8") {
-  let msgData = mailTestUtils
-    .loadMessageToString(gDraftFolder, mailTestUtils.firstMsgHdr(gDraftFolder));
+function checkDraftHeadersAndBody(
+  expectedHeaders,
+  expectedBody,
+  charset = "UTF-8"
+) {
+  let msgData = mailTestUtils.loadMessageToString(
+    gDraftFolder,
+    mailTestUtils.firstMsgHdr(gDraftFolder)
+  );
   checkMessageHeaders(msgData, expectedHeaders);
 
   // Get the message body, decode from base64 and check.
@@ -29,18 +36,22 @@ function checkDraftHeadersAndBody(expectedHeaders, expectedBody, charset = "UTF-
   let body = msgData.slice(endOfHeaders + 4);
   let endOfBody = body.indexOf("\r\n\r\n");
 
-  if (endOfBody > 0)
+  if (endOfBody > 0) {
     body = body.slice(0, endOfBody);
-  else
+  } else {
     body = body.slice(0, body.length);
+  }
 
   // Remove line breaks and decode from base64 if required.
-  if (expectedHeaders["Content-Transfer-Encoding"] == "base64")
+  if (expectedHeaders["Content-Transfer-Encoding"] == "base64") {
     body = atob(body.replace(/\r\n/g, ""));
+  }
 
   if (charset == "UTF-8") {
-    let expectedBinary = String.fromCharCode.apply(undefined,
-      new TextEncoder("UTF-8").encode(expectedBody));
+    let expectedBinary = String.fromCharCode.apply(
+      undefined,
+      new TextEncoder("UTF-8").encode(expectedBody)
+    );
     Assert.equal(body, expectedBinary);
   } else {
     let strView = stringToTypedArray(body);
@@ -52,24 +63,29 @@ function checkDraftHeadersAndBody(expectedHeaders, expectedBody, charset = "UTF-
 function checkMessageHeaders(msgData, expectedHeaders, partNum = "") {
   let seen = false;
   let handler = {
-    startPart: function (part, headers) {
-      if (part != partNum)
+    startPart(part, headers) {
+      if (part != partNum) {
         return;
+      }
       seen = true;
       for (let header in expectedHeaders) {
         let expected = expectedHeaders[header];
-        if (expected === undefined)
+        if (expected === undefined) {
           Assert.ok(!headers.has(header));
-        else {
+        } else {
           let value = headers.getRawHeader(header);
           Assert.equal(value.length, 1);
           value[0] = value[0].replace(/boundary=[^;]*(;|$)/, "boundary=.");
           Assert.equal(value[0], expected);
         }
       }
-    }
+    },
   };
-  MimeParser.parseSync(msgData, handler, {onerror: function (e) { throw e; }});
+  MimeParser.parseSync(msgData, handler, {
+    onerror(e) {
+      throw e;
+    },
+  });
   Assert.ok(seen);
 }
 
@@ -84,7 +100,7 @@ let longMultibyteLineCJK = "안".repeat(400);
 // And some Japanese.
 let longMultibyteLineJapanese = "語".repeat(450);
 
-function* testBodyWithLongLine() {
+async function testBodyWithLongLine() {
   let newline;
   // Windows uses CR+LF, the other platforms just LF.
   // Note: Services.appinfo.OS returns "XPCShell" in the test, so we
@@ -96,23 +112,28 @@ function* testBodyWithLongLine() {
   }
 
   let fields = new CompFields();
-  let identity = getSmtpIdentity("from@tinderbox.invalid",
-    getBasicSmtpServer());
+  let identity = getSmtpIdentity(
+    "from@tinderbox.invalid",
+    getBasicSmtpServer()
+  );
   identity.fullName = "Me";
   identity.organization = "World Destruction Committee";
   fields.from = "Nobody <nobody@tinderbox.invalid>";
   fields.to = "Nobody <nobody@tinderbox.invalid>";
   fields.subject = "Message with 1200 byte line in body";
   fields.characterSet = "UTF-8";
-  let htmlMessage = "<html><head>" +
-    "<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\">" +
-    "</head><body>" + longMultibyteLine + "</body></html>";
+  let htmlMessage =
+    "<html><head>" +
+    '<meta http-equiv="content-type" content="text/html; charset=utf-8">' +
+    "</head><body>" +
+    longMultibyteLine +
+    "</body></html>\r\n";
   fields.body = htmlMessage;
-  yield richCreateMessage(fields, [], identity);
+  await richCreateMessage(fields, [], identity);
   checkDraftHeadersAndBody(
     {
       "Content-Type": "text/html; charset=UTF-8",
-      "Content-Transfer-Encoding": "base64"
+      "Content-Transfer-Encoding": "base64",
     },
     htmlMessage
   );
@@ -121,26 +142,29 @@ function* testBodyWithLongLine() {
   fields.body = htmlMessage;
   fields.forcePlainText = true;
   fields.useMultipartAlternative = false;
-  yield richCreateMessage(fields, [], identity);
+  await richCreateMessage(fields, [], identity);
   checkDraftHeadersAndBody(
     {
       "Content-Type": "text/plain; charset=UTF-8; format=flowed",
-      "Content-Transfer-Encoding": "base64"
+      "Content-Transfer-Encoding": "base64",
     },
-    longMultibyteLine + newline // Expected body: The message without the tags.
+    longMultibyteLine + " " + newline + newline // Expected body: The message without the tags.
   );
 
   // Now CJK.
   fields.forcePlainText = false;
-  htmlMessage = "<html><head>" +
-    "<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\">" +
-    "</head><body>" + longMultibyteLineCJK + "</body></html>";
+  htmlMessage =
+    "<html><head>" +
+    '<meta http-equiv="content-type" content="text/html; charset=utf-8">' +
+    "</head><body>" +
+    longMultibyteLineCJK +
+    "</body></html>\r\n";
   fields.body = htmlMessage;
-  yield richCreateMessage(fields, [], identity);
+  await richCreateMessage(fields, [], identity);
   checkDraftHeadersAndBody(
     {
       "Content-Type": "text/html; charset=UTF-8",
-      "Content-Transfer-Encoding": "base64"
+      "Content-Transfer-Encoding": "base64",
     },
     htmlMessage
   );
@@ -149,28 +173,31 @@ function* testBodyWithLongLine() {
   fields.body = htmlMessage;
   fields.forcePlainText = true;
   fields.useMultipartAlternative = false;
-  yield richCreateMessage(fields, [], identity);
+  await richCreateMessage(fields, [], identity);
   checkDraftHeadersAndBody(
     {
       "Content-Type": "text/plain; charset=UTF-8; format=flowed",
-      "Content-Transfer-Encoding": "base64"
+      "Content-Transfer-Encoding": "base64",
     },
-    longMultibyteLineCJK + newline // Expected body: The message without the tags.
+    longMultibyteLineCJK + " " + newline + newline // Expected body: The message without the tags.
   );
 
   // Now a special test for ISO-2022-JP.
   fields.characterSet = "ISO-2022-JP";
 
   fields.forcePlainText = false;
-  htmlMessage = "<html><head>" +
-    "<meta http-equiv=\"content-type\" content=\"text/html; charset=ISO-2022-JP\">" +
-    "</head><body>" + longMultibyteLineJapanese + "</body></html>";
+  htmlMessage =
+    "<html><head>" +
+    '<meta http-equiv="content-type" content="text/html; charset=ISO-2022-JP">' +
+    "</head><body>" +
+    longMultibyteLineJapanese +
+    "</body></html>\r\n";
   fields.body = htmlMessage;
-  yield richCreateMessage(fields, [], identity);
+  await richCreateMessage(fields, [], identity);
   checkDraftHeadersAndBody(
     {
       "Content-Type": "text/html; charset=ISO-2022-JP",
-      "Content-Transfer-Encoding": "base64"
+      "Content-Transfer-Encoding": "base64",
     },
     htmlMessage,
     "ISO-2022-JP"
@@ -180,22 +207,24 @@ function* testBodyWithLongLine() {
   fields.body = htmlMessage;
   fields.forcePlainText = true;
   fields.useMultipartAlternative = false;
-  yield richCreateMessage(fields, [], identity);
+  await richCreateMessage(fields, [], identity);
 
   // Expected body: The message without the tags and chopped up in
   // chunks of 36 characters with a space appended to each line.
   let expectedBody = "";
   let lastIndex = 0;
   for (let i = 0; i + 36 < longMultibyteLineJapanese.length; i = i + 36) {
-    expectedBody = expectedBody + longMultibyteLineJapanese.substr(i, 36) + " \r\n";
+    expectedBody =
+      expectedBody + longMultibyteLineJapanese.substr(i, 36) + " \r\n";
     lastIndex = i + 36;
   }
   expectedBody += longMultibyteLineJapanese.substr(lastIndex) + "\r\n";
 
   checkDraftHeadersAndBody(
     {
-      "Content-Type": "text/plain; charset=ISO-2022-JP; format=flowed; delsp=yes",
-      "Content-Transfer-Encoding": "7bit"
+      "Content-Type":
+        "text/plain; charset=ISO-2022-JP; format=flowed; delsp=yes",
+      "Content-Transfer-Encoding": "7bit",
     },
     expectedBody,
     "ISO-2022-JP"
@@ -205,20 +234,18 @@ function* testBodyWithLongLine() {
   fields.body = htmlMessage;
   Services.prefs.setBoolPref("mailnews.send_plaintext_flowed", false);
 
-  yield richCreateMessage(fields, [], identity);
+  await richCreateMessage(fields, [], identity);
   checkDraftHeadersAndBody(
     {
       "Content-Type": "text/plain; charset=ISO-2022-JP",
-      "Content-Transfer-Encoding": "7bit"
+      "Content-Transfer-Encoding": "7bit",
     },
     expectedBody.replace(/ /g, ""), // No spaces expected this time.
     "ISO-2022-JP"
   );
 }
 
-var tests = [
-  testBodyWithLongLine,
-]
+var tests = [testBodyWithLongLine];
 
 function run_test() {
   // Ensure we have at least one mail account
