@@ -3,8 +3,8 @@
  * Test suite for checking correctly saved as draft with unread.
  */
 
-add_task(function* checkDraft() {
-  yield createMessage();
+add_task(async function checkDraft() {
+  await createMessage();
   Assert.equal(gDraftFolder.getTotalMessages(false), 1);
   Assert.equal(gDraftFolder.getNumUnread(false), 1);
 });
@@ -13,4 +13,3 @@ function run_test() {
   localAccountUtils.loadLocalMailAccount();
   run_next_test();
 }
-
