@@ -2,9 +2,9 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-this.EXPORTED_SYMBOLS = ['GlodaCollection', 'GlodaCollectionManager'];
+this.EXPORTED_SYMBOLS = ["GlodaCollection", "GlodaCollectionManager"];
 
-ChromeUtils.import("resource:///modules/gloda/log4moz.js");
+const { Log4Moz } = ChromeUtils.import("resource:///modules/gloda/log4moz.js");
 
 var LOG = Log4Moz.repository.getLogger("gloda.collection");
 
@@ -31,23 +31,23 @@ var GlodaCollectionManager = {
    *  is done using a weak reference so that the collection can go away if it
    *  wants to.
    */
-  registerCollection: function gloda_colm_registerCollection(aCollection) {
+  registerCollection(aCollection) {
     let collections;
     let nounID = aCollection.query._nounDef.id;
-    if (!(nounID in this._collectionsByNoun))
+    if (!(nounID in this._collectionsByNoun)) {
       collections = this._collectionsByNoun[nounID] = [];
-    else {
+    } else {
       // purge dead weak references while we're at it
-      collections = this._collectionsByNoun[nounID].filter(function (aRef) {
-        return aRef.get(); });
+      collections = this._collectionsByNoun[nounID].filter(aRef => aRef.get());
       this._collectionsByNoun[nounID] = collections;
     }
     collections.push(Cu.getWeakReference(aCollection));
   },
 
-  getCollectionsForNounID: function gloda_colm_getCollectionsForNounID(aNounID){
-    if (!(aNounID in this._collectionsByNoun))
+  getCollectionsForNounID(aNounID) {
+    if (!(aNounID in this._collectionsByNoun)) {
       return [];
+    }
 
     // generator would be nice, but I suspect get() is too expensive to use
     //  twice (guard/predicate and value)
@@ -55,15 +55,18 @@ var GlodaCollectionManager = {
     let collections = [];
     for (let iColl = 0; iColl < weakCollections.length; iColl++) {
       let collection = weakCollections[iColl].get();
-      if (collection)
+      if (collection) {
         collections.push(collection);
+      }
     }
     return collections;
   },
 
-  defineCache: function gloda_colm_defineCache(aNounDef, aCacheSize) {
-    this._cachesByNoun[aNounDef.id] = new GlodaLRUCacheCollection(aNounDef,
-                                                                   aCacheSize);
+  defineCache(aNounDef, aCacheSize) {
+    this._cachesByNoun[aNounDef.id] = new GlodaLRUCacheCollection(
+      aNounDef,
+      aCacheSize
+    );
   },
 
   /**
@@ -71,7 +74,7 @@ var GlodaCollectionManager = {
    *  given id.  Counts as a cache hit if found.  (And if it wasn't in a cache,
    *  but rather a collection, it is added to the cache.)
    */
-  cacheLookupOne: function gloda_colm_cacheLookupOne(aNounID, aID, aDoCache) {
+  cacheLookupOne(aNounID, aID, aDoCache) {
     let cache = this._cachesByNoun[aNounID];
 
     if (cache) {
@@ -81,14 +84,16 @@ var GlodaCollectionManager = {
       }
     }
 
-    if (aDoCache === false)
+    if (aDoCache === false) {
       cache = null;
+    }
 
     for (let collection of this.getCollectionsForNounID(aNounID)) {
       if (aID in collection._idMap) {
         let item = collection._idMap[aID];
-        if (cache)
+        if (cache) {
           cache.add([item]);
+        }
         return item;
       }
     }
@@ -114,9 +119,10 @@ var GlodaCollectionManager = {
    *          a dictionary whose keys are the ids of noun instances that
    *          were not found.]
    */
-  cacheLookupMany: function gloda_colm_cacheLookupMany(aNounID, aIDMap,
-      aTargetMap, aDoCache) {
-    let foundCount = 0, notFoundCount = 0, notFound = {};
+  cacheLookupMany(aNounID, aIDMap, aTargetMap, aDoCache) {
+    let foundCount = 0,
+      notFoundCount = 0,
+      notFound = {};
 
     let cache = this._cachesByNoun[aNounID];
 
@@ -126,8 +132,7 @@ var GlodaCollectionManager = {
         if (cacheValue === undefined) {
           notFoundCount++;
           notFound[key] = null;
-        }
-        else {
+        } else {
           foundCount++;
           aTargetMap[key] = cacheValue;
           cache.hit(cacheValue);
@@ -135,8 +140,9 @@ var GlodaCollectionManager = {
       }
     }
 
-    if (aDoCache === false)
+    if (aDoCache === false) {
       cache = null;
+    }
 
     for (let collection of this.getCollectionsForNounID(aNounID)) {
       for (let key in notFound) {
@@ -146,8 +152,9 @@ var GlodaCollectionManager = {
           delete notFound[key];
           foundCount++;
           notFoundCount--;
-          if (cache)
+          if (cache) {
             cache.add([collValue]);
+          }
         }
       }
     }
@@ -162,8 +169,9 @@ var GlodaCollectionManager = {
    *  assumption is this is being used for in-memory updates where we only need
    *  to tweak what is in memory.
    */
-  cacheLookupManyList: function gloda_colm_cacheLookupManyList(aNounID, aIds) {
-    let checkMap = {}, targetMap = {};
+  cacheLookupManyList(aNounID, aIds) {
+    let checkMap = {},
+      targetMap = {};
     for (let id of aIds) {
       checkMap[id] = null;
     }
@@ -177,9 +185,7 @@ var GlodaCollectionManager = {
    *  given id.  Counts as a cache hit if found.  (And if it wasn't in a cache,
    *  but rather a collection, it is added to the cache.)
    */
-  cacheLookupOneByUniqueValue:
-      function gloda_colm_cacheLookupOneByUniqueValue(aNounID, aUniqueValue,
-                                                      aDoCache) {
+  cacheLookupOneByUniqueValue(aNounID, aUniqueValue, aDoCache) {
     let cache = this._cachesByNoun[aNounID];
 
     if (cache) {
@@ -189,14 +195,16 @@ var GlodaCollectionManager = {
       }
     }
 
-    if (aDoCache === false)
+    if (aDoCache === false) {
       cache = null;
+    }
 
     for (let collection of this.getCollectionsForNounID(aNounID)) {
       if (aUniqueValue in collection._uniqueValueMap) {
         let item = collection._uniqueValueMap[aUniqueValue];
-        if (cache)
+        if (cache) {
           cache.add([item]);
+        }
         return item;
       }
     }
@@ -210,7 +218,7 @@ var GlodaCollectionManager = {
    *  the pre-existing instance is returned and counts as a cache hit.  If it
    *  is not, the passed-in instance is added to the cache and returned.
    */
-  cacheLoadUnifyOne: function gloda_colm_cacheLoadUnifyOne(aItem) {
+  cacheLoadUnifyOne(aItem) {
     let items = [aItem];
     this.cacheLoadUnify(aItem.NOUN_ID, items);
     return items[0];
@@ -223,11 +231,11 @@ var GlodaCollectionManager = {
    *  counts as a cache hit.  Items without pre-existing instances are added
    *  to the cache and left intact.
    */
-  cacheLoadUnify: function gloda_colm_cacheLoadUnify(aNounID, aItems,
-      aCacheIfMissing) {
+  cacheLoadUnify(aNounID, aItems, aCacheIfMissing) {
     let cache = this._cachesByNoun[aNounID];
-    if (aCacheIfMissing === undefined)
+    if (aCacheIfMissing === undefined) {
       aCacheIfMissing = true;
+    }
 
     // track the items we haven't yet found in a cache/collection (value) and
     //  their index in aItems (key).  We're somewhat abusing the dictionary
@@ -247,18 +255,17 @@ var GlodaCollectionManager = {
           // update the caller's array with the reference to the 'real' item
           aItems[iItem] = realItem;
           cache.hit(realItem);
-        }
-        else {
+        } else {
           unresolvedIndexToItem[iItem] = item;
           numUnresolved++;
         }
       }
 
       // we're done if everyone was a hit.
-      if (numUnresolved == 0)
+      if (numUnresolved == 0) {
         return;
-    }
-    else {
+      }
+    } else {
       for (let iItem = 0; iItem < aItems.length; iItem++) {
         unresolvedIndexToItem[iItem] = aItems[iItem];
       }
@@ -278,8 +285,9 @@ var GlodaCollectionManager = {
           // we no longer need to resolve this item...
           delete unresolvedIndexToItem[iItem];
           // stop checking collections if we got everybody
-          if (--numUnresolved == 0)
+          if (--numUnresolved == 0) {
             break;
+          }
         }
       }
     }
@@ -287,14 +295,17 @@ var GlodaCollectionManager = {
     // anything left in unresolvedIndexToItem should be added to the cache
     //  unless !aCacheIfMissing.  plus, we already have 'needToCache'
     if (cache && aCacheIfMissing) {
-      cache.add(needToCache.concat(Object.keys(unresolvedIndexToItem).
-                                   map(key => unresolvedIndexToItem[key])));
+      cache.add(
+        needToCache.concat(
+          Object.keys(unresolvedIndexToItem).map(
+            key => unresolvedIndexToItem[key]
+          )
+        )
+      );
     }
-
-    return aItems;
   },
 
-  cacheCommitDirty: function glod_colm_cacheCommitDirty() {
+  cacheCommitDirty() {
     for (let id in this._cachesByNoun) {
       let cache = this._cachesByNoun[id];
       cache.commitDirty();
@@ -305,7 +316,7 @@ var GlodaCollectionManager = {
    * Notifies the collection manager that an item has been loaded and should
    *  be cached, assuming caching is active.
    */
-  itemLoaded: function gloda_colm_itemsLoaded(aItem) {
+  itemLoaded(aItem) {
     let cache = this._cachesByNoun[aItem.NOUN_ID];
     if (cache) {
       cache.add([aItem]);
@@ -316,7 +327,7 @@ var GlodaCollectionManager = {
    * Notifies the collection manager that multiple items has been loaded and
    *  should be cached, assuming caching is active.
    */
-  itemsLoaded: function gloda_colm_itemsLoaded(aNounID, aItems) {
+  itemsLoaded(aNounID, aItems) {
     let cache = this._cachesByNoun[aNounID];
     if (cache) {
       cache.add(aItems);
@@ -330,7 +341,7 @@ var GlodaCollectionManager = {
    * We walk all existing collections for the given noun type and add the items
    *  to the collection if the item meets the query that defines the collection.
    */
-  itemsAdded: function gloda_colm_itemsAdded(aNounID, aItems) {
+  itemsAdded(aNounID, aItems) {
     let cache = this._cachesByNoun[aNounID];
     if (cache) {
       cache.add(aItems);
@@ -338,8 +349,9 @@ var GlodaCollectionManager = {
 
     for (let collection of this.getCollectionsForNounID(aNounID)) {
       let addItems = aItems.filter(item => collection.query.test(item));
-      if (addItems.length)
+      if (addItems.length) {
         collection._onItemsAdded(addItems);
+      }
     }
   },
   /**
@@ -353,30 +365,37 @@ var GlodaCollectionManager = {
    *  onItemsAdded events.  For items included that still match the query, we
    *  generate onItemsModified events.
    */
-  itemsModified: function gloda_colm_itemsModified(aNounID, aItems) {
+  itemsModified(aNounID, aItems) {
     for (let collection of this.getCollectionsForNounID(aNounID)) {
-      let added = [], modified = [], removed = [];
+      let added = [],
+        modified = [],
+        removed = [];
       for (let item of aItems) {
         if (item.id in collection._idMap) {
           // currently in... but should it still be there?
-          if (collection.query.test(item))
+          if (collection.query.test(item)) {
             modified.push(item); // yes, keep it
-          // oy, so null queries really don't want any notifications, and they
-          //  sorta fit into our existing model, except for the removal bit.
-          //  so we need a specialized check for them, and we're using the
-          //  frozen attribute to this end.
-          else if (!collection.query.frozen)
+          } else if (!collection.query.frozen) {
+            // oy, so null queries really don't want any notifications, and they
+            //  sorta fit into our existing model, except for the removal bit.
+            //  so we need a specialized check for them, and we're using the
+            //  frozen attribute to this end.
             removed.push(item); // no, bin it
-        }
-        else if (collection.query.test(item)) // not in, should it be?
+          }
+        } else if (collection.query.test(item)) {
+          // not in, should it be?
           added.push(item); // yep, add it
+        }
       }
-      if (added.length)
+      if (added.length) {
         collection._onItemsAdded(added);
-      if (modified.length)
+      }
+      if (modified.length) {
         collection._onItemsModified(modified);
-      if (removed.length)
+      }
+      if (removed.length) {
         collection._onItemsRemoved(removed);
+      }
     }
   },
   /**
@@ -390,22 +409,25 @@ var GlodaCollectionManager = {
    *
    * @param aItemIds A list of item ids that are being deleted.
    */
-  itemsDeleted: function gloda_colm_itemsDeleted(aNounID, aItemIds) {
+  itemsDeleted(aNounID, aItemIds) {
     // cache
     let cache = this._cachesByNoun[aNounID];
     if (cache) {
       for (let itemId of aItemIds) {
-        if (itemId in cache._idMap)
+        if (itemId in cache._idMap) {
           cache.deleted(cache._idMap[itemId]);
+        }
       }
     }
 
     // collections
     for (let collection of this.getCollectionsForNounID(aNounID)) {
-      let removeItems = aItemIds.filter(itemId => itemId in collection._idMap).
-        map(itemId => collection._idMap[itemId]);
-      if (removeItems.length)
+      let removeItems = aItemIds
+        .filter(itemId => itemId in collection._idMap)
+        .map(itemId => collection._idMap[itemId]);
+      if (removeItems.length) {
         collection._onItemsRemoved(removeItems);
+      }
     }
   },
   /**
@@ -425,23 +447,24 @@ var GlodaCollectionManager = {
    *     thought of as deleted, or false if the item is still good.  Screw this
    *     up and you will get some seriously wacky bugs, yo.
    */
-  itemsDeletedByAttribute: function gloda_colm_itemsDeletedByAttribute(
-      aNounID, aFilter) {
+  itemsDeletedByAttribute(aNounID, aFilter) {
     // cache
     let cache = this._cachesByNoun[aNounID];
     if (cache) {
       for (let id in cache._idMap) {
         let item = cache._idMap[id];
-        if (aFilter(item))
+        if (aFilter(item)) {
           cache.deleted(item);
+        }
       }
     }
 
     // collections
     for (let collection of this.getCollectionsForNounID(aNounID)) {
       let removeItems = collection.items.filter(aFilter);
-      if (removeItems.length)
+      if (removeItems.length) {
         collection._onItemsRemoved(removeItems);
+      }
     }
   },
 };
@@ -455,16 +478,23 @@ var GlodaCollectionManager = {
  *  because it is exposing those attributes).
  * @constructor
  */
-function GlodaCollection(aNounDef, aItems, aQuery, aListener,
-      aMasterCollection) {
+function GlodaCollection(
+  aNounDef,
+  aItems,
+  aQuery,
+  aListener,
+  aMasterCollection
+) {
   // if aNounDef is null, we are just being invoked for subclassing
-  if (aNounDef === undefined)
+  if (aNounDef === undefined) {
     return;
+  }
 
   this._nounDef = aNounDef;
   // should we also maintain a unique value mapping...
-  if (this._nounDef.usesUniqueValue)
+  if (this._nounDef.usesUniqueValue) {
     this._uniqueValueMap = {};
+  }
 
   this.pendingItems = [];
   this._pendingIdMap = {};
@@ -474,14 +504,16 @@ function GlodaCollection(aNounDef, aItems, aQuery, aListener,
   // force the listener to null for our call to _onItemsAdded; no events for
   //  the initial load-out.
   this._listener = null;
-  if (aItems && aItems.length)
+  if (aItems && aItems.length) {
     this._onItemsAdded(aItems);
+  }
 
   this.query = aQuery || null;
   if (this.query) {
     this.query.collection = this;
-    if (this.query.options.stashColumns)
+    if (this.query.options.stashColumns) {
       this.stashedColumns = {};
+    }
   }
   this._listener = aListener || null;
 
@@ -490,8 +522,7 @@ function GlodaCollection(aNounDef, aItems, aQuery, aListener,
 
   if (aMasterCollection) {
     this.masterCollection = aMasterCollection.masterCollection;
-  }
-  else {
+  } else {
     this.masterCollection = this;
     /** a dictionary of dictionaries. at the top level, the keys are noun IDs.
      * each of these sub-dictionaries maps the IDs of desired noun instances to
@@ -514,8 +545,12 @@ function GlodaCollection(aNounDef, aItems, aQuery, aListener,
 }
 
 GlodaCollection.prototype = {
-  get listener() { return this._listener; },
-  set listener(aListener) { this._listener = aListener; },
+  get listener() {
+    return this._listener;
+  },
+  set listener(aListener) {
+    this._listener = aListener;
+  },
 
   /**
    * If this collection still has a query associated with it, drop the query
@@ -527,7 +562,7 @@ GlodaCollection.prototype = {
    *  initial database query.  It will, however, receive onItemsModified
    *  notifications if items in the collection are re-indexed.
    */
-  becomeExplicit: function gloda_coll_becomeExplicit() {
+  becomeExplicit() {
     if (!(this.query instanceof this._nounDef.explicitQueryClass)) {
       this.query = new this._nounDef.explicitQueryClass(this);
     }
@@ -539,22 +574,22 @@ GlodaCollection.prototype = {
    *  should represent the state of the query, so unless we're going to delete
    *  all the items, clearing the collection would violate that constraint.)
    */
-  clear: function gloda_coll_clear() {
+  clear() {
     this._idMap = {};
-    if (this._uniqueValueMap)
+    if (this._uniqueValueMap) {
       this._uniqueValueMap = {};
+    }
     this.items = [];
   },
 
-  _onItemsAdded: function gloda_coll_onItemsAdded(aItems) {
+  _onItemsAdded(aItems) {
     this.items.push.apply(this.items, aItems);
     if (this._uniqueValueMap) {
       for (let item of this.items) {
         this._idMap[item.id] = item;
         this._uniqueValueMap[item.uniqueValue] = item;
       }
-    }
-    else {
+    } else {
       for (let item of this.items) {
         this._idMap[item.id] = item;
       }
@@ -562,22 +597,32 @@ GlodaCollection.prototype = {
     if (this._listener) {
       try {
         this._listener.onItemsAdded(aItems, this);
-      }
-      catch (ex) {
-        LOG.error("caught exception from listener in onItemsAdded: " +
-            ex.fileName + ":" + ex.lineNumber + ": " + ex);
+      } catch (ex) {
+        LOG.error(
+          "caught exception from listener in onItemsAdded: " +
+            ex.fileName +
+            ":" +
+            ex.lineNumber +
+            ": " +
+            ex
+        );
       }
     }
   },
 
-  _onItemsModified: function gloda_coll_onItemsModified(aItems) {
+  _onItemsModified(aItems) {
     if (this._listener) {
       try {
         this._listener.onItemsModified(aItems, this);
-      }
-      catch (ex) {
-        LOG.error("caught exception from listener in onItemsModified: " +
-            ex.fileName + ":" + ex.lineNumber + ": " + ex);
+      } catch (ex) {
+        LOG.error(
+          "caught exception from listener in onItemsModified: " +
+            ex.fileName +
+            ":" +
+            ex.lineNumber +
+            ": " +
+            ex
+        );
       }
     }
   },
@@ -587,7 +632,7 @@ GlodaCollection.prototype = {
    *  remove them from the collection and notify the listener.  The 'tricky'
    *  part is that we need to remove the deleted items from our list of items.
    */
-  _onItemsRemoved: function gloda_coll_onItemsRemoved(aItems) {
+  _onItemsRemoved(aItems) {
     // we want to avoid the O(n^2) deletion performance case, and deletion
     //  should be rare enough that the extra cost of building the deletion map
     //  should never be a real problem.
@@ -596,35 +641,43 @@ GlodaCollection.prototype = {
     for (let item of aItems) {
       deleteMap[item.id] = true;
       delete this._idMap[item.id];
-      if (this._uniqueValueMap)
+      if (this._uniqueValueMap) {
         delete this._uniqueValueMap[item.uniqueValue];
+      }
     }
     let items = this.items;
     // in-place filter.  probably needless optimization.
-    let iWrite=0;
+    let iWrite = 0;
     for (let iRead = 0; iRead < items.length; iRead++) {
       let item = items[iRead];
-      if (!(item.id in deleteMap))
+      if (!(item.id in deleteMap)) {
         items[iWrite++] = item;
+      }
     }
     items.splice(iWrite);
 
     if (this._listener) {
       try {
         this._listener.onItemsRemoved(aItems, this);
-      }
-      catch (ex) {
-        LOG.error("caught exception from listener in onItemsRemoved: " +
-            ex.fileName + ":" + ex.lineNumber + ": " + ex);
+      } catch (ex) {
+        LOG.error(
+          "caught exception from listener in onItemsRemoved: " +
+            ex.fileName +
+            ":" +
+            ex.lineNumber +
+            ": " +
+            ex
+        );
       }
     }
   },
 
-  _onQueryCompleted: function gloda_coll_onQueryCompleted() {
+  _onQueryCompleted() {
     this.query.completed = true;
-    if (this._listener && this._listener.onQueryCompleted)
+    if (this._listener && this._listener.onQueryCompleted) {
       this._listener.onQueryCompleted(this);
-  }
+    }
+  },
 };
 
 /**
@@ -638,8 +691,9 @@ function GlodaLRUCacheCollection(aNounDef, aCacheSize) {
   this._tail = null; // aka newest!
   this._size = 0;
   // let's keep things sane, and simplify our logic a little...
-  if (aCacheSize < 32)
+  if (aCacheSize < 32) {
     aCacheSize = 32;
+  }
   this._maxCacheSize = aCacheSize;
 }
 /**
@@ -649,8 +703,8 @@ function GlodaLRUCacheCollection(aNounDef, aCacheSize) {
  *  cached objects.
  * @augments GlodaCollection
  */
-GlodaLRUCacheCollection.prototype = new GlodaCollection;
-GlodaLRUCacheCollection.prototype.add = function cache_add(aItems) {
+GlodaLRUCacheCollection.prototype = new GlodaCollection();
+GlodaLRUCacheCollection.prototype.add = function(aItems) {
   for (let item of aItems) {
     if (item.id in this._idMap) {
       // DEBUGME so, we're dealing with this, but it shouldn't happen.  need
@@ -658,16 +712,18 @@ GlodaLRUCacheCollection.prototype.add = function cache_add(aItems) {
       continue;
     }
     this._idMap[item.id] = item;
-    if (this._uniqueValueMap)
+    if (this._uniqueValueMap) {
       this._uniqueValueMap[item.uniqueValue] = item;
+    }
 
     item._lruPrev = this._tail;
     // we do have to make sure that we will set _head the first time we insert
     //  something
-    if (this._tail !== null)
+    if (this._tail !== null) {
       this._tail._lruNext = item;
-    else
+    } else {
       this._head = item;
+    }
     item._lruNext = null;
     this._tail = item;
 
@@ -687,8 +743,9 @@ GlodaLRUCacheCollection.prototype.add = function cache_add(aItems) {
 
     // nuke from our id map
     delete this._idMap[item.id];
-    if (this._uniqueValueMap)
+    if (this._uniqueValueMap) {
       delete this._uniqueValueMap[item.uniqueValue];
+    }
 
     // flush dirty items to disk (they may not have this attribute, in which
     //  case, this returns false, which is fine.)
@@ -701,17 +758,19 @@ GlodaLRUCacheCollection.prototype.add = function cache_add(aItems) {
   }
 };
 
-GlodaLRUCacheCollection.prototype.hit = function cache_hit(aItem) {
+GlodaLRUCacheCollection.prototype.hit = function(aItem) {
   // don't do anything in the 0 or 1 items case, or if we're already
   //  the last item
-  if ((this._head === this._tail) || (this._tail === aItem))
+  if (this._head === this._tail || this._tail === aItem) {
     return aItem;
+  }
 
   // - unlink the item
-  if (aItem._lruPrev !== null)
+  if (aItem._lruPrev !== null) {
     aItem._lruPrev._lruNext = aItem._lruNext;
-  else
+  } else {
     this._head = aItem._lruNext;
+  }
   // (_lruNext cannot be null)
   aItem._lruNext._lruPrev = aItem._lruPrev;
   // - link it in to the end
@@ -724,16 +783,18 @@ GlodaLRUCacheCollection.prototype.hit = function cache_hit(aItem) {
   return aItem;
 };
 
-GlodaLRUCacheCollection.prototype.deleted = function cache_deleted(aItem) {
+GlodaLRUCacheCollection.prototype.deleted = function(aItem) {
   // unlink the item
-  if (aItem._lruPrev !== null)
+  if (aItem._lruPrev !== null) {
     aItem._lruPrev._lruNext = aItem._lruNext;
-  else
+  } else {
     this._head = aItem._lruNext;
-  if (aItem._lruNext !== null)
+  }
+  if (aItem._lruNext !== null) {
     aItem._lruNext._lruPrev = aItem._lruPrev;
-  else
+  } else {
     this._tail = aItem._lruPrev;
+  }
 
   // (because we are nice, we will delete the properties...)
   delete aItem._lruNext;
@@ -741,8 +802,9 @@ GlodaLRUCacheCollection.prototype.deleted = function cache_deleted(aItem) {
 
   // nuke from our id map
   delete this._idMap[aItem.id];
-  if (this._uniqueValueMap)
+  if (this._uniqueValueMap) {
     delete this._uniqueValueMap[aItem.uniqueValue];
+  }
 
   this._size--;
 };
@@ -751,10 +813,11 @@ GlodaLRUCacheCollection.prototype.deleted = function cache_deleted(aItem) {
  * If any of the cached items are dirty, commit them, and make them no longer
  *  dirty.
  */
-GlodaLRUCacheCollection.prototype.commitDirty = function cache_commitDirty() {
+GlodaLRUCacheCollection.prototype.commitDirty = function() {
   // we can only do this if there is an update method available...
-  if (!this._nounDef.objUpdate)
+  if (!this._nounDef.objUpdate) {
     return;
+  }
 
   for (let iItem in this._idMap) {
     let item = this._idMap[iItem];
