@@ -9,19 +9,19 @@
  *  read/unread, etc.
  */
 
-this.EXPORTED_SYMBOLS = ['GlodaExplicitAttr'];
+this.EXPORTED_SYMBOLS = ["GlodaExplicitAttr"];
 
-ChromeUtils.import("resource:///modules/gloda/log4moz.js");
-ChromeUtils.import("resource:///modules/StringBundle.js");
+const { Log4Moz } = ChromeUtils.import("resource:///modules/gloda/log4moz.js");
+const { StringBundle } = ChromeUtils.import(
+  "resource:///modules/StringBundle.js"
+);
 
-ChromeUtils.import("resource:///modules/gloda/utils.js");
-ChromeUtils.import("resource:///modules/gloda/gloda.js");
-ChromeUtils.import("resource:///modules/gloda/noun_tag.js");
-ChromeUtils.import("resource:///modules/mailServices.js");
-
-
-var nsMsgMessageFlags_Replied = Ci.nsMsgMessageFlags.Replied;
-var nsMsgMessageFlags_Forwarded = Ci.nsMsgMessageFlags.Forwarded;
+const { GlodaUtils } = ChromeUtils.import("resource:///modules/gloda/utils.js");
+const { Gloda } = ChromeUtils.import("resource:///modules/gloda/gloda.js");
+const { TagNoun } = ChromeUtils.import("resource:///modules/gloda/noun_tag.js");
+const { MailServices } = ChromeUtils.import(
+  "resource:///modules/MailServices.jsm"
+);
 
 var EXT_BUILTIN = "built-in";
 
@@ -36,15 +36,14 @@ var GlodaExplicitAttr = {
   _log: null,
   _msgTagService: null,
 
-  init: function gloda_explattr_init() {
-    this._log =  Log4Moz.repository.getLogger("gloda.explattr");
+  init() {
+    this._log = Log4Moz.repository.getLogger("gloda.explattr");
 
     this._msgTagService = MailServices.tags;
 
     try {
       this.defineAttributes();
-    }
-    catch (ex) {
+    } catch (ex) {
       this._log.error("Error in init: " + ex);
       throw ex;
     }
@@ -57,48 +56,50 @@ var GlodaExplicitAttr = {
   /** Boost for tagged messages, each additional tag. */
   NOTABILITY_TAGGED_ADDL: 1,
 
-  defineAttributes: function() {
+  defineAttributes() {
     // Tag
     this._attrTag = Gloda.defineAttribute({
-                        provider: this,
-                        extensionName: Gloda.BUILT_IN,
-                        attributeType: Gloda.kAttrExplicit,
-                        attributeName: "tag",
-                        bindName: "tags",
-                        singular: false,
-                        emptySetIsSignificant: true,
-                        facet: true,
-                        subjectNouns: [Gloda.NOUN_MESSAGE],
-                        objectNoun: Gloda.NOUN_TAG,
-                        parameterNoun: null,
-                        // Property change notifications that we care about:
-                        propertyChanges: ["keywords"],
-                        }); // not-tested
+      provider: this,
+      extensionName: Gloda.BUILT_IN,
+      attributeType: Gloda.kAttrExplicit,
+      attributeName: "tag",
+      bindName: "tags",
+      singular: false,
+      emptySetIsSignificant: true,
+      facet: true,
+      subjectNouns: [Gloda.NOUN_MESSAGE],
+      objectNoun: Gloda.NOUN_TAG,
+      parameterNoun: null,
+      // Property change notifications that we care about:
+      propertyChanges: ["keywords"],
+    }); // not-tested
 
     // Star
     this._attrStar = Gloda.defineAttribute({
-                        provider: this,
-                        extensionName: Gloda.BUILT_IN,
-                        attributeType: Gloda.kAttrExplicit,
-                        attributeName: "star",
-                        bindName: "starred",
-                        singular: true,
-                        facet: true,
-                        subjectNouns: [Gloda.NOUN_MESSAGE],
-                        objectNoun: Gloda.NOUN_BOOLEAN,
-                        parameterNoun: null,
-                        }); // tested-by: test_attributes_explicit
+      provider: this,
+      extensionName: Gloda.BUILT_IN,
+      attributeType: Gloda.kAttrExplicit,
+      attributeName: "star",
+      bindName: "starred",
+      singular: true,
+      facet: true,
+      subjectNouns: [Gloda.NOUN_MESSAGE],
+      objectNoun: Gloda.NOUN_BOOLEAN,
+      parameterNoun: null,
+    }); // tested-by: test_attributes_explicit
     // Read/Unread
     this._attrRead = Gloda.defineAttribute({
-                        provider: this,
-                        extensionName: Gloda.BUILT_IN,
-                        attributeType: Gloda.kAttrExplicit,
-                        attributeName: "read",
-                        singular: true,
-                        subjectNouns: [Gloda.NOUN_MESSAGE],
-                        objectNoun: Gloda.NOUN_BOOLEAN,
-                        parameterNoun: null,
-                        }); // tested-by: test_attributes_explicit
+      provider: this,
+      extensionName: Gloda.BUILT_IN,
+      attributeType: Gloda.kAttrExplicit,
+      attributeName: "read",
+      // Make the message query-able but without using the database.
+      canQuery: "truthy-but-not-true",
+      singular: true,
+      subjectNouns: [Gloda.NOUN_MESSAGE],
+      objectNoun: Gloda.NOUN_BOOLEAN,
+      parameterNoun: null,
+    }); // tested-by: test_attributes_explicit
 
     /**
      * Has this message been replied to by the user.
@@ -129,26 +130,26 @@ var GlodaExplicitAttr = {
     }); // tested-by: test_attributes_explicit
   },
 
-  process: function* Gloda_explattr_process(aGlodaMessage, aRawReps, aIsNew,
-                                            aCallbackHandle) {
+  *process(aGlodaMessage, aRawReps, aIsNew, aCallbackHandle) {
     let aMsgHdr = aRawReps.header;
 
     aGlodaMessage.starred = aMsgHdr.isFlagged;
-    if (aGlodaMessage.starred)
+    if (aGlodaMessage.starred) {
       aGlodaMessage.notability += this.NOTABILITY_STARRED;
+    }
 
     aGlodaMessage.read = aMsgHdr.isRead;
 
     let flags = aMsgHdr.flags;
-    aGlodaMessage.repliedTo = Boolean(flags & nsMsgMessageFlags_Replied);
-    aGlodaMessage.forwarded = Boolean(flags & nsMsgMessageFlags_Forwarded);
+    aGlodaMessage.repliedTo = Boolean(flags & Ci.nsMsgMessageFlags.Replied);
+    aGlodaMessage.forwarded = Boolean(flags & Ci.nsMsgMessageFlags.Forwarded);
 
-    let tags = aGlodaMessage.tags = [];
+    let tags = (aGlodaMessage.tags = []);
 
     // -- Tag
     // build a map of the keywords
     let keywords = aMsgHdr.getStringProperty("keywords");
-    let keywordList = keywords.split(' ');
+    let keywordList = keywords.split(" ");
     let keywordMap = {};
     for (let iKeyword = 0; iKeyword < keywordList.length; iKeyword++) {
       let keyword = keywordList[iKeyword];
@@ -158,13 +159,16 @@ var GlodaExplicitAttr = {
     let tagArray = TagNoun.getAllTags();
     for (let iTag = 0; iTag < tagArray.length; iTag++) {
       let tag = tagArray[iTag];
-      if (tag.key in keywordMap)
+      if (tag.key in keywordMap) {
         tags.push(tag);
+      }
     }
 
-    if (tags.length)
-      aGlodaMessage.notability += this.NOTABILITY_TAGGED_FIRST +
+    if (tags.length) {
+      aGlodaMessage.notability +=
+        this.NOTABILITY_TAGGED_FIRST +
         (tags.length - 1) * this.NOTABILITY_TAGGED_ADDL;
+    }
 
     yield Gloda.kWorkDone;
   },
@@ -174,13 +178,16 @@ var GlodaExplicitAttr = {
    *  be factored to call us, grokNounItem should be factored to call us, or we
    *  should get sufficiently fancy that our code wildly diverges.
    */
-  score: function Gloda_explattr_score(aMessage, aContext) {
+  score(aMessage, aContext) {
     let score = 0;
-    if (aMessage.starred)
+    if (aMessage.starred) {
       score += this.NOTABILITY_STARRED;
-    if (aMessage.tags.length)
-      score += this.NOTABILITY_TAGGED_FIRST +
+    }
+    if (aMessage.tags.length) {
+      score +=
+        this.NOTABILITY_TAGGED_FIRST +
         (aMessage.tags.length - 1) * this.NOTABILITY_TAGGED_ADDL;
+    }
     return score;
   },
 };
