@@ -17,6 +17,11 @@
  *  adds a lot of runtime overhead which makes certain debugging strategies like
  *  using chronicle-recorder impractical.
  */
+/* import-globals-from ../../../../test/resources/logHelper.js */
+/* import-globals-from ../../../../test/resources/asyncTestUtils.js */
+/* import-globals-from ../../../../test/resources/messageGenerator.js */
+/* import-globals-from ../../../../test/resources/messageModifier.js */
+/* import-globals-from ../../../../test/resources/messageInjection.js */
 load("../../../../resources/logHelper.js");
 load("../../../../resources/asyncTestUtils.js");
 
@@ -24,29 +29,34 @@ load("../../../../resources/messageGenerator.js");
 load("../../../../resources/messageModifier.js");
 load("../../../../resources/messageInjection.js");
 
+/* exported scenarios */
 // Create a message generator
-var msgGen = gMessageGenerator = new MessageGenerator();
+var msgGen = (gMessageGenerator = new MessageGenerator());
 // Create a message scenario generator using that message generator
-var scenarios = gMessageScenarioFactory = new MessageScenarioFactory(msgGen);
+var scenarios = new MessageScenarioFactory(msgGen);
 
-ChromeUtils.import("resource:///modules/gloda/mimemsg.js");
+var { MsgHdrToMimeMessage } = ChromeUtils.import(
+  "resource:///modules/gloda/mimemsg.js"
+);
 
 // While we're at it, we'll also test the correctness of the GlodaAttachment
 // representation, esp. its "I just need the part information to rebuild the
 // URLs" claim.
-ChromeUtils.import("resource:///modules/gloda/fundattr.js");
+var { GlodaFundAttr } = ChromeUtils.import(
+  "resource:///modules/gloda/fundattr.js"
+);
 
 var partText = new SyntheticPartLeaf("I am text! Woo!");
 var partHtml = new SyntheticPartLeaf(
   "<html><head></head><body>I am HTML! Woo! </body></html>",
   {
-    contentType: "text/html"
+    contentType: "text/html",
   }
 );
 var partEnriched = new SyntheticPartLeaf(
   "<bold><italic>I am not a popular format! sad woo :(</italic></bold>",
   {
-    contentType: "text/enriched"
+    contentType: "text/enriched",
   }
 );
 var partAlternative = new SyntheticPartMultiAlternative([partText, partHtml]);
@@ -66,49 +76,70 @@ var tachNoFilename = {
 // so this covers this case as well.
 var tachExternal = {
   body:
-    'You deleted an attachment from this message. The original MIME headers for the attachment were:\n'+
-    'Content-Type: image/png;\n'+
-    ' name="conversations-bug1.png"\n'+
-    'Content-Transfer-Encoding: base64\n'+
-    'Content-Disposition: attachment;\n'+
+    "You deleted an attachment from this message. The original MIME headers for the attachment were:\n" +
+    "Content-Type: image/png;\n" +
+    ' name="conversations-bug1.png"\n' +
+    "Content-Transfer-Encoding: base64\n" +
+    "Content-Disposition: attachment;\n" +
     ' filename="conversations-bug1.png"',
-  contentType: 'image/png',
+  contentType: "image/png",
   filename: "conversations-bug1.png",
   charset: null,
   format: null,
-  encoding: 'base64',
+  encoding: "base64",
   extraHeaders: {
-    'X-Mozilla-External-Attachment-URL': 'file:///tmp/conversations-bug1.png',
-    'X-Mozilla-Altered': 'AttachmentDetached; date="Wed Aug 03 11:11:33 2011"',
+    "X-Mozilla-External-Attachment-URL": "file:///tmp/conversations-bug1.png",
+    "X-Mozilla-Altered": 'AttachmentDetached; date="Wed Aug 03 11:11:33 2011"',
   },
 };
-var tachText = {filename: 'bob.txt', body: 'I like cheese!'};
+var tachText = { filename: "bob.txt", body: "I like cheese!" };
 var partTachText = new SyntheticPartLeaf(tachText.body, tachText);
-var tachInlineText = {filename: 'foo.txt', body: 'Rock the mic',
-                      format: null, charset: null,
-                      disposition: 'inline'};
-var partTachInlineText = new SyntheticPartLeaf(tachInlineText.body,
-                                               tachInlineText);
+var tachInlineText = {
+  filename: "foo.txt",
+  body: "Rock the mic",
+  format: null,
+  charset: null,
+  disposition: "inline",
+};
+new SyntheticPartLeaf(tachInlineText.body, tachInlineText);
 
-var tachImage = {filename: 'bob.png', contentType: 'image/png',
-                 encoding: 'base64', charset: null, format: null,
-                 body: 'YWJj\n'};
+var tachImage = {
+  filename: "bob.png",
+  contentType: "image/png",
+  encoding: "base64",
+  charset: null,
+  format: null,
+  body: "YWJj\n",
+};
 var partTachImage = new SyntheticPartLeaf(tachImage.body, tachImage);
 
-var relImage = {contentType: 'image/png',
-                encoding: 'base64', charset: null, format: null,
-                contentId: 'part1.foo@bar.invalid',
-                body: 'YWJj\n'};
+var relImage = {
+  contentType: "image/png",
+  encoding: "base64",
+  charset: null,
+  format: null,
+  contentId: "part1.foo@bar.invalid",
+  body: "YWJj\n",
+};
 var partRelImage = new SyntheticPartLeaf(relImage.body, relImage);
 
-var tachVCard = {filename: 'bob.vcf', contentType: 'text/x-vcard',
-                 encoding: '7bit', body: 'begin:vcard\nfn:Bob\nend:vcard\n'};
+var tachVCard = {
+  filename: "bob.vcf",
+  contentType: "text/x-vcard",
+  encoding: "7bit",
+  body: "begin:vcard\nfn:Bob\nend:vcard\n",
+};
 var partTachVCard = new SyntheticPartLeaf(tachVCard.body, tachVCard);
 
-var tachApplication = {filename: 'funky.funk',
-                       contentType: 'application/x-funky', body: 'funk!'};
-var partTachApplication = new SyntheticPartLeaf(tachApplication.body,
-                                                tachApplication);
+var tachApplication = {
+  filename: "funky.funk",
+  contentType: "application/x-funky",
+  body: "funk!",
+};
+var partTachApplication = new SyntheticPartLeaf(
+  tachApplication.body,
+  tachApplication
+);
 
 var partTachMessages = [msgGen.makeMessage(), msgGen.makeMessage()];
 
@@ -117,156 +148,165 @@ var partEmpty = new SyntheticDegeneratePartEmpty();
 var messageInfos = [
   // -- simple
   {
-    name: 'text/plain',
+    name: "text/plain",
     bodyPart: partText,
   },
   {
-    name: 'text/html',
+    name: "text/html",
     bodyPart: partHtml,
   },
   // -- simply ugly
   {
-    name: 'text/enriched',
+    name: "text/enriched",
     bodyPart: partEnriched,
   },
   // -- simple w/attachment
   {
-    name: 'text/plain w/text attachment (=> multipart/mixed)',
+    name: "text/plain w/text attachment (=> multipart/mixed)",
     bodyPart: partText,
     attachments: [tachText],
   },
   {
-    name: 'text/plain w/image attachment (=> multipart/mixed)',
+    name: "text/plain w/image attachment (=> multipart/mixed)",
     bodyPart: partText,
     attachments: [tachImage],
   },
   {
-    name: 'text/plain w/vcard attachment (=> multipart/mixed)',
+    name: "text/plain w/vcard attachment (=> multipart/mixed)",
     bodyPart: partText,
     attachments: [tachVCard],
   },
   {
-    name: 'text/plain w/app attachment (=> multipart/mixed)',
+    name: "text/plain w/app attachment (=> multipart/mixed)",
     bodyPart: partText,
     attachments: [tachApplication],
   },
   {
-    name: 'text/html w/text attachment (=> multipart/mixed)',
+    name: "text/html w/text attachment (=> multipart/mixed)",
     bodyPart: partHtml,
     attachments: [tachText],
   },
   {
-    name: 'text/html w/image attachment (=> multipart/mixed)',
+    name: "text/html w/image attachment (=> multipart/mixed)",
     bodyPart: partHtml,
     attachments: [tachImage],
   },
   {
-    name: 'text/html w/vcard attachment (=> multipart/mixed)',
+    name: "text/html w/vcard attachment (=> multipart/mixed)",
     bodyPart: partHtml,
     attachments: [tachVCard],
   },
   {
-    name: 'text/html w/app attachment (=> multipart/mixed)',
+    name: "text/html w/app attachment (=> multipart/mixed)",
     bodyPart: partHtml,
     attachments: [tachApplication],
   },
   // -- alternatives
   {
-    name: 'multipart/alternative: text/plain, text/html',
+    name: "multipart/alternative: text/plain, text/html",
     bodyPart: partAlternative,
   },
   {
-    name: 'multipart/alternative plain/html w/text attachment',
+    name: "multipart/alternative plain/html w/text attachment",
     bodyPart: partAlternative,
     attachments: [tachText],
   },
   {
-    name: 'multipart/alternative plain/html w/image attachment',
+    name: "multipart/alternative plain/html w/image attachment",
     bodyPart: partAlternative,
     attachments: [tachImage],
   },
   {
-    name: 'multipart/alternative plain/html w/vcard attachment',
+    name: "multipart/alternative plain/html w/vcard attachment",
     bodyPart: partAlternative,
     attachments: [tachVCard],
   },
   {
-    name: 'multipart/alternative plain/html w/app attachment',
+    name: "multipart/alternative plain/html w/app attachment",
     bodyPart: partAlternative,
     attachments: [tachApplication],
   },
   // -- S/MIME.
   {
-    name: 'S/MIME alternative',
+    name: "S/MIME alternative",
     bodyPart: new SyntheticPartMultiSignedSMIME(partAlternative),
   },
   {
-    name: 'S/MIME alternative with text attachment inside',
+    name: "S/MIME alternative with text attachment inside",
     // we have to do the attachment packing ourselves on this one.
     bodyPart: new SyntheticPartMultiSignedSMIME(
-      new SyntheticPartMultiMixed([partAlternative, partTachText])),
+      new SyntheticPartMultiMixed([partAlternative, partTachText])
+    ),
   },
   {
-    name: 'S/MIME alternative with image attachment inside',
+    name: "S/MIME alternative with image attachment inside",
     // we have to do the attachment packing ourselves on this one.
     bodyPart: new SyntheticPartMultiSignedSMIME(
-      new SyntheticPartMultiMixed([partAlternative, partTachImage])),
+      new SyntheticPartMultiMixed([partAlternative, partTachImage])
+    ),
   },
   {
-    name: 'S/MIME alternative with image attachment inside',
+    name: "S/MIME alternative with image attachment inside",
     // we have to do the attachment packing ourselves on this one.
     bodyPart: new SyntheticPartMultiSignedSMIME(
-      new SyntheticPartMultiMixed([partAlternative, partTachVCard])),
+      new SyntheticPartMultiMixed([partAlternative, partTachVCard])
+    ),
   },
   {
-    name: 'S/MIME alternative with app attachment inside',
+    name: "S/MIME alternative with app attachment inside",
     // we have to do the attachment packing ourselves on this one.
     bodyPart: new SyntheticPartMultiSignedSMIME(
-      new SyntheticPartMultiMixed([partAlternative, partTachApplication])),
+      new SyntheticPartMultiMixed([partAlternative, partTachApplication])
+    ),
   },
   {
-    name: 'S/MIME alternative wrapped in mailing list',
-    bodyPart: new SyntheticPartMultiMixed(
-      [new SyntheticPartMultiSignedSMIME(partAlternative),
-       partMailingListFooter]),
+    name: "S/MIME alternative wrapped in mailing list",
+    bodyPart: new SyntheticPartMultiMixed([
+      new SyntheticPartMultiSignedSMIME(partAlternative),
+      partMailingListFooter,
+    ]),
   },
   // -- PGP signature
   // We mainly care that all the content-type parameters show up.
   {
-    name: 'PGP signed alternative',
+    name: "PGP signed alternative",
     bodyPart: new SyntheticPartMultiSignedPGP(partAlternative),
   },
   // -- attached RFC822
   {
     // not your average attachment, pack ourselves for now
-    name: 'attached rfc822',
-    bodyPart: new SyntheticPartMultiMixed([partAlternative,
-                                           partTachMessages[0]]),
+    name: "attached rfc822",
+    bodyPart: new SyntheticPartMultiMixed([
+      partAlternative,
+      partTachMessages[0],
+    ]),
   },
   // -- multipart/related
   {
-    name: 'multipart/related',
+    name: "multipart/related",
     bodyPart: new SyntheticPartMultiRelated([partHtml, partRelImage]),
   },
   {
-    name: 'multipart/related inside multipart/alternative',
-    bodyPart: new SyntheticPartMultiAlternative([partText,
-      new SyntheticPartMultiRelated([partHtml, partRelImage])]),
+    name: "multipart/related inside multipart/alternative",
+    bodyPart: new SyntheticPartMultiAlternative([
+      partText,
+      new SyntheticPartMultiRelated([partHtml, partRelImage]),
+    ]),
   },
   // -- multipart/digest
   {
-    name: 'multipart/digest',
+    name: "multipart/digest",
     bodyPart: new SyntheticPartMultiDigest(partTachMessages.concat()),
   },
   // -- multipart/parallel (allegedly the same as mixed)
   {
-    name: 'multipart/parallel',
+    name: "multipart/parallel",
     bodyPart: new SyntheticPartMultiParallel([partText, partTachImage]),
   },
   // --- previous bugs
   // -- bug 495057, text/enriched was being dumb
   {
-    name: 'text/enriched inside related',
+    name: "text/enriched inside related",
     bodyPart: new SyntheticPartMultiRelated([partEnriched]),
   },
   // -- empty sections
@@ -276,19 +316,18 @@ var messageInfos = [
   //  nothing inherently nested-multipart-requiring to trigger the double-close
   //  bug.
   {
-    name: 'nested multipart with empty multipart section',
+    name: "nested multipart with empty multipart section",
     bodyPart: new SyntheticPartMultiMixed([
-        new SyntheticPartMultiRelated([partAlternative, partTachText]),
-        partEmpty
-      ])
+      new SyntheticPartMultiRelated([partAlternative, partTachText]),
+      partEmpty,
+    ]),
   },
   {
-    name: 'empty multipart section produces no child',
-    bodyPart: new SyntheticPartMultiMixed([partText, partEmpty, partTachText])
+    name: "empty multipart section produces no child",
+    bodyPart: new SyntheticPartMultiMixed([partText, partEmpty, partTachText]),
   },
 ];
 
-
 function* test_stream_message(info) {
   let synMsg = gMessageGenerator.makeMessage(info);
   let synSet = new SyntheticMessageSet([synMsg]);
@@ -317,8 +356,7 @@ function synTransformBody(aSynBodyPart) {
   if (aSynBodyPart._contentType == "text/enriched") {
     // Our job here is just to transform just enough for our example above.
     // We also could have provided a manual translation on the body part.
-    text = text.replace(/bold/g, "B")
-               .replace(/italic/g, "I") + "\n<BR>";
+    text = text.replace(/bold/g, "B").replace(/italic/g, "I") + "\n<BR>";
   }
   return text;
 }
@@ -330,21 +368,32 @@ function verify_body_part_equivalence(aSynBodyPart, aMimePart) {
   // the header representation of the content-type should also match unless
   //  this is an rfc822 part, in which case it should only match for the
   //  actual contents.
-  if (aMimePart.contentType != "message/rfc822")
-    Assert.equal(aSynBodyPart.contentTypeHeaderValue.replace(
-                   deathToNewlineTypeThings, ""),
-                 aMimePart.get("content-type").replace(
-                   deathToNewlineTypeThings, ""));
+  if (aMimePart.contentType != "message/rfc822") {
+    Assert.equal(
+      aSynBodyPart.contentTypeHeaderValue.replace(deathToNewlineTypeThings, ""),
+      aMimePart.get("content-type").replace(deathToNewlineTypeThings, "")
+    );
+  }
 
   // XXX body part checking will get brittle if we ever actually encode things!
-  if (aSynBodyPart.body && !aSynBodyPart._filename &&
-      aSynBodyPart._contentType.startsWith("text/"))
-    Assert.equal(synTransformBody(aSynBodyPart),
-                 aMimePart.body.trim().replace(/\r/g, "")
-                 // Remove stuff added by libmime for HTML parts.
-                 .replace(/[\n]*<meta http-equiv="content-type" content="text\/html; .*">[\n]*/g, "")
-                 .replace(/[\n]+<\/body>/, "</body>")
-                );
+  if (
+    aSynBodyPart.body &&
+    !aSynBodyPart._filename &&
+    aSynBodyPart._contentType.startsWith("text/")
+  ) {
+    Assert.equal(
+      synTransformBody(aSynBodyPart),
+      aMimePart.body
+        .trim()
+        .replace(/\r/g, "")
+        // Remove stuff added by libmime for HTML parts.
+        .replace(
+          /[\n]*<meta http-equiv="content-type" content="text\/html; .*">[\n]*/g,
+          ""
+        )
+        .replace(/[\n]+<\/body>/, "</body>")
+    );
+  }
   if (aSynBodyPart.parts) {
     let iPart;
     let realPartOffsetCompensator = 0;
@@ -360,16 +409,19 @@ function verify_body_part_equivalence(aSynBodyPart, aMimePart) {
       // our special case is the signature, which libmime does not expose to us.
       // ignore! (also, have our too-many-part checker below not trip on this)
       if (subSyn._contentType != PKCS_SIGNATURE_MIME_TYPE) {
-        if (subMime == null)
-          do_throw("No MIME part matching " +
-                   subSyn.contentTypeHeaderValue + "\n");
+        if (subMime == null) {
+          do_throw(
+            "No MIME part matching " + subSyn.contentTypeHeaderValue + "\n"
+          );
+        }
         verify_body_part_equivalence(subSyn, subMime);
       }
     }
     // only check if there are still more mime parts; don't check for a count
     //  mismatch (the PKCS case from above needs to be handled)
-    if (iPart < aMimePart.parts.length)
+    if (iPart < aMimePart.parts.length) {
       do_throw("MIME part has more sub-parts than syn part?");
+    }
   }
 }
 
@@ -378,26 +430,26 @@ function verify_body_part_equivalence(aSynBodyPart, aMimePart) {
  *  receiving a representation; we don't check it for correctness.
  */
 function verify_stream_message(aInfo, aSynMsg, aMsgHdr, aMimeMsg) {
-  if (aMimeMsg == null)
+  if (aMimeMsg == null) {
     do_throw("We really should have gotten a result!");
+  }
   try {
     // aMimeMsg is normalized; it only ever actually gets one child...
     verify_body_part_equivalence(aSynMsg.bodyPart, aMimeMsg.parts[0]);
-  }
-  catch (ex) {
+  } catch (ex) {
     dump("Something was wrong with the MIME rep!\n!!!!!!!!\n");
-    dump("Synthetic looks like:\n  " + aSynMsg.prettyString() +
-         "\n\n");
-    dump("MIME looks like:  \n" + aMimeMsg.prettyString(true, "  ", true) +
-         "\n\n");
+    dump("Synthetic looks like:\n  " + aSynMsg.prettyString() + "\n\n");
+    dump(
+      "MIME looks like:  \n" + aMimeMsg.prettyString(true, "  ", true) + "\n\n"
+    );
     do_throw(ex);
   }
 
   dump("Everything is just fine.\n");
-  dump("Synthetic looks like:\n  " + aSynMsg.prettyString() +
-       "\n\n");
-  dump("MIME looks like:\n  " + aMimeMsg.prettyString(true, "  ", false) +
-       "\n\n");
+  dump("Synthetic looks like:\n  " + aSynMsg.prettyString() + "\n\n");
+  dump(
+    "MIME looks like:\n  " + aMimeMsg.prettyString(true, "  ", false) + "\n\n"
+  );
 
   async_driver();
 }
@@ -416,20 +468,32 @@ function* test_sane_bodies() {
   // this will come out to be 60k, of course.
   Assert.equal(hugeString.length, 60 * Math.pow(2, powahsOfTwo));
 
-  let synMsg = gMessageGenerator.makeMessage(
-    {body: {body: hugeString, contentType: "text/plain"}});
+  let synMsg = gMessageGenerator.makeMessage({
+    body: { body: hugeString, contentType: "text/plain" },
+  });
   let synSet = new SyntheticMessageSet([synMsg]);
   yield add_sets_to_folder(gInbox, [synSet]);
 
   let msgHdr = synSet.getMsgHdr(0);
 
-  MsgHdrToMimeMessage(msgHdr, null, function(aMsgHdr, aMimeMsg) {
-    let bodyPart = aMimeMsg.parts[0];
-    // (the \r gets gone, so it's only 59 per line)
-    if (bodyPart.body.length > (20 * 1024 + 59))
-      do_throw("Mime body length is " + bodyPart.body.length + " bytes long but should not be!");
-    async_driver();
-  }, false, {saneBodySize: true});
+  MsgHdrToMimeMessage(
+    msgHdr,
+    null,
+    function(aMsgHdr, aMimeMsg) {
+      let bodyPart = aMimeMsg.parts[0];
+      // (the \r gets gone, so it's only 59 per line)
+      if (bodyPart.body.length > 20 * 1024 + 59) {
+        do_throw(
+          "Mime body length is " +
+            bodyPart.body.length +
+            " bytes long but should not be!"
+        );
+      }
+      async_driver();
+    },
+    false,
+    { saneBodySize: true }
+  );
 
   yield false;
 }
@@ -442,20 +506,20 @@ var partTachNestedMessages = [
   // all by itself. That allows us to create a non-UTF-8 subject, and ensure the
   // resulting attachment name is indeed São Paulo.eml.
   msgGen.makeMessage({
-    subject: "S"+String.fromCharCode(0xe3)+"o Paulo",
+    subject: "S" + String.fromCharCode(0xe3) + "o Paulo",
     bodyPart: new SyntheticPartLeaf(
       "<html><head></head><body>I am HTML! Woo! </body></html>",
       {
-        contentType: 'text/html',
+        contentType: "text/html",
       }
-    )
+    ),
   }),
   msgGen.makeMessage({
-      attachments: [tachImage]
-    }),
+    attachments: [tachImage],
+  }),
   msgGen.makeMessage({
-      attachments: [tachImage, tachApplication]
-    }),
+    attachments: [tachImage, tachApplication],
+  }),
 ];
 
 var attMessagesParams = [
@@ -466,20 +530,26 @@ var attMessagesParams = [
     attachments: [tachExternal],
   },
   {
-    name: 'attached rfc822',
-    bodyPart: new SyntheticPartMultiMixed([partAlternative,
-                                           partTachNestedMessages[0]]),
+    name: "attached rfc822",
+    bodyPart: new SyntheticPartMultiMixed([
+      partAlternative,
+      partTachNestedMessages[0],
+    ]),
   },
   {
-    name: 'attached rfc822 w. image inside',
-    bodyPart: new SyntheticPartMultiMixed([partAlternative,
-                                           partTachNestedMessages[1]]),
+    name: "attached rfc822 w. image inside",
+    bodyPart: new SyntheticPartMultiMixed([
+      partAlternative,
+      partTachNestedMessages[1],
+    ]),
   },
   {
-    name: 'attached x/funky + attached rfc822 w. (image + x/funky) inside',
-    bodyPart: new SyntheticPartMultiMixed([partAlternative,
-                                           partTachApplication,
-                                           partTachNestedMessages[2]]),
+    name: "attached x/funky + attached rfc822 w. (image + x/funky) inside",
+    bodyPart: new SyntheticPartMultiMixed([
+      partAlternative,
+      partTachApplication,
+      partTachNestedMessages[2],
+    ]),
   },
 ];
 
@@ -499,15 +569,19 @@ var expectedAttachmentsInfo = [
   },
   {
     allAttachmentsContentTypes: ["image/png"],
-    allUserAttachmentsContentTypes: ["message/rfc822"]
+    allUserAttachmentsContentTypes: ["message/rfc822"],
   },
   {
-    allAttachmentsContentTypes: ["application/x-funky", "image/png", "application/x-funky"],
-    allUserAttachmentsContentTypes: ["application/x-funky", "message/rfc822"]
+    allAttachmentsContentTypes: [
+      "application/x-funky",
+      "image/png",
+      "application/x-funky",
+    ],
+    allUserAttachmentsContentTypes: ["application/x-funky", "message/rfc822"],
   },
 ];
 
-function* test_attachments_correctness () {
+function* test_attachments_correctness() {
   for (let [i, params] of attMessagesParams.entries()) {
     let synMsg = gMessageGenerator.makeMessage(params);
     let synSet = new SyntheticMessageSet([synMsg]);
@@ -516,41 +590,65 @@ function* test_attachments_correctness () {
     let msgHdr = synSet.getMsgHdr(0);
     // dump(synMsg.toMboxString()+"\n\n");
 
-    MsgHdrToMimeMessage(msgHdr, null, function(aMsgHdr, aMimeMsg) {
-      try {
-        let expected = expectedAttachmentsInfo[i];
-        if ("firstAttachmentName" in expected) {
-          let att = aMimeMsg.allUserAttachments[0];
-          Assert.equal(att.name.length, expected.firstAttachmentName.length);
-          for (let i = 0; i < att.name.length; ++i)
-            Assert.equal(att.name.charCodeAt(i), expected.firstAttachmentName.charCodeAt(i));
+    MsgHdrToMimeMessage(
+      msgHdr,
+      null,
+      function(aMsgHdr, aMimeMsg) {
+        try {
+          let expected = expectedAttachmentsInfo[i];
+          if ("firstAttachmentName" in expected) {
+            let att = aMimeMsg.allUserAttachments[0];
+            Assert.equal(att.name.length, expected.firstAttachmentName.length);
+            for (let j = 0; j < att.name.length; ++j) {
+              Assert.equal(
+                att.name.charCodeAt(j),
+                expected.firstAttachmentName.charCodeAt(j)
+              );
+            }
+          }
+
+          Assert.equal(
+            aMimeMsg.allAttachments.length,
+            expected.allAttachmentsContentTypes.length
+          );
+          for (let [j, att] of aMimeMsg.allAttachments.entries()) {
+            Assert.equal(
+              att.contentType,
+              expected.allAttachmentsContentTypes[j]
+            );
+          }
+
+          Assert.equal(
+            aMimeMsg.allUserAttachments.length,
+            expected.allUserAttachmentsContentTypes.length
+          );
+          for (let [j, att] of aMimeMsg.allUserAttachments.entries()) {
+            Assert.equal(
+              att.contentType,
+              expected.allUserAttachmentsContentTypes[j]
+            );
+          }
+
+          // Test
+          for (let att of aMimeMsg.allUserAttachments) {
+            let uri = aMsgHdr.folder.getUriForMsg(aMsgHdr);
+            let glodaAttachment = GlodaFundAttr.glodaAttFromMimeAtt(
+              { folderMessageURI: uri },
+              att
+            );
+            // The GlodaAttachment appends the filename, which is not always
+            // present
+            Assert.ok(glodaAttachment.url.startsWith(att.url));
+          }
+        } catch (e) {
+          dump(aMimeMsg.prettyString() + "\n");
+          do_throw(e);
         }
 
-        Assert.equal(aMimeMsg.allAttachments.length, expected.allAttachmentsContentTypes.length);
-        for (let [j, att] of aMimeMsg.allAttachments.entries())
-          Assert.equal(att.contentType, expected.allAttachmentsContentTypes[j]);
-
-        Assert.equal(aMimeMsg.allUserAttachments.length, expected.allUserAttachmentsContentTypes.length);
-        for (let [j, att] of aMimeMsg.allUserAttachments.entries())
-          Assert.equal(att.contentType, expected.allUserAttachmentsContentTypes[j]);
-
-        // Test
-        for (let att of aMimeMsg.allUserAttachments) {
-          let uri = aMsgHdr.folder.getUriForMsg(aMsgHdr);
-          let glodaAttachment =
-            GlodaFundAttr.glodaAttFromMimeAtt({ folderMessageURI: uri }, att);
-          // The GlodaAttachment appends the filename, which is not always
-          // present
-          Assert.ok(glodaAttachment.url.startsWith(att.url));
-        }
-
-      } catch (e) {
-        dump(aMimeMsg.prettyString()+"\n");
-        do_throw(e);
-      }
-
-      async_driver();
-    }, false);
+        async_driver();
+      },
+      false
+    );
 
     yield false;
   }
@@ -566,10 +664,14 @@ var weirdMessageInfos = [
   // name Part 1.2. Now it's not the case anymore, so we should ensure this
   // message has no attachments.
   {
-    name: 'test message with part 1.2 attachment',
-    attachments: [{ body: 'attachment',
-                    filename: '',
-                    format: '' }],
+    name: "test message with part 1.2 attachment",
+    attachments: [
+      {
+        body: "attachment",
+        filename: "",
+        format: "",
+      },
+    ],
   },
 ];
 
@@ -607,10 +709,12 @@ var gInbox;
 
 function run_test() {
   registerCleanupFunction(function() {
-    ChromeUtils.import("resource:///modules/gloda/datastore.js");
+    let { GlodaDatastore } = ChromeUtils.import(
+      "resource:///modules/gloda/datastore.js"
+    );
     GlodaDatastore.shutdown();
   });
   // use mbox injection because the fake server chokes sometimes right now
-  gInbox = configure_message_injection({mode: "local"});
+  gInbox = configure_message_injection({ mode: "local" });
   async_run_tests(tests);
 }
