@@ -6,12 +6,17 @@
  * Tests imap msg header download chunking
  */
 
+/* import-globals-from ../../../test/resources/logHelper.js */
+/* import-globals-from ../../../test/resources/asyncTestUtils.js */
+/* import-globals-from ../../../test/resources/messageGenerator.js */
 load("../../../resources/logHelper.js");
 load("../../../resources/asyncTestUtils.js");
 load("../../../resources/messageGenerator.js");
 
-ChromeUtils.import("resource://gre/modules/Services.jsm");
-ChromeUtils.import("resource:///modules/mailServices.js");
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var { MailServices } = ChromeUtils.import(
+  "resource:///modules/MailServices.jsm"
+);
 // javascript mime emitter functions
 
 // IMAP pump
@@ -19,34 +24,36 @@ ChromeUtils.import("resource:///modules/mailServices.js");
 setupIMAPPump();
 
 // Dummy message window so we can say the inbox is open in a window.
-var dummyMsgWindow =
-{
-  openFolder : IMAPPump.inbox,
-  QueryInterface: XPCOMUtils.generateQI([Ci.nsIMsgWindow,
-                                         Ci.nsISupportsWeakReference])
+var dummyMsgWindow = {
+  openFolder: IMAPPump.inbox,
+  QueryInterface: ChromeUtils.generateQI([
+    Ci.nsIMsgWindow,
+    Ci.nsISupportsWeakReference,
+  ]),
 };
 
 var gFolderListener = {
   _gotNewMailBiff: false,
-  OnItemIntPropertyChanged : function(aItem, aProperty, aOldValue, aNewValue) {
-    if (aProperty == "BiffState" &&
-        aNewValue == Ci.nsIMsgFolder.nsMsgBiffState_NewMail) {
+  OnItemIntPropertyChanged(aItem, aProperty, aOldValue, aNewValue) {
+    if (
+      aProperty == "BiffState" &&
+      aNewValue == Ci.nsIMsgFolder.nsMsgBiffState_NewMail
+    ) {
       this._gotNewMailBiff = true;
       async_driver();
     }
-  }
+  },
 };
 
 var tests = [
   uploadImapMessages,
   testMessageFetched,
   testHdrsDownloaded,
-  endTest
-]
+  endTest,
+];
 
 // upload messages to the imap fake server Inbox
-function* uploadImapMessages()
-{
+function* uploadImapMessages() {
   // make 10 messages
   let messageGenerator = new MessageGenerator();
   let scenarioFactory = new MessageScenarioFactory(messageGenerator);
@@ -56,13 +63,15 @@ function* uploadImapMessages()
   messages = messages.concat(scenarioFactory.directReply(10));
 
   // Add 10 messages with uids 1-10.
-  let imapInbox = IMAPPump.daemon.getMailbox("INBOX")
+  let imapInbox = IMAPPump.daemon.getMailbox("INBOX");
   // Create the imapMessages and store them on the mailbox
-  messages.forEach(function (message)
-  {
-    let dataUri = Services.io.newURI("data:text/plain;base64," +
-                                     btoa(message.toMessageString()));
-    imapInbox.addMessage(new imapMessage(dataUri.spec, imapInbox.uidnext++, []));
+  messages.forEach(function(message) {
+    let dataUri = Services.io.newURI(
+      "data:text/plain;base64," + btoa(message.toMessageString())
+    );
+    imapInbox.addMessage(
+      new imapMessage(dataUri.spec, imapInbox.uidnext++, [])
+    );
   });
   // updateFolderWithListener with null for nsIMsgWindow makes biff notify.
   IMAPPump.inbox.updateFolderWithListener(null, asyncUrlListener);
@@ -90,21 +99,24 @@ function endTest() {
   teardownIMAPPump();
 }
 
-function run_test()
-{
+function run_test() {
   // We need to register the dummyMsgWindow so that we'll think the
   // Inbox is open in a folder and fetch headers in chunks.
   MailServices.mailSession.AddMsgWindow(dummyMsgWindow);
-  MailServices.mailSession.AddFolderListener(gFolderListener,
-                                             Ci.nsIFolderListener.intPropertyChanged);
+  MailServices.mailSession.AddFolderListener(
+    gFolderListener,
+    Ci.nsIFolderListener.intPropertyChanged
+  );
 
   // Set chunk size to 3, so we'll have to chain 4 requests to get
   // 10 headers.
   Services.prefs.setIntPref("mail.imap.hdr_chunk_size", 3);
   // Turn off offline sync to avoid complications in verifying that we can
   // run a url after the first header chunk.
-  Services.prefs.setBoolPref("mail.server.server1.autosync_offline_stores", false);
+  Services.prefs.setBoolPref(
+    "mail.server.server1.autosync_offline_stores",
+    false
+  );
 
   async_run_tests(tests);
 }
-
