@@ -9,29 +9,29 @@
  *     we get a new password prompt and can enter the password.
  */
 
-ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
-ChromeUtils.import("resource:///modules/mailServices.js");
-ChromeUtils.import("resource://gre/modules/Services.jsm");
+/* import-globals-from ../../../test/resources/logHelper.js */
+/* import-globals-from ../../../test/resources/asyncTestUtils.js */
+/* import-globals-from ../../../test/resources/alertTestUtils.js */
+/* import-globals-from ../../../test/resources/passwordStorage.js */
+/* import-globals-from ../../../test/resources/mailTestUtils.js */
 load("../../../resources/logHelper.js");
 load("../../../resources/asyncTestUtils.js");
 load("../../../resources/alertTestUtils.js");
 load("../../../resources/passwordStorage.js");
 load("../../../resources/mailTestUtils.js");
 
-var test = null;
 var server;
 var daemon;
 var incomingServer;
 var attempt = 0;
-var count = {};
 var logins;
 
 var kUserName = "testpop3";
 var kInvalidPassword = "pop3test";
 var kValidPassword = "testpop3";
 
-function alert(aDialogText, aText)
-{
+/* exported alert, confirmEx, promptPasswordPS */
+function alert(aDialogText, aText) {
   // The first few attempts may prompt about the password problem, the last
   // attempt shouldn't.
   Assert.ok(attempt < 4);
@@ -40,8 +40,16 @@ function alert(aDialogText, aText)
   dump("Alert Title: " + aDialogText + "\nAlert Text: " + aText + "\n");
 }
 
-function confirmEx(aDialogTitle, aText, aButtonFlags, aButton0Title,
-                   aButton1Title, aButton2Title, aCheckMsg, aCheckState) {
+function confirmEx(
+  aDialogTitle,
+  aText,
+  aButtonFlags,
+  aButton0Title,
+  aButton1Title,
+  aButton2Title,
+  aCheckMsg,
+  aCheckState
+) {
   switch (++attempt) {
     // First attempt, retry.
     case 1:
@@ -65,8 +73,14 @@ function confirmEx(aDialogTitle, aText, aButtonFlags, aButton0Title,
   }
 }
 
-function promptPasswordPS(aParent, aDialogTitle, aText, aPassword, aCheckMsg,
-                          aCheckState) {
+function promptPasswordPS(
+  aParent,
+  aDialogTitle,
+  aText,
+  aPassword,
+  aCheckMsg,
+  aCheckState
+) {
   if (attempt == 4) {
     aPassword.value = kValidPassword;
     aCheckState.value = true;
@@ -76,45 +90,45 @@ function promptPasswordPS(aParent, aDialogTitle, aText, aPassword, aCheckMsg,
 }
 
 function getPopMail() {
-  MailServices.pop3.GetNewMail(gDummyMsgWindow, urlListener, localAccountUtils.inboxFolder,
-                               incomingServer);
+  MailServices.pop3.GetNewMail(
+    gDummyMsgWindow,
+    urlListener,
+    localAccountUtils.inboxFolder,
+    incomingServer
+  );
 }
 
-var urlListener =
-{
-  OnStartRunningUrl: function (url) {
-  },
-  OnStopRunningUrl: function (url, result) {
+var urlListener = {
+  OnStartRunningUrl(url) {},
+  OnStopRunningUrl(url, result) {
     try {
       // On the last attempt, we should have successfully got one mail.
-      Assert.equal(localAccountUtils.inboxFolder.getTotalMessages(false),
-                   attempt == 4 ? 1 : 0);
+      Assert.equal(
+        localAccountUtils.inboxFolder.getTotalMessages(false),
+        attempt == 4 ? 1 : 0
+      );
 
       // If we've just cancelled, expect failure rather than success
       // because the server dropped the connection.
       dump("in onStopRunning, result = " + result + "\n");
       Assert.equal(result, attempt == 2 ? Cr.NS_ERROR_FAILURE : 0);
       async_driver();
-    }
-    catch (e) {
+    } catch (e) {
       // If we have an error, clean up nicely before we throw it.
       server.stop();
 
       var thread = gThreadManager.currentThread;
-      while (thread.hasPendingEvents())
+      while (thread.hasPendingEvents()) {
         thread.processNextEvent(true);
+      }
 
       do_throw(e);
     }
-  }
+  },
 };
 
 // Definition of tests
-var tests = [
-  getMail1,
-  getMail2,
-  endTest
-]
+var tests = [getMail1, getMail2, endTest];
 
 function actually_run_test() {
   daemon.setMessages(["message1.eml"]);
@@ -131,12 +145,14 @@ function* getMail1() {
 
   Assert.equal(attempt, 2);
 
-  // Check that we haven't forgetton the login even though we've retried and
-  // canceled.
-  logins = Services.logins.findLogins(count, "mailbox://localhost", null,
-                                      "mailbox://localhost");
+  // Check that we haven't forgetton the login even though we've retried and cancelled.
+  logins = Services.logins.findLogins(
+    "mailbox://localhost",
+    null,
+    "mailbox://localhost"
+  );
 
-  Assert.equal(count.value, 1);
+  Assert.equal(logins.length, 1);
   Assert.equal(logins[0].username, kUserName);
   Assert.equal(logins[0].password, kInvalidPassword);
 
@@ -155,19 +171,19 @@ function* getMail2() {
 
 function* endTest() {
   // Now check the new one has been saved.
-  logins = Services.logins.findLogins(count, "mailbox://localhost", null,
-                                      "mailbox://localhost");
+  logins = Services.logins.findLogins(
+    "mailbox://localhost",
+    null,
+    "mailbox://localhost"
+  );
 
-  Assert.equal(count.value, 1);
+  Assert.equal(logins.length, 1);
   Assert.equal(logins[0].username, kUserName);
   Assert.equal(logins[0].password, kValidPassword);
   yield true;
 }
 
-function run_test()
-{
-  mailTestUtils.registerUMimTypProvider();
-
+function run_test() {
   // Disable new mail notifications
   Services.prefs.setBoolPref("mail.biff.play_sound", false);
   Services.prefs.setBoolPref("mail.biff.show_alert", false);
@@ -200,8 +216,11 @@ function run_test()
   // it from the signons json file in which the login information is stored).
   localAccountUtils.loadLocalMailAccount();
 
-  incomingServer = MailServices.accounts
-                    .createIncomingServer(kUserName, "localhost", "pop3");
+  incomingServer = MailServices.accounts.createIncomingServer(
+    kUserName,
+    "localhost",
+    "pop3"
+  );
   incomingServer.port = server.port;
 
   // Check that we haven't got any messages in the folder, if we have its a test
