@@ -2,15 +2,18 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-ChromeUtils.import("resource://gre/modules/Deprecated.jsm");
-ChromeUtils.import("resource:///modules/jsmime.jsm");
-ChromeUtils.import("resource:///modules/mimeParser.jsm");
-ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
+var { jsmime } = ChromeUtils.import("resource:///modules/jsmime.jsm");
+var { MimeParser } = ChromeUtils.import("resource:///modules/mimeParser.jsm");
+var { XPCOMUtils } = ChromeUtils.import(
+  "resource://gre/modules/XPCOMUtils.jsm"
+);
 
 function HeaderHandler() {
   this.value = "";
-  this.deliverData = function (str) { this.value += str; };
-  this.deliverEOF = function () {};
+  this.deliverData = function(str) {
+    this.value += str;
+  };
+  this.deliverEOF = function() {};
 }
 
 function StringEnumerator(iterator) {
@@ -18,25 +21,29 @@ function StringEnumerator(iterator) {
   this._next = undefined;
 }
 StringEnumerator.prototype = {
-  QueryInterface: XPCOMUtils.generateQI([
-    Ci.nsIUTF8StringEnumerator]),
-  _setNext: function () {
-    if (this._next !== undefined)
+  QueryInterface: ChromeUtils.generateQI([Ci.nsIUTF8StringEnumerator]),
+  [Symbol.iterator]() {
+    return this._iterator;
+  },
+  _setNext() {
+    if (this._next !== undefined) {
       return;
+    }
     this._next = this._iterator.next();
   },
-  hasMore: function () {
+  hasMore() {
     this._setNext();
     return !this._next.done;
   },
-  getNext: function () {
+  getNext() {
     this._setNext();
     let result = this._next;
     this._next = undefined;
-    if (result.done)
+    if (result.done) {
       throw Cr.NS_ERROR_UNEXPECTED;
+    }
     return result.value;
-  }
+  },
 };
 
 /**
@@ -45,16 +52,19 @@ StringEnumerator.prototype = {
  * the addresses into the form that jsmime expects.
  */
 function fixXpconnectAddresses(addrs) {
-  return addrs.map((addr) => {
+  return addrs.map(addr => {
     // This is ideally !addr.group, but that causes a JS strict warning, if
     // group is not in addr, since that's enabled in all chrome code now.
-    if (!('group' in addr) || addr.group === undefined || addr.group === null) {
-      return MimeAddressParser.prototype.makeMailboxObject(addr.name,
-        addr.email);
-    } else {
-      return MimeAddressParser.prototype.makeGroupObject(addr.name,
-        fixXpconnectAddresses(addr.group));
+    if (!("group" in addr) || addr.group === undefined || addr.group === null) {
+      return MimeAddressParser.prototype.makeMailboxObject(
+        addr.name,
+        addr.email
+      );
     }
+    return MimeAddressParser.prototype.makeGroupObject(
+      addr.name,
+      fixXpconnectAddresses(addr.group)
+    );
   });
 }
 
@@ -62,26 +72,26 @@ function fixXpconnectAddresses(addrs) {
  * This is a base handler for supporting msgIStructuredHeaders, since we have
  * two implementations that need the readable aspects of the interface.
  */
-function MimeStructuredHeaders() {
-}
+function MimeStructuredHeaders() {}
 MimeStructuredHeaders.prototype = {
-  getHeader: function (aHeaderName) {
+  getHeader(aHeaderName) {
     let name = aHeaderName.toLowerCase();
     return this._headers.get(name);
   },
 
-  hasHeader: function (aHeaderName) {
+  hasHeader(aHeaderName) {
     return this._headers.has(aHeaderName.toLowerCase());
   },
 
-  getUnstructuredHeader: function (aHeaderName) {
+  getUnstructuredHeader(aHeaderName) {
     let result = this.getHeader(aHeaderName);
-    if (result === undefined || typeof result == "string")
+    if (result === undefined || typeof result == "string") {
       return result;
+    }
     throw Cr.NS_ERROR_ILLEGAL_VALUE;
   },
 
-  getAddressingHeader: function (aHeaderName, aPreserveGroups, count) {
+  getAddressingHeader(aHeaderName, aPreserveGroups, count) {
     let addrs = this.getHeader(aHeaderName);
     if (addrs === undefined) {
       addrs = [];
@@ -91,17 +101,21 @@ MimeStructuredHeaders.prototype = {
     return fixArray(addrs, aPreserveGroups, count);
   },
 
-  getRawHeader: function (aHeaderName) {
+  getRawHeader(aHeaderName) {
     let result = this.getHeader(aHeaderName);
-    if (result === undefined)
+    if (result === undefined) {
       return result;
+    }
 
-    let value = jsmime.headeremitter.emitStructuredHeader(aHeaderName,
-      result, {});
+    let value = jsmime.headeremitter.emitStructuredHeader(
+      aHeaderName,
+      result,
+      {}
+    );
     // Strip off the header name and trailing whitespace before returning...
     value = value.substring(aHeaderName.length + 2).trim();
     // ... as well as embedded newlines.
-    value = value.replace(/\r\n/g, '');
+    value = value.replace(/\r\n/g, "");
     return value;
   },
 
@@ -109,13 +123,13 @@ MimeStructuredHeaders.prototype = {
     return new StringEnumerator(this._headers.keys());
   },
 
-  buildMimeText: function () {
+  buildMimeText() {
     if (this._headers.size == 0) {
       return "";
     }
     let handler = new HeaderHandler();
     let emitter = jsmime.headeremitter.makeStreamingEmitter(handler, {
-      useASCII: true
+      useASCII: true,
     });
     for (let [value, header] of this._headers) {
       emitter.addStructuredHeader(value, header);
@@ -125,38 +139,40 @@ MimeStructuredHeaders.prototype = {
   },
 };
 
-
-function MimeHeaders() {
-}
+function MimeHeaders() {}
 MimeHeaders.prototype = {
   __proto__: MimeStructuredHeaders.prototype,
   classDescription: "Mime headers implementation",
   classID: Components.ID("d1258011-f391-44fd-992e-c6f4b461a42f"),
   contractID: "@mozilla.org/messenger/mimeheaders;1",
-  QueryInterface: XPCOMUtils.generateQI([Ci.nsIMimeHeaders,
-    Ci.msgIStructuredHeaders]),
+  QueryInterface: ChromeUtils.generateQI([
+    Ci.nsIMimeHeaders,
+    Ci.msgIStructuredHeaders,
+  ]),
 
-  initialize: function MimeHeaders_initialize(allHeaders) {
+  initialize(allHeaders) {
     this._headers = MimeParser.extractHeaders(allHeaders);
   },
 
-  extractHeader: function MimeHeaders_extractHeader(header, getAll) {
-    if (!this._headers)
+  extractHeader(header, getAll) {
+    if (!this._headers) {
       throw Cr.NS_ERROR_NOT_INITIALIZED;
+    }
     // Canonicalized to lower-case form
     header = header.toLowerCase();
-    if (!this._headers.has(header))
+    if (!this._headers.has(header)) {
       return null;
+    }
     var values = this._headers.getRawHeader(header);
-    if (getAll)
+    if (getAll) {
       return values.join(",\r\n\t");
-    else
-      return values[0];
+    }
+    return values[0];
   },
 
   get allHeaders() {
     return this._headers.rawHeaderText;
-  }
+  },
 };
 
 function MimeWritableStructuredHeaders() {
@@ -165,58 +181,59 @@ function MimeWritableStructuredHeaders() {
 MimeWritableStructuredHeaders.prototype = {
   __proto__: MimeStructuredHeaders.prototype,
   classID: Components.ID("c560806a-425f-4f0f-bf69-397c58c599a7"),
-  QueryInterface: XPCOMUtils.generateQI([
+  QueryInterface: ChromeUtils.generateQI([
     Ci.msgIStructuredHeaders,
-    Ci.msgIWritableStructuredHeaders]),
+    Ci.msgIWritableStructuredHeaders,
+  ]),
 
-  setHeader: function (aHeaderName, aValue) {
+  setHeader(aHeaderName, aValue) {
     this._headers.set(aHeaderName.toLowerCase(), aValue);
   },
 
-  deleteHeader: function (aHeaderName) {
+  deleteHeader(aHeaderName) {
     this._headers.delete(aHeaderName.toLowerCase());
   },
 
-  addAllHeaders: function (aHeaders) {
-    let headerList = aHeaders.headerNames;
-    while (headerList.hasMore()) {
-      let header = headerList.getNext();
+  addAllHeaders(aHeaders) {
+    for (let header of aHeaders.headerNames) {
       this.setHeader(header, aHeaders.getHeader(header));
     }
   },
 
-  setUnstructuredHeader: function (aHeaderName, aValue) {
+  setUnstructuredHeader(aHeaderName, aValue) {
     this.setHeader(aHeaderName, aValue);
   },
 
-  setAddressingHeader: function (aHeaderName, aAddresses, aCount) {
+  setAddressingHeader(aHeaderName, aAddresses, aCount) {
     this.setHeader(aHeaderName, fixXpconnectAddresses(aAddresses));
   },
 
-  setRawHeader: function (aHeaderName, aValue, aCharset) {
+  setRawHeader(aHeaderName, aValue, aCharset) {
     aValue = jsmime.headerparser.convert8BitHeader(aValue, aCharset);
     try {
-      this.setHeader(aHeaderName,
-        jsmime.headerparser.parseStructuredHeader(aHeaderName, aValue));
+      this.setHeader(
+        aHeaderName,
+        jsmime.headerparser.parseStructuredHeader(aHeaderName, aValue)
+      );
     } catch (e) {
       // This means we don't have a structured encoder. Just assume it's a raw
       // string value then.
       this.setHeader(aHeaderName, aValue);
     }
-  }
+  },
 };
 
 // These are prototypes for nsIMsgHeaderParser implementation
 var Mailbox = {
-  toString: function () {
+  toString() {
     return this.name ? this.name + " <" + this.email + ">" : this.email;
-  }
+  },
 };
 
 var EmailGroup = {
-  toString: function () {
+  toString() {
     return this.name + ": " + this.group.map(x => x.toString()).join(", ");
-  }
+  },
 };
 
 // A helper method for parse*Header that takes into account the desire to
@@ -227,7 +244,8 @@ function fixArray(addresses, preserveGroups, count) {
     let prototyped = Object.create(prototype);
     for (let key of Object.getOwnPropertyNames(obj)) {
       if (typeof obj[key] == "string") {
-        prototyped[key] = obj[key].replace(/\x00/g, '');
+        // eslint-disable-next-line no-control-regex
+        prototyped[key] = obj[key].replace(/\x00/g, "");
       } else {
         prototyped[key] = obj[key];
       }
@@ -236,77 +254,85 @@ function fixArray(addresses, preserveGroups, count) {
   }
   let outputArray = [];
   for (let element of addresses) {
-    if ('group' in element) {
+    if ("group" in element) {
       // Fix up the prototypes of the group and the list members
       element = resetPrototype(element, EmailGroup);
       element.group = element.group.map(e => resetPrototype(e, Mailbox));
 
       // Add to the output array
-      if (preserveGroups)
+      if (preserveGroups) {
         outputArray.push(element);
-      else
+      } else {
         outputArray = outputArray.concat(element.group);
+      }
     } else {
       element = resetPrototype(element, Mailbox);
       outputArray.push(element);
     }
   }
 
-  if (count)
+  if (count) {
     count.value = outputArray.length;
+  }
   return outputArray;
 }
 
-function MimeAddressParser() {
-}
+function MimeAddressParser() {}
 MimeAddressParser.prototype = {
   classID: Components.ID("96bd8769-2d0e-4440-963d-22b97fb3ba77"),
-  QueryInterface: XPCOMUtils.generateQI([Ci.nsIMsgHeaderParser]),
+  QueryInterface: ChromeUtils.generateQI([Ci.nsIMsgHeaderParser]),
 
-  parseEncodedHeader: function (aHeader, aCharset, aPreserveGroups, count) {
+  parseEncodedHeader(aHeader, aCharset, aPreserveGroups, count) {
     aHeader = aHeader || "";
-    let value = MimeParser.parseHeaderField(aHeader,
-      MimeParser.HEADER_ADDRESS | MimeParser.HEADER_OPTION_ALL_I18N, aCharset);
+    let value = MimeParser.parseHeaderField(
+      aHeader,
+      MimeParser.HEADER_ADDRESS | MimeParser.HEADER_OPTION_ALL_I18N,
+      aCharset
+    );
     return fixArray(value, aPreserveGroups, count);
   },
-  parseEncodedHeaderW: function (aHeader, count) {
+  parseEncodedHeaderW(aHeader, count) {
     aHeader = aHeader || "";
-    let value = MimeParser.parseHeaderField(aHeader,
+    let value = MimeParser.parseHeaderField(
+      aHeader,
       MimeParser.HEADER_ADDRESS |
-      MimeParser.HEADER_OPTION_DECODE_2231 |
-      MimeParser.HEADER_OPTION_DECODE_2047,
-      undefined);
+        MimeParser.HEADER_OPTION_DECODE_2231 |
+        MimeParser.HEADER_OPTION_DECODE_2047,
+      undefined
+    );
     return fixArray(value, false, count);
   },
-  parseDecodedHeader: function (aHeader, aPreserveGroups, count) {
+  parseDecodedHeader(aHeader, aPreserveGroups, count) {
     aHeader = aHeader || "";
     let value = MimeParser.parseHeaderField(aHeader, MimeParser.HEADER_ADDRESS);
     return fixArray(value, aPreserveGroups, count);
   },
 
-  makeMimeHeader: function (addresses, length) {
+  makeMimeHeader(addresses, length) {
     addresses = fixXpconnectAddresses(addresses);
     // Don't output any necessary continuations, so make line length as large as
     // possible first.
     let options = {
       softMargin: 900,
       hardMargin: 900,
-      useASCII: false // We don't want RFC 2047 encoding here.
+      useASCII: false, // We don't want RFC 2047 encoding here.
     };
     let handler = new HeaderHandler();
-    let emitter = new jsmime.headeremitter.makeStreamingEmitter(handler,
-      options);
+    let emitter = new jsmime.headeremitter.makeStreamingEmitter(
+      handler,
+      options
+    );
     emitter.addAddresses(addresses);
     emitter.finish(true);
-    return handler.value.replace(/\r\n( |$)/g, '');
+    return handler.value.replace(/\r\n( |$)/g, "");
   },
 
-  extractFirstName: function (aHeader) {
-    let address = this.parseDecodedHeader(aHeader, false)[0];
-    return address.name || address.email;
+  extractFirstName(aHeader) {
+    let addresses = this.parseDecodedHeader(aHeader, false);
+    return addresses.length > 0 ? addresses[0].name || addresses[0].email : "";
   },
 
-  removeDuplicateAddresses: function (aAddrs, aOtherAddrs) {
+  removeDuplicateAddresses(aAddrs, aOtherAddrs) {
     // This is actually a rather complicated algorithm, especially if we want to
     // preserve group structure. Basically, we use a set to identify which
     // headers we have seen and therefore want to remove. To work in several
@@ -321,12 +347,13 @@ MimeAddressParser.prototype = {
     // The filtration function, which removes email addresses that are
     // duplicates of those we have already seen.
     function filterAccept(e) {
-      if ('email' in e) {
+      if ("email" in e) {
         // If we've seen the address, don't keep this one; otherwise, add it to
         // the list.
         let key = normalize(e.email);
-        if (allAddresses.has(key))
+        if (allAddresses.has(key)) {
           return false;
+        }
         allAddresses.add(key);
       } else {
         // Groups -> filter out all the member addresses.
@@ -346,64 +373,99 @@ MimeAddressParser.prototype = {
     return this.makeMimeHeader(filtered);
   },
 
-  makeMailboxObject: function (aName, aEmail) {
+  makeMailboxObject(aName, aEmail) {
     let object = Object.create(Mailbox);
     object.name = aName;
     object.email = aEmail ? aEmail.trim() : aEmail;
     return object;
   },
 
-  makeGroupObject: function (aName, aMembers) {
+  makeGroupObject(aName, aMembers) {
     let object = Object.create(EmailGroup);
     object.name = aName;
     object.group = aMembers;
     return object;
   },
 
-  makeFromDisplayAddress: function (aDisplay, count) {
+  makeFromDisplayAddress(aDisplay, count) {
+    if (aDisplay.includes(";") && !/:.*;/.test(aDisplay)) {
+      // Using semicolons as mailbox separators in against the standard, but
+      // used in the wild by some clients.
+      // Looks like this isn't using group syntax, so let's assume it's a
+      // non-standards compliant input string, and fix it.
+      // Replace semicolons with commas, unless the semicolon is inside a quote.
+      // The regexp uses tricky lookahead, see bug 1059988 comment #70 for details.
+      aDisplay = aDisplay.replace(/;(?=(?:(?:[^"]*"){2})*[^"]*$)/g, ",");
+    }
+
     // The basic idea is to split on every comma, so long as there is a
     // preceding @.
     let output = [];
-    while (aDisplay.length) {
-      let at = aDisplay.indexOf('@');
-      let comma = aDisplay.indexOf(',', at + 1);
+    while (aDisplay.length > 0) {
+      let at = aDisplay.indexOf("@");
+      let comma = aDisplay.indexOf(",", at + 1);
       let addr;
       if (comma > 0) {
         addr = aDisplay.substr(0, comma);
         aDisplay = aDisplay.substr(comma + 1);
+
+        // Make sure we don't have any "empty addresses" (multiple commas).
+        comma = 0;
+        while (/[,\s]/.test(aDisplay.charAt(comma))) {
+          comma++;
+        }
+        aDisplay = aDisplay.substr(comma);
       } else {
         addr = aDisplay;
         aDisplay = "";
       }
-      output.push(this._makeSingleAddress(addr.trimLeft()));
+      addr = addr.trimLeft();
+      if (addr) {
+        output.push(this._makeSingleAddress(addr));
+      }
     }
-    if (count)
+    if (count) {
       count.value = output.length;
+    }
     return output;
   },
 
-  /// Construct a single email address from a name <local@domain> token.
-  _makeSingleAddress: function (aDisplayName) {
-    if (aDisplayName.includes('<')) {
-      let lbracket = aDisplayName.lastIndexOf('<');
-      let rbracket = aDisplayName.lastIndexOf('>');
-      return this.makeMailboxObject(
-        lbracket == 0 ? '' : aDisplayName.slice(0, lbracket).trim(),
-        aDisplayName.slice(lbracket + 1, rbracket));
-    } else {
-      return this.makeMailboxObject('', aDisplayName);
+  /**
+   * Construct a single email address from an |name <local@domain>| token.
+   * @param {string} aInput - a string to be parsed to a mailbox object.
+   * @returns {msgIAddressObject} the mailbox parsed from the input.
+   */
+  _makeSingleAddress(aInput) {
+    // If the whole string is within quotes, unquote it first.
+    aInput = aInput.trim().replace(/^"(.*)"$/, "$1");
+
+    if (/<.*>/.test(aInput)) {
+      // We don't want to look for the address within quotes, so first remove
+      // all quoted strings containing angle chars.
+      let cleanedInput = aInput.replace(/".*[<>]+.*"/g, "");
+
+      // Extract the address from within the quotes.
+      let addrMatch = cleanedInput.match(/<([^><]*)>/);
+
+      let addr = addrMatch ? addrMatch[1] : "";
+      let addrIdx = aInput.indexOf("<" + addr + ">");
+      return this.makeMailboxObject(aInput.slice(0, addrIdx).trim(), addr);
     }
+    return this.makeMailboxObject("", aInput);
   },
 
   // What follows is the deprecated API that will be removed shortly.
 
-  parseHeadersWithArray: function (aHeader, aAddrs, aNames, aFullNames) {
-    let addrs = [], names = [], fullNames = [];
+  parseHeadersWithArray(aHeader, aAddrs, aNames, aFullNames) {
+    let addrs = [],
+      names = [],
+      fullNames = [];
     let allAddresses = this.parseEncodedHeader(aHeader, undefined, false);
 
     // Don't index the dummy empty address.
-    if (aHeader.trim() == "")
+    if (aHeader.trim() == "") {
       allAddresses = [];
+    }
     for (let address of allAddresses) {
       addrs.push(address.email);
       names.push(address.name || null);
@@ -416,66 +478,55 @@ MimeAddressParser.prototype = {
     return allAddresses.length;
   },
 
-  extractHeaderAddressMailboxes: function (aLine) {
-    return this.parseDecodedHeader(aLine).map(addr => addr.email).join(", ");
+  extractHeaderAddressMailboxes(aLine) {
+    return this.parseDecodedHeader(aLine)
+      .map(addr => addr.email)
+      .join(", ");
   },
 
-  extractHeaderAddressNames: function (aLine) {
-    return this.parseDecodedHeader(aLine).map(addr => addr.name || addr.email)
-                                         .join(", ");
-  },
-
-  extractHeaderAddressName: function (aLine) {
-    let addrs = this.parseDecodedHeader(aLine).map(addr =>
-                 addr.name || addr.email);
-    return addrs.length == 0 ? "" : addrs[0];
-  },
-
-  makeMimeAddress: function (aName, aEmail) {
+  makeMimeAddress(aName, aEmail) {
     let object = this.makeMailboxObject(aName, aEmail);
     return this.makeMimeHeader([object]);
   },
 };
 
-function MimeConverter() {
-}
+function MimeConverter() {}
 MimeConverter.prototype = {
   classID: Components.ID("93f8c049-80ed-4dda-9000-94ad8daba44c"),
-  QueryInterface: XPCOMUtils.generateQI([Ci.nsIMimeConverter]),
-
-  encodeMimePartIIStr_UTF8: function (aHeader, aStructured, aCharset,
-      aFieldNameLen, aLineLength) {
-    // The JSMime encoder only works in UTF-8, so if someone requests to not do
-    // it, they need to change their code.
-    if (aCharset.toLowerCase() != "utf-8") {
-      Deprecated.warning("Encoding to non-UTF-8 values is obsolete",
-        "http://bugzilla.mozilla.org/show_bug.cgi?id=790855");
-    }
+  QueryInterface: ChromeUtils.generateQI([Ci.nsIMimeConverter]),
 
+  encodeMimePartIIStr_UTF8(aHeader, aStructured, aFieldNameLen, aLineLength) {
     // Compute the encoding options. The way our API is structured in this
     // method is really horrendous and does not align with the way that JSMime
     // handles it. Instead, we'll need to create a fake header to take into
     // account the aFieldNameLen parameter.
-    let fakeHeader = '-'.repeat(aFieldNameLen);
+    let fakeHeader = "-".repeat(aFieldNameLen);
     let options = {
       softMargin: aLineLength,
       useASCII: true,
     };
     let handler = new HeaderHandler();
-    let emitter = new jsmime.headeremitter.makeStreamingEmitter(handler,
-      options);
+    let emitter = new jsmime.headeremitter.makeStreamingEmitter(
+      handler,
+      options
+    );
 
     // Add the text to the be encoded.
     emitter.addHeaderName(fakeHeader);
     if (aStructured) {
       // Structured really means "this is an addressing header"
-      let addresses = MimeParser.parseHeaderField(aHeader,
-        MimeParser.HEADER_ADDRESS | MimeParser.HEADER_OPTION_DECODE_2047);
+      let addresses = MimeParser.parseHeaderField(
+        aHeader,
+        MimeParser.HEADER_ADDRESS | MimeParser.HEADER_OPTION_DECODE_2047
+      );
       // This happens in one of our tests if there is a "bare" email but no
       // @ sign. Without it, the result disappears since our emission code
       // assumes that an empty email is not worth emitting.
-      if (addresses.length === 1 && addresses[0].email === "" &&
-          addresses[0].name !== "") {
+      if (
+        addresses.length === 1 &&
+        addresses[0].email === "" &&
+        addresses[0].name !== ""
+      ) {
         addresses[0].email = addresses[0].name;
         addresses[0].name = "";
       }
@@ -492,24 +543,29 @@ MimeConverter.prototype = {
     return value.substring(0, value.length - 2);
   },
 
-  decodeMimeHeader: function (aHeader, aDefaultCharset, aOverride, aUnfold) {
-    let value = MimeParser.parseHeaderField(aHeader,
+  decodeMimeHeader(aHeader, aDefaultCharset, aOverride, aUnfold) {
+    let value = MimeParser.parseHeaderField(
+      aHeader,
       MimeParser.HEADER_UNSTRUCTURED | MimeParser.HEADER_OPTION_ALL_I18N,
-      aDefaultCharset);
+      aDefaultCharset
+    );
     if (aUnfold) {
-      value = value.replace(/[\r\n]\t/g, ' ')
-                   .replace(/[\r\n]/g, '');
+      value = value.replace(/[\r\n]\t/g, " ").replace(/[\r\n]/g, "");
     }
     return value;
   },
 
   // This is identical to the above, except for factors that are handled by the
   // xpconnect conversion process
-  decodeMimeHeaderToUTF8: function (...aArgs) {
+  decodeMimeHeaderToUTF8(...aArgs) {
     return this.decodeMimeHeader(...aArgs);
   },
 };
 
-var components = [MimeHeaders, MimeWritableStructuredHeaders, MimeAddressParser,
-  MimeConverter];
+var components = [
+  MimeHeaders,
+  MimeWritableStructuredHeaders,
+  MimeAddressParser,
+  MimeConverter,
+];
 var NSGetFactory = XPCOMUtils.generateNSGetFactory(components);
