@@ -18,9 +18,8 @@
 /*
  * This is the write call for outputting processed stream data.
  */
-extern "C" int  XPCOM_MimeObject_write(void *mimeObject, const char *data,
-                                  int32_t length,
-                                  bool user_visible_p);
+extern "C" int XPCOM_MimeObject_write(void *mimeObject, const char *data,
+                                      int32_t length, bool user_visible_p);
 /*
  * The following group of calls expose the pointers for the object
  * system within libmime.
@@ -33,6 +32,6 @@ extern "C" void *XPCOM_GetmimeMultipartClass(void);
 extern "C" void *XPCOM_GetmimeMultipartSignedClass(void);
 extern "C" void *XPCOM_GetmimeEncryptedClass(void);
 
-extern "C" void *XPCOM_Mime_create(char *content_type, void* hdrs, void* opts);
+extern "C" void *XPCOM_Mime_create(char *content_type, void *hdrs, void *opts);
 
 #endif /* _MIMECOM_H_ */
