@@ -11,73 +11,75 @@
 #include "nsString.h"
 #include "nsMimeStringResources.h"
 #include "nsIPrefBranch.h"
-#include "nsIServiceManager.h"
 #include "mimemoz2.h"
 #include "prprf.h"
 #include "nsMsgI18N.h"
 
-static const uint32_t kSpacesForATab = 4; // Must be at least 1.
+static const uint32_t kSpacesForATab = 4;  // Must be at least 1.
 
 #define MIME_SUPERCLASS mimeInlineTextClass
 MimeDefClass(MimeInlineTextPlainFlowed, MimeInlineTextPlainFlowedClass,
-       mimeInlineTextPlainFlowedClass, &MIME_SUPERCLASS);
+             mimeInlineTextPlainFlowedClass, &MIME_SUPERCLASS);
 
-static int MimeInlineTextPlainFlowed_parse_begin (MimeObject *);
-static int MimeInlineTextPlainFlowed_parse_line (const char *, int32_t, MimeObject *);
-static int MimeInlineTextPlainFlowed_parse_eof (MimeObject *, bool);
+static int MimeInlineTextPlainFlowed_parse_begin(MimeObject *);
+static int MimeInlineTextPlainFlowed_parse_line(const char *, int32_t,
+                                                MimeObject *);
+static int MimeInlineTextPlainFlowed_parse_eof(MimeObject *, bool);
 
-static MimeInlineTextPlainFlowedExData *MimeInlineTextPlainFlowedExDataList = nullptr;
+static MimeInlineTextPlainFlowedExData *MimeInlineTextPlainFlowedExDataList =
+    nullptr;
 
 // From mimetpla.cpp
 extern "C" void MimeTextBuildPrefixCSS(
-                       int32_t quotedSizeSetting,      // mail.quoted_size
-                       int32_t    quotedStyleSetting,  // mail.quoted_style
-                       nsACString &citationColor,      // mail.citation_color
-                       nsACString &style);
+    int32_t quotedSizeSetting,   // mail.quoted_size
+    int32_t quotedStyleSetting,  // mail.quoted_style
+    nsACString &citationColor,   // mail.citation_color
+    nsACString &style);
 // Definition below
-static
-nsresult Line_convert_whitespace(const nsString& a_line,
-                                 const bool a_convert_all_whitespace,
-                                 nsString& a_out_line);
+static nsresult Line_convert_whitespace(const nsString &a_line,
+                                        const bool a_convert_all_whitespace,
+                                        nsString &a_out_line);
 
-static int
-MimeInlineTextPlainFlowedClassInitialize(MimeInlineTextPlainFlowedClass *clazz)
-{
-  MimeObjectClass *oclass = (MimeObjectClass *) clazz;
+static int MimeInlineTextPlainFlowedClassInitialize(
+    MimeInlineTextPlainFlowedClass *clazz) {
+  MimeObjectClass *oclass = (MimeObjectClass *)clazz;
   NS_ASSERTION(!oclass->class_initialized, "class not initialized");
   oclass->parse_begin = MimeInlineTextPlainFlowed_parse_begin;
-  oclass->parse_line  = MimeInlineTextPlainFlowed_parse_line;
-  oclass->parse_eof   = MimeInlineTextPlainFlowed_parse_eof;
+  oclass->parse_line = MimeInlineTextPlainFlowed_parse_line;
+  oclass->parse_eof = MimeInlineTextPlainFlowed_parse_eof;
 
   return 0;
 }
 
-static int
-MimeInlineTextPlainFlowed_parse_begin (MimeObject *obj)
-{
-  int status = ((MimeObjectClass*)&MIME_SUPERCLASS)->parse_begin(obj);
+static int MimeInlineTextPlainFlowed_parse_begin(MimeObject *obj) {
+  int status = ((MimeObjectClass *)&MIME_SUPERCLASS)->parse_begin(obj);
   if (status < 0) return status;
 
-  status =  MimeObject_write(obj, "", 0, true); /* force out any separators... */
-  if(status<0) return status;
+  status = MimeObject_write(obj, "", 0, true); /* force out any separators... */
+  if (status < 0) return status;
 
-  bool quoting = ( obj->options
-    && ( obj->options->format_out == nsMimeOutput::nsMimeMessageQuoting ||
-         obj->options->format_out == nsMimeOutput::nsMimeMessageBodyQuoting
-       )       );  // The output will be inserted in the composer as quotation
-  bool plainHTML = quoting || (obj->options &&
-       obj->options->format_out == nsMimeOutput::nsMimeMessageSaveAs);
-       // Just good(tm) HTML. No reliance on CSS.
+  bool quoting =
+      (obj->options &&
+       (obj->options->format_out == nsMimeOutput::nsMimeMessageQuoting ||
+        obj->options->format_out ==
+            nsMimeOutput::nsMimeMessageBodyQuoting));  // The output will be
+                                                       // inserted in the
+                                                       // composer as quotation
+  bool plainHTML =
+      quoting || (obj->options && obj->options->format_out ==
+                                      nsMimeOutput::nsMimeMessageSaveAs);
+  // Just good(tm) HTML. No reliance on CSS.
 
   // Setup the data structure that is connected to the actual document
   // Saved in a linked list in case this is called with several documents
   // at the same time.
   /* This memory is freed when parse_eof is called. So it better be! */
   struct MimeInlineTextPlainFlowedExData *exdata =
-    (MimeInlineTextPlainFlowedExData *)PR_MALLOC(sizeof(struct MimeInlineTextPlainFlowedExData));
-  if(!exdata) return MIME_OUT_OF_MEMORY;
+      (MimeInlineTextPlainFlowedExData *)PR_MALLOC(
+          sizeof(struct MimeInlineTextPlainFlowedExData));
+  if (!exdata) return MIME_OUT_OF_MEMORY;
 
-  MimeInlineTextPlainFlowed *text = (MimeInlineTextPlainFlowed *) obj;
+  MimeInlineTextPlainFlowed *text = (MimeInlineTextPlainFlowed *)obj;
 
   // Link it up.
   exdata->next = MimeInlineTextPlainFlowedExDataList;
@@ -93,14 +95,15 @@ MimeInlineTextPlainFlowed_parse_begin (MimeObject *obj)
   // check for DelSp=yes (RFC 3676)
 
   char *content_type_row =
-    (obj->headers
-     ? MimeHeaders_get(obj->headers, HEADER_CONTENT_TYPE, false, false)
-     : 0);
+      (obj->headers
+           ? MimeHeaders_get(obj->headers, HEADER_CONTENT_TYPE, false, false)
+           : 0);
   char *content_type_delsp =
-    (content_type_row
-     ? MimeHeaders_get_parameter(content_type_row, "delsp", NULL,NULL)
-     : 0);
-  ((MimeInlineTextPlainFlowed *)obj)->delSp = content_type_delsp && !PL_strcasecmp(content_type_delsp, "yes");
+      (content_type_row
+           ? MimeHeaders_get_parameter(content_type_row, "delsp", NULL, NULL)
+           : 0);
+  ((MimeInlineTextPlainFlowed *)obj)->delSp =
+      content_type_delsp && !PL_strcasecmp(content_type_delsp, "yes");
   PR_Free(content_type_delsp);
   PR_Free(content_type_row);
 
@@ -108,46 +111,41 @@ MimeInlineTextPlainFlowed_parse_begin (MimeObject *obj)
 
   exdata->fixedwidthfont = false;
   //  Quotes
-  text->mQuotedSizeSetting = 0;   // mail.quoted_size
-  text->mQuotedStyleSetting = 0;  // mail.quoted_style
+  text->mQuotedSizeSetting = 0;     // mail.quoted_size
+  text->mQuotedStyleSetting = 0;    // mail.quoted_style
   text->mCitationColor.Truncate();  // mail.citation_color
-  text->mStripSig = true; // mail.strip_sig_on_reply
+  text->mStripSig = true;           // mail.strip_sig_on_reply
 
   nsIPrefBranch *prefBranch = GetPrefBranch(obj->options);
-  if (prefBranch)
-  {
+  if (prefBranch) {
     prefBranch->GetIntPref("mail.quoted_size", &(text->mQuotedSizeSetting));
     prefBranch->GetIntPref("mail.quoted_style", &(text->mQuotedStyleSetting));
     prefBranch->GetCharPref("mail.citation_color", text->mCitationColor);
     prefBranch->GetBoolPref("mail.strip_sig_on_reply", &(text->mStripSig));
-    mozilla::DebugOnly<nsresult> rv =
-      prefBranch->GetBoolPref("mail.fixed_width_messages", &(exdata->fixedwidthfont));
+    mozilla::DebugOnly<nsresult> rv = prefBranch->GetBoolPref(
+        "mail.fixed_width_messages", &(exdata->fixedwidthfont));
     NS_ASSERTION(NS_SUCCEEDED(rv), "failed to get pref");
-         // Check at least the success of one
+    // Check at least the success of one
   }
 
   // Get font
   // only used for viewing (!plainHTML)
   nsAutoCString fontstyle;
-  nsAutoCString fontLang;     // langgroup of the font
-
+  nsAutoCString fontLang;  // langgroup of the font
 
   // generic font-family name ( -moz-fixed for fixed font and NULL for
   // variable font ) is sufficient now that bug 105199 has been fixed.
 
-  if (exdata->fixedwidthfont)
-    fontstyle = "font-family: -moz-fixed";
+  if (exdata->fixedwidthfont) fontstyle = "font-family: -moz-fixed";
 
   if (nsMimeOutput::nsMimeMessageBodyDisplay == obj->options->format_out ||
-      nsMimeOutput::nsMimeMessagePrintOutput == obj->options->format_out)
-  {
-    int32_t fontSize;       // default font size
-    int32_t fontSizePercentage;   // size percentage
-    nsresult rv = GetMailNewsFont(obj, exdata->fixedwidthfont,
-                                  &fontSize, &fontSizePercentage, fontLang);
-    if (NS_SUCCEEDED(rv))
-    {
-      if ( ! fontstyle.IsEmpty() ) {
+      nsMimeOutput::nsMimeMessagePrintOutput == obj->options->format_out) {
+    int32_t fontSize;            // default font size
+    int32_t fontSizePercentage;  // size percentage
+    nsresult rv = GetMailNewsFont(obj, exdata->fixedwidthfont, &fontSize,
+                                  &fontSizePercentage, fontLang);
+    if (NS_SUCCEEDED(rv)) {
+      if (!fontstyle.IsEmpty()) {
         fontstyle += "; ";
       }
       fontstyle += "font-size: ";
@@ -158,48 +156,46 @@ MimeInlineTextPlainFlowed_parse_begin (MimeObject *obj)
 
   // Opening <div>.
   if (!quoting)
-       /* 4.x' editor can't break <div>s (e.g. to interleave comments).
-          We'll add the class to the <blockquote type=cite> later. */
+  /* 4.x' editor can't break <div>s (e.g. to interleave comments).
+     We'll add the class to the <blockquote type=cite> later. */
   {
     nsAutoCString openingDiv("<div class=\"moz-text-flowed\"");
     // We currently have to add formatting here. :-(
-    if (!plainHTML && !fontstyle.IsEmpty())
-    {
+    if (!plainHTML && !fontstyle.IsEmpty()) {
       openingDiv += " style=\"";
       openingDiv += fontstyle;
       openingDiv += '"';
     }
-    if (!plainHTML && !fontLang.IsEmpty())
-    {
+    if (!plainHTML && !fontLang.IsEmpty()) {
       openingDiv += " lang=\"";
       openingDiv += fontLang;
       openingDiv += '\"';
     }
     openingDiv += ">";
-    status = MimeObject_write(obj, openingDiv.get(), openingDiv.Length(), false);
+    status =
+        MimeObject_write(obj, openingDiv.get(), openingDiv.Length(), false);
     if (status < 0) return status;
   }
 
   return 0;
 }
 
-static int
-MimeInlineTextPlainFlowed_parse_eof (MimeObject *obj, bool abort_p)
-{
+static int MimeInlineTextPlainFlowed_parse_eof(MimeObject *obj, bool abort_p) {
   int status = 0;
   struct MimeInlineTextPlainFlowedExData *exdata = nullptr;
 
-  bool quoting = ( obj->options
-    && ( obj->options->format_out == nsMimeOutput::nsMimeMessageQuoting ||
-         obj->options->format_out == nsMimeOutput::nsMimeMessageBodyQuoting
-       )           );  // see above
+  bool quoting =
+      (obj->options &&
+       (obj->options->format_out == nsMimeOutput::nsMimeMessageQuoting ||
+        obj->options->format_out ==
+            nsMimeOutput::nsMimeMessageBodyQuoting));  // see above
 
   // Has this method already been called for this object?
   // In that case return.
   if (obj->closed_p) return 0;
 
   /* Run parent method first, to flush out any buffered data. */
-  status = ((MimeObjectClass*)&MIME_SUPERCLASS)->parse_eof(obj, abort_p);
+  status = ((MimeObjectClass *)&MIME_SUPERCLASS)->parse_eof(obj, abort_p);
   if (status < 0) goto EarlyOut;
 
   // Look up and unlink "our" extended data structure
@@ -216,26 +212,26 @@ MimeInlineTextPlainFlowed_parse_eof (MimeObject *obj, bool abort_p)
     }
     prevexdata = &exdata->next;
   }
-  NS_ASSERTION (exdata, "The extra data has disappeared!");
+  NS_ASSERTION(exdata, "The extra data has disappeared!");
 
   if (!obj->output_p) {
     status = 0;
     goto EarlyOut;
   }
 
-  for(; exdata->quotelevel > 0; exdata->quotelevel--) {
+  for (; exdata->quotelevel > 0; exdata->quotelevel--) {
     status = MimeObject_write(obj, "</blockquote>", 13, false);
-    if(status<0) goto EarlyOut;
+    if (status < 0) goto EarlyOut;
   }
 
   if (exdata->isSig && !quoting) {
-    status = MimeObject_write(obj, "</div>", 6, false); // .moz-txt-sig
-    if (status<0) goto EarlyOut;
+    status = MimeObject_write(obj, "</div>", 6, false);  // .moz-txt-sig
+    if (status < 0) goto EarlyOut;
   }
-  if (!quoting) // HACK (see above)
+  if (!quoting)  // HACK (see above)
   {
-    status = MimeObject_write(obj, "</div>", 6, false); // .moz-text-flowed
-    if (status<0) goto EarlyOut;
+    status = MimeObject_write(obj, "</div>", 6, false);  // .moz-text-flowed
+    if (status < 0) goto EarlyOut;
   }
 
   status = 0;
@@ -244,28 +240,29 @@ EarlyOut:
   PR_Free(exdata);
 
   // Clear mCitationColor
-  MimeInlineTextPlainFlowed *text = (MimeInlineTextPlainFlowed *) obj;
+  MimeInlineTextPlainFlowed *text = (MimeInlineTextPlainFlowed *)obj;
   text->mCitationColor.Truncate();
 
   return status;
 }
 
-
-static int
-MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObject *obj)
-{
+static int MimeInlineTextPlainFlowed_parse_line(const char *aLine,
+                                                int32_t length,
+                                                MimeObject *obj) {
   int status;
-  bool quoting = ( obj->options
-    && ( obj->options->format_out == nsMimeOutput::nsMimeMessageQuoting ||
-         obj->options->format_out == nsMimeOutput::nsMimeMessageBodyQuoting
-       )           );  // see above
-  bool plainHTML = quoting || (obj->options &&
-       obj->options->format_out == nsMimeOutput::nsMimeMessageSaveAs);
-       // see above
+  bool quoting =
+      (obj->options &&
+       (obj->options->format_out == nsMimeOutput::nsMimeMessageQuoting ||
+        obj->options->format_out ==
+            nsMimeOutput::nsMimeMessageBodyQuoting));  // see above
+  bool plainHTML =
+      quoting || (obj->options && obj->options->format_out ==
+                                      nsMimeOutput::nsMimeMessageSaveAs);
+  // see above
 
   struct MimeInlineTextPlainFlowedExData *exdata;
   exdata = MimeInlineTextPlainFlowedExDataList;
-  while(exdata && (exdata->ownerobj != obj)) {
+  while (exdata && (exdata->ownerobj != obj)) {
     exdata = exdata->next;
   }
 
@@ -279,16 +276,16 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
   char *line = real_line.BeginWriting();
   const char *linep = real_line.BeginReading();
   // Space stuffed?
-  if(' ' == *linep) {
+  if (' ' == *linep) {
     linep++;
   } else {
     // count '>':s before the first non-'>'
-    while('>' == *linep) {
+    while ('>' == *linep) {
       linep++;
       linequotelevel++;
     }
     // Space stuffed?
-    if(' ' == *linep) {
+    if (' ' == *linep) {
       linep++;
     }
   }
@@ -300,41 +297,39 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
   // be the case always.
   bool flowed = false;
   bool sigSeparator = false;
-  int32_t index = length-1;
-  while(index >= 0 && ('\r' == line[index] || '\n' == line[index])) {
+  int32_t index = length - 1;
+  while (index >= 0 && ('\r' == line[index] || '\n' == line[index])) {
     index--;
   }
   if (index > linep - line && ' ' == line[index])
-       /* Ignore space stuffing, i.e. lines with just
-          (quote marks and) a space count as empty */
+  /* Ignore space stuffing, i.e. lines with just
+     (quote marks and) a space count as empty */
   {
     flowed = true;
-    sigSeparator = (index - (linep - line) + 1 == 3) && !strncmp(linep, "-- ", 3);
-    if (((MimeInlineTextPlainFlowed *) obj)->delSp && !sigSeparator)
-       /* If line is flowed and DelSp=yes, logically
-          delete trailing space. Line consisting of
-          dash dash space ("-- "), commonly used as
-          signature separator, gets special handling
-          (RFC 3676) */
+    sigSeparator =
+        (index - (linep - line) + 1 == 3) && !strncmp(linep, "-- ", 3);
+    if (((MimeInlineTextPlainFlowed *)obj)->delSp && !sigSeparator)
+    /* If line is flowed and DelSp=yes, logically
+       delete trailing space. Line consisting of
+       dash dash space ("-- "), commonly used as
+       signature separator, gets special handling
+       (RFC 3676) */
     {
       length = index;
       line[index] = '\0';
     }
   }
 
-  if (obj->options &&
-      obj->options->decompose_file_p &&
-      obj->options->decompose_file_output_fn)
-  {
-    return obj->options->decompose_file_output_fn(line,
-                                                  length,
+  if (obj->options && obj->options->decompose_file_p &&
+      obj->options->decompose_file_output_fn) {
+    return obj->options->decompose_file_output_fn(line, length,
                                                   obj->options->stream_closure);
   }
 
   mozITXTToHTMLConv *conv = GetTextConverter(obj->options);
 
-  bool skipConversion = !conv ||
-                          (obj->options && obj->options->force_user_charset);
+  bool skipConversion =
+      !conv || (obj->options && obj->options->force_user_charset);
 
   nsAutoString lineSource;
   nsString lineResult;
@@ -342,54 +337,48 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
   char *mailCharset = NULL;
   nsresult rv;
 
-  if (!skipConversion)
-  {
+  if (!skipConversion) {
     // Convert only if the source string is not empty
-    if (length - (linep - line) > 0)
-    {
+    if (length - (linep - line) > 0) {
       uint32_t whattodo = obj->options->whattodo;
-      if (plainHTML)
-      {
+      if (plainHTML) {
         if (quoting)
           whattodo = 0;
         else
           whattodo = whattodo & ~mozITXTToHTMLConv::kGlyphSubstitution;
-                    /* Do recognition for the case, the result is viewed in
-                        Mozilla, but not GlyphSubstitution, because other UAs
-                        might not be able to display the glyphs. */
+        /* Do recognition for the case, the result is viewed in
+            Mozilla, but not GlyphSubstitution, because other UAs
+            might not be able to display the glyphs. */
       }
 
-      const nsDependentCSubstring& inputStr = Substring(linep, linep + (length - (linep - line)));
+      const nsDependentCSubstring &inputStr =
+          Substring(linep, linep + (length - (linep - line)));
 
       // For 'SaveAs', |line| is in |mailCharset|.
       // convert |line| to UTF-16 before 'html'izing (calling ScanTXT())
-      if (obj->options->format_out == nsMimeOutput::nsMimeMessageSaveAs)
-      {
+      if (obj->options->format_out == nsMimeOutput::nsMimeMessageSaveAs) {
         // Get the mail charset of this message.
-        MimeInlineText  *inlinetext = (MimeInlineText *) obj;
+        MimeInlineText *inlinetext = (MimeInlineText *)obj;
         if (!inlinetext->initializeCharset)
-          ((MimeInlineTextClass*)&mimeInlineTextClass)->initialize_charset(obj);
+          ((MimeInlineTextClass *)&mimeInlineTextClass)
+              ->initialize_charset(obj);
         mailCharset = inlinetext->charset;
         if (mailCharset && *mailCharset) {
           rv = nsMsgI18NConvertToUnicode(nsDependentCString(mailCharset),
                                          PromiseFlatCString(inputStr),
                                          lineSource);
           NS_ENSURE_SUCCESS(rv, -1);
-        }
-        else // this probably never happens...
+        } else  // this probably never happens...
           CopyUTF8toUTF16(inputStr, lineSource);
-      }
-      else   // line is in UTF-8
+      } else  // line is in UTF-8
         CopyUTF8toUTF16(inputStr, lineSource);
 
       // This is the main TXT to HTML conversion:
       // escaping (very important), eventually recognizing etc.
-      rv = conv->ScanTXT(lineSource.get(), whattodo, getter_Copies(lineResult));
+      rv = conv->ScanTXT(lineSource, whattodo, lineResult);
       NS_ENSURE_SUCCESS(rv, -1);
     }
-  }
-  else
-  {
+  } else {
     CopyUTF8toUTF16(nsDependentCString(line, length), lineResult);
     status = 0;
   }
@@ -397,34 +386,33 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
   nsAutoCString preface;
 
   /* Correct number of blockquotes */
-  int32_t quoteleveldiff=linequotelevel - exdata->quotelevel;
-  if((quoteleveldiff != 0) && flowed && exdata->inflow) {
+  int32_t quoteleveldiff = linequotelevel - exdata->quotelevel;
+  if ((quoteleveldiff != 0) && flowed && exdata->inflow) {
     // From RFC 2646 4.5
-    // The receiver SHOULD handle this error by using the 'quote-depth-wins' rule,
-    // which is to ignore the flowed indicator and treat the line as fixed.  That
-    // is, the change in quote depth ends the paragraph.
+    // The receiver SHOULD handle this error by using the 'quote-depth-wins'
+    // rule, which is to ignore the flowed indicator and treat the line as
+    // fixed.  That is, the change in quote depth ends the paragraph.
 
     // We get that behaviour by just going on.
   }
 
   // Cast so we have access to the prefs we need.
-  MimeInlineTextPlainFlowed *tObj = (MimeInlineTextPlainFlowed *) obj;
-  while(quoteleveldiff>0) {
+  MimeInlineTextPlainFlowed *tObj = (MimeInlineTextPlainFlowed *)obj;
+  while (quoteleveldiff > 0) {
     quoteleveldiff--;
     preface += "<blockquote type=cite";
 
     nsAutoCString style;
     MimeTextBuildPrefixCSS(tObj->mQuotedSizeSetting, tObj->mQuotedStyleSetting,
                            tObj->mCitationColor, style);
-    if (!plainHTML && !style.IsEmpty())
-    {
+    if (!plainHTML && !style.IsEmpty()) {
       preface += " style=\"";
       preface += style;
       preface += '"';
     }
     preface += '>';
   }
-  while(quoteleveldiff<0) {
+  while (quoteleveldiff < 0) {
     quoteleveldiff++;
     preface += "</blockquote>";
   }
@@ -432,49 +420,45 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
 
   nsAutoString lineResult2;
 
-  if(flowed) {
+  if (flowed) {
     // Check RFC 2646 "4.3. Usenet Signature Convention": "-- "+CRLF is
     // not a flowed line
-    if (sigSeparator)
-    {
-      if (linequotelevel > 0 || exdata->isSig)
-      {
+    if (sigSeparator) {
+      if (linequotelevel > 0 || exdata->isSig) {
         preface += "--&nbsp;<br>";
       } else {
         exdata->isSig = true;
-        preface += "<div class=\"moz-txt-sig\"><span class=\"moz-txt-tag\">"
-                   "--&nbsp;<br></span>";
+        preface +=
+            "<div class=\"moz-txt-sig\"><span class=\"moz-txt-tag\">"
+            "--&nbsp;<br></span>";
       }
     } else {
-      Line_convert_whitespace(lineResult, false /* Allow wraps */,
-                              lineResult2);
+      Line_convert_whitespace(lineResult, false /* Allow wraps */, lineResult2);
     }
 
-    exdata->inflow=true;
+    exdata->inflow = true;
   } else {
     // Fixed paragraph.
     Line_convert_whitespace(lineResult,
                             !plainHTML && !obj->options->wrap_long_lines_p
-                              /* If wrap, convert all spaces but the last in
-                                 a row into nbsp, otherwise all. */,
+                            /* If wrap, convert all spaces but the last in
+                               a row into nbsp, otherwise all. */
+                            ,
                             lineResult2);
     lineResult2.AppendLiteral("<br>");
     exdata->inflow = false;
-  } // End Fixed line
+  }  // End Fixed line
 
-  if (!(exdata->isSig && quoting && tObj->mStripSig))
-  {
+  if (!(exdata->isSig && quoting && tObj->mStripSig)) {
     status = MimeObject_write(obj, preface.get(), preface.Length(), true);
     if (status < 0) return status;
     nsAutoCString outString;
     if (obj->options->format_out != nsMimeOutput::nsMimeMessageSaveAs ||
         !mailCharset || !*mailCharset)
       CopyUTF16toUTF8(lineResult2, outString);
-    else
-    { // convert back to mailCharset before writing.
+    else {  // convert back to mailCharset before writing.
       rv = nsMsgI18NConvertFromUnicode(nsDependentCString(mailCharset),
-                                       lineResult2,
-                                       outString);
+                                       lineResult2, outString);
       NS_ENSURE_SUCCESS(rv, -1);
     }
     status = MimeObject_write(obj, outString.get(), outString.Length(), true);
@@ -483,7 +467,6 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
   return 0;
 }
 
-
 /**
  * Maintains a small state machine with three states. "Not in tag",
  * "In tag, but not in quote" and "In quote inside a tag". It also
@@ -497,37 +480,38 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
  * @param in a_current_char, the next char. It decides which state
  *                           will be next.
  */
-static void Update_in_tag_info(bool *a_in_tag, /* IN/OUT */
-                   bool *a_in_quote_in_tag, /* IN/OUT */
-                   char16_t *a_quote_char, /* IN/OUT (pointer to single char) */
-                   char16_t a_current_char) /* IN */
+static void Update_in_tag_info(
+    bool *a_in_tag,          /* IN/OUT */
+    bool *a_in_quote_in_tag, /* IN/OUT */
+    char16_t *a_quote_char,  /* IN/OUT (pointer to single char) */
+    char16_t a_current_char) /* IN */
 {
-  if(*a_in_tag) {
+  if (*a_in_tag) {
     // Keep us informed of what's quoted so that we
     // don't end the tag too soon. For instance in
     // <font face="weird>font<name">
-    if(*a_in_quote_in_tag) {
+    if (*a_in_quote_in_tag) {
       // We are in a quote. A quote is ended by the same
       // character that started it ('...' or "...")
-      if(*a_quote_char == a_current_char) {
+      if (*a_quote_char == a_current_char) {
         *a_in_quote_in_tag = false;
       }
     } else {
       // We are not currently in a quote, but we may enter
       // one right this minute.
-      switch(a_current_char) {
-      case '"':
-      case '\'':
-        *a_in_quote_in_tag = true;
-        *a_quote_char = a_current_char;
-        break;
-      case '>':
-        // Tag is ended
-        *a_in_tag = false;
-        break;
-      default:
-        // Do nothing
-        ;
+      switch (a_current_char) {
+        case '"':
+        case '\'':
+          *a_in_quote_in_tag = true;
+          *a_quote_char = a_current_char;
+          break;
+        case '>':
+          // Tag is ended
+          *a_in_tag = false;
+          break;
+        default:
+            // Do nothing
+            ;
       }
     }
     return;
@@ -543,7 +527,6 @@ static void Update_in_tag_info(bool *a_in_tag, /* IN/OUT */
   }
 }
 
-
 /**
  * Converts whitespace to |&nbsp;|, if appropriate.
  *
@@ -553,35 +536,34 @@ static void Update_in_tag_info(bool *a_in_tag, /* IN/OUT */
  *                                     in a sequence should be
  *                                     converted.
  * @param out a_out_string, result will be appended.
-*/
+ */
 static void Convert_whitespace(const char16_t a_current_char,
                                const char16_t a_next_char,
                                const bool a_convert_all_whitespace,
-                               nsString& a_out_string)
-{
+                               nsString &a_out_string) {
   NS_ASSERTION('\t' == a_current_char || ' ' == a_current_char,
                "Convert_whitespace got something else than a whitespace!");
 
   uint32_t number_of_nbsp = 0;
-  uint32_t number_of_space = 1; // Assume we're going to output one space.
+  uint32_t number_of_space = 1;  // Assume we're going to output one space.
 
   /* Output the spaces for a tab. All but the last are made into &nbsp;.
      The last is treated like a normal space.
   */
-  if('\t' == a_current_char) {
+  if ('\t' == a_current_char) {
     number_of_nbsp = kSpacesForATab - 1;
   }
 
-  if(' ' == a_next_char || '\t' == a_next_char || a_convert_all_whitespace) {
+  if (' ' == a_next_char || '\t' == a_next_char || a_convert_all_whitespace) {
     number_of_nbsp += number_of_space;
     number_of_space = 0;
   }
 
-  while(number_of_nbsp--) {
+  while (number_of_nbsp--) {
     a_out_string.AppendLiteral("&nbsp;");
   }
 
-  while(number_of_space--) {
+  while (number_of_space--) {
     // a_out_string += ' '; gives error
     a_out_string.Append(' ');
   }
@@ -596,18 +578,15 @@ static void Convert_whitespace(const char16_t a_current_char,
  *                                     in a sequence should be
  *                                     converted.
  * @param out a_out_string, result will be appended.
-*/
-static
-nsresult Line_convert_whitespace(const nsString& a_line,
-                                 const bool a_convert_all_whitespace,
-                                 nsString& a_out_line)
-{
+ */
+static nsresult Line_convert_whitespace(const nsString &a_line,
+                                        const bool a_convert_all_whitespace,
+                                        nsString &a_out_line) {
   bool in_tag = false;
   bool in_quote_in_tag = false;
   char16_t quote_char;
 
-  for (uint32_t i = 0; a_line.Length() > i; i++)
-  {
+  for (uint32_t i = 0; a_line.Length() > i; i++) {
     const char16_t ic = a_line[i];  // Cache
 
     Update_in_tag_info(&in_tag, &in_quote_in_tag, &quote_char, ic);
@@ -615,10 +594,10 @@ nsresult Line_convert_whitespace(const nsString& a_line,
     if (!in_tag) {
       if (ic == ' ' || ic == '\t') {
         // Convert the whitespace to something appropriate
-        Convert_whitespace(ic, a_line.Length() > i + 1 ? a_line[i + 1] : '\0',
-                           a_convert_all_whitespace ||
-                           !i, // First char on line
-                           a_out_line);
+        Convert_whitespace(
+            ic, a_line.Length() > i + 1 ? a_line[i + 1] : '\0',
+            a_convert_all_whitespace || !i,  // First char on line
+            a_out_line);
       } else if (ic == '\r') {
         // strip CRs
       } else {
