@@ -9,8 +9,6 @@
 #include "nsString.h"
 #include "MailNewsTypes2.h"
 
-class nsIMsgNewsFolder;
-
 #define kNewsRootURI "news:/"
 #define kNntpRootURI "nntp:/"
 #define kNewsMessageRootURI "news-message:/"
@@ -23,11 +21,10 @@ class nsIMsgNewsFolder;
 #define kNewsURIGroupQueryLen 7
 #define kNewsURIKeyQueryLen 5
 
-extern nsresult
-nsParseNewsMessageURI(const char* uri, nsCString& group, nsMsgKey *key);
+extern nsresult nsParseNewsMessageURI(const char *uri, nsCString &group,
+                                      nsMsgKey *key);
 
-extern nsresult
-nsCreateNewsBaseMessageURI(const char *baseURI, nsCString &baseMessageURI);
-
-#endif //NS_NEWSUTILS_H
+extern nsresult nsCreateNewsBaseMessageURI(const char *baseURI,
+                                           nsCString &baseMessageURI);
 
+#endif  // NS_NEWSUTILS_H
