@@ -9,9 +9,9 @@
  **/
 
 // Services = object with smart getters for common XPCOM services
-ChromeUtils.import("resource://gre/modules/Services.jsm");
-ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
-ChromeUtils.import("resource://gre/modules/BrowserUtils.jsm");
+var {Services} = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var {XPCOMUtils} = ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
+var {BrowserUtils} = ChromeUtils.import("resource://gre/modules/BrowserUtils.jsm");
 
 // XPCOMUtils.defineLazyGetter(this, "Weave", function() {
 //   let tmp = {};
@@ -1940,8 +1940,7 @@ function GetFileFromString(aString)
 
 function CopyImage()
 {
-  var param = Cc["@mozilla.org/embedcomp/command-params;1"]
-                .createInstance(Ci.nsICommandParams);
+  var param = Cu.createCommandParams();
   param.setLongValue("imageCopy",
                      Ci.nsIContentViewerEdit.COPY_IMAGE_ALL);
   document.commandDispatcher.getControllerForCommand("cmd_copyImage")
