@@ -3,8 +3,8 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
-ChromeUtils.import("resource://gre/modules/Services.jsm");
+var {Services} = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var {XPCOMUtils} = ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
 
 XPCOMUtils.defineLazyModuleGetters(this, {
   Downloads: "resource://gre/modules/Downloads.jsm",
@@ -916,7 +916,8 @@ function saveMedia()
         titleKey = "SaveAudioTitle";
 
       saveURL(url, null, titleKey, false, false, makeURI(item.baseURI),
-              null, (opener.gPrivate ? true : false));
+              null, (opener.gPrivate ? true : false),
+              gDocument.nodePrincipal);
     }
   } else {
     selectSaveFolder(function(aDirectory) {
@@ -925,7 +926,8 @@ function saveMedia()
           uniqueFile(aChosenData.file);
           internalSave(aURIString, null, null, null, null, false,
                        "SaveImageTitle", aChosenData, aBaseURI, null, false,
-                       null, (opener.gPrivate ? true : false));
+                       null, (opener.gPrivate ? true : false),
+                       gDocument.nodePrincipal);
         };
 
         for (var i = 0; i < rowArray.length; i++) {
