@@ -4,8 +4,8 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-ChromeUtils.import("resource://gre/modules/Services.jsm");
-ChromeUtils.import("resource://gre/modules/AppConstants.jsm");
+var {Services} = ChromeUtils.import("resource://gre/modules/Services.jsm");
+const {AppConstants} = ChromeUtils.import("resource://gre/modules/AppConstants.jsm");
 
 var kObserverService;
 
@@ -603,9 +603,9 @@ function filterCookies(aFilterValue)
 {
   var filterSet = [];
   for (let cookie of allCookies) {
-    if (cookie.rawHost.includes(aFilterValue) ||
-        cookie.name.includes(aFilterValue) ||
-        cookie.value.includes(aFilterValue))
+    if (cookie.rawHost.indexOf(aFilterValue) != -1 ||
+        cookie.name.indexOf(aFilterValue) != -1 ||
+        cookie.value.indexOf(aFilterValue) != -1)
       filterSet.push(cookie);
   }
   return filterSet;
