@@ -3,8 +3,8 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-ChromeUtils.import("resource://gre/modules/Services.jsm");
-ChromeUtils.import("resource:///modules/mailServices.js");
+var {Services} = ChromeUtils.import("resource://gre/modules/Services.jsm");
+const {MailServices} = ChromeUtils.import("resource:///modules/MailServices.jsm");
 
 var gEditButton;
 var gDeleteButton;
@@ -251,7 +251,8 @@ function toggleFilter(index)
     if (filter.unparseable)
     {
       Services.prompt.alert(window, null,
-                            gFilterBundle.getString("cannotEnableFilter"));
+                            gFilterBundle.getFormattedString("cannotEnableIncompatFilter",
+                            [document.getElementById("bundle_brand").getString("brandShortName")]));
       return false;
     }
     filter.enabled = !filter.enabled;
@@ -515,11 +516,13 @@ function getFilterFolderForSelection()
  */
 function getServerThatCanHaveFilters()
 {
-    var defaultIncomingServer = MailServices.accounts.defaultAccount.incomingServer;
-
-    // check to see if default server can have filters
-    if (defaultIncomingServer.canHaveFilters)
-      return defaultIncomingServer;
+    let defaultAccount = MailServices.accounts.defaultAccount;
+    if (defaultAccount) {
+      let defaultIncomingServer = defaultAccount.incomingServer;
+      // Check to see if default server can have filters.
+      if (defaultIncomingServer.canHaveFilters)
+        return defaultIncomingServer;
+    }
 
     // if it cannot, check all accounts to find a server
     // that can have filters
