@@ -58,13 +58,18 @@ function contentHandler(metadata, response) {
   }
 }
 
-function check_has_alt_data_in_index(aHasAltData) {
+function check_has_alt_data_in_index(aHasAltData, callback) {
   if (inChildProcess()) {
+    callback();
     return;
   }
-  var hasAltData = {};
-  cache_storage.getCacheIndexEntryAttrs(createURI(URL), "", hasAltData, {});
-  Assert.equal(hasAltData.value, aHasAltData);
+
+  syncWithCacheIOThread(() => {
+    var hasAltData = {};
+    cache_storage.getCacheIndexEntryAttrs(createURI(URL), "", hasAltData, {});
+    Assert.equal(hasAltData.value, aHasAltData);
+    callback();
+  }, true);
 }
 
 function run_test() {
@@ -96,20 +101,23 @@ function readServerContent(request, buffer) {
 
   Assert.equal(buffer, responseContent);
   Assert.equal(cc.alternativeDataType, "");
-  check_has_alt_data_in_index(false);
+  check_has_alt_data_in_index(false, () => {
+    executeSoon(() => {
+      var os = cc.openAlternativeOutputStream(
+        altContentType,
+        altContent.length
+      );
+      os.write(altContent, altContent.length);
+      os.close();
 
-  executeSoon(() => {
-    var os = cc.openAlternativeOutputStream(altContentType, altContent.length);
-    os.write(altContent, altContent.length);
-    os.close();
-
-    executeSoon(flushAndOpenAltChannel);
+      executeSoon(flushAndOpenAltChannel);
+    });
   });
 }
 
 // needs to be rooted
 var cacheFlushObserver = (cacheFlushObserver = {
-  observe: function() {
+  observe() {
     cacheFlushObserver = null;
     openAltChannel();
   },
@@ -146,12 +154,12 @@ function readAltContent(request, buffer) {
   Assert.equal(servedNotModified, true);
   Assert.equal(cc.alternativeDataType, altContentType);
   Assert.equal(buffer, altContent);
-  check_has_alt_data_in_index(true);
-
-  cc.getOriginalInputStream({
-    onInputStreamReady: function(aInputStream) {
-      executeSoon(() => readOriginalInputStream(aInputStream));
-    },
+  check_has_alt_data_in_index(true, () => {
+    cc.getOriginalInputStream({
+      onInputStreamReady(aInputStream) {
+        executeSoon(() => readOriginalInputStream(aInputStream));
+      },
+    });
   });
 }
 
@@ -182,7 +190,5 @@ function readEmptyAltContent(request, buffer) {
   // the cache is overwrite and the alt-data is reset
   Assert.equal(cc.alternativeDataType, "");
   Assert.equal(buffer, responseContent2);
-  check_has_alt_data_in_index(false);
-
-  httpServer.stop(do_test_finished);
+  check_has_alt_data_in_index(false, () => httpServer.stop(do_test_finished));
 }
