@@ -8,6 +8,7 @@
 #include "SandboxInfo.h"
 #include "SandboxLogging.h"
 
+#include "base/shared_memory.h"
 #include "mozilla/Array.h"
 #include "mozilla/ClearOnShutdown.h"
 #include "mozilla/Preferences.h"
@@ -29,11 +30,15 @@
 #include "nsNetCID.h"
 
 #ifdef ANDROID
-#include "cutils/properties.h"
+#  include "cutils/properties.h"
 #endif
 
 #ifdef MOZ_WIDGET_GTK
-#include <glib.h>
+#  include <glib.h>
+#  ifdef MOZ_WAYLAND
+#    include <gdk/gdk.h>
+#    include <gdk/gdkx.h>
+#  endif
 #endif
 
 #include <dirent.h>
@@ -41,27 +46,26 @@
 #include <sys/sysmacros.h>
 #include <sys/types.h>
 #ifndef ANDROID
-#include <glob.h>
+#  include <glob.h>
 #endif
 
 namespace mozilla {
 
-#if defined(MOZ_CONTENT_SANDBOX)
 namespace {
 static const int rdonly = SandboxBroker::MAY_READ;
 static const int wronly = SandboxBroker::MAY_WRITE;
 static const int rdwr = rdonly | wronly;
 static const int rdwrcr = rdwr | SandboxBroker::MAY_CREATE;
 static const int access = SandboxBroker::MAY_ACCESS;
-}
-#endif
+}  // namespace
 
-static void
-AddMesaSysfsPaths(SandboxBroker::Policy* aPolicy)
-{
+static void AddMesaSysfsPaths(SandboxBroker::Policy* aPolicy) {
   // Bug 1384178: Mesa driver loader
   aPolicy->AddPrefix(rdonly, "/sys/dev/char/226:");
 
+  // Bug 1480755: Mesa tries to probe /sys paths in turn
+  aPolicy->AddAncestors("/sys/dev/char/");
+
   // Bug 1401666: Mesa driver loader part 2: Mesa <= 12 using libudev
   if (auto dir = opendir("/dev/dri")) {
     while (auto entry = readdir(dir)) {
@@ -71,22 +75,29 @@ AddMesaSysfsPaths(SandboxBroker::Policy* aPolicy)
         if (stat(devPath.get(), &sb) == 0 && S_ISCHR(sb.st_mode)) {
           // For both the DRI node and its parent (the physical
           // device), allow reading the "uevent" file.
-          static const Array<const char*, 2> kSuffixes = { "", "/device" };
+          static const Array<const char*, 2> kSuffixes = {"", "/device"};
           for (const auto suffix : kSuffixes) {
-            nsPrintfCString sysPath("/sys/dev/char/%u:%u%s",
-                                    major(sb.st_rdev),
-                                    minor(sb.st_rdev),
-                                    suffix);
+            nsPrintfCString sysPath("/sys/dev/char/%u:%u%s", major(sb.st_rdev),
+                                    minor(sb.st_rdev), suffix);
             // libudev will expand the symlink but not do full
             // canonicalization, so it will leave in ".." path
             // components that will be realpath()ed in the
             // broker.  To match this, allow the canonical paths.
             UniqueFreePtr<char[]> realSysPath(realpath(sysPath.get(), nullptr));
             if (realSysPath) {
-              nsPrintfCString ueventPath("%s/uevent", realSysPath.get());
-              nsPrintfCString configPath("%s/config", realSysPath.get());
-              aPolicy->AddPath(rdonly, ueventPath.get());
-              aPolicy->AddPath(rdonly, configPath.get());
+              constexpr const char* kMesaAttrSuffixes[] = {
+                  "config",    "device",           "revision",
+                  "subsystem", "subsystem_device", "subsystem_vendor",
+                  "uevent",    "vendor",
+              };
+              for (const auto& attrSuffix : kMesaAttrSuffixes) {
+                nsPrintfCString attrPath("%s/%s", realSysPath.get(),
+                                         attrSuffix);
+                aPolicy->AddPath(rdonly, attrPath.get());
+              }
+              // Allowing stat-ing the parent dirs
+              nsPrintfCString basePath("%s/", realSysPath.get());
+              aPolicy->AddAncestors(basePath.get());
             }
           }
         }
@@ -96,9 +107,8 @@ AddMesaSysfsPaths(SandboxBroker::Policy* aPolicy)
   }
 }
 
-static void
-AddPathsFromFile(SandboxBroker::Policy* aPolicy, nsACString& aPath)
-{
+static void AddPathsFromFile(SandboxBroker::Policy* aPolicy,
+                             nsACString& aPath) {
   nsresult rv;
   nsCOMPtr<nsIFile> ldconfig(do_CreateInstance(NS_LOCAL_FILE_CONTRACTID, &rv));
   if (NS_FAILED(rv)) {
@@ -109,7 +119,7 @@ AddPathsFromFile(SandboxBroker::Policy* aPolicy, nsACString& aPath)
     return;
   }
   nsCOMPtr<nsIFileInputStream> fileStream(
-    do_CreateInstance(NS_LOCALFILEINPUTSTREAM_CONTRACTID, &rv));
+      do_CreateInstance(NS_LOCALFILEINPUTSTREAM_CONTRACTID, &rv));
   if (NS_FAILED(rv)) {
     return;
   }
@@ -125,6 +135,9 @@ AddPathsFromFile(SandboxBroker::Policy* aPolicy, nsACString& aPath)
   bool more = true;
   do {
     rv = lineStream->ReadLine(line, &more);
+    if (NS_FAILED(rv)) {
+      break;
+    }
     // Cut off any comments at the end of the line, also catches lines
     // that are entirely a comment
     int32_t hash = line.FindChar('#');
@@ -148,7 +161,8 @@ AddPathsFromFile(SandboxBroker::Policy* aPolicy, nsACString& aPath)
       nsAutoCString includes(Substring(token_end, end));
       for (const nsACString& includeGlob : includes.Split(' ')) {
         glob_t globbuf;
-        if (!glob(PromiseFlatCString(includeGlob).get(), GLOB_NOSORT, nullptr, &globbuf)) {
+        if (!glob(PromiseFlatCString(includeGlob).get(), GLOB_NOSORT, nullptr,
+                  &globbuf)) {
           for (size_t fileIdx = 0; fileIdx < globbuf.gl_pathc; fileIdx++) {
             nsAutoCString filePath(globbuf.gl_pathv[fileIdx]);
             AddPathsFromFile(aPolicy, filePath);
@@ -174,20 +188,22 @@ AddPathsFromFile(SandboxBroker::Policy* aPolicy, nsACString& aPath)
   } while (more);
 }
 
-static void
-AddLdconfigPaths(SandboxBroker::Policy* aPolicy)
-{
+static void AddLdconfigPaths(SandboxBroker::Policy* aPolicy) {
   nsAutoCString ldconfigPath(NS_LITERAL_CSTRING("/etc/ld.so.conf"));
   AddPathsFromFile(aPolicy, ldconfigPath);
 }
 
-SandboxBrokerPolicyFactory::SandboxBrokerPolicyFactory()
-{
+static void AddSharedMemoryPaths(SandboxBroker::Policy* aPolicy, pid_t aPid) {
+  std::string shmPath("/dev/shm");
+  if (base::SharedMemory::AppendPosixShmPrefix(&shmPath, aPid)) {
+    aPolicy->AddPrefix(rdwrcr, shmPath.c_str());
+  }
+}
+
+SandboxBrokerPolicyFactory::SandboxBrokerPolicyFactory() {
   // Policy entries that are the same in every process go here, and
   // are cached over the lifetime of the factory.
-#if defined(MOZ_CONTENT_SANDBOX)
   SandboxBroker::Policy* policy = new SandboxBroker::Policy;
-  policy->AddDir(rdwrcr, "/dev/shm");
   // Write permssions
   //
   // Bug 1308851: NVIDIA proprietary driver when using WebGL
@@ -251,14 +267,14 @@ SandboxBrokerPolicyFactory::SandboxBrokerPolicyFactory()
   // Extra configuration dirs in the homedir that we want to allow read
   // access to.
   mozilla::Array<const char*, 3> extraConfDirs = {
-    ".config",   // Fallback if XDG_CONFIG_PATH isn't set
-    ".themes",
-    ".fonts",
+      ".config",  // Fallback if XDG_CONFIG_PATH isn't set
+      ".themes",
+      ".fonts",
   };
 
   nsCOMPtr<nsIFile> homeDir;
-  nsresult rv = GetSpecialSystemDirectory(Unix_HomeDirectory,
-                                          getter_AddRefs(homeDir));
+  nsresult rv =
+      GetSpecialSystemDirectory(Unix_HomeDirectory, getter_AddRefs(homeDir));
   if (NS_SUCCEEDED(rv)) {
     nsCOMPtr<nsIFile> confDir;
 
@@ -347,17 +363,17 @@ SandboxBrokerPolicyFactory::SandboxBrokerPolicyFactory()
   }
 
   if (mozilla::IsDevelopmentBuild()) {
-    // If this is a developer build the resources are symlinks to outside the binary dir.
-    // Therefore in non-release builds we allow reads from the whole repository.
-    // MOZ_DEVELOPER_REPO_DIR is set by mach run.
-    const char *developer_repo_dir = PR_GetEnv("MOZ_DEVELOPER_REPO_DIR");
+    // If this is a developer build the resources are symlinks to outside the
+    // binary dir. Therefore in non-release builds we allow reads from the whole
+    // repository. MOZ_DEVELOPER_REPO_DIR is set by mach run.
+    const char* developer_repo_dir = PR_GetEnv("MOZ_DEVELOPER_REPO_DIR");
     if (developer_repo_dir) {
       policy->AddDir(rdonly, developer_repo_dir);
     }
   }
 
 #ifdef DEBUG
-  char *bloatLog = PR_GetEnv("XPCOM_MEM_BLOAT_LOG");
+  char* bloatLog = PR_GetEnv("XPCOM_MEM_BLOAT_LOG");
   // XPCOM_MEM_BLOAT_LOG has the format
   // /tmp/tmpd0YzFZ.mozrunner/runtests_leaks.log
   // but stores into /tmp/tmpd0YzFZ.mozrunner/runtests_leaks_tab_pid3411.log
@@ -380,48 +396,51 @@ SandboxBrokerPolicyFactory::SandboxBrokerPolicyFactory()
   }
   policy->AddPath(SandboxBroker::MAY_CONNECT, bumblebeeSocket);
 
+#if defined(MOZ_WIDGET_GTK)
   // Allow local X11 connections, for Primus and VirtualGL to contact
-  // the secondary X server.
+  // the secondary X server. No exception for Wayland.
+#  if defined(MOZ_WAYLAND)
+  if (GDK_IS_X11_DISPLAY(gdk_display_get_default())) {
+    policy->AddPrefix(SandboxBroker::MAY_CONNECT, "/tmp/.X11-unix/X");
+  }
+#  else
   policy->AddPrefix(SandboxBroker::MAY_CONNECT, "/tmp/.X11-unix/X");
+#  endif
   if (const auto xauth = PR_GetEnv("XAUTHORITY")) {
     policy->AddPath(rdonly, xauth);
   }
+#endif
 
   mCommonContentPolicy.reset(policy);
-#endif
 }
 
-#ifdef MOZ_CONTENT_SANDBOX
-UniquePtr<SandboxBroker::Policy>
-SandboxBrokerPolicyFactory::GetContentPolicy(int aPid, bool aFileProcess)
-{
+UniquePtr<SandboxBroker::Policy> SandboxBrokerPolicyFactory::GetContentPolicy(
+    int aPid, bool aFileProcess) {
   // Policy entries that vary per-process (currently the only reason
   // that can happen is because they contain the pid) are added here,
   // as well as entries that depend on preferences or paths not available
   // in early startup.
 
   MOZ_ASSERT(NS_IsMainThread());
-  // File broker usage is controlled through a pref.
-  if (!IsContentSandboxEnabled()) {
+  // The file broker is used at level 2 and up.
+  if (GetEffectiveContentSandboxLevel() <= 1) {
     return nullptr;
   }
 
   MOZ_ASSERT(mCommonContentPolicy);
-  UniquePtr<SandboxBroker::Policy>
-    policy(new SandboxBroker::Policy(*mCommonContentPolicy));
+  UniquePtr<SandboxBroker::Policy> policy(
+      new SandboxBroker::Policy(*mCommonContentPolicy));
 
   const int level = GetEffectiveContentSandboxLevel();
 
   // Read any extra paths that will get write permissions,
   // configured by the user or distro
   AddDynamicPathList(policy.get(),
-                     "security.sandbox.content.write_path_whitelist",
-                     rdwr);
+                     "security.sandbox.content.write_path_whitelist", rdwr);
 
   // Whitelisted for reading by the user/distro
   AddDynamicPathList(policy.get(),
-                    "security.sandbox.content.read_path_whitelist",
-                    rdonly);
+                     "security.sandbox.content.read_path_whitelist", rdonly);
 
   // No read blocking at level 2 and below.
   // file:// processes also get global read permissions
@@ -465,29 +484,29 @@ SandboxBrokerPolicyFactory::GetContentPolicy(int aPid, bool aFileProcess)
   rv = NS_GetSpecialDirectory(NS_APP_USER_PROFILE_50_DIR,
                               getter_AddRefs(profileDir));
   if (NS_SUCCEEDED(rv)) {
-      nsCOMPtr<nsIFile> workDir;
-      rv = profileDir->Clone(getter_AddRefs(workDir));
+    nsCOMPtr<nsIFile> workDir;
+    rv = profileDir->Clone(getter_AddRefs(workDir));
+    if (NS_SUCCEEDED(rv)) {
+      rv = workDir->AppendNative(NS_LITERAL_CSTRING("chrome"));
       if (NS_SUCCEEDED(rv)) {
-        rv = workDir->AppendNative(NS_LITERAL_CSTRING("chrome"));
+        nsAutoCString tmpPath;
+        rv = workDir->GetNativePath(tmpPath);
         if (NS_SUCCEEDED(rv)) {
-          nsAutoCString tmpPath;
-          rv = workDir->GetNativePath(tmpPath);
-          if (NS_SUCCEEDED(rv)) {
-            policy->AddDir(rdonly, tmpPath.get());
-          }
+          policy->AddDir(rdonly, tmpPath.get());
         }
       }
-      rv = profileDir->Clone(getter_AddRefs(workDir));
+    }
+    rv = profileDir->Clone(getter_AddRefs(workDir));
+    if (NS_SUCCEEDED(rv)) {
+      rv = workDir->AppendNative(NS_LITERAL_CSTRING("extensions"));
       if (NS_SUCCEEDED(rv)) {
-        rv = workDir->AppendNative(NS_LITERAL_CSTRING("extensions"));
+        nsAutoCString tmpPath;
+        rv = workDir->GetNativePath(tmpPath);
         if (NS_SUCCEEDED(rv)) {
-          nsAutoCString tmpPath;
-          rv = workDir->GetNativePath(tmpPath);
-          if (NS_SUCCEEDED(rv)) {
-            policy->AddDir(rdonly, tmpPath.get());
-          }
+          policy->AddDir(rdonly, tmpPath.get());
         }
       }
+    }
   }
 
   bool allowPulse = false;
@@ -506,6 +525,12 @@ SandboxBrokerPolicyFactory::GetContentPolicy(int aPid, bool aFileProcess)
     policy->AddDir(rdwr, "/dev/snd");
   }
 
+  if (allowPulse) {
+    policy->AddDir(rdwrcr, "/dev/shm");
+  } else {
+    AddSharedMemoryPaths(policy.get(), aPid);
+  }
+
 #ifdef MOZ_WIDGET_GTK
   if (const auto userDir = g_get_user_runtime_dir()) {
     // Bug 1321134: DConf's single bit of shared memory
@@ -521,7 +546,7 @@ SandboxBrokerPolicyFactory::GetContentPolicy(int aPid, bool aFileProcess)
       policy->AddPath(rdonly, pulsePath.get());
     }
   }
-#endif // MOZ_WIDGET_GTK
+#endif  // MOZ_WIDGET_GTK
 
   if (allowPulse) {
     // PulseAudio also needs access to read the $XAUTHORITY file (see
@@ -544,11 +569,8 @@ SandboxBrokerPolicyFactory::GetContentPolicy(int aPid, bool aFileProcess)
   return policy;
 }
 
-void
-SandboxBrokerPolicyFactory::AddDynamicPathList(SandboxBroker::Policy *policy,
-                                               const char* aPathListPref,
-                                               int perms)
-{
+void SandboxBrokerPolicyFactory::AddDynamicPathList(
+    SandboxBroker::Policy* policy, const char* aPathListPref, int perms) {
   nsAutoCString pathList;
   nsresult rv = Preferences::GetCString(aPathListPref, pathList);
   if (NS_SUCCEEDED(rv)) {
@@ -560,5 +582,16 @@ SandboxBrokerPolicyFactory::AddDynamicPathList(SandboxBroker::Policy *policy,
   }
 }
 
-#endif // MOZ_CONTENT_SANDBOX
-} // namespace mozilla
+/* static */ UniquePtr<SandboxBroker::Policy>
+SandboxBrokerPolicyFactory::GetUtilityPolicy(int aPid) {
+  auto policy = MakeUnique<SandboxBroker::Policy>();
+
+  AddSharedMemoryPaths(policy.get(), aPid);
+
+  if (policy->IsEmpty()) {
+    policy = nullptr;
+  }
+  return policy;
+}
+
+}  // namespace mozilla
