@@ -6,27 +6,29 @@
 
 #include "ProfilerBacktrace.h"
 
+#include "ProfileBuffer.h"
+#include "ProfiledThreadData.h"
 #include "ProfileJSONWriter.h"
 #include "ThreadInfo.h"
 
 ProfilerBacktrace::ProfilerBacktrace(const char* aName, int aThreadId,
-                                     UniquePtr<ProfileBuffer> aBuffer)
-    : mName(strdup(aName)), mThreadId(aThreadId), mBuffer(Move(aBuffer)) {
+                                     mozilla::UniquePtr<ProfileBuffer> aBuffer)
+    : mName(strdup(aName)), mThreadId(aThreadId), mBuffer(std::move(aBuffer)) {
   MOZ_COUNT_CTOR(ProfilerBacktrace);
 }
 
 ProfilerBacktrace::~ProfilerBacktrace() { MOZ_COUNT_DTOR(ProfilerBacktrace); }
 
 void ProfilerBacktrace::StreamJSON(SpliceableJSONWriter& aWriter,
-                                   const TimeStamp& aProcessStartTime,
+                                   const mozilla::TimeStamp& aProcessStartTime,
                                    UniqueStacks& aUniqueStacks) {
   // Unlike ProfiledThreadData::StreamJSON, we don't need to call
   // ProfileBuffer::AddJITInfoForRange because mBuffer does not contain any
   // JitReturnAddr entries. For synchronous samples, JIT frames get expanded
   // at sample time.
   StreamSamplesAndMarkers(mName.get(), mThreadId, *mBuffer.get(), aWriter,
-                          aProcessStartTime,
-                          /* aRegisterTime */ TimeStamp(),
-                          /* aUnregisterTime */ TimeStamp(),
+                          NS_LITERAL_CSTRING(""), aProcessStartTime,
+                          /* aRegisterTime */ mozilla::TimeStamp(),
+                          /* aUnregisterTime */ mozilla::TimeStamp(),
                           /* aSinceTime */ 0, aUniqueStacks);
 }
