@@ -4,21 +4,23 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-#include "gtest/gtest.h"
-
 #include "ProfileBufferEntry.h"
 #include "ThreadInfo.h"
 
+#include "gtest/gtest.h"
+
 // Make sure we can record one entry and read it
-TEST(ThreadProfile, InsertOneEntry) {
+TEST(ThreadProfile, InsertOneEntry)
+{
   auto pb = MakeUnique<ProfileBuffer>(10);
   pb->AddEntry(ProfileBufferEntry::Time(123.1));
   ASSERT_TRUE(pb->GetEntry(pb->mRangeStart).IsTime());
-  ASSERT_TRUE(pb->GetEntry(pb->mRangeStart).u.mDouble == 123.1);
+  ASSERT_TRUE(pb->GetEntry(pb->mRangeStart).GetDouble() == 123.1);
 }
 
 // See if we can insert some entries
-TEST(ThreadProfile, InsertEntriesNoWrap) {
+TEST(ThreadProfile, InsertEntriesNoWrap)
+{
   auto pb = MakeUnique<ProfileBuffer>(100);
   int test_size = 50;
   for (int i = 0; i < test_size; i++) {
@@ -27,13 +29,14 @@ TEST(ThreadProfile, InsertEntriesNoWrap) {
   uint64_t readPos = pb->mRangeStart;
   while (readPos != pb->mRangeEnd) {
     ASSERT_TRUE(pb->GetEntry(readPos).IsTime());
-    ASSERT_TRUE(pb->GetEntry(readPos).u.mDouble == readPos);
+    ASSERT_TRUE(pb->GetEntry(readPos).GetDouble() == readPos);
     readPos++;
   }
 }
 
 // See if evicting works as it should in the basic case
-TEST(ThreadProfile, InsertEntriesWrap) {
+TEST(ThreadProfile, InsertEntriesWrap)
+{
   int entries = 32;
   auto pb = MakeUnique<ProfileBuffer>(entries);
   ASSERT_TRUE(pb->mRangeStart == 0);
@@ -48,8 +51,7 @@ TEST(ThreadProfile, InsertEntriesWrap) {
   uint64_t readPos = pb->mRangeStart;
   while (readPos != pb->mRangeEnd) {
     ASSERT_TRUE(pb->GetEntry(readPos).IsTime());
-    ASSERT_TRUE(pb->GetEntry(readPos).u.mDouble == readPos);
+    ASSERT_TRUE(pb->GetEntry(readPos).GetDouble() == readPos);
     readPos++;
   }
 }
-
