@@ -8,13 +8,12 @@
 # Author: Darin Fisher
 #
 
-# shellcheck disable=SC1090
-. "$(dirname "$0")/common.sh"
+. $(dirname "$0")/common.sh
 
 # -----------------------------------------------------------------------------
 
 print_usage() {
-  notice "Usage: $(basename "$0") [OPTIONS] ARCHIVE FROMDIR TODIR"
+  notice "Usage: $(basename $0) [OPTIONS] ARCHIVE FROMDIR TODIR"
   notice ""
   notice "The differences between FROMDIR and TODIR will be stored in ARCHIVE."
   notice ""
@@ -32,39 +31,54 @@ check_for_forced_update() {
   local f
 
   if [ "$forced_file_chk" = "precomplete" ]; then
+    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "Contents/Resources/precomplete" ]; then
+    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "removed-files" ]; then
+    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "Contents/Resources/removed-files" ]; then
+    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "chrome.manifest" ]; then
+    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "Contents/Resources/chrome.manifest" ]; then
+    ## "true" *giggle*
+    return 0;
+  fi
+
+  # notarization ticket
+  if [ "$forced_file_chk" = "Contents/CodeResources" ]; then
+    ## "true" *giggle*
     return 0;
   fi
 
   if [ "${forced_file_chk##*.}" = "chk" ]; then
+    ## "true" *giggle*
     return 0;
   fi
 
   for f in $force_list; do
     #echo comparing $forced_file_chk to $f
     if [ "$forced_file_chk" = "$f" ]; then
+      ## "true" *giggle*
       return 0;
     fi
   done
+  ## 'false'... because this is bash. Oh yay!
   return 1;
 }
 
@@ -89,7 +103,7 @@ done
 
 # -----------------------------------------------------------------------------
 
-arg_start=$((OPTIND-1))
+let arg_start=$OPTIND-1
 shift $arg_start
 
 archive="$1"
@@ -97,10 +111,10 @@ olddir="$2"
 newdir="$3"
 # Prevent the workdir from being inside the targetdir so it isn't included in
 # the update mar.
-
-# Remove the /
-newdir="${newdir%/}"
-
+if [ $(echo "$newdir" | grep -c '\/$') = 1 ]; then
+  # Remove the /
+  newdir=$(echo "$newdir" | sed -e 's:\/$::')
+fi
 workdir="$newdir.work"
 updatemanifestv2="$workdir/updatev2.manifest"
 updatemanifestv3="$workdir/updatev3.manifest"
@@ -109,55 +123,62 @@ archivefiles="updatev2.manifest updatev3.manifest"
 mkdir -p "$workdir"
 
 # Generate a list of all files in the target directory.
-pushd "$olddir" || exit 1
-
-declare -a oldfiles
-list_files oldfiles
-declare -a olddirs
-list_dirs olddirs
-
-popd || exit 1
-
-pushd "$newdir" || exit 1
-
-if [ ! -f "precomplete" ] && [ ! -f "Contents/Resources/precomplete" ]
-then
-  notice "precomplete file is missing!"
+pushd "$olddir"
+if test $? -ne 0 ; then
   exit 1
 fi
 
-declare -a newfiles
+list_files oldfiles
+list_dirs olddirs
+
+popd
+
+pushd "$newdir"
+if test $? -ne 0 ; then
+  exit 1
+fi
+
+if [ ! -f "precomplete" ]; then
+  if [ ! -f "Contents/Resources/precomplete" ]; then
+    notice "precomplete file is missing!"
+    exit 1
+  fi
+fi
+
+list_dirs newdirs
 list_files newfiles
 
-popd || exit 1
+popd
 
 # Add the type of update to the beginning of the update manifests.
 notice ""
 notice "Adding type instruction to update manifests"
-: > "$updatemanifestv2"
-: > "$updatemanifestv3"
+> $updatemanifestv2
+> $updatemanifestv3
 notice "       type partial"
-echo 'type "partial"' >> "$updatemanifestv2"
-echo 'type "partial"' >> "$updatemanifestv3"
+echo "type \"partial\"" >> $updatemanifestv2
+echo "type \"partial\"" >> $updatemanifestv3
 
 notice ""
 notice "Adding file patch and add instructions to update manifests"
 
-declare -a remove_array
+num_oldfiles=${#oldfiles[*]}
+remove_array=
 num_removes=0
 
-for f in "${oldfiles[@]}"
-do
+for ((i=0; $i<$num_oldfiles; i=$i+1)); do
+  f="${oldfiles[$i]}"
+
   # If this file exists in the new directory as well, then check if it differs.
   if [ -f "$newdir/$f" ]; then
 
     if check_for_add_if_not_update "$f"; then
       # The full workdir may not exist yet, so create it if necessary.
-      mkdir -p "$(dirname "$workdir/$f")"
+      mkdir -p `dirname "$workdir/$f"`
       if [[ -n $MAR_OLD_FORMAT ]]; then
         $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
       else
-        $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
+        $XZ --compress $BCJ_OPTIONS --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
       fi
       copy_perm "$newdir/$f" "$workdir/$f"
       make_add_if_not_instruction "$f" "$updatemanifestv3"
@@ -167,11 +188,11 @@ do
 
     if check_for_forced_update "$requested_forced_updates" "$f"; then
       # The full workdir may not exist yet, so create it if necessary.
-      mkdir -p "$(dirname "$workdir/$f")"
+      mkdir -p `dirname "$workdir/$f"`
       if [[ -n $MAR_OLD_FORMAT ]]; then
         $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
       else
-        $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
+        $XZ --compress $BCJ_OPTIONS --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
       fi
       copy_perm "$newdir/$f" "$workdir/$f"
       make_add_instruction "$f" "$updatemanifestv2" "$updatemanifestv3" 1
@@ -197,41 +218,51 @@ do
       #
       # Note: patches are bzipped or xz stashed in funsize to gain more speed
 
-      if [[ -n $MAR_OLD_FORMAT ]]
-      then
-        COMPRESS="$BZIP2 -z9"
-        EXT=".bz2"
-        STDOUT="-c"
-      else
-        COMPRESS="$XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force"
-        EXT=".xz"
-        STDOUT="--stdout"
-      fi
-
-      if [ -z "$MBSDIFF_HOOK" ]
-      then
+      # if service is not enabled then default to old behavior
+      if [ -z "$MBSDIFF_HOOK" ]; then
         $MBSDIFF "$olddir/$f" "$newdir/$f" "$workdir/$f.patch"
-        $COMPRESS "$workdir/$f.patch"
-      else
-        if $MBSDIFF_HOOK -g "$olddir/$f" "$newdir/$f" "$workdir/$f.patch${EXT}"
-        then
-          notice "file \"$f\" found in funsize, diffing skipped"
+        if [[ -n $MAR_OLD_FORMAT ]]; then
+          $BZIP2 -z9 "$workdir/$f.patch"
         else
-          # if not found already - compute it and cache it for future use
-          $MBSDIFF "$olddir/$f" "$newdir/$f" "$workdir/$f.patch"
-          $COMPRESS "$workdir/$f.patch"
-          $MBSDIFF_HOOK -u "$olddir/$f" "$newdir/$f" "$workdir/$f.patch${EXT}"
+          $XZ --compress $BCJ_OPTIONS --lzma2 --format=xz --check=crc64 --force "$workdir/$f.patch"
+        fi
+      else
+        # if service enabled then check patch existence for retrieval
+        if [[ -n $MAR_OLD_FORMAT ]]; then
+          if $MBSDIFF_HOOK -g "$olddir/$f" "$newdir/$f" "$workdir/$f.patch.bz2"; then
+            notice "file \"$f\" found in funsize, diffing skipped"
+          else
+            # if not found already - compute it and cache it for future use
+            $MBSDIFF "$olddir/$f" "$newdir/$f" "$workdir/$f.patch"
+            $BZIP2 -z9 "$workdir/$f.patch"
+            $MBSDIFF_HOOK -u "$olddir/$f" "$newdir/$f" "$workdir/$f.patch.bz2"
+          fi
+        else
+          if $MBSDIFF_HOOK -g "$olddir/$f" "$newdir/$f" "$workdir/$f.patch.xz"; then
+            notice "file \"$f\" found in funsize, diffing skipped"
+          else
+            # if not found already - compute it and cache it for future use
+            $MBSDIFF "$olddir/$f" "$newdir/$f" "$workdir/$f.patch"
+            $XZ --compress $BCJ_OPTIONS --lzma2 --format=xz --check=crc64 --force "$workdir/$f.patch"
+            $MBSDIFF_HOOK -u "$olddir/$f" "$newdir/$f" "$workdir/$f.patch.xz"
+          fi
         fi
       fi
-      $COMPRESS $STDOUT "$newdir/$f" > "$workdir/$f"
-
+      if [[ -n $MAR_OLD_FORMAT ]]; then
+        $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
+      else
+        $XZ --compress $BCJ_OPTIONS --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
+      fi
       copy_perm "$newdir/$f" "$workdir/$f"
-      patchfile="$workdir/$f.patch${EXT}"
-
+      if [[ -n $MAR_OLD_FORMAT ]]; then
+        patchfile="$workdir/$f.patch.bz2"
+      else
+        patchfile="$workdir/$f.patch.xz"
+      fi
       patchsize=$(get_file_size "$patchfile")
       fullsize=$(get_file_size "$workdir/$f")
 
-      if [ "$patchsize" -lt "$fullsize" ]; then
+      if [ $patchsize -lt $fullsize ]; then
         make_patch_instruction "$f" "$updatemanifestv2" "$updatemanifestv3"
         mv -f "$patchfile" "$workdir/$f.patch"
         rm -f "$workdir/$f"
@@ -253,23 +284,25 @@ done
 # Newly added files
 notice ""
 notice "Adding file add instructions to update manifests"
+num_newfiles=${#newfiles[*]}
 
-for f in "${newfiles[@]}"
-do
-  for j in "${oldfiles[@]}"
-  do
-    if [ "$f" = "$j" ]
-    then
+for ((i=0; $i<$num_newfiles; i=$i+1)); do
+  f="${newfiles[$i]}"
+
+  # If we've already tested this file, then skip it
+  for ((j=0; $j<$num_oldfiles; j=$j+1)); do
+    if [ "$f" = "${oldfiles[j]}" ]; then
       continue 2
     fi
   done
+
   dir=$(dirname "$workdir/$f")
   mkdir -p "$dir"
 
   if [[ -n $MAR_OLD_FORMAT ]]; then
     $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
   else
-    $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
+    $XZ --compress $BCJ_OPTIONS --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
   fi
   copy_perm "$newdir/$f" "$workdir/$f"
 
@@ -285,11 +318,11 @@ done
 
 notice ""
 notice "Adding file remove instructions to update manifests"
-for f in "${remove_array[@]}"
-do
+for ((i=0; $i<$num_removes; i=$i+1)); do
+  f="${remove_array[$i]}"
   notice "     remove \"$f\""
-  echo "remove \"$f\"" >> "$updatemanifestv2"
-  echo "remove \"$f\"" >> "$updatemanifestv3"
+  echo "remove \"$f\"" >> $updatemanifestv2
+  echo "remove \"$f\"" >> $updatemanifestv3
 done
 
 # Add remove instructions for any dead files.
@@ -299,14 +332,15 @@ append_remove_instructions "$newdir" "$updatemanifestv2" "$updatemanifestv3"
 
 notice ""
 notice "Adding directory remove instructions for directories that no longer exist"
+num_olddirs=${#olddirs[*]}
 
-for f in "${olddirs[@]}"
-do
+for ((i=0; $i<$num_olddirs; i=$i+1)); do
+  f="${olddirs[$i]}"
   # If this dir doesn't exist in the new directory remove it.
   if [ ! -d "$newdir/$f" ]; then
     notice "      rmdir $f/"
-    echo "rmdir \"$f/\"" >> "$updatemanifestv2"
-    echo "rmdir \"$f/\"" >> "$updatemanifestv3"
+    echo "rmdir \"$f/\"" >> $updatemanifestv2
+    echo "rmdir \"$f/\"" >> $updatemanifestv3
   fi
 done
 
@@ -314,8 +348,8 @@ if [[ -n $MAR_OLD_FORMAT ]]; then
   $BZIP2 -z9 "$updatemanifestv2" && mv -f "$updatemanifestv2.bz2" "$updatemanifestv2"
   $BZIP2 -z9 "$updatemanifestv3" && mv -f "$updatemanifestv3.bz2" "$updatemanifestv3"
 else
-  $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force "$updatemanifestv2" && mv -f "$updatemanifestv2.xz" "$updatemanifestv2"
-  $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force "$updatemanifestv3" && mv -f "$updatemanifestv3.xz" "$updatemanifestv3"
+  $XZ --compress $BCJ_OPTIONS --lzma2 --format=xz --check=crc64 --force "$updatemanifestv2" && mv -f "$updatemanifestv2.xz" "$updatemanifestv2"
+  $XZ --compress $BCJ_OPTIONS --lzma2 --format=xz --check=crc64 --force "$updatemanifestv3" && mv -f "$updatemanifestv3.xz" "$updatemanifestv3"
 fi
 
 mar_command="$MAR"
